@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Colin Ian King
+ * Copyright (C) 2022-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -82,6 +82,13 @@
 #define STRESS_OPCODE_MASK	(0xffffffffUL)
 #endif
 
+/* Arch specific PPC (32 bit ) */
+#if defined(__PPC__)
+#define STRESS_ARCH_PPC		(1)
+#define STRESS_OPCODE_SIZE	(32)
+#define STRESS_OPCODE_MASK	(0xffffffffUL)
+#endif
+
 /* Arch specific M68K */
 #if defined(__m68k__) ||	\
     defined(__mc68000__) ||	\
