@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023      Colin Ian King.
+ * Copyright (C) 2024-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,10 +24,19 @@
 
 #if defined(STRESS_ARCH_ARM)
 
-static inline void stress_asm_arm_yield(void)
+#if defined(HAVE_ASM_ARM_YIELD)
+static inline void ALWAYS_INLINE stress_asm_arm_yield(void)
 {
 	__asm__ __volatile__("yield;\n");
 }
+#endif
+
+#if defined(HAVE_ASM_ARM_DMB_SY)
+static inline void ALWAYS_INLINE stress_asm_arm_dmb_sy(void)
+{
+	__asm__ __volatile__("dmb sy;\n");
+}
+#endif
 
 /* #if defined(STRESS_ARCH_ARM) */
 #endif
