@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023-2024 Colin Ian King.
+ * Copyright (C) 2023-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -17,6 +17,7 @@
  *
  */
 #include "stress-ng.h"
+#include "core-attribute.h"
 
 #ifndef CORE_ASM_RET_H
 #define CORE_ASM_RET_H
@@ -30,7 +31,7 @@ typedef struct {
 
 typedef void (*stress_ret_func_t)(void);
 
-extern stress_ret_opcode_t stress_ret_opcode;
+extern const stress_ret_opcode_t stress_ret_opcode;
 extern int stress_asm_ret_supported(const char *name);
 
 #endif
