@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2024      Colin Ian King.
+ * Copyright (C) 2024-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -58,7 +58,7 @@
 
 static inline uint64_t ALWAYS_INLINE stress_asm_riscv_rdtime(void)
 {
-	register unsigned long ticks;
+	register unsigned long int ticks;
 
         __asm__ __volatile__("rdtime %0"
                               : "=r" (ticks)
@@ -89,7 +89,7 @@ static inline void ALWAYS_INLINE stress_asm_riscv_pause(void)
 	__asm__ __volatile__ (".4byte 0x100000F");
 }
 
-/* cbo.zero instrution */
+/* cbo.zero instruction */
 #if defined(HAVE_ASM_RISCV_CBO_ZERO)
 static inline void ALWAYS_INLINE stress_asm_riscv_cbo_zero(char *addr)
 {
