@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2024      Colin Ian King.
+ * Copyright (C) 2024-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,9 +24,11 @@
 #if defined(__linux__)
 static inline void stress_clocksource_tolower(char *str)
 {
-	while (*str) {
-		if (isupper((int)*str))
-			*str = (char)tolower((int)*str);
+	unsigned char ch;
+
+	while ((ch = (unsigned char)*str)) {
+		if (isupper(ch))
+			*str = (char)tolower(ch);
 		str++;
 	}
 }
