@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023-2024 Colin Ian King.
+ * Copyright (C) 2023-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -46,7 +46,7 @@ cpu_cstate_t *stress_cpuidle_cstate_list_head(void)
 
 static PURE int stress_cpuidle_value(const char *cstate)
 {
-	while (isalpha((int)*cstate))
+	while (isalpha((unsigned char)*cstate))
 		cstate++;
 	return atoi(cstate);
 }
@@ -79,11 +79,11 @@ static void stress_cpuidle_cstate_add_unique(
 		if (cmp < 0)
 			break;
 	}
-	new_cc = malloc(sizeof(*new_cc));
-	if (!new_cc)
+	new_cc = (cpu_cstate_t *)malloc(sizeof(*new_cc));
+	if (UNLIKELY(!new_cc))
 		return;
 	new_cc->cstate = strdup(cstate);
-	if (!new_cc->cstate) {
+	if (UNLIKELY(!new_cc->cstate)) {
 		free(new_cc);
 		return;
 	}
@@ -109,7 +109,7 @@ void stress_cpuidle_init(void)
 	cpu_cstate_list_len = 0;
 
 	cpu_dir = opendir("/sys/devices/system/cpu");
-	if (!cpu_dir)
+	if (UNLIKELY(!cpu_dir))
 		return;
 
 	/*
@@ -191,11 +191,11 @@ static void stress_cpuidle_read_cstates(
 	size_t i;
 	stress_cstate_stats_t stats;
 
-	if ((which < 0) || (which > 1))
+	if (UNLIKELY((which < 0) || (which > 1)))
 		return;
 
 	cpu_dir = opendir("/sys/devices/system/cpu");
-	if (!cpu_dir)
+	if (UNLIKELY(!cpu_dir))
 		return;
 
 	for (i = 0, cc = cpu_cstate_list; (i < STRESS_CSTATES_MAX) && cc; i++, cc = cc->next) {
@@ -208,7 +208,7 @@ static void stress_cpuidle_read_cstates(
 	 *  total up cpu C state timings
 	 */
 	while ((cpu_d = readdir(cpu_dir)) != NULL) {
-		char cpuidle_path[512];
+		char cpuidle_path[768];
 		DIR *cpuidle_dir;
 		const struct dirent *cpuidle_d;
 
@@ -223,7 +223,7 @@ static void stress_cpuidle_read_cstates(
 			continue;
 
 		while ((cpuidle_d = readdir(cpuidle_dir)) != NULL) {
-			char path[PATH_MAX + 512], cstate[64], data[64], *ptr;
+			char path[PATH_MAX + 768], cstate[64], data[64], *ptr;
 			uint64_t cstate_time;
 			double now;
 
@@ -290,13 +290,11 @@ void stress_cpuidle_dump(FILE *yaml, stress_stressor_t *stressors_list)
 		double residencies[STRESS_CSTATES_MAX];
 		cpu_cstate_t *cc;
 		double c0_residency = 100.0;
-		char tmp[64];
 		bool valid = false;
 
 		if (ss->ignore.run)
 			continue;
 
-		(void)stress_munge_underscore(tmp, ss->stressor->name, sizeof(tmp));
 		for (i = 0, cc = cpu_cstate_list; (i < STRESS_CSTATES_MAX) && cc; i++, cc = cc->next) {
 			double duration_us = 0.0;
 			double residency_us = 0.0;
@@ -313,8 +311,8 @@ void stress_cpuidle_dump(FILE *yaml, stress_stressor_t *stressors_list)
 		}
 
 		if (valid) {
-			pr_inf("%s:\n", tmp);
-			pr_yaml(yaml, "    - stressor: %s\n", tmp);
+			pr_inf("%s:\n", ss->stressor->name);
+			pr_yaml(yaml, "    - stressor: %s\n", ss->stressor->name);
 
 			for (i = 0, cc = cpu_cstate_list; (i < STRESS_CSTATES_MAX) && cc; i++, cc = cc->next) {
 				if (strcmp(cc->cstate, busy_state) == 0)
@@ -343,8 +341,8 @@ void stress_cpuidle_log_info(void)
 	for (cc = cpu_cstate_list; cc; cc = cc->next) {
 		len += strlen(cc->cstate) + 2;
 	}
-	buf = calloc(len, sizeof(*buf));
-	if (!buf)
+	buf = (char *)calloc(len, sizeof(*buf));
+	if (UNLIKELY(!buf))
 		return;
 
 	for (cc = cpu_cstate_list; cc; cc = cc->next) {
