@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2016-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -64,6 +64,7 @@ static stress_settings_t settings[] = {
 	/* x86 Intel P-State maximizing settings */
 	SETTING("/sys/devices/system/cpu/intel_pstate/max_perf_pct", "100"),
 	SETTING("/sys/devices/system/cpu/intel_pstate/no_turbo", "0"),
+	SETTING("/sys/devices/system/cpu/cpufreq/boost", "1"),
 #endif
 	SETTING(NULL, NULL)
 };
@@ -84,10 +85,13 @@ static void stress_ignite_cpu_set(
 {
 	char path[PATH_MAX];
 	char buffer[128];
+	const int max_retries = 16;
 
-	if (((*setting_flag & SETTING_FREQ) == SETTING_FREQ) && (max_freq > 0) && (min_freq <= max_freq)) {
-		const uint64_t freq_delta = (max_freq - min_freq) / 10;
+	if (((*setting_flag & SETTING_FREQ) == SETTING_FREQ) &&
+		(min_freq > 0) && (max_freq > 0) && (min_freq < max_freq)) {
+		const int64_t freq_delta = (max_freq - min_freq) / 10;
 		uint64_t freq;
+		int retry = 0;
 
 		(void)snprintf(path, sizeof(path),
 			"/sys/devices/system/cpu/cpu%" PRId32
@@ -96,12 +100,12 @@ static void stress_ignite_cpu_set(
 		if (stress_system_write(path, buffer, strlen(buffer)) < 0)
 			*setting_flag &= ~SETTING_SCALING_FREQ;
 
-		/* Try to set min to be 100% of max down to lowest, which ever works first*/
+		/* Try to set min to be 100% of max down to lowest, which ever works first */
 		(void)snprintf(path, sizeof(path),
 			"/sys/devices/system/cpu/cpu%" PRId32
 			"/cpufreq/scaling_min_freq", cpu);
 		freq = (maximize_freq) ? max_freq : min_freq;
-		while ((freq_delta > 0) && (freq >= min_freq)) {
+		while ((retry++ < max_retries) && (freq_delta > 0) && (freq >= min_freq)) {
 			(void)snprintf(buffer, sizeof(buffer), "%" PRIu64 "\n", freq);
 			if (stress_system_write(path, buffer, strlen(buffer)) >= 0)
 				break;
@@ -315,7 +319,6 @@ void stress_ignite_cpu_start(void)
 				 *  Attempt to crank CPUs up to max freq
 				 */
 				for (cpu = 0; cpu < max_cpus; cpu++) {
-
 					if (cpu_settings[cpu].setting_flag == 0)
 						continue;
 
