@@ -106,7 +106,7 @@ static int stress_wait_until_reaped(
 		 *  Retry if EINTR unless we've have 2 mins
 		 *  consecutive EINTRs then give up.
 		 */
-		if (!stress_continue_flag()) {
+		if (UNLIKELY(!stress_continue_flag())) {
 			(void)stress_kill_sig(pid, signum);
 			if (count > 120) {
 				if (set_stress_force_killed_bogo)
@@ -117,7 +117,7 @@ static int stress_wait_until_reaped(
 			 *  Process seems unkillable, report and bail out
 			 */
 			if (count > 600) {
-				pr_dbg("%s: cannot kill PID %jd after 10 minutes, giving up\n",
+				pr_dbg("%s: cannot kill PID %" PRIdMAX " after 10 minutes, giving up\n",
 					args->name, (intmax_t)pid);
 				stress_process_info(args, pid);
 				break;
@@ -141,15 +141,15 @@ int stress_kill_and_wait(
 {
 	const pid_t mypid = getpid();
 
-	if ((pid == 0) || (pid == 1) || (pid == mypid)) {
-		pr_inf("%s: warning, attempt to kill PID %jd ignored\n",
+	if (UNLIKELY((pid == 0) || (pid == 1) || (pid == mypid))) {
+		pr_inf("%s: warning, attempt to kill PID %" PRIdMAX " ignored\n",
 			args->name, (intmax_t)pid);
 	}
 	/*
 	 *  bad pids, won't kill, but return success to avoid
 	 *  confusion of a kill that failed.
 	 */
-	if ((pid <= 1) || (pid == mypid))
+	if (UNLIKELY((pid <= 1) || (pid == mypid)))
 		return EXIT_SUCCESS;
 
 	stress_kill_sig(pid, signum);
