@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,6 +22,7 @@
 #include "core-syslog.h"
 
 #include <stdarg.h>
+#include <time.h>
 
 #if defined(HAVE_SYSLOG_H)
 #include <syslog.h>
@@ -63,7 +64,7 @@ static void pr_log_write_buf_fd(const int fd, const char *buf, const size_t buf_
 		ssize_t ret;
 
 		ret = write(fd, ptr, n);
-		if (ret <= 0)
+		if (UNLIKELY(ret <= 0))
 			break;
 		n -= ret;
 		ptr += ret;
@@ -109,7 +110,7 @@ static void pr_log_write(const char *buf, const size_t buf_len)
 			const size_t len = strlen(pr_msg_buf.buf);
 
 			new_buf = realloc(pr_msg_buf.buf, len + buf_len + 1);
-			if (!new_buf) {
+			if (UNLIKELY(!new_buf)) {
 				pr_log_write_buf(pr_msg_buf.buf, strlen(pr_msg_buf.buf));
 				free(pr_msg_buf.buf);
 				pr_msg_buf.buf = NULL;
@@ -243,7 +244,7 @@ static int pr_msg(
 
 			(void)snprintf(ts, sizeof(ts), "%2.2d:%2.2d:%2.2d.%2.2ld ",
 				tm.tm_hour, tm.tm_min, tm.tm_sec,
-				(long)tv.tv_usec / 10000);
+				(long int)tv.tv_usec / 10000);
 #else
 			strncpy(ts, empty_ts, sizeof(ts));
 #endif
@@ -253,7 +254,7 @@ static int pr_msg(
 	}
 
 	if ((flag & (OPT_FLAGS_PR_FAIL | OPT_FLAGS_PR_WARN)) || (g_opt_flags & flag)) {
-		char buf[4096];
+		char buf[8192];
 		const char *type = "";
 
 		if (flag & OPT_FLAGS_PR_ERROR)
