@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -265,6 +265,7 @@ uint8_t OPTIMIZE3 stress_mwc1(void)
 	return mwc.saved1 & 0x1;
 }
 
+#if !defined(HAVE_FAST_MODULO_REDUCTION)
 /*
  *  stress_mwc8mask()
  *	generate a mask large enough for 8 bit val
@@ -283,7 +284,6 @@ static inline ALWAYS_INLINE OPTIMIZE3 uint8_t stress_mwc8mask(const uint8_t val)
  *  stress_mwc8modn()
  *	see https://research.kudelskisecurity.com/2020/07/28/the-definitive-guide-to-modulo-bias-and-how-to-avoid-it/
  *	return 8 bit non-modulo biased value 1..max (inclusive)
- *	where max is most probably not a power of 2
  */
 uint8_t OPTIMIZE3 stress_mwc8modn(const uint8_t max)
 {
@@ -370,7 +370,10 @@ uint32_t OPTIMIZE3 stress_mwc32modn(const uint32_t max)
 
 	return val;
 }
+#endif
 
+#if !defined(HAVE_FAST_MODULO_REDUCTION) ||	\
+    !defined(HAVE_INT128_T)
 /*
  *  stress_mwc64mask()
  *	generate a mask large enough for 64 bit val
@@ -407,6 +410,7 @@ uint64_t OPTIMIZE3 stress_mwc64modn(const uint64_t max)
 
 	return val;
 }
+#endif
 
 /*
  *  stress_rndbuf()
