@@ -389,6 +389,7 @@ const struct option stress_long_options[] = {
 	{ "insertionsort-ops",	1,	0,	OPT_insertionsort_ops },
 	{ "insertionsort-size",	1,	0,	OPT_insertionsort_size },
 	{ "intmath",		1,	0,	OPT_intmath },
+	{ "intmath-fast",	0,	0,	OPT_intmath_fast },
 	{ "intmath-method",	1,	0,	OPT_intmath_method },
 	{ "intmath-ops",	1,	0,	OPT_intmath_ops },
 	{ "io",			1,	0,	OPT_io },
@@ -547,6 +548,7 @@ const struct option stress_long_options[] = {
 	{ "memrate",		1,	0,	OPT_memrate },
 	{ "memrate-bytes",	1,	0,	OPT_memrate_bytes },
 	{ "memrate-flush",	0,	0,	OPT_memrate_flush },
+	{ "memrate-method",	1,	0,	OPT_memrate_method },
 	{ "memrate-ops",	1,	0,	OPT_memrate_ops },
 	{ "memrate-rd-mbs",	1,	0,	OPT_memrate_rd_mbs },
 	{ "memrate-wr-mbs",	1,	0,	OPT_memrate_wr_mbs },
@@ -621,6 +623,10 @@ const struct option stress_long_options[] = {
 	{ "mmapmany-mlock",	0,	0,	OPT_mmapmany_mlock },
 	{ "mmapmany-numa",	0,	0,	OPT_mmapmany_numa },
 	{ "mmapmany-ops",	1,	0,	OPT_mmapmany_ops },
+	{ "mmaptorture",	1,	0,	OPT_mmaptorture },
+	{ "mmaptorture-bytes",	1,	0,	OPT_mmaptorture_bytes },
+	{ "mmaptorture-msync",	1,	0,	OPT_mmaptorture_msync },
+	{ "mmaptorture-ops",	1,	0,	OPT_mmaptorture_ops },
 	{ "module",		1,	0,	OPT_module},
 	{ "module-ops",		1,	0,	OPT_module_ops },
 	{ "module-name",	1,	0,	OPT_module_name},
@@ -717,6 +723,7 @@ const struct option stress_long_options[] = {
 	{ "pci",		1,	0,	OPT_pci},
 	{ "pci-dev",		1,	0,	OPT_pci_dev},
 	{ "pci-ops",		1,	0,	OPT_pci_ops },
+	{ "pci-ops-rate",	1,	0,	OPT_pci_ops_rate },
 #if defined(STRESS_PERF_STATS) && 	\
     defined(HAVE_LINUX_PERF_EVENT_H)
 	{ "perf",		0,	0,	OPT_perf_stats },
