@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2024      Colin Ian King
+ * Copyright (C) 2024-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -115,20 +115,21 @@ typedef enum {
 	OPT_dentry = 'D',
 	OPT_fork = 'f',
 	OPT_fallocate = 'F',
+	OPT_help = 'h',
 	OPT_io = 'i',
 	OPT_job = 'j',
-	OPT_help = 'h',
 	OPT_keep_name = 'k',
+	OPT_klog_check = 'K',
 	OPT_cpu_load = 'l',
 	OPT_vm = 'm',
 	OPT_metrics = 'M',
 	OPT_dry_run = 'n',
-	OPT_rename = 'R',
 	OPT_open = 'o',
 	OPT_pipe = 'p',
 	OPT_poll = 'P',
 	OPT_quiet = 'q',
 	OPT_random = 'r',
+	OPT_rename = 'R',
 	OPT_switch = 's',
 	OPT_sock = 'S',
 	OPT_timeout = 't',
@@ -136,9 +137,10 @@ typedef enum {
 	OPT_urandom = 'u',
 	OPT_verbose = 'v',
 	OPT_version = 'V',
+	OPT_with = 'w',
+	OPT_exclude = 'x',
 	OPT_yield = 'y',
 	OPT_yaml = 'Y',
-	OPT_exclude = 'x',
 
 	/* Long options only */
 
@@ -248,8 +250,12 @@ typedef enum {
 	OPT_cache_sfence,
 	OPT_cache_no_affinity,
 	OPT_cache_prefetch,
+	OPT_cache_prefetchw,
 	OPT_cache_ways,
 
+	OPT_cachehammer,
+	OPT_cachehammer_ops,
+
 	OPT_cacheline,
 	OPT_cacheline_ops,
 	OPT_cacheline_affinity,
@@ -614,6 +620,7 @@ typedef enum {
 	OPT_insertionsort_size,
 
 	OPT_intmath,
+	OPT_intmath_fast,
 	OPT_intmath_method,
 	OPT_intmath_ops,
 
@@ -676,8 +683,6 @@ typedef enum {
 	OPT_klog,
 	OPT_klog_ops,
 
-	OPT_klog_check,
-
 	OPT_ksm,
 
 	OPT_kvm,
@@ -714,6 +719,7 @@ typedef enum {
 	OPT_llc_affinity,
 	OPT_llc_affinity_clflush,
 	OPT_llc_affinity_mlock,
+	OPT_llc_affinity_numa,
 	OPT_llc_affinity_ops,
 
 	OPT_loadavg,
@@ -792,6 +798,7 @@ typedef enum {
 	OPT_max_fd,
 
 	OPT_mcontend,
+	OPT_mcontend_numa,
 	OPT_mcontend_ops,
 
 	OPT_membarrier,
@@ -806,6 +813,7 @@ typedef enum {
 	OPT_memfd_fds,
 	OPT_memfd_madvise,
 	OPT_memfd_mlock,
+	OPT_memfd_numa,
 	OPT_memfd_ops,
 	OPT_memfd_zap_pte,
 
@@ -816,6 +824,7 @@ typedef enum {
 	OPT_memrate,
 	OPT_memrate_bytes,
 	OPT_memrate_flush,
+	OPT_memrate_method,
 	OPT_memrate_ops,
 	OPT_memrate_rd_mbs,
 	OPT_memrate_wr_mbs,
@@ -869,6 +878,7 @@ typedef enum {
 	OPT_mmap_mlock,
 	OPT_mmap_mmap2,
 	OPT_mmap_mprotect,
+	OPT_mmap_numa,
 	OPT_mmap_odirect,
 	OPT_mmap_ops,
 	OPT_mmap_osync,
@@ -881,12 +891,14 @@ typedef enum {
 	OPT_mmapaddr_ops,
 
 	OPT_mmapfiles,
+	OPT_mmapfiles_numa,
 	OPT_mmapfiles_ops,
 	OPT_mmapfiles_populate,
 	OPT_mmapfiles_shared,
 
 	OPT_mmapfixed,
 	OPT_mmapfixed_mlock,
+	OPT_mmapfixed_numa,
 	OPT_mmapfixed_ops,
 
 	OPT_mmapfork,
@@ -897,12 +909,19 @@ typedef enum {
 	OPT_mmaphuge_file,
 	OPT_mmaphuge_mlock,
 	OPT_mmaphuge_mmaps,
+	OPT_mmaphuge_numa,
 	OPT_mmaphuge_ops,
 
 	OPT_mmapmany,
 	OPT_mmapmany_mlock,
+	OPT_mmapmany_numa,
 	OPT_mmapmany_ops,
 
+	OPT_mmaptorture,
+	OPT_mmaptorture_bytes,
+	OPT_mmaptorture_msync,
+	OPT_mmaptorture_ops,
+
 	OPT_module,
 	OPT_module_name,
 	OPT_module_no_modver,
@@ -931,6 +950,7 @@ typedef enum {
 	OPT_mremap_ops,
 	OPT_mremap_bytes,
 	OPT_mremap_mlock,
+	OPT_mremap_numa,
 
 	OPT_mseal,
 	OPT_mseal_ops,
@@ -1018,6 +1038,7 @@ typedef enum {
 	OPT_pagemove,
 	OPT_pagemove_bytes,
 	OPT_pagemove_mlock,
+	OPT_pagemove_numa,
 	OPT_pagemove_ops,
 
 	OPT_pageswap,
@@ -1026,6 +1047,7 @@ typedef enum {
 	OPT_pci,
 	OPT_pci_dev,
 	OPT_pci_ops,
+	OPT_pci_ops_rate,
 
 	OPT_perf_stats,
 
@@ -1064,8 +1086,9 @@ typedef enum {
 	OPT_plugin_method,
 	OPT_plugin_so,
 
-	OPT_poll_ops,
 	OPT_poll_fds,
+	OPT_poll_ops,
+	OPT_poll_random_us,
 
 	OPT_powmath,
 	OPT_powmath_method,
@@ -1178,6 +1201,9 @@ typedef enum {
 	OPT_reboot,
 	OPT_reboot_ops,
 
+	OPT_regex,
+	OPT_regex_ops,
+
 	OPT_regs,
 	OPT_regs_ops,
 
@@ -1618,6 +1644,9 @@ typedef enum {
 	OPT_vdso_ops,
 	OPT_vdso_func,
 
+	OPT_veccmp,
+	OPT_veccmp_ops,
+
 	OPT_vecfp,
 	OPT_vecfp_ops,
 	OPT_vecfp_method,
@@ -1655,10 +1684,12 @@ typedef enum {
 	OPT_vm_ops,
 	OPT_vm_madvise,
 	OPT_vm_method,
+	OPT_vm_numa,
 
 	OPT_vm_addr,
 	OPT_vm_addr_method,
 	OPT_vm_addr_mlock,
+	OPT_vm_addr_numa,
 	OPT_vm_addr_ops,
 
 	OPT_vm_rw,
@@ -1691,8 +1722,6 @@ typedef enum {
 	OPT_watchdog,
 	OPT_watchdog_ops,
 
-	OPT_with,
-
 	OPT_wcs,
 	OPT_wcs_ops,
 	OPT_wcs_method,
