@@ -51,7 +51,8 @@ bool stress_process_oomed(const pid_t pid)
 		return oomed;
 
 	for (;;) {
-		char buf[4096], *ptr;
+		char buf[4096];
+		const char *ptr;
 		ssize_t ret;
 
 		ret = read(fd, buf, sizeof(buf) - 1);
@@ -142,7 +143,7 @@ void stress_set_oom_adjustment(stress_args_t *args, const bool killable)
 {
 	bool high_priv;
 	bool make_killable = killable;
-	char *str;
+	const char *str;
 	int ret;
 
 	/*
@@ -280,13 +281,15 @@ again:
 	} else if (pid > 0) {
 		/* Parent, wait for child */
 		int status, ret;
-		double t_end = stress_time_now() + WAIT_TIMEOUT;
+		double t_end = -1.0;
 
 		args->stats->s_pid.oomable_child = pid;
 rewait:
 		stress_set_proc_state(args->name, STRESS_STATE_WAIT);
 		ret = waitpid(pid, &status, 0);
 		if (ret < 0) {
+			if (t_end < 0.0)
+				t_end = stress_time_now() + WAIT_TIMEOUT;
 			stress_set_proc_state(args->name, STRESS_STATE_RUN);
 			/* No longer alive? */
 			if (errno == ECHILD)
