@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2021-2024 Colin Ian King.
+ * Copyright (C) 2021-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -53,7 +53,7 @@
 /* used for table of perf events to gather */
 typedef struct {
 	const unsigned int type;	/* perf types */
-	unsigned long config;		/* perf type specific config */
+	unsigned long int config;	/* perf type specific config */
 	const char *path;		/* perf trace point path (only for trace points) */
 	const char *label;		/* human readable name for perf type */
 } stress_perf_info_t;
@@ -272,9 +272,7 @@ static stress_perf_info_t perf_info[STRESS_PERF_MAX] = {
 
 	PERF_INFO_TP("mmap_lock/mmap_lock_start_locking","MMAP lock start"),
 	PERF_INFO_TP("mmap_lock/mmap_lock_released",	"MMAP lock release"),
-#if 1
 	PERF_INFO_TP("mmap_lock/mmap_lock_acquire_returned","MMAP lock acquire"),
-#endif
 
 	PERF_INFO_TP("rcu/rcu_utilization",		"RCU Utilization"),
 	PERF_INFO_TP("rcu/rcu_stall_warning",		"RCU Stall Warning"),
@@ -310,6 +308,7 @@ static stress_perf_info_t perf_info[STRESS_PERF_MAX] = {
 	PERF_INFO_TP("ipi/ipi_entry",			"IPI Entry"),
 	PERF_INFO_TP("ipi/ipi_raise",			"IPI Raise"),
 	PERF_INFO_TP("ipi/ipi_send_cpu",		"IPI Send CPU"),
+	PERF_INFO_TP("ipi/ipi_send_cpumask",		"IPI Send CPU Mask"),
 	PERF_INFO_TP("ipi/ipi_exit",			"IPI Exit"),
 
 	PERF_INFO_TP("irq_vectors/x86_platform_ipi_entry", "x86 Platform IPI Entry"),
@@ -325,7 +324,8 @@ static stress_perf_info_t perf_info[STRESS_PERF_MAX] = {
 	PERF_INFO_TP("iomap/iomap_writepage",		"IOMAP Write Page"),
 #endif
 
-	PERF_INFO_TP("io_uring/io_uring_submit_sqe",	"IO uring submit"),
+	PERF_INFO_TP("io_uring/io_uring_submit_sqe",	"IO uring submit SQE"),
+	PERF_INFO_TP("io_uring/io_uring_submit_req",	"IO uring submit REQ"),
 	PERF_INFO_TP("io_uring/io_uring_complete",	"IO uring complete"),
 
 	PERF_INFO_TP("writeback/writeback_dirty_inode",	"Writeback Dirty Inode"),
@@ -356,9 +356,12 @@ static stress_perf_info_t perf_info[STRESS_PERF_MAX] = {
 
 	PERF_INFO_TP("filemap/mm_filemap_add_to_page_cache",		"Filemap Page-Cache Add"),
 	PERF_INFO_TP("filemap/mm_filemap_delete_from_page_cache",	"Filemap Page-Cache Del"),
+	PERF_INFO_TP("filemap/mm_filemap_fault",	"Filemap Page Fault"),
+	PERF_INFO_TP("filemap/mm_filemap_map_pages",	"Filemap Map Pages"),
 
 	PERF_INFO_TP("oom/compact_retry",		"OOM Compact Retry"),
 	PERF_INFO_TP("oom/wake_reaper",			"OOM Wake Reaper"),
+	PERF_INFO_TP("oom/mark_victim",			"OOM Mark Victim"),
 	PERF_INFO_TP("oom/oom_score_adj_update",	"OOM Score Adjust Update"),
 
 	PERF_INFO_TP("thermal/thermal_zone_trip",	"Thermal Zone Trip"),
@@ -366,7 +369,7 @@ static stress_perf_info_t perf_info[STRESS_PERF_MAX] = {
 	{ 0, 0, NULL, NULL }
 };
 
-static inline size_t stress_perf_info_find(const unsigned int type, const unsigned long config)
+static inline size_t stress_perf_info_find(const unsigned int type, const unsigned long int config)
 {
 	size_t i;
 
@@ -384,7 +387,7 @@ static inline size_t stress_perf_info_find(const unsigned int type, const unsign
 static inline void stress_perf_type_tracepoint_resolve_config(stress_perf_info_t *pi)
 {
 	char path[PATH_MAX];
-	unsigned long config;
+	unsigned long int config;
 	FILE *fp;
 
 	if (!pi->path)
@@ -427,7 +430,7 @@ static inline int stress_sys_perf_event_open(
 	pid_t pid,
 	int cpu,
 	int group_fd,
-	unsigned long flags)
+	unsigned long int flags)
 {
 	return (int)syscall(__NR_perf_event_open, attr, pid, cpu, group_fd, flags);
 }
@@ -444,12 +447,14 @@ static char *stress_perf_yaml_label(char *dst, const char *src, const size_t n)
 		size_t i = n;
 
 		do {
-			if (*s == ' ')
+			unsigned char ch = (unsigned char)*s;
+
+			if (ch == ' ')
 				*d = '_';
-			else if (isupper(*s))
-				*d = (char)tolower(*s);
-			else if (*s)
-				*d = *s;
+			else if (isupper(ch))
+				*d = (char)tolower(ch);
+			else if (ch)
+				*d = (char)ch;
 			else {
 				while (--i != 0)
 					*d++ = 0;
@@ -679,9 +684,9 @@ static const char *stress_perf_stat_scale(const uint64_t counter, const double d
  */
 typedef struct {
 	const unsigned int	type;
-	const unsigned long	config;
+	const unsigned long int	config;
 	const unsigned int	ref_type;
-	const unsigned long	ref_config;
+	const unsigned long int	ref_config;
 	const bool		percent;	/* scale by 100.0 for percentages? */
 	const char 		*fmt;		/* snprintf format */
 } perf_relative_t;
@@ -744,7 +749,6 @@ void stress_perf_stat_dump(FILE *yaml, stress_stressor_t *stressors_list, const
 		int p;
 		uint64_t counter_totals[STRESS_PERF_MAX];
 		bool got_data = false;
-		char munged[64];
 		stress_perf_t *sp;
 
 		if (ss->ignore.run)
@@ -776,16 +780,15 @@ void stress_perf_stat_dump(FILE *yaml, stress_stressor_t *stressors_list, const
 		if (!got_data)
 			continue;
 
-		(void)stress_munge_underscore(munged, ss->stressor->name, sizeof(munged));
-		pr_inf("%s:\n", munged);
-		pr_yaml(yaml, "    - stressor: %s\n", munged);
+		pr_inf("%s:\n", ss->stressor->name);
+		pr_yaml(yaml, "    - stressor: %s\n", ss->stressor->name);
 		pr_yaml(yaml, "      duration: %f\n", duration);
 
 		for (p = 0; (p < STRESS_PERF_MAX) && perf_info[p].label; p++) {
-			const char *l = perf_info[p].label;
+			const char *label = perf_info[p].label;
 			const uint64_t ct = counter_totals[p];
 
-			if (l && (ct != STRESS_PERF_INVALID)) {
+			if (label && (ct != STRESS_PERF_INVALID)) {
 				char extra[32];
 				char yaml_label[128];
 				*extra = '\0';
@@ -810,11 +813,11 @@ void stress_perf_stat_dump(FILE *yaml, stress_stressor_t *stressors_list, const
 				}
 
 				pr_inf("%'26" PRIu64 " %-24s %s%s\n",
-					ct, l, stress_perf_stat_scale(ct, duration),
+					ct, label, stress_perf_stat_scale(ct, duration),
 					extra);
 
 				*yaml_label = '\0';
-				stress_perf_yaml_label(yaml_label, l, sizeof(yaml_label));
+				stress_perf_yaml_label(yaml_label, label, sizeof(yaml_label));
 				pr_yaml(yaml, "      %s_total: %" PRIu64
 					"\n", yaml_label, ct);
 				pr_yaml(yaml, "      %s_per_second: %f\n",
