@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Colin Ian King
+ * Copyright (C) 2022-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,6 +20,7 @@
 #define CORE_PERF_H
 
 #include "stress-ng.h"
+#include "core-attribute.h"
 
 /* perf related constants */
 #if defined(HAVE_LIB_PTHREAD) &&	\
@@ -47,7 +48,6 @@ extern int stress_perf_open(stress_perf_t *sp);
 extern int stress_perf_enable(stress_perf_t *sp);
 extern int stress_perf_disable(stress_perf_t *sp);
 extern int stress_perf_close(stress_perf_t *sp);
-extern bool stress_perf_stat_succeeded(const stress_perf_t *sp);
 extern void stress_perf_stat_dump(FILE *yaml, stress_stressor_t *procs_head,
 	const double duration);
 extern void stress_perf_init(void);
