@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,6 +20,10 @@
 #define CORE_SORT_H
 
 #include <inttypes.h>
+#include "core-attribute.h"
+
+typedef void (*sort_swap_func_t)(void *p1, void *p2, register size_t size);
+typedef void (*sort_copy_func_t)(void *p1, void *p2, register size_t size);
 
 extern void stress_sort_data_int32_init(int32_t *data, const size_t n);
 extern void stress_sort_data_int32_shuffle(int32_t *data, const size_t n);
@@ -28,6 +32,9 @@ extern void stress_sort_compare_reset(void);
 extern uint64_t stress_sort_compare_get(void);
 extern uint64_t stress_sort_compares ALIGN64;
 
+extern sort_swap_func_t sort_swap_func(const size_t size);
+extern sort_copy_func_t sort_copy_func(const size_t size);
+
 static inline int stress_sort_cmp_str(const void *p1, const void *p2)
 {
 	return strcmp(*(const char * const *)p1, *(const char * const *)p2);
