@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Colin Ian King
+ * Copyright (C) 2022-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,19 +31,23 @@
 	MACRO(affinity) 	\
 	MACRO(aio) 		\
 	MACRO(aiol) 		\
-	MACRO(apparmor) 	\
 	MACRO(alarm)		\
+	MACRO(apparmor) 	\
 	MACRO(atomic)		\
 	MACRO(bad_altstack) 	\
 	MACRO(bad_ioctl) 	\
+	MACRO(besselmath)	\
 	MACRO(bigheap)		\
-	MACRO(bind_mount)	\
 	MACRO(binderfs)		\
+	MACRO(bind_mount)	\
 	MACRO(bitonicsort)	\
+	MACRO(bitops)		\
 	MACRO(branch)		\
 	MACRO(brk)		\
 	MACRO(bsearch)		\
+	MACRO(bubblesort)	\
 	MACRO(cache)		\
+	MACRO(cachehammer)	\
 	MACRO(cacheline)	\
 	MACRO(cap)		\
 	MACRO(cgroup)		\
@@ -59,6 +63,7 @@
 	MACRO(copy_file)	\
 	MACRO(cpu)		\
 	MACRO(cpu_online)	\
+	MACRO(cpu_sched)	\
 	MACRO(crypt)		\
 	MACRO(cyclic)		\
 	MACRO(daemon)		\
@@ -67,20 +72,22 @@
 	MACRO(dentry)		\
 	MACRO(dev)		\
 	MACRO(dev_shm)		\
+	MACRO(dfp)		\
 	MACRO(dir)		\
 	MACRO(dirdeep)		\
 	MACRO(dirmany)		\
 	MACRO(dnotify)		\
 	MACRO(dup)		\
 	MACRO(dynlib)		\
-	MACRO(eigen)		\
 	MACRO(efivar)		\
+	MACRO(eigen)		\
 	MACRO(enosys)		\
 	MACRO(env)		\
 	MACRO(epoll)		\
 	MACRO(eventfd) 		\
 	MACRO(exec)		\
 	MACRO(exit_group)	\
+	MACRO(expmath)		\
 	MACRO(factor)		\
 	MACRO(fallocate)	\
 	MACRO(fanotify)		\
@@ -88,10 +95,13 @@
 	MACRO(fault)		\
 	MACRO(fcntl)		\
 	MACRO(fd_fork)		\
+	MACRO(fd_race)		\
+	MACRO(fibsearch)	\
 	MACRO(fiemap)		\
 	MACRO(fifo)		\
 	MACRO(file_ioctl)	\
 	MACRO(filename)		\
+	MACRO(flipflop)		\
 	MACRO(flock)		\
 	MACRO(flushcache)	\
 	MACRO(fma)		\
@@ -100,6 +110,7 @@
 	MACRO(fp)		\
 	MACRO(fp_error)		\
 	MACRO(fpunch)		\
+	MACRO(fractal)		\
 	MACRO(fsize)		\
 	MACRO(fstat)		\
 	MACRO(full)		\
@@ -117,11 +128,14 @@
 	MACRO(heapsort)		\
 	MACRO(hrtimers)		\
 	MACRO(hsearch)		\
+	MACRO(hyperbolic)	\
 	MACRO(icache)		\
 	MACRO(icmp_flood)	\
 	MACRO(idle_page)	\
 	MACRO(inode_flags)	\
 	MACRO(inotify)		\
+	MACRO(insertionsort)	\
+	MACRO(intmath)		\
 	MACRO(io)		\
 	MACRO(iomix)		\
 	MACRO(ioport)		\
@@ -147,10 +161,13 @@
 	MACRO(locka)		\
 	MACRO(lockbus)		\
 	MACRO(lockf)		\
+	MACRO(lockmix)		\
 	MACRO(lockofd)		\
+	MACRO(logmath)		\
 	MACRO(longjmp)		\
 	MACRO(loop)		\
 	MACRO(lsearch)		\
+	MACRO(lsm)		\
 	MACRO(madvise)		\
 	MACRO(malloc)		\
 	MACRO(matrix)		\
@@ -165,6 +182,7 @@
 	MACRO(mergesort)	\
 	MACRO(metamix)		\
 	MACRO(mincore)		\
+	MACRO(min_nanosleep)	\
 	MACRO(misaligned)	\
 	MACRO(mknod)		\
 	MACRO(mlock)		\
@@ -176,15 +194,18 @@
 	MACRO(mmapfork)		\
 	MACRO(mmaphuge)		\
 	MACRO(mmapmany)		\
+	MACRO(mmaptorture)	\
 	MACRO(module)		\
 	MACRO(monte_carlo)	\
-	MACRO(mprotect)		\
 	MACRO(mpfr)		\
+	MACRO(mprotect)		\
 	MACRO(mq)		\
 	MACRO(mremap)		\
+	MACRO(mseal)		\
 	MACRO(msg)		\
 	MACRO(msync)		\
 	MACRO(msyncmany)	\
+	MACRO(mtx)		\
 	MACRO(munmap)		\
 	MACRO(mutex)		\
 	MACRO(nanosleep)	\
@@ -211,20 +232,24 @@
 	MACRO(pkey)		\
 	MACRO(plugin)		\
 	MACRO(poll)		\
+	MACRO(powmath)		\
 	MACRO(prctl)		\
 	MACRO(prefetch)		\
+	MACRO(prime)		\
 	MACRO(prio_inv)		\
 	MACRO(priv_instr)	\
 	MACRO(procfs)		\
+	MACRO(pseek)		\
 	MACRO(pthread)		\
 	MACRO(ptrace)		\
+	MACRO(ptr_chase)	\
 	MACRO(pty)		\
 	MACRO(qsort)		\
 	MACRO(quota)		\
 	MACRO(race_sched)	\
 	MACRO(radixsort)	\
-	MACRO(randlist)		\
 	MACRO(ramfs)		\
+	MACRO(randlist)		\
 	MACRO(rawdev)		\
 	MACRO(rawpkt)		\
 	MACRO(rawsock)		\
@@ -232,6 +257,7 @@
 	MACRO(rdrand)		\
 	MACRO(readahead)	\
 	MACRO(reboot)		\
+	MACRO(regex)		\
 	MACRO(regs)		\
 	MACRO(remap)		\
 	MACRO(rename)		\
@@ -264,7 +290,9 @@
 	MACRO(sigchld)		\
 	MACRO(sigfd)		\
 	MACRO(sigfpe)		\
+	MACRO(sighup)		\
 	MACRO(sigio)		\
+	MACRO(sigill)		\
 	MACRO(signal)		\
 	MACRO(signest)		\
 	MACRO(sigpending)	\
@@ -274,6 +302,8 @@
 	MACRO(sigsegv)		\
 	MACRO(sigsuspend)	\
 	MACRO(sigtrap)		\
+	MACRO(sigurg)		\
+	MACRO(sigvtalrm)	\
 	MACRO(sigxcpu)		\
 	MACRO(sigxfsz)		\
 	MACRO(skiplist)		\
@@ -283,14 +313,16 @@
 	MACRO(sockabuse)	\
 	MACRO(sockdiag)		\
 	MACRO(sockfd)		\
-	MACRO(sockpair)		\
 	MACRO(sockmany)		\
+	MACRO(sockpair)		\
 	MACRO(softlockup)	\
-	MACRO(spawn)		\
 	MACRO(sparsematrix)	\
+	MACRO(spawn)		\
+	MACRO(spinmem)		\
 	MACRO(splice)		\
 	MACRO(stack)		\
 	MACRO(stackmmap)	\
+	MACRO(statmount)	\
 	MACRO(str)		\
 	MACRO(stream)		\
 	MACRO(swap)		\
@@ -300,9 +332,9 @@
 	MACRO(syncload)		\
 	MACRO(sysbadaddr)	\
 	MACRO(syscall)		\
+	MACRO(sysfs)		\
 	MACRO(sysinfo)		\
 	MACRO(sysinval)		\
-	MACRO(sysfs)		\
 	MACRO(tee)		\
 	MACRO(timer)		\
 	MACRO(timerfd)		\
@@ -318,6 +350,7 @@
 	MACRO(udp)		\
 	MACRO(udp_flood)	\
 	MACRO(umount)		\
+	MACRO(unlink)		\
 	MACRO(unshare)		\
 	MACRO(uprobe)		\
 	MACRO(urandom)		\
@@ -325,6 +358,7 @@
 	MACRO(usersyscall)	\
 	MACRO(utime)		\
 	MACRO(vdso)		\
+	MACRO(veccmp)		\
 	MACRO(vecfp)		\
 	MACRO(vecmath)		\
 	MACRO(vecshuf)		\
@@ -333,11 +367,11 @@
 	MACRO(vfork)		\
 	MACRO(vforkmany)	\
 	MACRO(vm)		\
+	MACRO(vma)		\
 	MACRO(vm_addr)		\
 	MACRO(vm_rw)		\
 	MACRO(vm_segv)		\
 	MACRO(vm_splice)	\
-	MACRO(vma)		\
 	MACRO(vnni)		\
 	MACRO(wait)		\
 	MACRO(waitcpu)		\
@@ -358,14 +392,12 @@
 #define STRESSOR_ENUM(name)	\
 	STRESS_ ## name,
 
-
 /*
  *  Elements in stressor array
  */
 #define STRESSOR_ELEM(name)		\
 {					\
 	&stress_ ## name ## _info,	\
-	STRESS_ ## name,		\
 	OPT_ ## name,			\
 	OPT_ ## name  ## _ops,		\
 	# name				\
@@ -374,7 +406,6 @@
 /*
  *  Declaration of stress_*_info object
  */
-#define STRESSOR_INFO(name)     \
-	extern stressor_info_t stress_ ## name ## _info;
+#define STRESSOR_INFO(name)	extern stressor_info_t stress_ ## name ## _info;
 
 #endif
