@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Colin Ian King
+ * Copyright (C) 2022-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -158,6 +158,14 @@
 #define TARGET_CLONE_ARROWLAKE
 #endif
 
+#if defined(HAVE_TARGET_CLONES_LUNARLAKE) &&		\
+    defined(HAVE_COMPILER_GCC_OR_MUSL)
+#define TARGET_CLONE_LUNARLAKE "arch=lunarlake",
+#define TARGET_CLONE_USE
+#else
+#define TARGET_CLONE_LUNARLAKE
+#endif
+
 #define TARGET_CLONES_ALL		\
 	TARGET_CLONE_AVX		\
 	TARGET_CLONE_AVX2 		\
@@ -176,6 +184,7 @@
 	TARGET_CLONE_ROCKETLAKE		\
 	TARGET_CLONE_GRANITERAPIDS	\
 	TARGET_CLONE_ARROWLAKE		\
+	TARGET_CLONE_LUNARLAKE		\
 	TARGET_CLONE_PANTHERLAKE	\
 	"default"
 
@@ -189,23 +198,34 @@
 #if defined(STRESS_ARCH_PPC64) &&	\
     defined(HAVE_TARGET_CLONES)
 
-#if defined(HAVE_TARGET_CLONES_POWER9)
+#if defined(HAVE_TARGET_CLONES_POWER9) &&	\
+    defined(HAVE_BUILTIN_CPU_IS_POWER10)
 #define TARGET_CLONE_POWER9 "cpu=power9",
 #define TARGET_CLONE_USE
 #else
 #define TARGET_CLONE_POWER9
 #endif
 
-#if defined(HAVE_TARGET_CLONES_POWER10)
+#if defined(HAVE_TARGET_CLONES_POWER10)	&&	\
+    defined(HAVE_BUILTIN_CPU_IS_POWER10)
 #define TARGET_CLONE_POWER10 "cpu=power10",
 #define TARGET_CLONE_USE
 #else
 #define TARGET_CLONE_POWER10
 #endif
 
+#if defined(HAVE_TARGET_CLONES_POWER11) &&	\
+    defined(HAVE_BUILTIN_CPU_IS_POWER11)
+#define TARGET_CLONE_POWER11 "cpu=power11",
+#define TARGET_CLONE_USE
+#else
+#define TARGET_CLONE_POWER11
+#endif
+
 #define TARGET_CLONES_ALL	\
 	TARGET_CLONE_POWER9	\
 	TARGET_CLONE_POWER10	\
+	TARGET_CLONE_POWER11	\
 	"default"
 
 #if defined(TARGET_CLONE_USE)
