@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,6 +18,7 @@
  *
  */
 #include "stress-ng.h"
+#include "core-attribute.h"
 #include "core-killpid.h"
 #include "core-thrash.h"
 
@@ -175,12 +176,28 @@ static int stress_pagein_proc(const pid_t pid)
 	 * Look for field 0060b000-0060c000 r--p 0000b000 08:01 1901726
 	 */
 	while (thrash_run && fgets(buffer, sizeof(buffer), fpmap)) {
-		off_t begin, end, len, off;
+		off_t off, begin, end, len;
 		char tmppath[1024];
 		char prot[6];
 
-		if (sscanf(buffer, "%jx-%jx %5s %*x %*x:%*x %*d %1023s", &begin, &end, prot, tmppath) != 4)
+		/* portable off_t and scanf is a pain */
+		if ((sizeof(off_t) < 32) || (sizeof(off_t) > 64))
 			continue;
+		else if (sizeof(off_t) == 32) {
+			uint32_t begin32, end32;
+
+			if (sscanf(buffer, "%" SCNx32 "-%" SCNx32 " %5s %*x %*x:%*x %*d %1023s", &begin32, &end32, prot, tmppath) != 4)
+				continue;
+			begin = (off_t)begin32;
+			end = (off_t)end32;
+		} else if (sizeof(off_t) <= 64) {
+			uint64_t begin64, end64;
+
+			if (sscanf(buffer, "%" SCNx64 "-%" SCNx64 " %5s %*x %*x:%*x %*d %1023s", &begin64, &end64, prot, tmppath) != 4)
+				continue;
+			begin = (off_t)begin64;
+			end = (off_t)end64;
+		}
 
 		/* ignore non-readable or non-private mappings */
 		if ((prot[0] != 'r') && (prot[3] != 'p'))
@@ -196,7 +213,7 @@ static int stress_pagein_proc(const pid_t pid)
 			continue;
 
 		for (off = begin; thrash_run && (off < end); off += page_size) {
-			unsigned long data;
+			unsigned long int data;
 			off_t pos;
 
 			pos = lseek(fdmem, off, SEEK_SET);
@@ -213,6 +230,105 @@ exit_fdmem:
 	return rc;
 }
 
+#if defined(__linux__)
+/*
+ *  stress_proc_file_read()
+ *	read a proc file
+ */
+static void stress_file_read(const char *filename)
+{
+	char buf[4096];
+	int fd;
+
+	fd = open(filename, O_RDONLY);
+	if (fd < 0)
+		return;
+
+	while (read(fd, buf, sizeof(buf)) > 0)
+		;
+	(void)close(fd);
+}
+#endif
+
+/*
+ *  stress_sys_memory()
+ *	stress sys files that are memory related
+ */
+static inline void stress_sys_memory(void)
+{
+#if defined(__linux__)
+	static const char * const sys_files[] = {
+		"/sys/kernel/vmcoreinfo",
+		"/sys/kernel/debug/percpu_stats",
+	};
+
+	size_t i;
+
+	for (i = 0; i < SIZEOF_ARRAY(sys_files); i++) {
+		stress_file_read(sys_files[i]);
+	}
+#endif
+}
+
+/*
+ *  stress_proc_memory()
+ *	stress proc files that are memory related
+ */
+static inline void stress_proc_memory(void)
+{
+#if defined(__linux__)
+	static const char * const proc_files[] = {
+		"/proc/allocinfo",
+		"/proc/buddyinfo",
+		"/proc/meminfo",
+		"/proc/slabinfo",
+		"/proc/pagetypeinfo",
+		"/proc/pressure/memory",
+		"/proc/vmallocinfo",
+		"/proc/zoneinfo",
+	};
+
+	size_t i;
+	DIR *dir;
+	const struct dirent *d;
+
+	for (i = 0; i < SIZEOF_ARRAY(proc_files); i++) {
+		stress_file_read(proc_files[i]);
+	}
+
+	/*
+	 *  scan through all /proc/$PID directories
+	 *  reading proc_pid_files
+	 */
+	dir = opendir("/proc");
+	if (!dir)
+		return;
+
+	while ((d = readdir(dir)) != NULL) {
+		static const char * const proc_pid_files[] = {
+			"maps",
+			"numa_maps",
+			"projid_map",
+			"smaps",
+			"smaps_rollup",
+		};
+
+		if (!isdigit((unsigned char)d->d_name[0]))
+			continue;
+
+		for (i = 0; i < SIZEOF_ARRAY(proc_pid_files); i++) {
+			char filename[PATH_MAX];
+
+			(void)snprintf(filename, sizeof(filename),
+				"/proc/%s/%s", d->d_name,
+				proc_pid_files[i]);
+			stress_file_read(filename);
+		}
+	}
+	(void)closedir(dir);
+#endif
+}
+
 /*
  *  stress_compact_memory()
  *	trigger memory compaction, Linux only
@@ -287,7 +403,7 @@ static inline void stress_slab_shrink(void)
 	 *  shrink all slabs
 	 */
 	while ((d = readdir(dir)) != NULL) {
-		if (isalpha((int)d->d_name[0]))  {
+		if (isalpha((unsigned char)d->d_name[0]))  {
 			char path[PATH_MAX];
 
 			(void)snprintf(path, sizeof(path), "%s/%s", slabpath, d->d_name);
@@ -348,7 +464,7 @@ static int stress_pagein_all_procs(void)
 	while (thrash_run && ((d = readdir(dp)) != NULL)) {
 		intmax_t pid;
 
-		if (isdigit(d->d_name[0]) &&
+		if (isdigit((unsigned char)d->d_name[0]) &&
 		    sscanf(d->d_name, "%" SCNdMAX, &pid) == 1) {
 			char procpath[128];
 			struct stat statbuf;
@@ -414,6 +530,10 @@ int stress_thrash_start(void)
 
 			stress_kmemleak_scan();
 
+			stress_proc_memory();
+
+			stress_sys_memory();
+
 			stress_thrash_state("sleep");
 			(void)sleep(1);
 		}
@@ -448,7 +568,7 @@ void stress_thrash_stop(void)
 }
 
 #else
-int stress_thrash_start(void)
+int PURE stress_thrash_start(void)
 {
 	return 0;
 }
@@ -457,7 +577,7 @@ void stress_thrash_stop(void)
 {
 }
 
-int stress_pagein_self(const char *name)
+int PURE stress_pagein_self(const char *name)
 {
 	(void)name;
 
