@@ -1,5 +1,5 @@
 /*
- * Copyright (C)      2022 Colin Ian King
+ * Copyright (C) 2022-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,8 +19,11 @@
 #ifndef CORE_THRASH_H
 #define CORE_THRASH_H
 
+#include "core-attribute.h"
+
 /* CPU thrashing start/stop helpers */
 extern int  stress_thrash_start(void);
 extern void stress_thrash_stop(void);
+extern int stress_pagein_self(const char *name);
 
 #endif
