@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2023 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,29 +18,35 @@
  *
  */
 #include "stress-ng.h"
+#include "core-builtin.h"
+#include "core-killpid.h"
+#include "core-try-open.h"
+
+#include <time.h>
 
 /*
  *  stress_try_kill()
  *	hammer away and try to kill a process
  */
 static void stress_try_kill(
-	const stress_args_t *args,
+	stress_args_t *args,
 	const pid_t pid,
 	const char *path)
 {
 	int i;
 
-	for (i = 0; i < 10; i++) {
+	for (i = 1; LIKELY(stress_continue(args) && (i <= 20)); i++) {
 		int status;
 
-		VOID_RET(int, kill(pid, SIGKILL));
+		VOID_RET(int, stress_kill_pid(pid));
 		VOID_RET(int, waitpid(pid, &status, WNOHANG));
-		if ((kill(pid, 0) < 0) && (errno == ESRCH))
+		if ((shim_kill(pid, 0) < 0) && (errno == ESRCH))
 			return;
-		(void)shim_usleep(100000);
+		(void)shim_usleep(10000 * i);
 	}
-	pr_dbg("%s: can't kill pid %" PRIdMAX " opening %s\n",
+	pr_dbg("%s: can't kill PID %" PRIdMAX " opening %s\n",
 		args->name, (intmax_t)pid, path);
+	stress_process_info(args, pid);
 }
 
 /*
@@ -48,22 +54,22 @@ static void stress_try_kill(
  *  if it cannot be opened within timeout nanoseconds.
  */
 int stress_try_open(
-	const stress_args_t *args,
+	stress_args_t *args,
 	const char *path,
 	const int flags,
-	const unsigned long timeout_ns)
+	const unsigned long int timeout_ns)
 {
 	pid_t pid;
 	int ret, status = 0;
 	struct stat statbuf;
 	const int retries = 20;
-	const unsigned long sleep_ns = timeout_ns / retries;
+	const unsigned long int sleep_ns = timeout_ns / retries;
 	int i;
 
 	(void)args;
 
 	/* Don't try to open if file can't be stat'd */
-	if (stat(path, &statbuf) < 0)
+	if (shim_stat(path, &statbuf) < 0)
 		return -1;
 
 	pid = fork();
@@ -102,7 +108,7 @@ int stress_try_open(
 			return STRESS_TRY_OPEN_WAIT_FAIL;
 		}
 		/* Has pid gone? */
-		if ((kill(pid, 0) < 0) && (errno == ESRCH))
+		if ((shim_kill(pid, 0) < 0) && (errno == ESRCH))
 			goto done;
 
 		/* Sleep and retry */
@@ -133,7 +139,7 @@ int stress_open_timeout(
 	const char *name,
 	const char *path,
 	const int flags,
-	const unsigned long timeout_ns)
+	const unsigned long int timeout_ns)
 {
 	int ret, t_ret, tmp;
 	struct sigevent sev;
@@ -152,7 +158,7 @@ int stress_open_timeout(
 	/*
 	 *  Enable a timer to interrupt log open waits
 	 */
-	(void)memset(&sev, 0, sizeof(sev));
+	(void)shim_memset(&sev, 0, sizeof(sev));
 	sev.sigev_notify = SIGEV_SIGNAL;
 	sev.sigev_signo = SIGRTMIN;
 	sev.sigev_value.sival_ptr = &timerid;
@@ -178,7 +184,7 @@ int stress_open_timeout(
 	const char *name,
 	const char *path,
 	const int flags,
-	const unsigned long timeout_ns)
+	const unsigned long int timeout_ns)
 {
 	(void)name;
 	(void)timeout_ns;
