@@ -1,6 +1,6 @@
 /*
  * Copyright (C)      2021 Canonical, Ltd.
- * Copyright (C) 2021-2024 Colin Ian King
+ * Copyright (C) 2021-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -140,7 +140,7 @@ static void freebsd_get_cpu_time(
 	*idle_time = 0;
 
 	vals = (long int *)calloc(cpus * 5, sizeof(*vals));
-	if (!vals)
+	if (UNLIKELY(!vals))
 		return;
 
 	if (stress_bsd_getsysctl("kern.cp_times", vals, cpus * 5 * sizeof(*vals)) < 0)
@@ -180,7 +180,7 @@ static void netbsd_get_cpu_time(
 
 /*
  *  stress_set_generic_stat()
- *	parse and check op for valud time range
+ *	parse and check op for valid time range
  */
 static int stress_set_generic_stat(
 	const char *const opt,
@@ -189,7 +189,7 @@ static int stress_set_generic_stat(
 {
 	const uint64_t delay64 = stress_get_uint64_time(opt);
 
-        if ((delay64 < 1) || (delay64 > 3600)) {
+        if (UNLIKELY((delay64 < 1) || (delay64 > 3600))) {
                 (void)fprintf(stderr, "%s must in the range 1 to 3600 seconds.\n", name);
                 _exit(EXIT_FAILURE);
         }
@@ -366,7 +366,7 @@ static char *stress_iostat_iostat_name(
 
 	/* Resolve links */
 	temp_path = realpath(stress_get_temp_path(), NULL);
-	if (!temp_path)
+	if (UNLIKELY(!temp_path))
 		return NULL;
 
 	/* Find device */
@@ -389,7 +389,7 @@ static char *stress_iostat_iostat_name(
 		(void)snprintf(iostat_name, iostat_name_len, "/sys/block/%s/stat", dev);
 		if (shim_stat(iostat_name, &statbuf) == 0)
 			return iostat_name;
-		if (!isdigit(*ptr))
+		if (!isdigit((unsigned char)*ptr))
 			break;
 		*ptr = '\0';
 		ptr--;
@@ -875,7 +875,7 @@ static void stress_read_vmstat(stress_vmstat_t *vmstat)
 				break;
 
 			result = (struct kinfo_proc *)malloc(length);
-			if (!result)
+			if (UNLIKELY(!result))
 				break;
 
 			ret = sysctl((int *)name, (sizeof(name)/sizeof(*name))-1, result,
@@ -1015,7 +1015,7 @@ static void stress_get_cpu_ghz(
 	for (i = 0; i < n_cpus; i++) {
 		const char *name = cpu_list[i]->d_name;
 
-		if (!strncmp(name, "cpu", 3) && isdigit(name[3])) {
+		if (!strncmp(name, "cpu", 3) && isdigit((unsigned char)name[3])) {
 			char path[PATH_MAX];
 			double freq;
 			FILE *fp;
