@@ -604,6 +604,9 @@ do_stress --mmaphuge -1 --mmaphuge-mmaps 32768
 do_stress --mmapmany -1 --mmapmany-mlock
 do_stress --mmapmany -1 --mmapmany-numa
 
+do_stress --mmaptorture -1 --mmaptorture-bytes 30%
+do_stress --mmaptorture -1 --mmaptorture-msync 95
+
 do_stress --module -1 --module-name bfq
 
 do_stress --mpfr -1 --mpfr-precision 8192
@@ -840,5 +843,15 @@ if [ -e $PERF_PARANOID ]; then
 	(echo $paranoid_saved | sudo tee $PERF_PARANOID) > /dev/null
 fi
 
-sudo lcov -c -o kernel.info --keep-going >& /dev/null
+#
+#  Process gcov data
+#
+sudo lcov -c --branch-coverage -o kernel.info --keep-going >& /dev/null
+#
+#  Convert to html
+#
 sudo genhtml --ignore-errors inconsistent -o html kernel.info
+#
+#  Covert to ascii for machine parsing
+#
+sudo find html -print -name "*.html" -exec html2text -ascii -o {}.txt {} \;
