@@ -146,7 +146,7 @@ static void MLOCKED_TEXT stress_af_alg_alarm_handler(int signum)
  */
 static stress_crypto_type_t name_to_type(const char *buffer)
 {
-	char *end, *ptr = strchr(buffer, ':');
+	const char *end, *ptr = strchr(buffer, ':');
 	size_t i;
 
 	if (!ptr)
@@ -278,13 +278,13 @@ retry_bind:
 		double t, delta;
 		ssize_t ret;
 
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 
 		t = stress_time_now();
 		ret = send(fd, input, j, 0);
 		if (UNLIKELY(ret != (ssize_t)j)) {
-			if (ret < 0) {
+			if ((ret < 0) && (errno != 0)) {
 				if (errno == EINTR)
 					break;
 				if ((errno == ENOKEY) || (errno == ENOENT))
@@ -531,6 +531,8 @@ retry_bind:
 		msg.msg_iovlen = 1;
 
 		if (UNLIKELY(sendmsg(fd, &msg, 0) < 0)) {
+			if (errno == 0)
+				break;
 			if (errno == EINTR)
 				break;
 			if (errno == ENOMEM)
@@ -593,6 +595,8 @@ retry_bind:
 
 		t = stress_time_now();
 		if (UNLIKELY(sendmsg(fd, &msg, 0) < 0)) {
+			if (errno == 0)
+				break;
 			if (errno == ENOMEM)
 				break;
 			if (errno == EINTR)
@@ -938,7 +942,7 @@ static int stress_af_alg(stress_args_t *args)
 	}
 
 	do {
-		for (info = crypto_info_list; info && stress_continue(args); info = info->next) {
+		for (info = crypto_info_list; LIKELY(info && stress_continue(args)); info = info->next) {
 			if (info->internal || info->ignore)
 				continue;
 
