@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,6 +20,10 @@
 #include "stress-ng.h"
 #include "core-attribute.h"
 #include "core-builtin.h"
+#include "core-pragma.h"
+#include "core-target-clones.h"
+
+#include <time.h>
 
 #if defined(HAVE_LIBAIO_H)
 #include <libaio.h>
@@ -43,19 +47,9 @@ static const stress_help_t help[] = {
 	{ NULL,	NULL,		   NULL }
 };
 
-static int stress_set_aio_linux_requests(const char *opt)
-{
-	uint32_t aio_linux_requests;
-
-	aio_linux_requests = stress_get_uint32(opt);
-	stress_check_range("aiol-requests", aio_linux_requests,
-		MIN_AIO_LINUX_REQUESTS, MAX_AIO_LINUX_REQUESTS);
-	return stress_set_setting("aiol-requests", TYPE_ID_UINT32, &aio_linux_requests);
-}
-
-static const stress_opt_set_func_t opt_set_funcs[] = {
-	{ OPT_aiol_requests,	stress_set_aio_linux_requests },
-	{ 0,			NULL }
+static const stress_opt_t opts[] = {
+	{ OPT_aiol_requests, "aiol-requests", TYPE_ID_UINT32, MIN_AIO_LINUX_REQUESTS, MAX_AIO_LINUX_REQUESTS, NULL },
+	END_OPT,
 };
 
 #if defined(HAVE_LIB_AIO) &&		\
@@ -67,8 +61,23 @@ static const stress_opt_set_func_t opt_set_funcs[] = {
     defined(__NR_io_submit) &&		\
     defined(__NR_io_getevents)
 
+typedef struct {
+	uint64_t aiol_completions;
+	uint8_t *buffer;
+	struct iocb *cb;
+	struct io_event *events;
+	struct iocb **cbs;
+	int *fds;
+	struct iovec *iov;
+	io_context_t ctx_id;
+} stress_aiol_info_t;
+
 #if defined(__NR_io_cancel)
-static int shim_io_cancel(
+/*
+ *  shim_io_cancel
+ * 	wrapper for io_cancel system call
+ */
+static inline int shim_io_cancel(
 	io_context_t ctx_id,
 	struct iocb *iocb,
 	struct io_event *result)
@@ -83,10 +92,14 @@ struct shim_aio_sigset {
 	size_t		sigsetsize;
 };
 
-static int shim_io_pgetevents(
+/*
+ *  shim_io_pgetevents
+ * 	wrapper for io_pgetevents system call
+ */
+static inline int shim_io_pgetevents(
 	io_context_t ctx_id,
-	long min_nr,
-	long nr,
+	long int min_nr,
+	long int nr,
 	struct io_event *events,
 	struct timespec *timeout,
 	const struct shim_aio_sigset *usig)
@@ -95,25 +108,41 @@ static int shim_io_pgetevents(
 }
 #endif
 
-static int shim_io_setup(unsigned nr_events, io_context_t *ctx_idp)
+/*
+ *  shim_io_setup
+ * 	wrapper for io_setup system call
+ */
+static inline int shim_io_setup(unsigned nr_events, io_context_t *ctx_id)
 {
-	return (int)syscall(__NR_io_setup, nr_events, ctx_idp);
+	return (int)syscall(__NR_io_setup, nr_events, ctx_id);
 }
 
-static int shim_io_destroy(io_context_t ctx_id)
+/*
+ *  shim_io_destroy
+ * 	wrapper for io_destroy system call
+ */
+static inline int shim_io_destroy(io_context_t ctx_id)
 {
 	return (int)syscall(__NR_io_destroy, ctx_id);
 }
 
-static int shim_io_submit(io_context_t ctx_id, long nr, struct iocb **iocbpp)
+/*
+ *  shim_io_submit
+ * 	wrapper for io_submit system call
+ */
+static inline int shim_io_submit(io_context_t ctx_id, long int nr, struct iocb **iocbpp)
 {
 	return (int)syscall(__NR_io_submit, ctx_id, nr, iocbpp);
 }
 
-static int shim_io_getevents(
+/*
+ *  shim_io_getevents
+ * 	wrapper for io_getevents system call
+ */
+static inline int shim_io_getevents(
 	io_context_t ctx_id,
-	long min_nr,
-	long nr,
+	long int min_nr,
+	long int nr,
 	struct io_event *events,
 	struct timespec *timeout)
 {
@@ -126,11 +155,10 @@ static int shim_io_getevents(
  *	random choice. If shim_io_pgetevents does not exist, don't
  *	try it again.
  */
-static int shim_io_getevents_random(
-	const io_context_t ctx_id,
-	const long min_nr,
-	const long nr,
-	struct io_event *const events,
+static inline int shim_io_getevents_random(
+	stress_aiol_info_t *info,
+	const long int min_nr,
+	const long int nr,
 	struct timespec *const timeout)
 {
 #if defined(__NR_io_pgetevents)
@@ -139,7 +167,7 @@ static int shim_io_getevents_random(
 	if (try_io_pgetevents && stress_mwc1()) {
 		int ret;
 
-		ret = shim_io_pgetevents(ctx_id, min_nr, nr, events, timeout, NULL);
+		ret = shim_io_pgetevents(info->ctx_id, min_nr, nr, info->events, timeout, NULL);
 		if (ret >= 0)
 			return ret;
 		/* system call not wired up? never try again */
@@ -152,14 +180,14 @@ static int shim_io_getevents_random(
 #else
 	UNEXPECTED
 #endif
-	return shim_io_getevents(ctx_id, min_nr, nr, events, timeout);
+	return shim_io_getevents(info->ctx_id, min_nr, nr, info->events, timeout);
 }
 
 /*
- *  aio_linux_fill_buffer()
+ *  stress_aiol_fill_buffer()
  *	fill buffer with some known pattern
  */
-static inline OPTIMIZE3 void aio_linux_fill_buffer(
+static inline OPTIMIZE3 TARGET_CLONES void stress_aiol_fill_buffer(
 	const uint8_t pattern,
 	uint8_t *const buffer,
 	const size_t size)
@@ -167,23 +195,26 @@ static inline OPTIMIZE3 void aio_linux_fill_buffer(
 	register size_t i;
 	register uint8_t pat = pattern;
 
+PRAGMA_UNROLL_N(2)
 	for (i = 0; i < size; i++, pat++)
 		buffer[i] = (uint8_t)pat;
 }
 
 /*
- *  aio_linux_check_buffer()
+ *  stress_aiol_check_buffer()
  *	check buffer contains some known pattern
  */
-static inline PURE OPTIMIZE3 bool aio_linux_check_buffer(
+static inline PURE OPTIMIZE3 bool stress_aiol_check_buffer(
 	const int request,
 	const uint8_t *const buffer,
 	const size_t size)
 {
 	register size_t i;
+	register uint8_t pat = (uint8_t)request;
 
-	for (i = 0; i < size; i++) {
-		if (buffer[i] != (uint8_t)(request + (int)i))
+PRAGMA_UNROLL_N(2)
+	for (i = 0; i < size; i++, pat++) {
+		if (UNLIKELY(buffer[i] != pat))
 			return false;
 	}
 
@@ -196,8 +227,7 @@ static inline PURE OPTIMIZE3 bool aio_linux_check_buffer(
  */
 static int stress_aiol_submit(
 	stress_args_t *args,
-	const io_context_t ctx,
-	struct iocb *cbs[],
+	stress_aiol_info_t *info,
 	const size_t n,
 	const bool ignore_einval)
 {
@@ -205,8 +235,8 @@ static int stress_aiol_submit(
 		int ret;
 
 		errno = 0;
-		ret = shim_io_submit(ctx, (long)n, cbs);
-		if (ret >= 0) {
+		ret = shim_io_submit(info->ctx_id, (long int)n, info->cbs);
+		if (LIKELY(ret >= 0)) {
 			break;
 		} else {
 			if ((errno == EINVAL) && ignore_einval)
@@ -228,10 +258,8 @@ static int stress_aiol_submit(
  */
 static ssize_t stress_aiol_wait(
 	stress_args_t *args,
-	const io_context_t ctx,
-	struct io_event events[],
-	const size_t n,
-	uint64_t *aiol_completions)
+	stress_aiol_info_t *info,
+	const size_t n)
 {
 	size_t i = 0;
 
@@ -239,7 +267,7 @@ static ssize_t stress_aiol_wait(
 		struct timespec timeout, *timeout_ptr;
 		int ret;
 
-		if (clock_gettime(CLOCK_REALTIME, &timeout) < 0) {
+		if (UNLIKELY(clock_gettime(CLOCK_REALTIME, &timeout) < 0)) {
 			timeout_ptr = NULL;
 		} else {
 			timeout.tv_nsec += 1000000;
@@ -250,10 +278,10 @@ static ssize_t stress_aiol_wait(
 			timeout_ptr = &timeout;
 		}
 
-		ret = shim_io_getevents_random(ctx, 1, (long)(n - i), events, timeout_ptr);
-		if (ret < 0) {
+		ret = shim_io_getevents_random(info, 1, (long int)(n - i), timeout_ptr);
+		if (UNLIKELY(ret < 0)) {
 			if (errno == EINTR) {
-				if (stress_continue_flag()) {
+				if (LIKELY(stress_continue_flag())) {
 					continue;
 				} else {
 					/* indicate terminated early */
@@ -266,9 +294,9 @@ static ssize_t stress_aiol_wait(
 			return -1;
 		} else {
 			i += (size_t)ret;
-			(*aiol_completions) += ret;
+			info->aiol_completions += ret;
 		}
-		if (!stress_continue_flag()) {
+		if (UNLIKELY(!stress_continue_flag())) {
 			/* indicate terminated early */
 			return -1;
 		}
@@ -285,56 +313,45 @@ static ssize_t stress_aiol_wait(
 static int stress_aiol_alloc(
 	stress_args_t *args,
 	const size_t n,
-	uint8_t **buffer,
-	struct iocb **cb,
-	struct io_event **events,
-	struct iocb ***cbs,
-	int **fds,
-	struct iovec **iov)
+	stress_aiol_info_t *info)
 {
 	int ret;
 
-	ret = posix_memalign((void **)buffer, 4096, n * BUFFER_SZ);
+	ret = posix_memalign((void **)&info->buffer, 4096, n * BUFFER_SZ);
 	if (ret)
 		goto err_msg;
-	*cb = calloc(n, sizeof(**cb));
-	if (!*cb)
+	info->cb = (struct iocb *)calloc(n, sizeof(*info->cb));
+	if (!info->cb)
 		goto free_buffer;
-	*events = calloc(n, sizeof(**events));
-	if (!*events)
+	info->events = (struct io_event *)calloc(n, sizeof(*info->events));
+	if (!info->events)
 		goto free_cb;
-	*cbs = calloc(n, sizeof(**cbs));
-	if (!*cbs)
+	info->cbs = (struct iocb **)calloc(n, sizeof(*info->cbs));
+	if (!info->cbs)
 		goto free_events;
-	*fds = calloc(n, sizeof(**fds));
-	if (!*fds)
+	info->fds = (int *)calloc(n, sizeof(*info->fds));
+	if (!info->fds)
 		goto free_cbs;
-	*iov = calloc(n, sizeof(**iov));
-	if (!*iov)
+	info->iov = (struct iovec *)calloc(n, sizeof(*info->iov));
+	if (!info->iov)
 		goto free_fds;
 	return 0;
 
 free_fds:
-	free(*fds);
+	free(info->fds);
 free_cbs:
-	free(*cbs);
+	free(info->cbs);
 free_events:
-	free(*events);
+	free(info->events);
 free_cb:
-	free(*cb);
+	free(info->cb);
 free_buffer:
-	free(*buffer);
+	free(info->buffer);
 err_msg:
 	pr_inf_skip("%s: out of memory allocating buffers, skipping stressors\n",
 		args->name);
 
-	*buffer = NULL;
-	*cb = NULL;
-	*events = NULL;
-	*cbs = NULL;
-	*fds = NULL;
-	*iov = NULL;
-
+	(void)shim_memset(info, 0, sizeof(*info));
 	return -1;
 }
 
@@ -342,20 +359,15 @@ err_msg:
  *  stress_aiol_free()
  *	free allocated memory
  */
-static void stress_aiol_free(
-	uint8_t *buffer,
-	struct iocb *cb,
-	struct io_event *events,
-	struct iocb **cbs,
-	int *fds,
-	struct iovec *iov)
+static void stress_aiol_free(stress_aiol_info_t *info)
 {
-	free(buffer);
-	free(cb);
-	free(events);
-	free(cbs);
-	free(fds);
-	free(iov);
+	free(info->buffer);
+	free(info->cb);
+	free(info->events);
+	free(info->cbs);
+	free(info->fds);
+	free(info->iov);
+	(void)shim_memset(info, 0, sizeof(*info));
 }
 
 /*
@@ -368,31 +380,27 @@ static int stress_aiol(stress_args_t *args)
 	int flags = O_DIRECT;
 	char filename[PATH_MAX];
 	char buf[1];
-	io_context_t ctx = 0;
-	uint64_t aiol_completions = 0;
-	uint32_t aio_linux_requests = DEFAULT_AIO_LINUX_REQUESTS;
-	uint8_t *buffer;
-	struct iocb *cb;
-	struct io_event *events;
-	struct iocb **cbs;
-	struct iovec *iov;
-	int *fds;
+	uint32_t aiol_requiests = DEFAULT_AIO_LINUX_REQUESTS;
 	uint32_t aio_max_nr = DEFAULT_AIO_MAX_NR;
 	int j = 0;
 	size_t i;
 	int warnings = 0;
+	stress_aiol_info_t info ALIGN64;
 #if defined(__NR_io_cancel)
 	int bad_fd;
 #endif
+	double t, duration = 0.0, rate;
 
-	if (!stress_get_setting("aiol-requests", &aio_linux_requests)) {
+	(void)shim_memset(&info, 0, sizeof(info));
+
+	if (!stress_get_setting("aiol-requests", &aiol_requiests)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
-			aio_linux_requests = MAX_AIO_LINUX_REQUESTS;
+			aiol_requiests = MAX_AIO_LINUX_REQUESTS;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
-			aio_linux_requests = MIN_AIO_LINUX_REQUESTS;
+			aiol_requiests = MIN_AIO_LINUX_REQUESTS;
 	}
-	if ((aio_linux_requests < MIN_AIO_LINUX_REQUESTS) ||
-	    (aio_linux_requests > MAX_AIO_LINUX_REQUESTS)) {
+	if ((aiol_requiests < MIN_AIO_LINUX_REQUESTS) ||
+	    (aiol_requiests > MAX_AIO_LINUX_REQUESTS)) {
 		pr_fail("%s: iol_requests out of range", args->name);
 		return EXIT_FAILURE;
 	}
@@ -410,16 +418,16 @@ static int stress_aiol(stress_args_t *args)
 	aio_max_nr /= (args->num_instances == 0) ? 1 : args->num_instances;
 	if (aio_max_nr < 1)
 		aio_max_nr = 1;
-	if (aio_linux_requests > aio_max_nr) {
-		aio_linux_requests = aio_max_nr;
+	if (aiol_requiests > aio_max_nr) {
+		aiol_requiests = aio_max_nr;
 		if (args->instance == 0)
 			pr_inf("%s: Limiting AIO requests to "
 				"%" PRIu32 " per stressor (avoids running out of resources)\n",
-				args->name, aio_linux_requests);
+				args->name, aiol_requiests);
 	}
 
-	if (stress_aiol_alloc(args, aio_linux_requests, &buffer, &cb, &events, &cbs, &fds, &iov)) {
-		stress_aiol_free(buffer, cb, events, cbs, fds, iov);
+	if (stress_aiol_alloc(args, aiol_requiests, &info)) {
+		stress_aiol_free(&info);
 		return EXIT_NO_RESOURCE;
 	}
 
@@ -427,11 +435,11 @@ static int stress_aiol(stress_args_t *args)
 	 * Exercise invalid io_setup syscall
 	 * on invalid(zero) nr_events
 	 */
-	ret = shim_io_setup(0, &ctx);
+	ret = shim_io_setup(0, &info.ctx_id);
 	if (ret >= 0)
-		(void)shim_io_destroy(ctx);
+		(void)shim_io_destroy(info.ctx_id);
 
-	ret = shim_io_setup(aio_linux_requests, &ctx);
+	ret = shim_io_setup(aiol_requiests, &info.ctx_id);
 	if (ret < 0) {
 		/*
 		 *  The libaio interface returns -errno in the
@@ -474,8 +482,8 @@ static int stress_aiol(stress_args_t *args)
 		filename, sizeof(filename), stress_mwc32());
 
 retry_open:
-	fds[0] = open(filename, O_CREAT | O_RDWR | flags, S_IRUSR | S_IWUSR);
-	if (fds[0] < 0) {
+	info.fds[0] = open(filename, O_CREAT | O_RDWR | flags, S_IRUSR | S_IWUSR);
+	if (info.fds[0] < 0) {
 		if ((flags & O_DIRECT) && (errno == EINVAL)) {
 			flags &= ~O_DIRECT;
 			goto retry_open;
@@ -487,7 +495,7 @@ retry_open:
 		goto finish;
 	}
 
-	stress_file_rw_hint_short(fds[0]);
+	stress_file_rw_hint_short(info.fds[0]);
 
 #if defined(__NR_io_cancel)
 	bad_fd = stress_get_bad_fd();
@@ -498,72 +506,75 @@ retry_open:
 	 *  same file. If we can't open a file (e.g. out of file descriptors)
 	 *  then use the same fd as fd[0]
 	 */
-	for (i = 1; i < aio_linux_requests; i++) {
-		fds[i] = open(filename, O_RDWR | flags, S_IRUSR | S_IWUSR);
-		if (fds[i] < 0)
-			fds[i] = fds[0];
+	for (i = 1; i < aiol_requiests; i++) {
+		info.fds[i] = open(filename, O_RDWR | flags, S_IRUSR | S_IWUSR);
+		if (info.fds[i] < 0)
+			info.fds[i] = info.fds[0];
 		else
-			stress_file_rw_hint_short(fds[i]);
+			stress_file_rw_hint_short(info.fds[i]);
 	}
 	(void)shim_unlink(filename);
 
-	stress_set_proc_state(args->name, STRESS_STATE_RUN);
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
+	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
+	t = stress_time_now();
 	do {
-		uint8_t *bufptr;
+		register uint8_t *bufptr;
 		ssize_t n;
-		int64_t off, offset = (int64_t)(stress_mwc16() * BUFFER_SZ);
+		int64_t off;
+		const int64_t offset = (int64_t)(stress_mwc16() * BUFFER_SZ);
 
 		/*
 		 *  async writes
 		 */
-		(void)shim_memset(cb, 0, aio_linux_requests * sizeof(*cb));
-		for (bufptr = buffer, i = 0, off = offset; i < aio_linux_requests; i++, bufptr += BUFFER_SZ, off += BUFFER_SZ) {
+		(void)shim_memset(info.cb, 0, aiol_requiests * sizeof(*info.cb));
+		for (bufptr = info.buffer, i = 0, off = offset; i < aiol_requiests; i++, bufptr += BUFFER_SZ, off += BUFFER_SZ) {
 			const uint8_t pattern = (uint8_t)(j + ((((intptr_t)bufptr) >> 12) & 0xff));
 
-			aio_linux_fill_buffer(pattern, bufptr, BUFFER_SZ);
+			stress_aiol_fill_buffer(pattern, bufptr, BUFFER_SZ);
 
-			cb[i].aio_fildes = fds[i];
-			cb[i].aio_lio_opcode = IO_CMD_PWRITE;
-			cb[i].u.c.buf = bufptr;
-			cb[i].u.c.offset = off;
-			cb[i].u.c.nbytes = BUFFER_SZ;
-			cbs[i] = &cb[i];
+			info.cb[i].aio_fildes = info.fds[i];
+			info.cb[i].aio_lio_opcode = IO_CMD_PWRITE;
+			info.cb[i].u.c.buf = bufptr;
+			info.cb[i].u.c.offset = off;
+			info.cb[i].u.c.nbytes = BUFFER_SZ;
+			info.cbs[i] = &info.cb[i];
 		}
-		if (stress_aiol_submit(args, ctx, cbs, aio_linux_requests, false) < 0)
+		if (UNLIKELY(stress_aiol_submit(args, &info, aiol_requiests, false) < 0))
 			break;
-		if (stress_aiol_wait(args, ctx, events, aio_linux_requests, &aiol_completions) < 0)
+		if (UNLIKELY(stress_aiol_wait(args, &info, aiol_requiests) < 0))
 			break;
 		stress_bogo_inc(args);
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 
 		/*
 		 *  async reads
 		 */
-		(void)shim_memset(cb, 0, aio_linux_requests * sizeof(*cb));
-		for (bufptr = buffer, i = 0, off = offset; i < aio_linux_requests; i++, bufptr += BUFFER_SZ, off += BUFFER_SZ) {
+		(void)shim_memset(info.cb, 0, aiol_requiests * sizeof(*info.cb));
+		for (bufptr = info.buffer, i = 0, off = offset; i < aiol_requiests; i++, bufptr += BUFFER_SZ, off += BUFFER_SZ) {
 			(void)shim_memset(bufptr, 0, BUFFER_SZ);
 
-			cb[i].aio_fildes = fds[i];
-			cb[i].aio_lio_opcode = IO_CMD_PREAD;
-			cb[i].u.c.buf = bufptr;
-			cb[i].u.c.offset = off;
-			cb[i].u.c.nbytes = BUFFER_SZ;
-			cbs[i] = &cb[i];
+			info.cb[i].aio_fildes = info.fds[i];
+			info.cb[i].aio_lio_opcode = IO_CMD_PREAD;
+			info.cb[i].u.c.buf = bufptr;
+			info.cb[i].u.c.offset = off;
+			info.cb[i].u.c.nbytes = BUFFER_SZ;
+			info.cbs[i] = &info.cb[i];
 		}
 
-		if (stress_aiol_submit(args, ctx, cbs, aio_linux_requests, false) < 0)
+		if (UNLIKELY(stress_aiol_submit(args, &info, aiol_requiests, false) < 0))
 			break;
 
-		n = stress_aiol_wait(args, ctx, events, aio_linux_requests, &aiol_completions);
-		if (n < 0)
+		n = stress_aiol_wait(args, &info, aiol_requiests);
+		if (UNLIKELY(n < 0))
 			break;
 
 		for (i = 0; i < (size_t)n; i++) {
 			uint8_t pattern;
-			struct iocb *obj = events[i].obj;
+			struct iocb *obj = info.events[i].obj;
 
 			if (!obj)
 				continue;
@@ -571,7 +582,7 @@ retry_open:
 			bufptr = obj->u.c.buf;
 			pattern = (uint8_t)(j + ((((intptr_t)bufptr) >> 12) & 0xff));
 
-			if (aio_linux_check_buffer(pattern, bufptr, BUFFER_SZ) != true) {
+			if (stress_aiol_check_buffer(pattern, bufptr, BUFFER_SZ) != true) {
 				if (warnings++ < 5) {
 					pr_inf("%s: unexpected data mismatch in buffer %zd (maybe a wait timeout issue)\n",
 						args->name, i);
@@ -583,55 +594,55 @@ retry_open:
 		/*
 		 *  async pwritev
 		 */
-		(void)shim_memset(cb, 0, aio_linux_requests * sizeof(*cb));
-		for (bufptr = buffer, i = 0, off = offset; i < aio_linux_requests; i++, bufptr += BUFFER_SZ, off += BUFFER_SZ) {
+		(void)shim_memset(info.cb, 0, aiol_requiests * sizeof(*info.cb));
+		for (bufptr = info.buffer, i = 0, off = offset; i < aiol_requiests; i++, bufptr += BUFFER_SZ, off += BUFFER_SZ) {
 			const uint8_t pattern = (uint8_t)(j + ((((intptr_t)bufptr) >> 12) & 0xff));
 
-			aio_linux_fill_buffer(pattern, bufptr, BUFFER_SZ);
+			stress_aiol_fill_buffer(pattern, bufptr, BUFFER_SZ);
 
-			iov[i].iov_base = bufptr;
-			iov[i].iov_len = BUFFER_SZ;
+			info.iov[i].iov_base = bufptr;
+			info.iov[i].iov_len = BUFFER_SZ;
 
-			cb[i].aio_fildes = fds[i];
-			cb[i].aio_lio_opcode = IO_CMD_PWRITEV;
-			cb[i].u.c.buf = &iov[i];
-			cb[i].u.c.offset = off;
-			cb[i].u.c.nbytes = 1;
-			cbs[i] = &cb[i];
+			info.cb[i].aio_fildes = info.fds[i];
+			info.cb[i].aio_lio_opcode = IO_CMD_PWRITEV;
+			info.cb[i].u.c.buf = &info.iov[i];
+			info.cb[i].u.c.offset = off;
+			info.cb[i].u.c.nbytes = 1;
+			info.cbs[i] = &info.cb[i];
 		}
-		if (stress_aiol_submit(args, ctx, cbs, aio_linux_requests, false) < 0)
+		if (UNLIKELY(stress_aiol_submit(args, &info, aiol_requiests, false) < 0))
 			break;
-		if (stress_aiol_wait(args, ctx, events, aio_linux_requests, &aiol_completions) < 0)
+		if (UNLIKELY(stress_aiol_wait(args, &info, aiol_requiests) < 0))
 			break;
 		stress_bogo_inc(args);
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 
 		/*
 		 *  async preadv
 		 */
-		(void)shim_memset(cb, 0, aio_linux_requests * sizeof(*cb));
-		for (bufptr = buffer, i = 0, off = offset; i < aio_linux_requests; i++, bufptr += BUFFER_SZ, off += BUFFER_SZ) {
+		(void)shim_memset(info.cb, 0, aiol_requiests * sizeof(*info.cb));
+		for (bufptr = info.buffer, i = 0, off = offset; i < aiol_requiests; i++, bufptr += BUFFER_SZ, off += BUFFER_SZ) {
 			const uint8_t pattern = (uint8_t)(j + ((((intptr_t)bufptr) >> 12) & 0xff));
 
-			aio_linux_fill_buffer(pattern, bufptr, BUFFER_SZ);
+			stress_aiol_fill_buffer(pattern, bufptr, BUFFER_SZ);
 
-			iov[i].iov_base = bufptr;
-			iov[i].iov_len = BUFFER_SZ;
+			info.iov[i].iov_base = bufptr;
+			info.iov[i].iov_len = BUFFER_SZ;
 
-			cb[i].aio_fildes = fds[i];
-			cb[i].aio_lio_opcode = IO_CMD_PREADV;
-			cb[i].u.c.buf = &iov[i];
-			cb[i].u.c.offset = off;
-			cb[i].u.c.nbytes = 1;
-			cbs[i] = &cb[i];
+			info.cb[i].aio_fildes = info.fds[i];
+			info.cb[i].aio_lio_opcode = IO_CMD_PREADV;
+			info.cb[i].u.c.buf = &info.iov[i];
+			info.cb[i].u.c.offset = off;
+			info.cb[i].u.c.nbytes = 1;
+			info.cbs[i] = &info.cb[i];
 		}
-		if (stress_aiol_submit(args, ctx, cbs, aio_linux_requests, false) < 0)
+		if (UNLIKELY(stress_aiol_submit(args, &info, aiol_requiests, false) < 0))
 			break;
-		if (stress_aiol_wait(args, ctx, events, aio_linux_requests, &aiol_completions) < 0)
+		if (UNLIKELY(stress_aiol_wait(args, &info, aiol_requiests) < 0))
 			break;
 		stress_bogo_inc(args);
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 
 #if defined(__NR_io_cancel)
@@ -648,11 +659,11 @@ retry_open:
 
 				cancel = 0;
 
-				VOID_RET(int, shim_io_cancel(ctx, &cb[0], &event));
+				VOID_RET(int, shim_io_cancel(info.ctx_id, &info.cb[0], &event));
 
 				/* Exercise with io_cancel invalid context */
 				(void)shim_memset(&bad_ctx, stress_mwc8() | 0x1, sizeof(bad_ctx));
-				VOID_RET(int, shim_io_cancel(bad_ctx, &cb[0], &event));
+				VOID_RET(int, shim_io_cancel(bad_ctx, &info.cb[0], &event));
 
 				/* Exercise with io_invalid iocb */
 				(void)shim_memset(&bad_iocb, 0, sizeof(bad_iocb));
@@ -661,7 +672,7 @@ retry_open:
 				bad_iocb.u.c.buf = NULL;
 				bad_iocb.u.c.offset = 0;
 				bad_iocb.u.c.nbytes = 0;
-				VOID_RET(int, shim_io_cancel(ctx, &bad_iocb, &event));
+				VOID_RET(int, shim_io_cancel(info.ctx_id, &bad_iocb, &event));
 
 				/* Exercise io_destroy with illegal context, EINVAL */
 				VOID_RET(int, shim_io_destroy(bad_ctx));
@@ -670,23 +681,23 @@ retry_open:
 				/* Exercise io_getevents with illegal context, EINVAL */
 				timeout.tv_sec = 0;
 				timeout.tv_nsec = 100000;
-				VOID_RET(int, shim_io_getevents(bad_ctx, 1, 1, events, &timeout));
+				VOID_RET(int, shim_io_getevents(bad_ctx, 1, 1, info.events, &timeout));
 
 				/* Exercise io_getevents with illegal min */
 				timeout.tv_sec = 0;
 				timeout.tv_nsec = 100000;
-				VOID_RET(int, shim_io_getevents(ctx, 1, 0, events, &timeout));
-				VOID_RET(int, shim_io_getevents(ctx, -1, 0, events, &timeout));
+				VOID_RET(int, shim_io_getevents(info.ctx_id, 1, 0, info.events, &timeout));
+				VOID_RET(int, shim_io_getevents(info.ctx_id, -1, 0, info.events, &timeout));
 
 				/* Exercise io_getevents with illegal nr */
 				timeout.tv_sec = 0;
 				timeout.tv_nsec = 100000;
-				VOID_RET(int, shim_io_getevents(ctx, 0, -1, events, &timeout));
+				VOID_RET(int, shim_io_getevents(info.ctx_id, 0, -1, info.events, &timeout));
 
 				/* Exercise io_getevents with illegal timeout */
 				timeout.tv_sec = 0;
 				timeout.tv_nsec = ~0L;
-				VOID_RET(int, shim_io_getevents(ctx, 0, 1, events, &timeout));
+				VOID_RET(int, shim_io_getevents(info.ctx_id, 0, 1, info.events, &timeout));
 
 				/* Exercise io_setup with illegal nr_events */
 				ret = shim_io_setup(0, &bad_ctx);
@@ -707,40 +718,41 @@ retry_open:
 				VOID_RET(int, shim_io_submit(bad_ctx, 1, bad_iocbs));
 
 				/* Exercise io_submit with useless or illegal nr ios */
-				VOID_RET(int, shim_io_submit(ctx, 0, bad_iocbs));
-				VOID_RET(int, shim_io_submit(ctx, -1, bad_iocbs));
+				VOID_RET(int, shim_io_submit(info.ctx_id, 0, bad_iocbs));
+				VOID_RET(int, shim_io_submit(info.ctx_id, -1, bad_iocbs));
 
 				/* Exercise io_submit with illegal iocb */
-				VOID_RET(int, shim_io_submit(ctx, 1, bad_iocbs));
+				VOID_RET(int, shim_io_submit(info.ctx_id, 1, bad_iocbs));
 			}
 		}
 #else
 		UNEXPECTED
 #endif
 		stress_bogo_inc(args);
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 
-#if defined(HAVE_POLL_H)
+#if defined(HAVE_POLL_H) &&	\
+    defined(HAVE_POLL)
 		/*
 		 *  Exercise aio_poll with illegal settings
 		 */
-		(void)shim_memset(cb, 0, aio_linux_requests * sizeof(*cb));
-		for (i = 0; i < aio_linux_requests; i++) {
-			cb[i].aio_fildes = fds[i];
-			cb[i].aio_lio_opcode = IO_CMD_POLL;
-			cb[i].u.c.buf = (void *)POLLIN;
+		(void)shim_memset(info.cb, 0, aiol_requiests * sizeof(*info.cb));
+		for (i = 0; i < aiol_requiests; i++) {
+			info.cb[i].aio_fildes = info.fds[i];
+			info.cb[i].aio_lio_opcode = IO_CMD_POLL;
+			info.cb[i].u.c.buf = (void *)POLLIN;
 			/* Set invalid sizes */
-			(void)shim_memset(&cb[i].u.c.offset, 0xff, sizeof(cb[i].u.c.offset));
-			(void)shim_memset(&cb[i].u.c.nbytes, 0xff, sizeof(cb[i].u.c.nbytes));
-			cbs[i] = &cb[i];
+			(void)shim_memset(&info.cb[i].u.c.offset, 0xff, sizeof(info.cb[i].u.c.offset));
+			(void)shim_memset(&info.cb[i].u.c.nbytes, 0xff, sizeof(info.cb[i].u.c.nbytes));
+			info.cbs[i] = &info.cb[i];
 		}
-		if (stress_aiol_submit(args, ctx, cbs, aio_linux_requests, true) < 0)
+		if (UNLIKELY(stress_aiol_submit(args, &info, aiol_requiests, true) < 0))
 			break;
 		if (errno == 0)
-			(void)stress_aiol_wait(args, ctx, events, aio_linux_requests, &aiol_completions);
+			(void)stress_aiol_wait(args, &info, aiol_requiests);
 		stress_bogo_inc(args);
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 #else
 		UNEXPECTED
@@ -755,16 +767,16 @@ retry_open:
 
 			j = 0;
 			if (do_sync) {
-				(void)shim_memset(cb, 0, aio_linux_requests * sizeof(*cb));
-				cb[0].aio_fildes = fds[0];
-				cb[0].aio_lio_opcode = stress_mwc1() ? IO_CMD_FDSYNC : IO_CMD_FSYNC;
-				cb[0].u.c.buf = NULL;
-				cb[0].u.c.offset = 0;
-				cb[0].u.c.nbytes = 0;
-				cbs[0] = &cb[0];
-				(void)stress_aiol_submit(args, ctx, cbs, 1, true);
+				(void)shim_memset(info.cb, 0, aiol_requiests * sizeof(*info.cb));
+				info.cb[0].aio_fildes = info.fds[0];
+				info.cb[0].aio_lio_opcode = stress_mwc1() ? IO_CMD_FDSYNC : IO_CMD_FSYNC;
+				info.cb[0].u.c.buf = NULL;
+				info.cb[0].u.c.offset = 0;
+				info.cb[0].u.c.nbytes = 0;
+				info.cbs[0] = &info.cb[0];
+				(void)stress_aiol_submit(args, &info, 1, true);
 				if (errno == 0) {
-					(void)stress_aiol_wait(args, ctx, events, 1, &aiol_completions);
+					(void)stress_aiol_wait(args, &info, 1);
 				} else {
 					/* Don't try again */
 					do_sync = false;
@@ -774,41 +786,46 @@ retry_open:
 		stress_bogo_inc(args);
 	} while (stress_continue(args));
 
+	duration = stress_time_now() - t;
 	rc = EXIT_SUCCESS;
 
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
-	(void)close(fds[0]);
-	for (i = 1; i < aio_linux_requests; i++) {
-		if (fds[i] != fds[0])
-			(void)close(fds[i]);
+	(void)close(info.fds[0]);
+	for (i = 1; i < aiol_requiests; i++) {
+		if (info.fds[i] != info.fds[0])
+			(void)close(info.fds[i]);
 	}
 finish:
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
-	(void)shim_io_destroy(ctx);
+	(void)shim_io_destroy(info.ctx_id);
 	(void)stress_temp_dir_rm_args(args);
 
 free_memory:
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
-	stress_aiol_free(buffer, cb, events, cbs, fds, iov);
 
-	stress_metrics_set(args, 1, "async I/O events completed",
-		(double)aiol_completions, STRESS_METRIC_TOTAL);
+	stress_metrics_set(args, 0, "async I/O events completed",
+		(double)info.aiol_completions, STRESS_METRIC_TOTAL);
+	rate = (duration > 0) ? (double)info.aiol_completions / duration : 0.0;
+	stress_metrics_set(args, 1, "async I/O events completed per sec",
+		rate, STRESS_METRIC_HARMONIC_MEAN);
+
+	stress_aiol_free(&info);
 
 	return rc;
 }
 
-stressor_info_t stress_aiol_info = {
+const stressor_info_t stress_aiol_info = {
 	.stressor = stress_aiol,
 	.class = CLASS_IO | CLASS_INTERRUPT | CLASS_OS,
-	.opt_set_funcs = opt_set_funcs,
+	.opts = opts,
 	.verify = VERIFY_ALWAYS,
 	.help = help
 };
 #else
-stressor_info_t stress_aiol_info = {
+const stressor_info_t stress_aiol_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_IO | CLASS_INTERRUPT | CLASS_OS,
-	.opt_set_funcs = opt_set_funcs,
+	.opts = opts,
 	.help = help,
 	.verify = VERIFY_ALWAYS,
 	.unimplemented_reason = "built without libaio.h or poll.h"
