@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -114,7 +114,7 @@ static void NORETURN MLOCKED_TEXT stress_signal_handler(int signum)
 static int stress_bad_altstack_child(stress_args_t *args)
 {
 #if defined(HAVE_VDSO_VIA_GETAUXVAL)
-	unsigned long vdso = getauxval(AT_SYSINFO_EHDR);
+	unsigned long int vdso = getauxval(AT_SYSINFO_EHDR);
 #else
 	UNEXPECTED
 #endif
@@ -133,7 +133,7 @@ static int stress_bad_altstack_child(stress_args_t *args)
 		 *  but not a segfault in the sighandler
 		 *  ..bail out fast as we can
 		 */
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			_exit(EXIT_SUCCESS);
 	}
 
@@ -205,7 +205,7 @@ static int stress_bad_altstack_child(stress_args_t *args)
 
 	for (i = 0; i < 10; i++) {
 retry:
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			return EXIT_SUCCESS;
 		rnd = stress_mwc32modn(11);
 		switch (rnd) {
@@ -298,7 +298,7 @@ retry:
 		}
 	}
 	/* No luck, well that's unexpected.. */
-	if (!stress_continue(args))
+	if (UNLIKELY(!stress_continue(args)))
 		pr_fail("%s: child process with illegal stack unexpectedly worked, %d\n",
 			args->name, rnd);
 	return EXIT_FAILURE;
@@ -384,13 +384,13 @@ static int stress_bad_altstack(stress_args_t *args)
 
 		(void)stress_mwc32();
 again:
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			return EXIT_SUCCESS;
 		pid = fork();
 		if (pid < 0) {
 			if (stress_redo_fork(args, errno))
 				goto again;
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				return EXIT_SUCCESS;
 			pr_err("%s: fork failed: errno=%d: (%s)\n",
 				args->name, errno, strerror(errno));
@@ -456,14 +456,14 @@ finish:
 	return rc;
 }
 
-stressor_info_t stress_bad_altstack_info = {
+const stressor_info_t stress_bad_altstack_info = {
 	.stressor = stress_bad_altstack,
 	.class = CLASS_VM | CLASS_MEMORY | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
 	.help = help
 };
 #else
-stressor_info_t stress_bad_altstack_info = {
+const stressor_info_t stress_bad_altstack_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_VM | CLASS_MEMORY | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
