@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,32 +30,28 @@
 #include <sys/ioctl.h>
 
 static const stress_help_t help[] = {
-	{ NULL,	"bad-ioctl N",		"start N stressors that perform illegal read ioctls on devices" },
+	{ NULL,	"bad-ioctl N",		"start N stressors that perform illegal ioctls on devices" },
 	{ NULL,	"bad-ioctl-ops  N",	"stop after N bad ioctl bogo operations" },
 	{ NULL,	"bad-ioctl-method M",	"method of selecting ioctl command [ random | inc | random-inc | stride ]" },
 	{ NULL,	NULL,			NULL }
 };
 
-#define STRESS_BAD_IOCTL_CMD_RANDOM	(0)
-#define STRESS_BAD_IOCTL_CMD_INC	(1)
+/* Index order to stress_bad_ioctl_methods */
+#define STRESS_BAD_IOCTL_CMD_INC	(0)
+#define STRESS_BAD_IOCTL_CMD_RANDOM	(1)
 #define STRESS_BAD_IOCTL_CMD_RANDOM_INC	(2)
 #define STRESS_BAD_IOCTL_CMD_STRIDE	(3)
 
-typedef struct {
-	const char *name;
-	const int ioctl_cmd_method;
-} bad_ioct_method_t;
-
-static const bad_ioct_method_t stress_bad_ioctl_methods[] = {
-	{ "inc",	STRESS_BAD_IOCTL_CMD_INC },
-	{ "random",	STRESS_BAD_IOCTL_CMD_RANDOM },
-	{ "random-inc",	STRESS_BAD_IOCTL_CMD_RANDOM_INC },
-	{ "stride",	STRESS_BAD_IOCTL_CMD_STRIDE },
+static const char *stress_bad_ioctl_methods[] = {
+	"inc",
+	"random",
+	"random-inc",
+	"stride",
 };
 
 static const char *stress_bad_ioctl_method(const size_t i)
 {
-	return (i < SIZEOF_ARRAY(stress_bad_ioctl_methods)) ?  stress_bad_ioctl_methods[i].name : NULL;
+	return (i < SIZEOF_ARRAY(stress_bad_ioctl_methods)) ? stress_bad_ioctl_methods[i] : NULL;
 }
 
 static const stress_opt_t opts[] = {
@@ -116,7 +112,7 @@ static dev_ioctl_info_t *stress_bad_ioctl_dev_new(
 			return *head;
 		head = (cmp > 0) ? &(*head)->left : &(*head)->right;
 	}
-	node = calloc(1, sizeof(*node));
+	node = (dev_ioctl_info_t *)calloc(1, sizeof(*node));
 	if (!node)
 		return NULL;
 	node->dev_path = strdup(dev_path);
@@ -158,7 +154,7 @@ static void stress_bad_ioctl_dev_dir(
 	const mode_t flags = S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH;
 	int i, n;
 
-	if (!stress_continue_flag())
+	if (UNLIKELY(!stress_continue_flag()))
 		return;
 
 	/* Don't want to go too deep */
@@ -177,7 +173,7 @@ static void stress_bad_ioctl_dev_dir(
 		const struct dirent *d = dlist[i];
 		size_t len;
 
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 		if (stress_is_dot_filename(d->d_name))
 			continue;
@@ -192,7 +188,7 @@ static void stress_bad_ioctl_dev_dir(
 			int dev_n;
 			const char *ptr = d->d_name + len - 1;
 
-			while ((ptr > d->d_name) && isdigit((int)*ptr))
+			while ((ptr > d->d_name) && isdigit((unsigned char)*ptr))
 				ptr--;
 			ptr++;
 			dev_n = atoi(ptr);
@@ -225,18 +221,6 @@ done:
 	stress_dirent_list_free(dlist, n);
 }
 
-static int stress_bad_ioctl_supported(const char *name)
-{
-        if (stress_check_capability(SHIM_CAP_IS_ROOT) ||
-	    (geteuid() == 0)) {
-                pr_inf_skip("%s stressor will be skipped, "
-                        "need to be running without root privilege "
-                        "for this stressor\n", name);
-                return -1;
-        }
-	return 0;
-}
-
 static void NORETURN MLOCKED_TEXT stress_segv_handler(int signum)
 {
 	(void)signum;
@@ -360,23 +344,98 @@ static inline void stress_bad_ioctl_rw(
 			break;
 		}
 
+		VOID_RET(int, ioctl(fd, _IOR(type, nr, uint64_t), NULL));
+		if (stress_time_now() - t_start > threshold) {
+			(void)close(fd);
+			break;
+		}
+
+		VOID_RET(int, ioctl(fd, _IOR(type, nr, uint32_t), NULL));
+		if (stress_time_now() - t_start > threshold) {
+			(void)close(fd);
+			break;
+		}
+
+		VOID_RET(int, ioctl(fd, _IOR(type, nr, uint16_t), NULL));
+		if (stress_time_now() - t_start > threshold) {
+			(void)close(fd);
+			break;
+		}
+
 		VOID_RET(int, ioctl(fd, _IOR(type, nr, uint8_t), NULL));
 		if (stress_time_now() - t_start > threshold) {
 			(void)close(fd);
 			break;
 		}
 
+		VOID_RET(int, ioctl(fd, _IOR(type, nr, uint64_t), args->mapped->page_none));
+		if (stress_time_now() - t_start > threshold) {
+			(void)close(fd);
+			break;
+		}
+
+		VOID_RET(int, ioctl(fd, _IOR(type, nr, uint32_t), args->mapped->page_none));
+		if (stress_time_now() - t_start > threshold) {
+			(void)close(fd);
+			break;
+		}
+
+		VOID_RET(int, ioctl(fd, _IOR(type, nr, uint16_t), args->mapped->page_none));
+		if (stress_time_now() - t_start > threshold) {
+			(void)close(fd);
+			break;
+		}
+
 		VOID_RET(int, ioctl(fd, _IOR(type, nr, uint8_t), args->mapped->page_none));
 		if (stress_time_now() - t_start > threshold) {
 			(void)close(fd);
 			break;
 		}
 
+		VOID_RET(int, ioctl(fd, _IOR(type, nr, uint32_t), args->mapped->page_ro));
+		if (stress_time_now() - t_start > threshold) {
+			(void)close(fd);
+			break;
+		}
+
+		VOID_RET(int, ioctl(fd, _IOR(type, nr, uint16_t), args->mapped->page_ro));
+		if (stress_time_now() - t_start > threshold) {
+			(void)close(fd);
+			break;
+		}
+
 		VOID_RET(int, ioctl(fd, _IOR(type, nr, uint8_t), args->mapped->page_ro));
 		if (stress_time_now() - t_start > threshold) {
 			(void)close(fd);
 			break;
 		}
+
+#if defined(_IOW)
+		VOID_RET(int, ioctl(fd, _IOW(type, nr, uint64_t), args->mapped->page_none));
+		if (stress_time_now() - t_start > threshold) {
+			(void)close(fd);
+			break;
+		}
+
+		VOID_RET(int, ioctl(fd, _IOW(type, nr, uint32_t), args->mapped->page_none));
+		if (stress_time_now() - t_start > threshold) {
+			(void)close(fd);
+			break;
+		}
+
+		VOID_RET(int, ioctl(fd, _IOW(type, nr, uint16_t), args->mapped->page_none));
+		if (stress_time_now() - t_start > threshold) {
+			(void)close(fd);
+			break;
+		}
+
+		VOID_RET(int, ioctl(fd, _IOW(type, nr, uint8_t), args->mapped->page_none));
+		if (stress_time_now() - t_start > threshold) {
+			(void)close(fd);
+			break;
+		}
+#endif
+
 		(void)close(fd);
 		if ((thread_index >= 0) && (thread_index < MAX_DEV_THREADS)) {
 			ret = stress_lock_acquire(lock);
@@ -397,7 +456,6 @@ static inline void stress_bad_ioctl_rw(
  */
 static void *stress_bad_ioctl_thread(void *arg)
 {
-	static void *nowt = NULL;
 	const stress_pthread_args_t *pa = (stress_pthread_args_t *)arg;
 	stress_args_t *args = pa->args;
 	const stress_bad_ioctl_thread_t *thread = (const stress_bad_ioctl_thread_t *)pa->data;
@@ -408,10 +466,12 @@ static void *stress_bad_ioctl_thread(void *arg)
 	 */
 	(void)sigprocmask(SIG_BLOCK, &set, NULL);
 
+	stress_random_small_sleep();
+
 	while (stress_continue_flag())
 		stress_bad_ioctl_rw(args, true, thread->thread_index);
 
-	return &nowt;
+	return &g_nowt;
 }
 
 /*
@@ -426,7 +486,7 @@ static void stress_bad_ioctl_dir(
 {
 	int ret;
 
-	if (!stress_continue_flag())
+	if (UNLIKELY(!stress_continue_flag()))
 		return;
 	if (!node)
 		return;
@@ -492,6 +552,10 @@ static int stress_bad_ioctl(stress_args_t *args)
 	int rc = EXIT_SUCCESS;
 	int bad_ioctl_method = STRESS_BAD_IOCTL_CMD_RANDOM_INC;
 
+	lock = NULL;
+	dev_ioctl_info_head = NULL;
+	dev_ioctl_node = NULL;
+
 	(void)stress_get_setting("bad-ioctl-method", &bad_ioctl_method);
 
 	stress_bad_ioctl_dev_dir(args, "/dev", 0);
@@ -580,20 +644,19 @@ again:
 				if (threads[i].ret == 0)
 					(void)pthread_join(threads[i].pthread, NULL);
 			}
+			(void)stress_lock_destroy(lock);
 			_exit(EXIT_SUCCESS);
 		}
 	} while (stress_continue(args));
 
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 
-	(void)stress_lock_destroy(lock);
 	stress_bad_ioctl_dev_free(dev_ioctl_info_head);
 
 	return rc;
 }
 const stressor_info_t stress_bad_ioctl_info = {
 	.stressor = stress_bad_ioctl,
-	.supported = stress_bad_ioctl_supported,
 	.class = CLASS_DEV | CLASS_OS | CLASS_PATHOLOGICAL,
 	.opts = opts,
 	.help = help
