@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -81,7 +81,7 @@ static int stress_bind_mount_child(void *parg)
 	do {
 		int rc, retries, stat_count, stat_okay;
 		DIR *dir;
-		struct dirent *d;
+		const struct dirent *d;
 		double t;
 
 		t = stress_time_now();
@@ -249,14 +249,14 @@ static int stress_bind_mount(stress_args_t *args)
 	return rc;
 }
 
-stressor_info_t stress_bind_mount_info = {
+const stressor_info_t stress_bind_mount_info = {
 	.stressor = stress_bind_mount,
 	.class = CLASS_FILESYSTEM | CLASS_OS | CLASS_PATHOLOGICAL,
 	.verify = VERIFY_ALWAYS,
 	.help = help
 };
 #else
-stressor_info_t stress_bind_mount_info = {
+const stressor_info_t stress_bind_mount_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_FILESYSTEM | CLASS_OS | CLASS_PATHOLOGICAL,
 	.verify = VERIFY_ALWAYS,
