@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2024      Colin Ian King.
+ * Copyright (C) 2024-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -17,6 +17,7 @@
  *
  */
 #include "stress-ng.h"
+#include "core-pragma.h"
 #include "core-sort.h"
 
 #define MIN_BITONICSORT_SIZE		(1 * KB)
@@ -137,7 +138,7 @@ static int OPTIMIZE3 stress_bitonicsort(stress_args_t *args)
 	}
 	n = (size_t)bitonicsort_size;
 
-	if ((data = calloc(n, sizeof(*data))) == NULL) {
+	if ((data = (int32_t *)calloc(n, sizeof(*data))) == NULL) {
 		pr_inf_skip("%s: malloc failed to allocate %zu integers, "
 			"skipping stressor\n", args->name, n);
 		return EXIT_NO_RESOURCE;
@@ -179,8 +180,9 @@ static int OPTIMIZE3 stress_bitonicsort(stress_args_t *args)
 		if (UNLIKELY(verify)) {
 			register size_t i;
 
+PRAGMA_UNROLL_N(4)
 			for (ptr = data, i = 0; i < n - 1; i++, ptr++) {
-				if (*ptr > *(ptr + 1)) {
+				if (UNLIKELY(*ptr > *(ptr + 1))) {
 					pr_fail("%s: sort error "
 						"detected, incorrect ordering "
 						"found\n", args->name);
@@ -189,7 +191,7 @@ static int OPTIMIZE3 stress_bitonicsort(stress_args_t *args)
 				}
 			}
 		}
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 
 		/* Reverse sort */
@@ -203,8 +205,9 @@ static int OPTIMIZE3 stress_bitonicsort(stress_args_t *args)
 		if (UNLIKELY(verify)) {
 			register size_t i;
 
+PRAGMA_UNROLL_N(4)
 			for (ptr = data, i = 0; i < n - 1; i++, ptr++) {
-				if (*ptr < *(ptr + 1)) {
+				if (UNLIKELY(*ptr < *(ptr + 1))) {
 					pr_fail("%s: reverse sort "
 						"error detected, incorrect "
 						"ordering found\n", args->name);
@@ -213,7 +216,7 @@ static int OPTIMIZE3 stress_bitonicsort(stress_args_t *args)
 				}
 			}
 		}
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 
 		/* And re-order */
@@ -231,7 +234,7 @@ static int OPTIMIZE3 stress_bitonicsort(stress_args_t *args)
 			register size_t i;
 
 			for (ptr = data, i = 0; i < n - 1; i++, ptr++) {
-				if (*ptr < *(ptr + 1)) {
+				if (UNLIKELY(*ptr < *(ptr + 1))) {
 					pr_fail("%s: reverse sort "
 						"error detected, incorrect "
 						"ordering found\n", args->name);
@@ -240,7 +243,7 @@ static int OPTIMIZE3 stress_bitonicsort(stress_args_t *args)
 				}
 			}
 		}
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 
 		stress_bogo_inc(args);
