@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2021-2024 Colin Ian King
+ * Copyright (C) 2021-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -221,9 +221,9 @@ L0x000:
 		stress_bogo_inc(args);
 #if defined(STRESS_ARCH_SH4)
 		/* For some reason, can't interrupt SH4 in QEMU, add yield to do so */
-		shim_sched_yield();
+		(void)shim_sched_yield();
 #endif
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 		RESEED_JMP(0x000)
 
