@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -41,9 +41,9 @@ typedef struct {
 } brk_context_t;
 
 static const stress_opt_t opts[] = {
-	{ OPT_brk_bytes,   "brk-bytes",   TYPE_ID_SIZE_T_BYTES, MIN_BRK_BYTES, MAX_BRK_BYTES, NULL },
-	{ OPT_brk_mlock,   "brk-mlock",   TYPE_ID_BOOL,         0,             1,             NULL },
-	{ OPT_brk_notouch, "brk-notouch", TYPE_ID_BOOL,         0,             1,             NULL },
+	{ OPT_brk_bytes,   "brk-bytes",   TYPE_ID_SIZE_T_BYTES_VM, MIN_BRK_BYTES, MAX_BRK_BYTES, NULL },
+	{ OPT_brk_mlock,   "brk-mlock",   TYPE_ID_BOOL,            0,             1,             NULL },
+	{ OPT_brk_notouch, "brk-notouch", TYPE_ID_BOOL,            0,             1,             NULL },
 	END_OPT,
 };
 
@@ -110,7 +110,8 @@ static inline size_t PURE stress_brk_abs(const uint8_t *ptr1, const uint8_t *ptr
 
 static int OPTIMIZE3 stress_brk_child(stress_args_t *args, void *context)
 {
-	uint8_t *start_ptr, *unmap_ptr = NULL, *brk_failed_ptr = NULL;
+	uint8_t *start_ptr, *unmap_ptr = NULL;
+	const uint8_t *brk_failed_ptr = NULL;
 	int i = 0, brk_failed_count = 0;
 	size_t brk_bytes = DEFAULT_BRK_BYTES;
 	const size_t page_size = args->page_size;
@@ -140,6 +141,7 @@ static int OPTIMIZE3 stress_brk_child(stress_args_t *args, void *context)
 
 	do {
 		double t;
+		int saved_errno = 0;
 
 		if (stress_brk_abs(ptr, start_ptr) > brk_bytes) {
 			ptr = start_ptr;
@@ -174,6 +176,7 @@ static int OPTIMIZE3 stress_brk_child(stress_args_t *args, void *context)
 				tmp = (uintptr_t *)((uintptr_t)ptr - sizeof(uintptr_t));
 				*tmp = (uintptr_t)tmp;
 			} else {
+				saved_errno = errno;
 				if (brk_failed_ptr == ptr) {
 					brk_failed_count++;
 					if (brk_failed_count > 32) {
@@ -187,6 +190,7 @@ static int OPTIMIZE3 stress_brk_child(stress_args_t *args, void *context)
 		} else if (i < 9) {
 			/* brk to same brk position */
 			if (UNLIKELY(shim_brk(ptr) < 0)) {
+				saved_errno = errno;
 				ptr = start_ptr;
 				i = 0;
 			}
@@ -194,6 +198,7 @@ static int OPTIMIZE3 stress_brk_child(stress_args_t *args, void *context)
 			/* Shrink brk by 1 page */
 			t = stress_time_now();
 			if (LIKELY(shim_sbrk(-page_size) != (void *)-1)) {
+				saved_errno = errno;
 				sbrk_shr_duration += stress_time_now() - t;
 				sbrk_shr_count += 1.0;
 				ptr -= page_size;
@@ -225,13 +230,13 @@ static int OPTIMIZE3 stress_brk_child(stress_args_t *args, void *context)
 		}
 
 		if (UNLIKELY(ptr == (void *)-1)) {
-			if (LIKELY((errno == ENOMEM) || (errno == EAGAIN))) {
+			if (LIKELY((saved_errno == ENOMEM) || (saved_errno == EAGAIN))) {
 				VOID_RET(int, shim_brk(start_ptr));
 				i = 0;
 			} else {
 				pr_fail("%s: sbrk(%d) failed: errno=%d (%s)\n",
-					args->name, (int)page_size, errno,
-					strerror(errno));
+					args->name, (int)page_size, saved_errno,
+					strerror(saved_errno));
 				return EXIT_FAILURE;
 			}
 		}
@@ -281,7 +286,7 @@ static int stress_brk(stress_args_t *args)
 	return rc;
 }
 
-stressor_info_t stress_brk_info = {
+const stressor_info_t stress_brk_info = {
 	.stressor = stress_brk,
 	.supported = stress_brk_supported,
 	.class = CLASS_OS | CLASS_VM,
