@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2024      Colin Ian King.
+ * Copyright (C) 2024-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,6 +18,7 @@
  */
 #include "stress-ng.h"
 #include "core-sort.h"
+#include "core-pragma.h"
 
 #define MIN_HEAPSORT_SIZE	(1 * KB)
 #define MAX_HEAPSORT_SIZE	(4 * MB)
@@ -63,6 +64,7 @@ static int bubblesort_fast(
 		register uintptr_t p1 = (uintptr_t)base;
 		register uintptr_t p2 = size + (uintptr_t)base;
 
+PRAGMA_UNROLL_N(4)
 		for (i = 1; i < nmemb; i++) {
 			if (compar((void *)p1, (void *)p2) > 0) {
 				swap_func((void *)p1, (void *)p2, size);
@@ -101,6 +103,7 @@ static int bubblesort_naive(
 		register uintptr_t p2 = size + (uintptr_t)base;
 
 		swapped = false;
+PRAGMA_UNROLL_N(4)
 		for (i = 1; i < nmemb; i++) {
 			if (compar((void *)p1, (void *)p2) > 0) {
 				swap_func((void *)p1, (void *)p2, size);
@@ -176,7 +179,7 @@ static int stress_bubblesort(stress_args_t *args)
 	}
 	n = (size_t)bubblesort_size;
 
-	if ((data = calloc(n, sizeof(*data))) == NULL) {
+	if ((data = (int32_t *)calloc(n, sizeof(*data))) == NULL) {
 		pr_inf_skip("%s: failed to allocate %zu integers, skipping stressor\n",
 			args->name, n);
 		return EXIT_NO_RESOURCE;
@@ -221,7 +224,7 @@ static int stress_bubblesort(stress_args_t *args)
 			sorted += (double)n;
 			if (g_opt_flags & OPT_FLAGS_VERIFY) {
 				for (ptr = data, i = 0; i < n - 1; i++, ptr++) {
-					if (*ptr > *(ptr + 1)) {
+					if (UNLIKELY(*ptr > *(ptr + 1))) {
 						pr_fail("%s: sort error "
 							"detected, incorrect ordering "
 							"found\n", args->name);
@@ -231,7 +234,7 @@ static int stress_bubblesort(stress_args_t *args)
 				}
 			}
 		}
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 
 		/* Reverse sort */
@@ -247,7 +250,7 @@ static int stress_bubblesort(stress_args_t *args)
 			sorted += (double)n;
 			if (g_opt_flags & OPT_FLAGS_VERIFY) {
 				for (ptr = data, i = 0; i < n - 1; i++, ptr++) {
-					if (*ptr < *(ptr + 1)) {
+					if (UNLIKELY(*ptr < *(ptr + 1))) {
 						pr_fail("%s: reverse sort "
 							"error detected, incorrect "
 							"ordering found\n", args->name);
@@ -257,7 +260,7 @@ static int stress_bubblesort(stress_args_t *args)
 				}
 			}
 		}
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 		/* And re-order  */
 		stress_sort_data_int32_mangle(data, n);
@@ -276,7 +279,7 @@ static int stress_bubblesort(stress_args_t *args)
 			sorted += (double)n;
 			if (g_opt_flags & OPT_FLAGS_VERIFY) {
 				for (ptr = data, i = 0; i < n - 1; i++, ptr++) {
-					if (*ptr < *(ptr + 1)) {
+					if (UNLIKELY(*ptr < *(ptr + 1))) {
 						pr_fail("%s: reverse sort "
 							"error detected, incorrect "
 							"ordering found\n", args->name);
@@ -286,7 +289,7 @@ static int stress_bubblesort(stress_args_t *args)
 				}
 			}
 		}
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 
 		stress_bogo_inc(args);
