@@ -17,10 +17,12 @@
  *
  */
 #include "stress-ng.h"
+#include "core-affinity.h"
 #include "core-builtin.h"
 #include "core-cpu-cache.h"
 #include "core-killpid.h"
 #include "core-lock.h"
+#include "core-pragma.h"
 
 #include <sched.h>
 
@@ -67,7 +69,7 @@ static uint64_t get_L1_line_size(stress_args_t *args)
 #if defined(__linux__) ||	\
     defined(__APPLE__)
 	stress_cpu_cache_cpus_t *cpu_caches;
-	stress_cpu_cache_t *cache = NULL;
+	const stress_cpu_cache_t *cache = NULL;
 
 	cpu_caches = stress_cpu_cache_get_all_details();
 	if (!cpu_caches) {
@@ -118,6 +120,7 @@ static int stress_cacheline_adjacent(
 	(void)parent;
 	(void)l1_cacheline_size;
 
+PRAGMA_UNROLL
 	for (i = 0; i < 1024; i++) {
 		(*data8)++;
 		(void)(*data8adjacent);
@@ -165,6 +168,7 @@ static int stress_cacheline_copy(
 	(void)parent;
 	(void)l1_cacheline_size;
 
+PRAGMA_UNROLL
 	for (i = 0; i < 1024; i++) {
 		register uint8_t val8;
 
@@ -201,6 +205,7 @@ static int stress_cacheline_inc(
 	(void)parent;
 	(void)l1_cacheline_size;
 
+PRAGMA_UNROLL
 	for (i = 0; i < 1024; i++) {
 		(*data8)++;
 		stress_asm_mb();
@@ -241,6 +246,7 @@ static int stress_cacheline_rdwr(
 	(void)parent;
 	(void)l1_cacheline_size;
 
+PRAGMA_UNROLL
 	for (i = 0; i < 1024; i++) {
 		uint8_t tmp;
 
@@ -316,6 +322,7 @@ static int stress_cacheline_mix(
 	(void)parent;
 	(void)l1_cacheline_size;
 
+PRAGMA_UNROLL
 	for (i = 0; i < 1024; i++) {
 		register uint8_t val8;
 
@@ -356,6 +363,7 @@ static int stress_cacheline_rdrev64(
 		val8 = *data8;
 
 		/* read cache line backwards */
+PRAGMA_UNROLL
 		for (j = cacheline_size - 8; j >= 0; j -= 8) {
 			volatile uint64_t *data64 = (volatile uint64_t *)(aligned_cacheline + (size_t)j);
 
@@ -394,6 +402,9 @@ static int stress_cacheline_rdfwd64(
 		val8 = *data8;
 
 		/* read cache line forwards */
+#if !defined(HAVE_COMPILER_CLANG)
+PRAGMA_UNROLL
+#endif
 		for (j = 0; j < cacheline_size; j += 8) {
 			volatile uint64_t *data64 = (volatile uint64_t *)(aligned_cacheline + j);
 
@@ -428,6 +439,7 @@ static int stress_cacheline_rdints(
 	(void)parent;
 	(void)l1_cacheline_size;
 
+PRAGMA_UNROLL
 	for (i = 0; i < 1024; i++) {
 		uint8_t val8;
 
@@ -475,6 +487,7 @@ static int stress_cacheline_bits(
 	(void)parent;
 	(void)l1_cacheline_size;
 
+PRAGMA_UNROLL
 	for (i = 0; i < 1024; i++) {
 		register uint8_t val8;
 
@@ -484,7 +497,7 @@ static int stress_cacheline_bits(
 		val8 = (uint8_t)(1U << (i & 7));
 		*data8 = val8;
 		stress_asm_mb();
-		if (*data8 != val8) {
+		if (UNLIKELY(*data8 != val8)) {
 			pr_fail("%s: bits method: cache line error in offset 0x%x, expected %2" PRIx8 ", got %2" PRIx8 "\n",
 				args->name, idx, val8, *data8);
 			return EXIT_FAILURE;
@@ -492,7 +505,7 @@ static int stress_cacheline_bits(
 		val8 ^= 0xff;
 		*data8 = val8;
 		stress_asm_mb();
-		if (*data8 != val8) {
+		if (UNLIKELY(*data8 != val8)) {
 			pr_fail("%s: bits method: cache line error in offset 0x%x, expected %2" PRIx8 ", got %2" PRIx8 "\n",
 				args->name, idx, val8, *data8);
 			return EXIT_FAILURE;
@@ -516,6 +529,7 @@ static int stress_cacheline_atomicinc(
 	(void)parent;
 	(void)l1_cacheline_size;
 
+PRAGMA_UNROLL
 	for (i = 0; i < 1024; i++) {
 		SHIM_ATOMIC_INC(data8);
 		SHIM_ATOMIC_INC(data8);
@@ -572,7 +586,7 @@ static int stress_cacheline_all(
 	size_t i;
 	const size_t n = SIZEOF_ARRAY(cacheline_methods);
 
-	for (i = 1; stress_continue(args) && (i < n); i++) {
+	for (i = 1; LIKELY(stress_continue(args) && (i < n)); i++) {
 		int rc;
 
 		rc = cacheline_methods[i].func(args, idx, parent, l1_cacheline_size);
@@ -591,16 +605,20 @@ static int stress_cacheline_all(
  */
 static inline void stress_cacheline_change_affinity(
 	stress_args_t *args,
-	const uint32_t cpus,
+	const uint32_t n_cpus,
+	const uint32_t *cpus,
 	bool parent)
 {
-	cpu_set_t mask;
-	const double now = stress_time_now() * 100;
-	uint32_t cpu = ((uint32_t)args->instance + (uint32_t)parent + (uint32_t)now) % cpus;
+	if (n_cpus > 0) {
+		cpu_set_t mask;
+		const double now = stress_time_now() * 100;
+		const uint32_t cpu_idx = ((uint32_t)args->instance + (uint32_t)parent + (uint32_t)now) % n_cpus;
+		const uint32_t cpu = cpus[cpu_idx];
 
-	CPU_ZERO(&mask);
-	CPU_SET((int)cpu, &mask);
-	VOID_RET(int, sched_setaffinity(0, sizeof(mask), &mask));
+		CPU_ZERO(&mask);
+		CPU_SET((int)cpu, &mask);
+		VOID_RET(int, sched_setaffinity(0, sizeof(mask), &mask));
+	}
 }
 #endif
 
@@ -615,7 +633,8 @@ static int stress_cacheline_child(
 	int rc;
 #if defined(HAVE_SCHED_GETAFFINITY) &&	\
     defined(HAVE_SCHED_SETAFFINITY)
-	const uint32_t cpus = (uint32_t)stress_get_processors_configured();
+	uint32_t *cpus;
+	const uint32_t n_cpus = stress_get_usable_cpus(&cpus, true);
 #endif
 
 	(void)cacheline_affinity;
@@ -628,10 +647,14 @@ static int stress_cacheline_child(
 #if defined(HAVE_SCHED_GETAFFINITY) &&	\
     defined(HAVE_SCHED_SETAFFINITY)
 		if (cacheline_affinity)
-			stress_cacheline_change_affinity(args, cpus, parent);
+			stress_cacheline_change_affinity(args, n_cpus, cpus, parent);
 #endif
 	} while ((rc == EXIT_SUCCESS) && stress_continue(args));
 
+#if defined(HAVE_SCHED_GETAFFINITY) &&	\
+    defined(HAVE_SCHED_SETAFFINITY)
+	stress_free_usable_cpus(&cpus);
+#endif
 	return rc;
 }
 
@@ -678,7 +701,7 @@ static int stress_cacheline_next_idx(void)
 
 /*
  *  stress_cacheline()
- *	execise a cacheline by multiple processes
+ *	exercise a cacheline by multiple processes
  */
 static int stress_cacheline(stress_args_t *args)
 {
@@ -727,7 +750,7 @@ again:
 	if (pid < 0) {
 		if (stress_redo_fork(args, errno))
 			goto again;
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			goto finish;
 		pr_err("%s: fork failed: errno=%d: (%s)\n",
 			args->name, errno, strerror(errno));
