@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,6 +27,8 @@ static const stress_help_t help[] = {
 
 #if defined(__linux__)
 
+#include <sys/ioctl.h>
+
 #define SHIM_EXT2_SECRM_FL		0x00000001 /* Secure deletion */
 #define SHIM_EXT2_UNRM_FL		0x00000002 /* Undelete */
 #define SHIM_EXT2_COMPR_FL		0x00000004 /* Compress file */
@@ -43,11 +45,11 @@ static const stress_help_t help[] = {
 #define SHIM_FS_NOCOW_FL		0x00800000 /* Do not cow file */
 #define SHIM_EXT4_PROJINHERIT_FL	0x20000000 /* Create with parents projid */
 
-#define SHIM_EXT2_IOC_GETFLAGS		_IOR('f', 1, long)
-#define SHIM_EXT2_IOC_SETFLAGS		_IOW('f', 2, long)
+#define SHIM_EXT2_IOC_GETFLAGS		_IOR('f', 1, long int)
+#define SHIM_EXT2_IOC_SETFLAGS		_IOW('f', 2, long int)
 
 typedef struct {
-	const unsigned long flag;
+	const unsigned long int flag;
 	const char attr;
 } stress_chattr_flag_t;
 
@@ -69,7 +71,22 @@ static const stress_chattr_flag_t stress_chattr_flags[] = {
 	{ SHIM_FS_NOCOW_FL, 		'C' },
 };
 
-static char *stress_chattr_flags_str(const unsigned long flags, char *str, const size_t str_len)
+static sigjmp_buf jmp_env;
+static volatile bool do_jmp = false;
+
+/*
+ *  stress_chattr_fault_handler()
+ *	SIGSEGV/SIGBUS fault handler
+ */
+static void MLOCKED_TEXT stress_chattr_fault_handler(int signum)
+{
+	(void)signum;
+
+	if (do_jmp)
+		siglongjmp(jmp_env, 1);		/* Ugly, bounce back */
+}
+
+static char *stress_chattr_flags_str(const unsigned long int flags, char *str, const size_t str_len)
 {
 	unsigned int i;
 	size_t j = 0;
@@ -93,26 +110,34 @@ static char *stress_chattr_flags_str(const unsigned long flags, char *str, const
 static int do_chattr(
 	stress_args_t *args,
 	const char *filename,
-	const unsigned long flags,
-	const unsigned long mask)
+	const unsigned long int flags,
+	const unsigned long int mask,
+	uint64_t *chattr_count)
 {
 	int i;
-	int rc = EXIT_SUCCESS;
+	NOCLOBBER int rc = EXIT_SUCCESS;
 
-	for (i = 0; (i < 128) && stress_continue(args); i++) {
-		int fd, fdw, ret;
-		unsigned long zero = 0UL;
-		unsigned long orig, tmp, check;
-		bool verify;
-		unsigned int j;
+	for (i = 0; LIKELY((i < 128) && stress_continue(args)); i++) {
+		NOCLOBBER int fd, fdw;
+		int ret;
+		unsigned long int zero = 0UL, tmp, check;
+		NOCLOBBER unsigned long int orig_flags;
+		NOCLOBBER unsigned int j;
+		NOCLOBBER uint8_t *page;
 
 		fd = open(filename, O_RDWR | O_NONBLOCK | O_CREAT, S_IRUSR | S_IWUSR);
 		if (fd < 0)
 			continue;
 
-		if (!stress_continue(args))
-			goto tidy_fd;
-		ret = ioctl(fd, SHIM_EXT2_IOC_GETFLAGS, &orig);
+		if (shim_fallocate(fd, 0, 0, args->page_size) == 0) {
+			page = mmap(NULL, args->page_size, PROT_READ | PROT_WRITE,
+				MAP_SHARED, fd, 0);
+		} else {
+			page = MAP_FAILED;
+		}
+
+		orig_flags = 0UL;
+		ret = ioctl(fd, SHIM_EXT2_IOC_GETFLAGS, &orig_flags);
 		if (ret < 0) {
 			if ((errno != EOPNOTSUPP) &&
 			    (errno != ENOTTY) &&
@@ -124,20 +149,20 @@ static int do_chattr(
 				rc = EXIT_FAILURE;
 				goto tidy_fd;
 			}
-			/* most probably not supported */
+			/* cannot get flags, so most probably not supported */
 			rc = EXIT_NO_RESOURCE;
 			goto tidy_fd;
 		}
 
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			goto tidy_fd;
 
 		/* work through flags disabling them one by one */
-		tmp = orig;
-		for (j = 0; (j < sizeof(orig) * 8); j++) {
-			register unsigned long bitmask = 1ULL << j;
+		tmp = orig_flags;
+		for (j = 0; (j < sizeof(orig_flags) * 8); j++) {
+			register const unsigned long int bitmask = 1ULL << j;
 
-			if (orig & bitmask) {
+			if (orig_flags & bitmask) {
 				tmp &= ~bitmask;
 
 				ret = ioctl(fd, SHIM_EXT2_IOC_SETFLAGS, &tmp);
@@ -156,21 +181,22 @@ static int do_chattr(
 					}
 					/* failed, so re-eable the bit */
 					tmp |= bitmask;
+				} else {
+					(*chattr_count)++;
 				}
 			}
 		}
 
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			goto tidy_fd;
 		fdw = open(filename, O_RDWR);
 		if (fdw < 0)
 			goto tidy_fd;
 		VOID_RET(ssize_t, write(fdw, &zero, sizeof(zero)));
 
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			goto tidy_fdw;
 
-		verify = (args->num_instances == 1);
 		ret = ioctl(fd, SHIM_EXT2_IOC_SETFLAGS, &flags);
 		if (ret < 0) {
 			if ((errno != EOPNOTSUPP) &&
@@ -189,10 +215,12 @@ static int do_chattr(
 				goto tidy_fdw;
 			}
 			/* most probably not supported */
-			rc = EXIT_NO_RESOURCE;
 			goto tidy_fdw;
+		} else {
+			(*chattr_count)++;
 		}
 
+		check = 0UL;
 		ret = ioctl(fd, SHIM_EXT2_IOC_GETFLAGS, &check);
 		if (ret < 0) {
 			if ((errno != EOPNOTSUPP) &&
@@ -206,67 +234,84 @@ static int do_chattr(
 				rc = EXIT_FAILURE;
 				goto tidy_fdw;
 			}
-			/* most probably not supported */
-			rc = EXIT_NO_RESOURCE;
-			goto tidy_fdw;
-		}
+			/* most probably not supported, don't verify */
+		} else {
+			/*
+			 *  check that no other *extra* flag bits have been set
+			 *  (as opposed to see if flags set is same as flags got
+			 *  since some flag settings are not set if the filesystem
+			 *  cannot honor them).
+			 */
+			if (args->num_instances == 1) {
+				tmp = mask & ~(SHIM_EXT3_JOURNAL_DATA_FL | SHIM_EXT4_EXTENTS_FL);
+				if (((flags & tmp) | (check & tmp)) != (flags & tmp)) {
+					char flags_str[65], check_str[65];
 
-		/*
-		 *  check that no other *extra* flag bits have been set
-		 *  (as opposed to see if flags set is same as flags got
-		 *  since some flag settings are not set if the filesystem
-		 *  cannot honor them).
-		 */
-		if (verify) {
-			tmp = mask & ~(SHIM_EXT3_JOURNAL_DATA_FL | SHIM_EXT4_EXTENTS_FL);
-			if (((flags & tmp) | (check & tmp)) != (flags & tmp)) {
-				char flags_str[65], check_str[65];
+					stress_chattr_flags_str(flags & tmp, flags_str, sizeof(flags_str));
+					stress_chattr_flags_str(check & tmp, check_str, sizeof(check_str));
 
-				stress_chattr_flags_str(flags & tmp, flags_str, sizeof(flags_str));
-				stress_chattr_flags_str(check & tmp, check_str, sizeof(check_str));
+					pr_fail("%s: EXT2_IOC_GETFLAGS returned different "
+						"flags 0x%lx ('%s') from set flags 0x%lx ('%s')\n",
+						args->name, check & tmp, check_str,
+						flags & tmp, flags_str);
 
-				pr_fail("%s: EXT2_IOC_GETFLAGS returned different "
-					"flags 0x%lx ('%s') from set flags 0x%lx ('%s')\n",
-					args->name, check & tmp, check_str,
-					flags & tmp, flags_str);
-
-				rc = EXIT_FAILURE;
-				goto tidy_fdw;
+					rc = EXIT_FAILURE;
+					goto tidy_fdw;
+				}
 			}
 		}
 
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			goto tidy_fdw;
 		VOID_RET(ssize_t, write(fdw, &zero, sizeof(zero)));
 
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			goto tidy_fdw;
-		VOID_RET(int, ioctl(fd, SHIM_EXT2_IOC_SETFLAGS, &zero));
+		if (ioctl(fd, SHIM_EXT2_IOC_SETFLAGS, &zero) == 0)
+			(*chattr_count)++;
 
 		/*
 		 *  Try some random flag, exercises any illegal flags
 		 */
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			goto tidy_fdw;
 		tmp = 1ULL << (stress_mwc8() & 0x1f);
-		VOID_RET(int, ioctl(fd, SHIM_EXT2_IOC_SETFLAGS, &tmp));
+		if (ioctl(fd, SHIM_EXT2_IOC_SETFLAGS, &tmp) == 0)
+			(*chattr_count)++;
+
+		/*
+		 *  Some flags make a file based mmapping unmodifyable
+		 *  so exercise this by trying to change a the page
+		 *  and handling any SIGBUS/SIGSEGV faults
+		 */
+		if (page != MAP_FAILED) {
+			ret = sigsetjmp(jmp_env, 1);
+			do_jmp = true;
+			if (ret == 0)
+				*page = j;
+			do_jmp = false;
+		}
 
 		/*
 		 *  Restore original setting
 		 */
 		tmp = 0;
-		for (j = 0; (j < sizeof(orig) * 8); j++) {
-			register unsigned long bitmask = 1ULL << j;
+		for (j = 0; (j < sizeof(orig_flags) * 8); j++) {
+			register const unsigned long int bitmask = 1ULL << j;
 
 			tmp |= bitmask;
 			ret = ioctl(fd, SHIM_EXT2_IOC_SETFLAGS, &tmp);
 			if (ret < 0)
 				tmp &= ~bitmask;
+			else
+				(*chattr_count)++;
 		}
 tidy_fdw:
 
 		(void)close(fdw);
 tidy_fd:
+		if (page != MAP_FAILED)
+			(void)munmap((void *)page, args->page_size);
 		(void)shim_fsync(fd);
 		(void)close(fd);
 		(void)shim_unlink(filename);
@@ -284,9 +329,17 @@ static int stress_chattr(stress_args_t *args)
 	const pid_t ppid = getppid();
 	int rc = EXIT_SUCCESS;
 	char filename[PATH_MAX], pathname[PATH_MAX];
-	unsigned long mask = 0;;
+	unsigned long int mask = 0;
 	int *flag_perms = NULL;
-	size_t i, index, flag_count;
+	size_t i, idx, flag_count;
+	uint64_t chattr_count = 0;
+	double rate, t, duration;
+
+	do_jmp = false;
+	if (stress_sighandler(args->name, SIGSEGV, stress_chattr_fault_handler, NULL) < 0)
+		return EXIT_FAILURE;
+	if (stress_sighandler(args->name, SIGBUS, stress_chattr_fault_handler, NULL) < 0)
+		return EXIT_FAILURE;
 
 	for (i = 0; i < SIZEOF_ARRAY(stress_chattr_flags); i++) {
 		mask |= stress_chattr_flags[i].flag;
@@ -310,16 +363,19 @@ static int stress_chattr(stress_args_t *args)
 	(void)stress_temp_filename(filename, sizeof(filename),
 		args->name, ppid, 0, 0);
 
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
+	stress_sync_start_wait(args);
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
-	index = 0;
+	idx = 0;
+	t = stress_time_now();
 	do {
 		size_t fail = 0;
 
 		for (i = 0; i < SIZEOF_ARRAY(stress_chattr_flags); i++) {
 			int ret;
 
-			ret = do_chattr(args, filename, stress_chattr_flags[i].flag, mask);
+			ret = do_chattr(args, filename, stress_chattr_flags[i].flag, mask, &chattr_count);
 			switch (ret) {
 			case EXIT_FAILURE:
 				fail++;
@@ -343,16 +399,22 @@ static int stress_chattr(stress_args_t *args)
 
 		/* Try next flag permutation */
 		if ((flag_count > 0) && (flag_perms)) {
-			(void)do_chattr(args, filename, (unsigned long)flag_perms[index], mask);
-			index++;
-			if (index >= flag_count)
-				index = 0;
+			(void)do_chattr(args, filename, (unsigned long int)flag_perms[idx], mask, &chattr_count);
+			idx++;
+			if (idx >= flag_count)
+				idx = 0;
 		}
 		stress_bogo_inc(args);
 	} while (stress_continue(args));
 
+	duration = stress_time_now() - t;
+
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 
+	rate = (duration > 0.0) ? (double)chattr_count / duration : 0.0;
+	stress_metrics_set(args, 0, "successful chattr flags set per sec",
+		rate, STRESS_METRIC_GEOMETRIC_MEAN);
+
 	(void)shim_unlink(filename);
 	(void)shim_rmdir(pathname);
 	free(flag_perms);
@@ -360,7 +422,7 @@ static int stress_chattr(stress_args_t *args)
 	return rc;
 }
 
-stressor_info_t stress_chattr_info = {
+const stressor_info_t stress_chattr_info = {
 	.stressor = stress_chattr,
 	.class = CLASS_FILESYSTEM | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
@@ -369,7 +431,7 @@ stressor_info_t stress_chattr_info = {
 
 #else
 
-stressor_info_t stress_chattr_info = {
+const stressor_info_t stress_chattr_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_FILESYSTEM | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
