@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -211,7 +211,7 @@ static int stress_chown(stress_args_t *args)
 			(void)shim_usleep(100000);
 #endif
 			/* Timed out, then give up */
-			if (!stress_continue_flag()) {
+			if (UNLIKELY(!stress_continue_flag())) {
 				rc = EXIT_SUCCESS;
 				goto tidy;
 			}
@@ -233,7 +233,7 @@ static int stress_chown(stress_args_t *args)
 
 #if defined(HAVE_PATHCONF) &&	\
     defined(_PC_CHOWN_RESTRICTED)
-	VOID_RET(long, pathconf(filename, _PC_CHOWN_RESTRICTED));
+	VOID_RET(long int, pathconf(filename, _PC_CHOWN_RESTRICTED));
 #endif
 
 	rc = EXIT_SUCCESS;
@@ -280,7 +280,7 @@ tidy:
 	return rc;
 }
 
-stressor_info_t stress_chown_info = {
+const stressor_info_t stress_chown_info = {
 	.stressor = stress_chown,
 	.class = CLASS_FILESYSTEM | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
