@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -607,10 +607,8 @@ static int stress_clone(stress_args_t *args)
 		return EXIT_NO_RESOURCE;
 	}
 	stress_set_vma_anon_name(shared, sizeof(*shared), "clone-state");
+	stress_zero_metrics(&shared->metrics, 1);
 	shared->metrics.lock = stress_lock_create("metrics");
-	shared->metrics.duration = 0.0;
-	shared->metrics.count = 0.0;
-	shared->metrics.t_start = 0.0;
 
 	flag_count = stress_flag_permutation((int)all_flags, &flag_perms);
 
