@@ -56,7 +56,7 @@ static inline shim_off64_t stress_copy_file_seek64(int fd, shim_off64_t off64, i
 
 	if (off64 > max_off64) {
 		errno = EINVAL;
-		return -1;
+		return (shim_off64_t)-1;
 	}
 	return (shim_off64_t)lseek(fd, (off_t)off64, whence);
 #endif
@@ -87,7 +87,7 @@ static int stress_copy_file_fill(
 		if (n < 0)
 			return -1;
 		sz -= n;
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			return 0;
 	}
 	return 0;
@@ -230,10 +230,10 @@ static int stress_copy_file(stress_args_t *args)
 		off64_out_orig = (shim_loff_t)stress_mwc64modn(copy_file_bytes - DEFAULT_COPY_FILE_SIZE);
 		off64_out = off64_out_orig;
 
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 		stress_copy_file_fill(args, fd_in, off64_in, DEFAULT_COPY_FILE_SIZE);
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 		t = stress_time_now();
 		copy_ret = shim_copy_file_range(fd_in, &off64_in, fd_out,
@@ -273,11 +273,11 @@ static int stress_copy_file(stress_args_t *args)
 			verify_ret = stress_copy_file_range_verify(fd_in, &off64_in,
 					fd_out, &off64_out, copy_ret);
 			if (verify_ret < 0) {
-				pr_fail("%s: copy_file_range verify failed, input offset=%jd, output offset=%jd\n",
+				pr_fail("%s: copy_file_range verify failed, input offset=%" PRIdMAX " output offset=%" PRIdMAX "\n",
 					args->name, (intmax_t)off64_in_orig, (intmax_t)off64_out_orig);
 			}
 		}
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 
 		/*
@@ -295,7 +295,7 @@ static int stress_copy_file(stress_args_t *args)
 		 */
 		VOID_RET(ssize_t, shim_copy_file_range(fd_in, &off64_in, fd_out,
 						&off64_out, DEFAULT_COPY_FILE_SIZE, ~0U));
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 		(void)shim_fsync(fd_out);
 		stress_bogo_inc(args);
