@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2016-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -70,7 +70,7 @@ static int stress_cpu_online_set(
 	const int setting)
 {
 	char filename[PATH_MAX];
-	char data[3] = { '0' + (char)setting, '\n', 0 };
+	const char data[3] = { '0' + (char)setting, '\n', 0 };
 	ssize_t ret;
 
 	(void)snprintf(filename, sizeof(filename),
@@ -196,7 +196,7 @@ static int stress_cpu_online(stress_args_t *args)
 		cpus = STRESS_CPU_ONLINE_MAX_CPUS;
 	}
 
-	cpu_online = calloc((size_t)cpus, sizeof(*cpu_online));
+	cpu_online = (bool *)calloc((size_t)cpus, sizeof(*cpu_online));
 	if (!cpu_online) {
 		pr_inf_skip("%s: out of memory allocating %" PRId32 " boolean flags, "
 			    "skipping stressor\n", args->name, cpus);
@@ -328,7 +328,7 @@ static int stress_cpu_online(stress_args_t *args)
 			/* Don't try if already offline */
 			stress_cpu_online_get(cpu, &setting);
 			if (setting == 0) {
-				shim_sched_yield();
+				(void)shim_sched_yield();
 				continue;
 			}
 
@@ -376,7 +376,7 @@ static int stress_cpu_online(stress_args_t *args)
 				}
 			}
 			stress_bogo_inc(args);
-			shim_sched_yield();
+			(void)shim_sched_yield();
 		}
 	} while (stress_continue(args));
 
