@@ -711,7 +711,7 @@ again:
 	if (pid < 0) {
 		if (stress_redo_fork(args, errno))
 			goto again;
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			goto finish;
 		pr_inf("%s: cannot fork, errno=%d (%s)\n",
 			args->name, errno, strerror(errno));
