@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -17,7 +17,9 @@
  *
  */
 #include "stress-ng.h"
+#include "core-asm-arm.h"
 #include "core-affinity.h"
+#include "core-builtin.h"
 #include "core-cpu-cache.h"
 #include "core-killpid.h"
 
@@ -47,12 +49,60 @@ typedef struct dekker {
 	stress_metrics_t p1;
 } dekker_t;
 
-dekker_t *dekker;
+static dekker_t *dekker;
+static sigjmp_buf jmp_env;
 
 static inline void ALWAYS_INLINE dekker_mfence(void)
 {
 	shim_mfence();
-	stress_asm_mb();
+}
+
+static inline void ALWAYS_INLINE dekker_mbarrier(void)
+{
+#if defined(HAVE_ASM_ARM_DMB_SY)
+	stress_asm_arm_dmb_sy();
+#endif
+}
+
+static void stress_decker_sigill_handler(int signum)
+{
+	(void)signum;
+
+	siglongjmp(jmp_env, 1);
+}
+
+static int stress_dekker_supported(const char *name)
+{
+	static struct sigaction act, oldact;
+	int ret;
+
+	(void)shim_memset(&act, 0, sizeof(act));
+	(void)shim_memset(&oldact, 0, sizeof(oldact));
+
+	ret = sigsetjmp(jmp_env, 1);
+	if (ret == 1) {
+		pr_inf_skip("%s: memory barrier not functional, skipping stressor\n", name);
+		(void)sigaction(SIGILL, &oldact, &act);
+		return -1;
+	}
+
+	act.sa_handler = stress_decker_sigill_handler;
+        (void)sigemptyset(&act.sa_mask);
+        act.sa_flags = SA_NOCLDSTOP;
+	if (sigaction(SIGILL, &act, &oldact) < 0) {
+		pr_inf_skip("%s: sigaction for SIGILL failed, skipping stressor\n",
+			name);
+		return -1;
+	}
+
+	dekker_mbarrier();
+
+	if (sigaction(SIGILL, &oldact, NULL) < 0) {
+		pr_inf_skip("%s: sigaction for SIGILL failed, skipping stressor\n",
+			name);
+		return -1;
+	}
+	return 0;
 }
 
 static int stress_dekker_p0(stress_args_t *args)
@@ -63,14 +113,17 @@ static int stress_dekker_p0(stress_args_t *args)
 	t = stress_time_now();
 	dekker->m.wants_to_enter[0] = true;
 	dekker_mfence();
+	dekker_mbarrier();
 	while (LIKELY(dekker->m.wants_to_enter[1])) {
 		if (dekker->m.turn != 0) {
 			dekker->m.wants_to_enter[0] = false;
 			dekker_mfence();
+			dekker_mbarrier();
 			while (dekker->m.turn != 0) {
 			}
 			dekker->m.wants_to_enter[0] = true;
 			dekker_mfence();
+			dekker_mbarrier();
 		}
 	}
 
@@ -79,10 +132,12 @@ static int stress_dekker_p0(stress_args_t *args)
 	dekker->m.check++;
 	check1 = dekker->m.check;
 	dekker_mfence();
+	dekker_mbarrier();
 
 	dekker->m.turn = 1;
 	dekker->m.wants_to_enter[0] = false;
 	dekker_mfence();
+	dekker_mbarrier();
 	dekker->p0.duration += stress_time_now() - t;
 	dekker->p0.count += 1.0;
 
@@ -103,14 +158,17 @@ static int stress_dekker_p1(stress_args_t *args)
 
 	dekker->m.wants_to_enter[1] = true;
 	dekker_mfence();
+	dekker_mbarrier();
 	while (LIKELY(dekker->m.wants_to_enter[0])) {
 		if (dekker->m.turn != 1) {
 			dekker->m.wants_to_enter[1] = false;
 			dekker_mfence();
+			dekker_mbarrier();
 			while (dekker->m.turn != 1) {
 			}
 			dekker->m.wants_to_enter[1] = true;
 			dekker_mfence();
+			dekker_mbarrier();
 		}
 	}
 
@@ -119,11 +177,13 @@ static int stress_dekker_p1(stress_args_t *args)
 	dekker->m.check--;
 	check1 = dekker->m.check;
 	dekker_mfence();
+	dekker_mbarrier();
 	stress_bogo_inc(args);
 
 	dekker->m.turn = 0;
 	dekker->m.wants_to_enter[1] = false;
 	dekker_mfence();
+	dekker_mbarrier();
 	dekker->p1.duration += stress_time_now() - t;
 	dekker->p1.count += 1.0;
 
@@ -156,6 +216,9 @@ static int stress_dekker(stress_args_t *args)
 	}
 
 	stress_set_vma_anon_name(dekker, sz, "dekker-mutex");
+	stress_zero_metrics(&dekker->p0, 1);
+	stress_zero_metrics(&dekker->p1, 1);
+
 	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
@@ -204,16 +267,17 @@ static int stress_dekker(stress_args_t *args)
 	return rc;
 }
 
-stressor_info_t stress_dekker_info = {
+const stressor_info_t stress_dekker_info = {
 	.stressor = stress_dekker,
 	.class = CLASS_CPU_CACHE | CLASS_IPC,
 	.verify = VERIFY_ALWAYS,
+	.supported = stress_dekker_supported,
 	.help = help
 };
 
 #else
 
-stressor_info_t stress_dekker_info = {
+const stressor_info_t stress_dekker_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_CPU | CLASS_IPC,
 	.verify = VERIFY_ALWAYS,
