@@ -130,13 +130,13 @@ static int stress_dir_read(
 	const char *path)
 {
 	DIR *dp;
-	struct dirent *de;
+	const struct dirent *de;
 
 	dp = opendir(path);
 	if (!dp)
 		return -1;
 
-	while (stress_continue(args) && ((de = readdir(dp)) != NULL)) {
+	while (LIKELY(stress_continue(args) && ((de = readdir(dp)) != NULL))) {
 		char filename[PATH_MAX];
 		struct stat statbuf;
 		int fd;
@@ -173,7 +173,7 @@ static int stress_dir_rename(
 	const char *path)
 {
 	DIR *dp;
-	struct dirent *de;
+	const struct dirent *de;
 	char new_filename[PATH_MAX];
 	char tmp[32];
 
@@ -184,7 +184,7 @@ static int stress_dir_rename(
 	if (!dp)
 		return -1;
 
-	while (stress_continue(args) && ((de = readdir(dp)) != NULL)) {
+	while (LIKELY(stress_continue(args) && ((de = readdir(dp)) != NULL))) {
 		char old_filename[PATH_MAX];
 
 #if !defined(__CYGWIN__)
@@ -248,7 +248,8 @@ static int stress_mkdir(const int dir_fd, const char *path, const int mode)
 	 *  50% of the time use mkdirat rather than mkdir
 	 */
 	if ((dir_fd >= 0) && stress_mwc1()) {
-		char tmp[PATH_MAX], *filename;
+		char tmp[PATH_MAX];
+		const char *filename;
 
 		(void)shim_strscpy(tmp, path, sizeof(tmp));
 		filename = basename(tmp);
@@ -377,7 +378,7 @@ static int stress_dir_readdir(
 	char dirpath[PATH_MAX + 64];
 	char filename[PATH_MAX + 70];
 	int rc = 0, i, got_mask, all_mask;
-	struct dirent *entry;
+	const struct dirent *de;
 
 	(void)snprintf(dirpath, sizeof(dirpath), "%s/test-%" PRIdMAX "-%" PRIu32, pathname,
 		(intmax_t)getpid(), stress_mwc32());
@@ -411,9 +412,9 @@ static int stress_dir_readdir(
 
 	rewinddir(dir);
 	got_mask = 0;
-	while ((entry = readdir(dir))) {
-		if (isdigit((unsigned char)entry->d_name[0])) {
-			const int d = atoi(entry->d_name);
+	while ((de = readdir(dir))) {
+		if (isdigit((unsigned char)de->d_name[0])) {
+			const int d = atoi(de->d_name);
 
 			got_mask |= (1U << d);
 		}
@@ -478,7 +479,7 @@ static int stress_dir(stress_args_t *args)
 		stress_dir_flock(dir_fd);
 		stress_dir_truncate(pathname, dir_fd);
 
-		for (i = 0; stress_continue(args) && (i < n); i++) {
+		for (i = 0; LIKELY(stress_continue(args) && (i < n)); i++) {
 			char path[PATH_MAX];
 			const uint64_t gray_code = (i >> 1) ^ i;
 
@@ -501,19 +502,19 @@ static int stress_dir(stress_args_t *args)
 		stress_invalid_rmdir(pathname);
 		stress_invalid_mkdirat(bad_fd);
 
-		if (!stress_continue(args)) {
+		if (UNLIKELY(!stress_continue(args))) {
 			stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 			stress_dir_tidy(args, i);
 			break;
 		}
 		stress_dir_read(args, pathname);
-		if (!stress_continue(args)) {
+		if (UNLIKELY(!stress_continue(args))) {
 			stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 			stress_dir_tidy(args, i);
 			break;
 		}
 		stress_dir_rename(args, pathname);
-		if (!stress_continue(args)) {
+		if (UNLIKELY(!stress_continue(args))) {
 			stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 			stress_dir_tidy(args, i);
 			break;
