@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -324,7 +324,7 @@ static int get_variable_sysfs_efi_vars(
 {
 	size_t i;
 	stress_efi_var_t var;
-	uint32_t *attributes = (uint32_t *)var.attributes;
+	const uint32_t *attributes = (uint32_t *)var.attributes;
 
 	static const char * const efi_sysfs_names[] = {
 		"attributes",
@@ -392,7 +392,7 @@ static int efi_vars_get(
 	static char data[4096];
 	int i, rc = 0;
 
-	for (i = 0; stress_continue(args) && (i < dir_count); i++) {
+	for (i = 0; LIKELY(stress_continue(args) && (i < dir_count)); i++) {
 		char *d_name = efi_dentries[i]->d_name;
 		int ret;
 
@@ -507,7 +507,7 @@ again:
 	if (pid < 0) {
 		if (stress_redo_fork(args, errno))
 			goto again;
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			goto finish;
 		pr_err("%s: fork failed: errno=%d (%s)\n",
 			args->name, errno, strerror(errno));
