@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,6 +21,10 @@
 #include "core-killpid.h"
 #include "core-out-of-memory.h"
 
+#if defined(HAVE_SYS_PARAM_H)
+#include <sys/param.h>
+#endif
+
 static const stress_help_t help[] = {
 	{ NULL,	"env N",	"start N workers setting environment vars" },
 	{ NULL,	"env-ops N",	"stop after N env bogo operations" },
@@ -126,7 +130,7 @@ static int stress_env_child(stress_args_t *args, void *context)
 			for (j = 0; j < i; j++) {
 				if (verify) {
 					const size_t env_sz = stress_env_size(arg_max);
-					char *val;
+					const char *val;
 
 					(void)snprintf(name, sizeof(name), "STRESS_ENV_%" PRIx64, j);
 					val = getenv(name);
@@ -152,7 +156,7 @@ static int stress_env_child(stress_args_t *args, void *context)
 					rc = EXIT_FAILURE;
 				}
 				stress_bogo_inc(args);
-				if (!stress_continue(args))
+				if (UNLIKELY(!stress_continue(args)))
 					goto reap;
 			}
 			i = 0;
@@ -167,7 +171,7 @@ static int stress_env_child(stress_args_t *args, void *context)
 reap:
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 
-	(void)munmap(value, arg_max);
+	(void)munmap((void *)value, arg_max);
 
 	return rc;
 }
