@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2024      Colin Ian King
+ * Copyright (C) 2024-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,18 +29,9 @@ static const stress_help_t help[] = {
 	{ NULL,	NULL,		 	NULL }
 };
 
-static int stress_set_factor_digits(const char *opt)
-{
-	size_t factor_digits;
-
-	factor_digits = (size_t)stress_get_int32(opt);
-	stress_check_range("factor-digits", (uint64_t)factor_digits, 8, 100000000);
-	return stress_set_setting("factor-digits", TYPE_ID_SIZE_T, &factor_digits);
-}
-
-static const stress_opt_set_func_t opt_set_funcs[] = {
-	{ OPT_factor_digits,	stress_set_factor_digits },
-	{ 0,			NULL },
+static const stress_opt_t opts[] = {
+	{ OPT_factor_digits, "factor-digits", TYPE_ID_SIZE_T, 8, 100000000, NULL },
+	END_OPT,
 };
 
 #if defined(HAVE_GMP_H) &&	\
@@ -57,8 +48,9 @@ static int OPTIMIZE3 stress_factor(stress_args_t *args)
 
 	mpz_inits(value, divisor, q, r, tmp, NULL);
 
-	stress_set_proc_state(args->name, STRESS_STATE_RUN);
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
+	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	do {
 		size_t digits;
@@ -74,7 +66,7 @@ static int OPTIMIZE3 stress_factor(stress_args_t *args)
 			unsigned long int n;
 			size_t digitsleft = factor_digits - mpz_sizeinbase(value, 10);
 
-			if (!stress_continue_flag())
+			if (UNLIKELY(!stress_continue_flag()))
 				goto abort;
 
 			if (digitsleft > 6)
@@ -102,7 +94,7 @@ static int OPTIMIZE3 stress_factor(stress_args_t *args)
 		factors = 0;
 
 		while (mpz_cmp_ui(value, 1) != 0) {
-			if (!stress_continue_flag())
+			if (UNLIKELY(!stress_continue_flag()))
 				goto abort;
 			mpz_cdiv_qr(q, r, value, divisor);
 
@@ -137,20 +129,20 @@ abort:
 	return EXIT_SUCCESS;
 }
 
-stressor_info_t stress_factor_info = {
+const stressor_info_t stress_factor_info = {
 	.stressor = stress_factor,
-	.class = CLASS_CPU,
+	.class = CLASS_CPU | CLASS_INTEGER | CLASS_COMPUTE,
 	.verify = VERIFY_ALWAYS,
-	.opt_set_funcs = opt_set_funcs,
+	.opts = opts,
 	.help = help
 };
 
 #else
 
-stressor_info_t stress_factor_info = {
+const stressor_info_t stress_factor_info = {
 	.stressor = stress_unimplemented,
-	.class = CLASS_CPU | CLASS_COMPUTE,
-	.opt_set_funcs = opt_set_funcs,
+	.class = CLASS_CPU | CLASS_INTEGER | CLASS_COMPUTE,
+	.opts = opts,
 	.verify = VERIFY_ALWAYS,
 	.help = help,
 	.unimplemented_reason = "built without gmp.h, or libgmp"
