@@ -107,8 +107,7 @@ static void stress_fd_race_close_fds(
 	const int fds_max,
 	const int flag)
 {
-	size_t i, j;
-	int tmp;
+	size_t i;
 
 	if (!fds)
 		return;
@@ -143,6 +142,9 @@ static void stress_fd_race_close_fds(
 	case 3:
 		/* Close fds in randomized order */
 		for (i = 0; i < n; i++) {
+			register size_t j;
+			register int tmp;
+
 			j = (size_t)stress_mwc32modn(n);
 
 			tmp = fds[i];
@@ -244,6 +246,8 @@ static void *stress_fd_race_pthread(void *ptr)
 
 	int i;
 
+	stress_random_small_sleep();
+
 	for (i = 0; i < context->n; i++) {
 		if (context->fds[i] > 0) {
 			struct stat statbuf;
@@ -289,7 +293,7 @@ static int OPTIMIZE3 stress_race_fd_client(stress_fd_race_context *context)
 
 		(void)shim_memset(context->fds, 0, context->fds_size);
 retry:
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			return EXIT_NO_RESOURCE;
 
 		if (UNLIKELY((fd = socket(AF_UNIX, SOCK_STREAM, 0)) < 0)) {
@@ -325,7 +329,7 @@ retry:
 		if (UNLIKELY(!stress_continue_flag()))
 			return EXIT_SUCCESS;
 
-		for (n = 0; stress_continue(args) && (n < context->max_fd); n++) {
+		for (n = 0; LIKELY(stress_continue(args) && (n < context->max_fd)); n++) {
 			context->fds[n] = stress_race_fd_recv(fd);
 			if (context->fds[n] < 0)
 				continue;
@@ -544,7 +548,7 @@ static int OPTIMIZE3 stress_race_fd_server(
 	do {
 		int sfd;
 
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 
 		sfd = accept(fd, (struct sockaddr *)NULL, NULL);
@@ -555,7 +559,7 @@ static int OPTIMIZE3 stress_race_fd_server(
 
 			(void)shim_memset(context->fds, 0, context->fds_size);
 
-			for (i = 0; stress_continue(args) && (i < context->max_fd); i++) {
+			for (i = 0; LIKELY(stress_continue(args) && (i < context->max_fd)); i++) {
 				context->fds[i] = open(entry->filename, entry->flags);
 				context->current_fd = context->fds[i];
 
@@ -762,8 +766,7 @@ static void stress_fd_race_get_dev(
 static int stress_fd_race(stress_args_t *args)
 {
 	pid_t pid;
-	int rc = EXIT_SUCCESS, ret, reserved_port;
-	int *fds, fd;
+	int fd, rc = EXIT_SUCCESS, ret, reserved_port;
 	char filename[PATH_MAX];
 	stress_fd_race_filename_t *list = NULL;
 	bool fd_race_dev = false;
@@ -842,7 +845,7 @@ static int stress_fd_race(stress_args_t *args)
 	if (context.max_fd > (1024 * 1024))
 		context.max_fd  = 1024 * 1024;
 
-	context.fds_size = sizeof(*fds) * (size_t)context.max_fd;
+	context.fds_size = sizeof(*context.fds) * (size_t)context.max_fd;
 	context.fds = (int *)malloc(context.fds_size);
 	if (!context.fds) {
 		pr_inf_skip("%s: cannot allocate %zd file descriptors, skipping stressor\n",
@@ -864,7 +867,7 @@ again:
 	if (pid < 0) {
 		if (stress_redo_fork(args, errno))
 			goto again;
-		if (!stress_continue(args)) {
+		if (UNLIKELY(!stress_continue(args))) {
 			rc = EXIT_SUCCESS;
 			goto tidy_barrier;
 		}
