@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -703,7 +703,7 @@ static int stress_file_ioctl(stress_args_t *args)
 		{
 			struct fsuuid2 uuid2;
 
-			(void)memset(&uuid2, 0, sizeof(uuid2));
+			(void)shim_memset(&uuid2, 0, sizeof(uuid2));
 			VOID_RET(int, ioctl(fd, FS_IOC_GETFSUUID, &uuid2));
 			exercised++;
 
@@ -715,7 +715,7 @@ static int stress_file_ioctl(stress_args_t *args)
 		{
 			struct fs_sysfs_path	sysfs_path;
 
-			(void)memset(&sysfs_path, 0, sizeof(sysfs_path));
+			(void)shim_memset(&sysfs_path, 0, sizeof(sysfs_path));
 			VOID_RET(int, ioctl(fd, FS_IOC_GETFSSYSFSPATH, &sysfs_path));
 			exercised++;
 		}
