@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,15 +30,11 @@
 #define STRESS_FILENAME_POSIX	(1)	/* POSIX 2008.1 */
 #define STRESS_FILENAME_EXT	(2)	/* EXT* filesystems */
 
-typedef struct {
-	const uint8_t opt;
-	const char *opt_text;
-} stress_filename_opts_t;
-
-static const stress_filename_opts_t filename_opts[] = {
-	{ STRESS_FILENAME_PROBE,	"probe" },
-	{ STRESS_FILENAME_POSIX,	"posix" },
-	{ STRESS_FILENAME_EXT,		"ext" },
+/* mapping of opts text to STRESS_FILE_NAME_* values */
+static const char *filename_opts[] = {
+	"probe",	/* STRESS_FILENAME_PROBE */
+	"posix",	/* STRESS_FILENAME_POSIX */
+	"ext",		/* STRESS_FILENAME_EXT */
 };
 
 static const stress_help_t help[] = {
@@ -214,7 +210,7 @@ static void stress_filename_tidy(const char *path)
 
 	dir = opendir(path);
 	if (dir) {
-		struct dirent *d;
+		const struct dirent *d;
 
 		while ((d = readdir(dir)) != NULL) {
 			char filename[PATH_MAX];
@@ -415,7 +411,7 @@ static int stress_filename(stress_args_t *args)
 	stress_sync_start_wait(args);
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 again:
-	if (!stress_continue_flag()) {
+	if (UNLIKELY(!stress_continue_flag())) {
 		/* Time to die */
 		rc = EXIT_SUCCESS;
 		goto tidy_dir;
@@ -424,7 +420,7 @@ again:
 	if (pid < 0) {
 		if (stress_redo_fork(args, errno))
 			goto again;
-		if (!stress_continue(args)) {
+		if (UNLIKELY(!stress_continue(args))) {
 			rc = EXIT_SUCCESS;
 			goto tidy_dir;
 		}
@@ -489,61 +485,61 @@ again:
 			/* Should succeed */
 			stress_filename_generate(ptr, 1, ch);
 			stress_filename_test(args, filename, 1, true, mypid, &rc);
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				break;
 			stress_filename_generate_random(ptr, 1, chars_allowed);
 			stress_filename_test(args, filename, 1, true, mypid, &rc);
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				break;
 
 			/* Should succeed */
 			stress_filename_generate(ptr, sz_max, ch);
 			stress_filename_test(args, filename, sz_max, true, mypid, &rc);
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				break;
 			stress_filename_generate_random(ptr, sz_max, chars_allowed);
 			stress_filename_test(args, filename, sz_max, true, mypid, &rc);
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				break;
 
 			/* Should succeed */
 			stress_filename_generate(ptr, sz_max - 1, ch);
 			stress_filename_test(args, filename, sz_max - 1, true, mypid, &rc);
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				break;
 			stress_filename_generate_random(ptr, sz_max - 1, chars_allowed);
 			stress_filename_test(args, filename, sz_max - 1, true, mypid, &rc);
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				break;
 
 			/* Should fail */
 			stress_filename_generate(ptr, sz_max + 1, ch);
 			stress_filename_test(args, filename, sz_max + 1, false, mypid, &rc);
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				break;
 			stress_filename_generate_random(ptr, sz_max + 1, chars_allowed);
 			stress_filename_test(args, filename, sz_max + 1, false, mypid, &rc);
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				break;
 
 			/* Should succeed */
 			stress_filename_generate(ptr, sz, ch);
 			stress_filename_test(args, filename, sz, true, mypid, &rc);
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				break;
 			stress_filename_generate_random(ptr, sz, chars_allowed);
 			stress_filename_test(args, filename, sz, true, mypid, &rc);
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				break;
 
 			/* Should succeed */
 			stress_filename_generate(ptr, rnd_sz, ch);
 			stress_filename_test(args, filename, rnd_sz, true, mypid, &rc);
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				break;
 			stress_filename_generate_random(ptr, rnd_sz, chars_allowed);
 			stress_filename_test(args, filename, rnd_sz, true, mypid, &rc);
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				break;
 
 #if defined(HAVE_PATHCONF)
@@ -575,7 +571,7 @@ tidy_dir:
 
 static const char *stress_filename_opts(const size_t i)
 {
-	return (i < SIZEOF_ARRAY(filename_opts)) ? filename_opts[i].opt_text : NULL;
+	return (i < SIZEOF_ARRAY(filename_opts)) ? filename_opts[i] : NULL;
 }
 
 static const stress_opt_t opts[] = {
