@@ -179,7 +179,7 @@ static inline int stress_flush_icache(
 	if (stress_flushcache_mprotect(args, page_addr, context->i_size, PROT_READ | PROT_WRITE | PROT_EXEC) < 0)
 		return -1;
 
-	while ((ptr < ptr_end) && stress_continue_flag()) {
+	while (LIKELY((ptr < ptr_end) && stress_continue_flag())) {
 		volatile uint8_t *vptr = (volatile uint8_t *)ptr;
 		const uint8_t val = *vptr;
 
@@ -224,7 +224,7 @@ static inline int stress_flush_dcache(
 	register uint8_t *ptr = (uint8_t *)d_addr;
 	const uint8_t *ptr_end = ptr + d_size;
 
-	while ((ptr < ptr_end) && stress_continue_flag()) {
+	while (LIKELY((ptr < ptr_end) && stress_continue_flag())) {
 #if defined(HAVE_ASM_X86_CLFLUSH)
 		if (context->x86_clfsh)
 			clflush_page((void *)ptr, page_size, cl_size);
