@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2024 Colin Ian King
+ * Copyright (C) 2021-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,20 +26,25 @@
 
 #include <math.h>
 
+#define D_ALIGNED	ALIGNED(64)	/* alignment for doubles */
+#define F_ALIGNED       ALIGNED(64)	/* alignment for floats */
+
 #define FMA_ELEMENTS	(512)
 #define FMA_UNROLL	(8)
+#define FMA_FUNCS	(6)
+
 /* #define USE_FMA_FAST	 */
 
 typedef struct {
 	double  *double_a;
-	double	double_init[FMA_ELEMENTS];
-	double	double_a1[FMA_ELEMENTS];
-	double	double_a2[FMA_ELEMENTS];
+	double	double_init[FMA_ELEMENTS] D_ALIGNED;
+	double	double_a1[FMA_ELEMENTS] D_ALIGNED;
+	double	double_a2[FMA_ELEMENTS] D_ALIGNED;
 
 	float	*float_a;
-	float	float_init[FMA_ELEMENTS];
-	float	float_a1[FMA_ELEMENTS];
-	float	float_a2[FMA_ELEMENTS];
+	float	float_init[FMA_ELEMENTS] F_ALIGNED;
+	float	float_a1[FMA_ELEMENTS] F_ALIGNED;
+	float	float_a2[FMA_ELEMENTS] F_ALIGNED;
 
 	double	double_b;
 	double	double_c;
@@ -48,7 +53,7 @@ typedef struct {
 	float	float_c;
 } stress_fma_t;
 
-typedef void (*stress_fma_func)(stress_fma_t *fma);
+typedef void (*stress_fma_func_t)(stress_fma_t *fma);
 
 static const stress_help_t help[] = {
 	{ NULL,	"fma N",	"start N workers performing floating point multiply-add ops" },
@@ -57,11 +62,6 @@ static const stress_help_t help[] = {
 	{ NULL,	NULL,		 NULL }
 };
 
-static int stress_set_fma_libc(const char *opt)
-{
-	return stress_set_setting_true("fma-libc", opt);
-}
-
 static inline float stress_fma_rnd_float(void)
 {
 	register const float fhalfpwr32 = (float)1.0 / (float)(0x80000000);
@@ -81,6 +81,18 @@ PRAGMA_UNROLL_N(FMA_UNROLL)
 		a[i] = (a[i] * c) + b;
 }
 
+static void TARGET_CLONES stress_fma_sub132_double(stress_fma_t *fma)
+{
+	register size_t i;
+	register double *a = fma->double_a;
+	register double b = fma->double_b;
+	register double c = fma->double_c;
+
+PRAGMA_UNROLL_N(FMA_UNROLL)
+	for (i = 0; i < FMA_ELEMENTS; i++)
+		a[i] = (a[i] * c) - b;
+}
+
 static void TARGET_CLONES stress_fma_add132_float(stress_fma_t *fma)
 {
 	register size_t i;
@@ -93,6 +105,18 @@ PRAGMA_UNROLL_N(FMA_UNROLL)
 		a[i] = (a[i] * c) + b;
 }
 
+static void TARGET_CLONES stress_fma_sub132_float(stress_fma_t *fma)
+{
+	register size_t i;
+	register float *a = fma->float_a;
+	register float b = fma->float_b;
+	register float c = fma->float_c;
+
+PRAGMA_UNROLL_N(FMA_UNROLL)
+	for (i = 0; i < FMA_ELEMENTS; i++)
+		a[i] = (a[i] * c) - b;
+}
+
 static void TARGET_CLONES stress_fma_add213_double(stress_fma_t *pfma)
 {
 	register size_t i;
@@ -105,6 +129,18 @@ PRAGMA_UNROLL_N(FMA_UNROLL)
 		a[i] = (b * a[i]) + c;
 }
 
+static void TARGET_CLONES stress_fma_sub213_double(stress_fma_t *pfma)
+{
+	register size_t i;
+	register double *a = pfma->double_a;
+	register double b = pfma->double_b;
+	register double c = pfma->double_c;
+
+PRAGMA_UNROLL_N(FMA_UNROLL)
+	for (i = 0; i < FMA_ELEMENTS; i++)
+		a[i] = (b * a[i]) + c;
+}
+
 static void TARGET_CLONES stress_fma_add213_float(stress_fma_t *pfma)
 {
 	register size_t i;
@@ -117,6 +153,18 @@ PRAGMA_UNROLL_N(FMA_UNROLL)
 		a[i] = (b * a[i]) + c;
 }
 
+static void TARGET_CLONES stress_fma_sub213_float(stress_fma_t *pfma)
+{
+	register size_t i;
+	register float *a = pfma->float_a;
+	register const float b = pfma->float_b;
+	register const float c = pfma->float_c;
+
+PRAGMA_UNROLL_N(FMA_UNROLL)
+	for (i = 0; i < FMA_ELEMENTS; i++)
+		a[i] = (b * a[i]) + c;
+}
+
 static void TARGET_CLONES stress_fma_add231_double(stress_fma_t *pfma)
 {
 	register size_t i;
@@ -131,6 +179,20 @@ PRAGMA_UNROLL_N(FMA_UNROLL)
 	}
 }
 
+static void TARGET_CLONES stress_fma_sub231_double(stress_fma_t *pfma)
+{
+	register size_t i;
+	register double *a = pfma->double_a;
+	register double b = pfma->double_b;
+	register const double c = pfma->double_c;
+
+PRAGMA_UNROLL_N(FMA_UNROLL)
+	for (i = 0; i < FMA_ELEMENTS; i++) {
+		a[i] = (b * c) + a[i];
+		b += 0.125;
+	}
+}
+
 static void TARGET_CLONES stress_fma_add231_float(stress_fma_t *pfma)
 {
 	register size_t i;
@@ -145,13 +207,34 @@ PRAGMA_UNROLL_N(FMA_UNROLL)
 	}
 }
 
-stress_fma_func stress_fma_funcs[] = {
+static void TARGET_CLONES stress_fma_sub231_float(stress_fma_t *pfma)
+{
+	register size_t i;
+	register float *a = pfma->float_a;
+	register float b = pfma->float_b;
+	register const float c = pfma->float_c;
+
+PRAGMA_UNROLL_N(FMA_UNROLL)
+	for (i = 0; i < FMA_ELEMENTS; i++) {
+		a[i] = (b * c) + a[i];
+		b += 0.125;
+	}
+}
+
+stress_fma_func_t stress_fma_funcs[] = {
 	stress_fma_add132_double,
 	stress_fma_add132_float,
 	stress_fma_add213_double,
 	stress_fma_add213_float,
 	stress_fma_add231_double,
 	stress_fma_add231_float,
+
+	stress_fma_sub132_double,
+	stress_fma_sub132_float,
+	stress_fma_sub213_double,
+	stress_fma_sub213_float,
+	stress_fma_sub231_double,
+	stress_fma_sub231_float,
 };
 
 /* libc variants */
@@ -175,6 +258,24 @@ PRAGMA_UNROLL_N(FMA_UNROLL)
 	}
 }
 
+static void TARGET_CLONES stress_fma_sub132_libc_double(stress_fma_t *pfma)
+{
+	register size_t i;
+	register double *a = pfma->double_a;
+	register const double b = -(pfma->double_b);
+	register const double c = pfma->double_c;
+
+PRAGMA_UNROLL_N(FMA_UNROLL)
+	for (i = 0; i < FMA_ELEMENTS; i++) {
+#if defined(FP_FAST_FMA) &&	\
+    defined(USE_FMA_FAST)
+		a[i] = FP_FAST_FMA(a[i], c, b);
+#else
+		a[i] = shim_fma(a[i], c, b);
+#endif
+	}
+}
+
 static void TARGET_CLONES stress_fma_add132_libc_float(stress_fma_t *pfma)
 {
 	register size_t i;
@@ -193,6 +294,24 @@ PRAGMA_UNROLL_N(FMA_UNROLL)
 	}
 }
 
+static void TARGET_CLONES stress_fma_sub132_libc_float(stress_fma_t *pfma)
+{
+	register size_t i;
+	register float *a = pfma->float_a;
+	register const float b = -(pfma->float_b);
+	register const float c = pfma->float_c;
+
+PRAGMA_UNROLL_N(FMA_UNROLL)
+	for (i = 0; i < FMA_ELEMENTS; i++) {
+#if defined(FP_FAST_FMAF) &&	\
+    defined(USE_FMA_FAST)
+		a[i] = FP_FAST_FMAF(a[i], c, b);
+#else
+		a[i] = shim_fmaf(a[i], c, b);
+#endif
+	}
+}
+
 static void TARGET_CLONES stress_fma_add213_libc_double(stress_fma_t *pfma)
 {
 	register size_t i;
@@ -211,6 +330,24 @@ PRAGMA_UNROLL_N(FMA_UNROLL)
 	}
 }
 
+static void TARGET_CLONES stress_fma_sub213_libc_double(stress_fma_t *pfma)
+{
+	register size_t i;
+	register double *a = pfma->double_a;
+	register const double b = pfma->double_b;
+	register const double c = -(pfma->double_c);
+
+PRAGMA_UNROLL_N(FMA_UNROLL)
+	for (i = 0; i < FMA_ELEMENTS; i++) {
+#if defined(FP_FAST_FMA) && 	\
+    defined(USE_FMA_FAST)
+		a[i] = FP_FAST_FMA(b, a[i], c);
+#else
+		a[i] = shim_fma(b, a[i], c);
+#endif
+	}
+}
+
 static void TARGET_CLONES stress_fma_add213_libc_float(stress_fma_t *pfma)
 {
 	register size_t i;
@@ -229,6 +366,24 @@ PRAGMA_UNROLL_N(FMA_UNROLL)
 	}
 }
 
+static void TARGET_CLONES stress_fma_sub213_libc_float(stress_fma_t *pfma)
+{
+	register size_t i;
+	register float *a = pfma->float_a;
+	register const float b = pfma->float_b;
+	register const float c = -(pfma->float_c);
+
+PRAGMA_UNROLL_N(FMA_UNROLL)
+	for (i = 0; i < FMA_ELEMENTS; i++) {
+#if defined(FP_FAST_FMAF) &&	\
+    defined(USE_FMA_FAST)
+		a[i] = FP_FAST_FMAF(b, a[i], c);
+#else
+		a[i] = shim_fmaf(b, a[i], c);
+#endif
+	}
+}
+
 static void TARGET_CLONES stress_fma_add231_libc_double(stress_fma_t *pfma)
 {
 	register size_t i;
@@ -248,6 +403,25 @@ PRAGMA_UNROLL_N(FMA_UNROLL)
 	}
 }
 
+static void TARGET_CLONES stress_fma_sub231_libc_double(stress_fma_t *pfma)
+{
+	register size_t i;
+	register double *a = pfma->double_a;
+	register double b = pfma->double_b;
+	register const double c = pfma->double_c;
+
+PRAGMA_UNROLL_N(FMA_UNROLL)
+	for (i = 0; i < FMA_ELEMENTS; i++) {
+#if defined(FP_FAST_FMA) &&	\
+    defined(USE_FMA_FAST)
+		a[i] = FP_FAST_FMA(b, c, -a[i]);
+#else
+		a[i] = shim_fma(b, c, -a[i]);
+#endif
+		b += 0.125;
+	}
+}
+
 static void TARGET_CLONES stress_fma_add231_libc_float(stress_fma_t *pfma)
 {
 	register size_t i;
@@ -267,13 +441,39 @@ PRAGMA_UNROLL_N(FMA_UNROLL)
 	}
 }
 
-stress_fma_func stress_fma_libc_funcs[] = {
+static void TARGET_CLONES stress_fma_sub231_libc_float(stress_fma_t *pfma)
+{
+	register size_t i;
+	register float *a = pfma->float_a;
+	register float b = pfma->float_b;
+	register const float c = pfma->float_c;
+
+PRAGMA_UNROLL_N(FMA_UNROLL)
+	for (i = 0; i < FMA_ELEMENTS; i++) {
+#if defined(FP_FAST_FMAF) &&	\
+    defined(USE_FMA_FAST)
+		a[i] = FP_FAST_FMAF(b, c,-a[i]);
+#else
+		a[i] = shim_fmaf(b, c, -a[i]);
+#endif
+		b += 0.125;
+	}
+}
+
+stress_fma_func_t stress_fma_libc_funcs[] = {
 	stress_fma_add132_libc_double,
 	stress_fma_add132_libc_float,
 	stress_fma_add213_libc_double,
 	stress_fma_add213_libc_float,
 	stress_fma_add231_libc_double,
 	stress_fma_add231_libc_float,
+
+	stress_fma_sub132_libc_double,
+	stress_fma_sub132_libc_float,
+	stress_fma_sub213_libc_double,
+	stress_fma_sub213_libc_float,
+	stress_fma_sub231_libc_double,
+	stress_fma_sub231_libc_float,
 };
 #endif
 
@@ -304,20 +504,21 @@ static int stress_fma(stress_args_t *args)
 	stress_fma_t *pfma;
 	register size_t idx_b = 0, idx_c = 0;
 	const bool verify = !!(g_opt_flags & OPT_FLAGS_VERIFY);
-	stress_fma_func *fma_funcs;
+	const stress_fma_func_t *fma_func_array;
 	bool fma_libc = false;
 	int rc = EXIT_SUCCESS;
+	size_t offset = 0;
 
 	(void)stress_get_setting("fma-libc", &fma_libc);
 #if (defined(HAVE_FMA)  || defined(FP_FAST_FMA)) && 	\
     (defined(HAVE_FMAF) || defined(FP_FAST_FMAF))
-	fma_funcs = fma_libc ? stress_fma_libc_funcs : stress_fma_funcs;
+	fma_func_array = fma_libc ? stress_fma_libc_funcs : stress_fma_funcs;
 #else
 	if (fma_libc) {
 		pr_inf("%s: libc fma functions not available, defaulting "
 			"to non-libc fma operations\n", args->name);
 	}
-	fma_funcs = stress_fma_funcs;
+	fma_func_array = &stress_fma_funcs;
 #endif
 
 	stress_catch_sigill();
@@ -330,15 +531,17 @@ static int stress_fma(stress_args_t *args)
 			args->name, sizeof(*pfma));
 		return EXIT_NO_RESOURCE;
 	}
+	stress_set_vma_anon_name(pfma, sizeof(*pfma), "fma-data");
 	stress_madvise_mergeable(pfma, sizeof(*pfma));
 
-	stress_set_proc_state(args->name, STRESS_STATE_RUN);
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
+	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	stress_fma_init(pfma);
 
 	do {
-		size_t i;
+		register size_t i;
 
 		stress_fma_reset_a(pfma);
 
@@ -356,8 +559,8 @@ static int stress_fma(stress_args_t *args)
 		pfma->float_b = pfma->float_a[idx_b];
 		pfma->float_c = pfma->float_a[idx_c];
 
-		for (i = 0; i < SIZEOF_ARRAY(stress_fma_funcs); i++) {
-			fma_funcs[i](pfma);
+		for (i = 0; i < FMA_FUNCS; i++) {
+			fma_func_array[i + offset](pfma);
 		}
 		stress_bogo_inc(args);
 
@@ -369,8 +572,8 @@ static int stress_fma(stress_args_t *args)
 			pfma->float_b = pfma->float_a[idx_b];
 			pfma->float_c = pfma->float_a[idx_c];
 
-			for (i = 0; i < SIZEOF_ARRAY(stress_fma_funcs); i++) {
-				fma_funcs[i](pfma);
+			for (i = 0; i < FMA_FUNCS; i++) {
+				fma_func_array[i + offset](pfma);
 			}
 			stress_bogo_inc(args);
 
@@ -383,6 +586,7 @@ static int stress_fma(stress_args_t *args)
 				rc = EXIT_FAILURE;
 			}
 		}
+		offset = 6 - offset;
 	} while (stress_continue(args));
 
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
@@ -392,14 +596,15 @@ static int stress_fma(stress_args_t *args)
 	return rc;
 }
 
-static const stress_opt_set_func_t opt_set_funcs[] = {
-	{ OPT_fma_libc,	stress_set_fma_libc },
+static const stress_opt_t opts[] = {
+	{ OPT_fma_libc, "fma-libc", TYPE_ID_BOOL, 0, 1, NULL },
+	END_OPT,
 };
 
-stressor_info_t stress_fma_info = {
+const stressor_info_t stress_fma_info = {
 	.stressor = stress_fma,
-	.class = CLASS_CPU | CLASS_COMPUTE,
-	.opt_set_funcs = opt_set_funcs,
+	.class = CLASS_CPU | CLASS_FP | CLASS_COMPUTE,
+	.opts = opts,
 	.verify = VERIFY_OPTIONAL,
 	.help = help
 };
