@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -77,7 +77,7 @@ static stress_forkheavy_t *stress_forkheavy_new(void)
 		forkheavy_list.free = new->next;
 		new->next = NULL;
 	} else {
-		new = malloc(sizeof(*new));
+		new = (stress_forkheavy_t *)malloc(sizeof(*new));
 		if (!new)
 			return NULL;
 	}
@@ -246,7 +246,7 @@ static int stress_forkheavy(stress_args_t *args)
 	(void)shim_memset(&forkheavy_args, 0, sizeof(forkheavy_args));
 	forkheavy_args.pipe_size = stress_probe_max_pipe_size();
 	forkheavy_args.num_resources = DEFAULT_FORKHEAVY_ALLOCS;
-	forkheavy_args.resources = malloc(forkheavy_args.num_resources * sizeof(*forkheavy_args.resources));
+	forkheavy_args.resources = (stress_resources_t *)malloc(forkheavy_args.num_resources * sizeof(*forkheavy_args.resources));
 	if (!forkheavy_args.resources) {
 		pr_inf_skip("%s: cannot allocate %zd resource structures, skipping stressor\n",
 			args->name, forkheavy_args.num_resources);
@@ -264,10 +264,8 @@ static int stress_forkheavy(stress_args_t *args)
 		return EXIT_NO_RESOURCE;
 	}
 	stress_set_vma_anon_name(metrics, sizeof(*metrics), "metrics");
+	stress_zero_metrics(metrics, 1);
 	metrics->lock = stress_lock_create("metrics");
-	metrics->duration = 0.0;
-	metrics->count = 0.0;
-	metrics->t_start = 0.0;
 
 	forkheavy_args.metrics = metrics;
 
