@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023-2024 Colin Ian King
+ * Copyright (C) 2023-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,6 +19,7 @@
 #include "stress-ng.h"
 #include "core-arch.h"
 #include "core-attribute.h"
+#include "core-builtin.h"
 #include "core-madvise.h"
 #include "core-put.h"
 #include "core-target-clones.h"
@@ -42,7 +43,9 @@
 #define STRESS_FP_TYPE_FLOAT64		(6)
 #define STRESS_FP_TYPE_FLOAT80		(7)
 #define STRESS_FP_TYPE_FLOAT128		(8)
-#define STRESS_FP_TYPE_ALL		(9)
+#define STRESS_FP_TYPE_IBM128		(9)
+#define STRESS_FP_TYPE_BF16		(10)
+#define STRESS_FP_TYPE_ALL		(11)
 
 static const stress_help_t help[] = {
 	{ NULL,	"fp N",	 	"start N workers performing floating point math ops" },
@@ -76,6 +79,16 @@ typedef struct {
 		float mul;		/* value to multiply */
 		float mul_rev;		/* value to multiply to revert back */
 	} f;
+#if defined(HAVE__bf16)
+	struct {
+		__bf16 r_init;		/* initialization value for r */
+		__bf16 r[2];		/* result of computation */
+		__bf16 add;		/* value to add */
+		__bf16 add_rev;		/* value to add to revert back */
+		__bf16 mul;		/* value to multiply */
+		__bf16 mul_rev;		/* value to multiply to revert back */
+	} bf16;
+#endif
 #if defined(HAVE_Float16)
 	struct {
 		_Float16 r_init;	/* initialization value for r */
@@ -134,7 +147,16 @@ typedef struct {
 		_Float128 mul;		/* value to multiply */
 		_Float128 mul_rev;	/* value to multiply to revert back */
 	} f128;
-
+#endif
+#if defined(HAVE__ibm128)
+	struct {
+		__ibm128 r_init;	/* initialization value for r */
+		__ibm128 r[2];	/* result of computation */
+		__ibm128 add;		/* value to add */
+		__ibm128 add_rev;	/* value to add to revert back */
+		__ibm128 mul;		/* value to multiply */
+		__ibm128 mul_rev;	/* value to multiply to revert back */
+	} ibm128;
 #endif
 } fp_data_t;
 
@@ -243,7 +265,7 @@ static double TARGET_CLONES OPTIMIZE3 name(				\
 	}								\
 									\
 	t1 = stress_time_now();						\
-	for (i = 0; stress_continue_flag() && (i < loops); i++) {	\
+	for (i = 0; LIKELY(stress_continue_flag() && (i < loops)); i++) {\
 		fp_data[0].field.r[idx] /= fp_data[0].field.mul;	\
 		fp_data[0].field.r[idx] /= fp_data[0].field.mul_rev;	\
 		fp_data[1].field.r[idx] /= fp_data[1].field.mul;	\
@@ -280,6 +302,12 @@ STRESS_FP_ADD(f, stress_fp_float_add, true)
 STRESS_FP_MUL(f, stress_fp_float_mul, true)
 STRESS_FP_DIV(f, stress_fp_float_div, true)
 
+#if defined(HAVE__bf16)
+STRESS_FP_ADD(bf16, stress_fp_bf16_add, false)
+STRESS_FP_MUL(bf16, stress_fp_bf16_mul, false)
+STRESS_FP_DIV(bf16, stress_fp_bf16_div, false)
+#endif
+
 #if defined(HAVE_Float16)
 STRESS_FP_ADD(f16, stress_fp_float16_add, false)
 STRESS_FP_MUL(f16, stress_fp_float16_mul, false)
@@ -311,6 +339,12 @@ STRESS_FP_MUL(f128, stress_fp_float128_mul, false)
 STRESS_FP_DIV(f128, stress_fp_float128_div, false)
 #endif
 
+#if defined(HAVE__ibm128)
+STRESS_FP_ADD(ibm128, stress_fp_ibm128_add, false)
+STRESS_FP_MUL(ibm128, stress_fp_ibm128_mul, false)
+STRESS_FP_DIV(ibm128, stress_fp_ibm128_div, false)
+#endif
+
 typedef struct {
 	const char *name;
 	const char *description;
@@ -327,6 +361,9 @@ static stress_fp_funcs_t stress_fp_funcs[] = {
     defined(HAVE_Float128)
 	{ "float128add",	"float128 add",		stress_fp_float128_add,	STRESS_FP_TYPE_FLOAT128,	0.0, 0.0 },
 #endif
+#if defined(HAVE__ibm128)
+	{ "ibm128add",		"ibm128 add",		stress_fp_ibm128_add,	STRESS_FP_TYPE_IBM128,		0.0, 0.0 },
+#endif
 #if defined(HAVE__float80)
 	{ "float80add",		"float80 add",		stress_fp_float80_add,	STRESS_FP_TYPE_FLOAT80,		0.0, 0.0 },
 #endif
@@ -336,6 +373,9 @@ static stress_fp_funcs_t stress_fp_funcs[] = {
 #if defined(HAVE_Float32)
 	{ "float32add",		"float32 add",		stress_fp_float32_add,	STRESS_FP_TYPE_FLOAT32,		0.0, 0.0 },
 #endif
+#if defined(HAVE__bf16)
+	{ "bf16add",		"bf16 add",		stress_fp_bf16_add,	STRESS_FP_TYPE_BF16,		0.0, 0.0 },
+#endif
 #if defined(HAVE_Float16)
 	{ "float16add",		"float16 add",		stress_fp_float16_add,	STRESS_FP_TYPE_FLOAT16,		0.0, 0.0 },
 #endif
@@ -347,6 +387,9 @@ static stress_fp_funcs_t stress_fp_funcs[] = {
     defined(HAVE_Float128)
 	{ "float128mul",	"float128 multiply",	stress_fp_float128_mul,	STRESS_FP_TYPE_FLOAT128,	0.0, 0.0 },
 #endif
+#if defined(HAVE__ibm128)
+	{ "ibm128mul",		"ibm128 multiply",	stress_fp_ibm128_mul,	STRESS_FP_TYPE_IBM128,		0.0, 0.0 },
+#endif
 #if defined(HAVE__float80)
 	{ "float80mul",		"float80 multiply",	stress_fp_float80_mul,	STRESS_FP_TYPE_FLOAT80,		0.0, 0.0 },
 #endif
@@ -356,6 +399,9 @@ static stress_fp_funcs_t stress_fp_funcs[] = {
 #if defined(HAVE_Float32)
 	{ "float32mul",		"float32 multiply",	stress_fp_float32_mul,	STRESS_FP_TYPE_FLOAT32,		0.0, 0.0 },
 #endif
+#if defined(HAVE__bf16)
+	{ "bf16mul",		"bf16 multiply",	stress_fp_bf16_mul,	STRESS_FP_TYPE_BF16,		0.0, 0.0 },
+#endif
 #if defined(HAVE_Float16)
 	{ "float16mul",		"float16 multiply",	stress_fp_float16_mul,	STRESS_FP_TYPE_FLOAT16,		0.0, 0.0 },
 #endif
@@ -367,6 +413,9 @@ static stress_fp_funcs_t stress_fp_funcs[] = {
     defined(HAVE_Float128)
 	{ "float128div",	"float128 divide",	stress_fp_float128_div,	STRESS_FP_TYPE_FLOAT128,	0.0, 0.0 },
 #endif
+#if defined(HAVE__ibm128)
+	{ "ibm128div",		"ibm128 divide",	stress_fp_ibm128_div,	STRESS_FP_TYPE_IBM128,		0.0, 0.0 },
+#endif
 #if defined(HAVE__float80)
 	{ "float80div",		"float80 divide",	stress_fp_float80_div,	STRESS_FP_TYPE_FLOAT80,		0.0, 0.0 },
 #endif
@@ -376,6 +425,9 @@ static stress_fp_funcs_t stress_fp_funcs[] = {
 #if defined(HAVE_Float32)
 	{ "float32div",		"float32 divide",	stress_fp_float32_div,	STRESS_FP_TYPE_FLOAT32,		0.0, 0.0 },
 #endif
+#if defined(HAVE__bf16)
+	{ "bf16div",		"bf16 divide",		stress_fp_bf16_div,	STRESS_FP_TYPE_BF16,		0.0, 0.0 },
+#endif
 #if defined(HAVE_Float16)
 	{ "float16div",		"float16 divide",	stress_fp_float16_div,	STRESS_FP_TYPE_FLOAT16,		0.0, 0.0 },
 #endif
@@ -395,6 +447,7 @@ static const fp_type_map_t fp_type_map[] = {
 	{ STRESS_FP_TYPE_LONG_DOUBLE,	"long double" },
 	{ STRESS_FP_TYPE_DOUBLE,	"double" },
 	{ STRESS_FP_TYPE_FLOAT,		"float" },
+	{ STRESS_FP_TYPE_BF16,		"bf16" },
 	{ STRESS_FP_TYPE_FLOAT16,	"float16" },
 	{ STRESS_FP_TYPE_FLOAT32,	"float32" },
 	{ STRESS_FP_TYPE_FLOAT64,	"float64" },
@@ -444,7 +497,7 @@ static int stress_fp_call_method(
 		 *  cause long doubles on some arches to abort early, so
 		 *  don't verify these results
 		 */
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			return EXIT_SUCCESS;
 
 		for (i = 0; i < FP_ELEMENTS; i++) {
@@ -453,37 +506,37 @@ static int stress_fp_call_method(
 
 			switch (fp_type) {
 			case STRESS_FP_TYPE_LONG_DOUBLE:
-				ret = memcmp(&fp_data[i].ld.r[0], &fp_data[i].ld.r[1], sizeof(fp_data[i].ld.r[0]));
+				ret = shim_memcmp(&fp_data[i].ld.r[0], &fp_data[i].ld.r[1], sizeof(fp_data[i].ld.r[0]));
 				r0 = (long double)fp_data[i].ld.r[0];
 				r1 = (long double)fp_data[i].ld.r[1];
 				break;
 			case STRESS_FP_TYPE_DOUBLE:
-				ret = memcmp(&fp_data[i].d.r[0], &fp_data[i].d.r[1], sizeof(fp_data[i].d.r[0]));
+				ret = shim_memcmp(&fp_data[i].d.r[0], &fp_data[i].d.r[1], sizeof(fp_data[i].d.r[0]));
 				r0 = (long double)fp_data[i].d.r[0];
 				r1 = (long double)fp_data[i].d.r[1];
 				break;
 			case STRESS_FP_TYPE_FLOAT:
-				ret = memcmp(&fp_data[i].f.r[0], &fp_data[i].f.r[1], sizeof(fp_data[i].f.r[0]));
+				ret = shim_memcmp(&fp_data[i].f.r[0], &fp_data[i].f.r[1], sizeof(fp_data[i].f.r[0]));
 				r0 = (long double)fp_data[i].f.r[0];
 				r1 = (long double)fp_data[i].f.r[1];
 				break;
 #if defined(HAVE_Float32)
 			case STRESS_FP_TYPE_FLOAT32:
-				ret = memcmp(&fp_data[i].f32.r[0], &fp_data[i].f32.r[1], sizeof(fp_data[i].f32.r[0]));
+				ret = shim_memcmp(&fp_data[i].f32.r[0], &fp_data[i].f32.r[1], sizeof(fp_data[i].f32.r[0]));
 				r0 = (long double)fp_data[i].f32.r[0];
 				r1 = (long double)fp_data[i].f32.r[1];
 				break;
 #endif
 #if defined(HAVE_Float64)
 			case STRESS_FP_TYPE_FLOAT64:
-				ret = memcmp(&fp_data[i].f64.r[0], &fp_data[i].f64.r[1], sizeof(fp_data[i].f64.r[0]));
+				ret = shim_memcmp(&fp_data[i].f64.r[0], &fp_data[i].f64.r[1], sizeof(fp_data[i].f64.r[0]));
 				r0 = (long double)fp_data[i].f64.r[0];
 				r1 = (long double)fp_data[i].f64.r[1];
 				break;
 #endif
 #if defined(HAVE__float80)
 			case STRESS_FP_TYPE_FLOAT80:
-				ret = memcmp(&fp_data[i].f80.r[0], &fp_data[i].f80.r[1], sizeof(fp_data[i].f80.r[0]));
+				ret = shim_memcmp(&fp_data[i].f80.r[0], &fp_data[i].f80.r[1], sizeof(fp_data[i].f80.r[0]));
 				r0 = (long double)fp_data[i].f80.r[0];
 				r1 = (long double)fp_data[i].f80.r[1];
 				break;
@@ -491,7 +544,7 @@ static int stress_fp_call_method(
 #if defined(HAVE__float128) ||	\
     defined(HAVE_Float128)
 			case STRESS_FP_TYPE_FLOAT128:
-				ret = memcmp(&fp_data[i].f128.r[0], &fp_data[i].f128.r[1], sizeof(fp_data[i].f128.r[0]));
+				ret = shim_memcmp(&fp_data[i].f128.r[0], &fp_data[i].f128.r[1], sizeof(fp_data[i].f128.r[0]));
 				r0 = (long double)fp_data[i].f128.r[0];
 				r1 = (long double)fp_data[i].f128.r[1];
 				break;
@@ -572,6 +625,12 @@ static int stress_fp(stress_args_t *args)
 		fp_data[i].f.r[0] = (float)ld;
 		fp_data[i].f.r[1] = (float)ld;
 
+#if defined(HAVE__bf16)
+		fp_data[i].bf16.r_init = (__bf16)ld;
+		fp_data[i].bf16.r[0] = (__bf16)ld;
+		fp_data[i].bf16.r[1] = (__bf16)ld;
+#endif
+
 #if defined(HAVE_Float16)
 		fp_data[i].f16.r_init = (_Float16)ld;
 		fp_data[i].f16.r[0] = (_Float16)ld;
@@ -611,6 +670,9 @@ static int stress_fp(stress_args_t *args)
 		fp_data[i].ld.add = ld;
 		fp_data[i].d.add = (double)ld;
 		fp_data[i].f.add = (float)ld;
+#if defined(HAVE__bf16)
+		fp_data[i].bf16.add = (__bf16)ld;
+#endif
 #if defined(HAVE_Float16)
 		fp_data[i].f16.add = (_Float16)ld;
 #endif
@@ -633,6 +695,9 @@ static int stress_fp(stress_args_t *args)
 		fp_data[i].ld.add_rev = ld;
 		fp_data[i].d.add_rev = (double)ld;
 		fp_data[i].f.add_rev = (float)ld;
+#if defined(HAVE__bf16)
+		fp_data[i].bf16.add_rev = (__bf16)ld;
+#endif
 #if defined(HAVE_Float16)
 		fp_data[i].f16.add_rev = (_Float16)ld;
 #endif
@@ -656,6 +721,9 @@ static int stress_fp(stress_args_t *args)
 		fp_data[i].ld.mul = ld;
 		fp_data[i].d.mul = (double)ld;
 		fp_data[i].f.mul = (float)ld;
+#if defined(HAVE__bf16)
+		fp_data[i].bf16.mul = (__bf16)ld;
+#endif
 #if defined(HAVE_Float16)
 		fp_data[i].f16.mul = (_Float16)ld;
 #endif
