@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2023 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -79,8 +79,8 @@ static bool stress_fsize_reported(const off_t offset, const uint8_t type)
  *	set RLIMIT_FSIZE on offset, test file size up to
  *	offset -1  + size and equal to offset + size
  */
-static void stress_fsize_boundary(
-	const stress_args_t *args,
+static int stress_fsize_boundary(
+	stress_args_t *args,
 	const int fd,
 	const struct rlimit *old_rlim,
 	const off_t offset,
@@ -88,19 +88,19 @@ static void stress_fsize_boundary(
 {
 	struct rlimit new_rlim;
 	off_t off;
-	int ret;
+	int ret, rc = EXIT_SUCCESS;
 
 	if ((rlim_t)offset >= old_rlim->rlim_max)
-		return;
+		return rc;
 	if (offset < 1)
-		return;
+		return rc;
 
 	off = (off_t)old_rlim->rlim_max;
 	new_rlim.rlim_max = off;
 	new_rlim.rlim_cur = offset;
 
 	if (setrlimit(RLIMIT_FSIZE, &new_rlim) < 0) {
-		pr_fail("%s: failed to set RLIMIT_FSIZE to %jd (0x%jx), errno=%d (%s)\n",
+		pr_fail("%s: failed to set RLIMIT_FSIZE to %" PRIdMAX " (0x%" PRIxMAX "), errno=%d (%s)\n",
 			args->name, (intmax_t)new_rlim.rlim_cur, (intmax_t)new_rlim.rlim_cur,
 			errno, strerror(errno));
 	}
@@ -110,39 +110,52 @@ static void stress_fsize_boundary(
 	ret = shim_fallocate(fd, 0, off, size);
 	if (ret < 0) {
 		if ((errno != EFBIG) && (errno != ENOSPC) && (errno != EINTR)) {
-			pr_fail("%s: fallocate failed at offset %jd (0x%jx) with unexpected error: %d (%s)\n",
+			pr_fail("%s: fallocate failed at offset %" PRIdMAX" (0x%" PRIxMAX ") with unexpected error: %d (%s)\n",
 				args->name, (intmax_t)off, (intmax_t)off,
 				errno, strerror(errno));
+			rc = EXIT_FAILURE;
 		}
-		return;
+		return rc;
 	}
-	if (sigxfsz)
-		pr_fail("%s: got an unexpected SIGXFSZ signal at offset %jd (0x%jx)\n",
+	if (sigxfsz) {
+		pr_fail("%s: got an unexpected SIGXFSZ signal at offset %" PRIdMAX " (0x%" PRIxMAX ")\n",
 			args->name, (intmax_t)off, (intmax_t)off);
+		return EXIT_FAILURE;
+	}
+	/* We should be able to fruncate a file to zero bytes */
+	if (ftruncate(fd, 0) < 0) {
+		pr_inf("%s: truncating file to zero bytes failed, errno=%d (%s)\n",
+			args->name, errno, strerror(errno));
+		return EXIT_FAILURE;
+	}
 
 	sigxfsz = false;
 	off = (off_t)new_rlim.rlim_cur;
 	ret = shim_fallocate(fd, 0, off, size);
 	if (ret == 0) {
 		if (!stress_fsize_reported(off, FSIZE_TYPE_FALLOC)) {
-			pr_inf("%s: fallocate unexpectedly succeeded at offset %jd (0x%jx), expecting EFBIG error\n",
+			pr_inf("%s: fallocate unexpectedly succeeded at offset %" PRIdMAX " (0x%" PRIxMAX "), expecting EFBIG error\n",
 				args->name, (intmax_t)off, (intmax_t)off);
+			return EXIT_FAILURE;
 		}
-		return;
+		return rc;
 	} else if ((errno != EFBIG) && (errno != ENOSPC) && (errno != EINTR)) {
-		pr_fail("%s: fallocate failed at offset %jd (0x%jx) with unexpected error: %d (%s)\n",
+		pr_fail("%s: fallocate failed at offset %" PRIdMAX" (0x%" PRIxMAX ") with unexpected error: %d (%s)\n",
 			args->name, (intmax_t)off, (intmax_t)off,
 			errno, strerror(errno));
-		return;
+		return EXIT_FAILURE;
 	}
-	if (!sigxfsz && !stress_fsize_reported(off, FSIZE_TYPE_SIGXFSZ))
-		pr_inf("%s: did not get expected SIGXFSZ signal at offset %jd (0x%jx)\n",
+	if (!sigxfsz && !stress_fsize_reported(off, FSIZE_TYPE_SIGXFSZ)) {
+		pr_inf("%s: did not get expected SIGXFSZ signal at offset %" PRIdMAX " (0x%" PRIxMAX ")\n",
 			args->name, (intmax_t)off, (intmax_t)off);
+		return EXIT_FAILURE;
+	}
+	return rc;
 }
 
 /*
  *  stress_fsize_max_off_t()
- *	detemine max off_t, we can't rely on a POSIXly defined
+ *	determine max off_t, we can't rely on a POSIXly defined
  *	macro for this, so determine it by the naive method
  */
 static off_t stress_fsize_max_off_t(void)
@@ -160,12 +173,11 @@ static off_t stress_fsize_max_off_t(void)
  *  stress_fsize
  *	stress file size limits
  */
-static int stress_fsize(const stress_args_t *args)
+static int stress_fsize(stress_args_t *args)
 {
 	char filename[PATH_MAX];
 	int fd, ret, rc = EXIT_SUCCESS;
 	struct rlimit old_rlim;
-	off_t offset;
 	rlim_t max;
 	const off_t max_offset = stress_fsize_max_off_t();
 	double t, duration, rate;
@@ -194,18 +206,23 @@ static int stress_fsize(const stress_args_t *args)
 	}
 	(void)shim_unlink(filename);
 
+	stress_file_rw_hint_short(fd);
+
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
+	stress_sync_start_wait(args);
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	t = stress_time_now();
 	max = STRESS_MINIMUM(old_rlim.rlim_max, 1024 * 256);
 	do {
 		struct rlimit new_rlim;
+		off_t offset;
 
 		new_rlim.rlim_cur = max;
 		new_rlim.rlim_max = old_rlim.rlim_max;
 
 		if (setrlimit(RLIMIT_FSIZE, &new_rlim) < 0) {
-			pr_fail("%s: failed to set RLIMIT_FSIZE to %jd (0x%jx), errno=%d (%s)\n",
+			pr_fail("%s: failed to set RLIMIT_FSIZE to %" PRIdMAX " (0x%" PRIxMAX "), errno=%d (%s)\n",
 				args->name, (intmax_t)max, (intmax_t)max, errno, strerror(errno));
 		}
 
@@ -223,13 +240,13 @@ static int stress_fsize(const stress_args_t *args)
 		if (shim_fallocate(fd, 0, 0, (off_t)max) < 0) {
 			if ((errno == ENOSPC) || (errno == EINTR)) {
 				/* No resource */
-				pr_inf_skip("%s: allocating file to %jd (0x%jx) bytes failed, errno=%d (%s), "
+				pr_inf_skip("%s: allocating file to %" PRIdMAX " (0x%" PRIxMAX ") bytes failed, errno=%d (%s), "
 					"skipping stressor\n", args->name, (intmax_t)max, (intmax_t)max,
 					errno, strerror(errno));
 				rc = EXIT_NO_RESOURCE;
 			} else {
 				/* A real issue, report it */
-				pr_inf("%s: allocating file to %jd bytes (0x%jx) failed, errno=%d (%s), "
+				pr_inf("%s: allocating file to %" PRIdMAX " bytes (0x%" PRIxMAX ") failed, errno=%d (%s), "
 					"terminating stressor\n", args->name, (intmax_t)max, (intmax_t)max,
 					errno, strerror(errno));
 				rc = EXIT_FAILURE;
@@ -238,15 +255,19 @@ static int stress_fsize(const stress_args_t *args)
 		}
 		sigxfsz = false;
 		if (shim_fallocate(fd, 0, (off_t)max, 4096) == 0) {
-			pr_fail("%s: fallocate unexpectedly succeeded at offset %jd (0x%jx), expecting EFBIG error\n",
+			pr_fail("%s: fallocate unexpectedly succeeded at offset %" PRIdMAX " (0x%" PRIxMAX "), expecting EFBIG error\n",
 				args->name, (intmax_t)max, (intmax_t)max);
+			rc = EXIT_FAILURE;
 		} else if ((errno != EFBIG) && (errno != ENOSPC) && (errno != EINTR)) {
-			pr_fail("%s: failed at offset %jd (0x%jx) with unexpected error: %d (%s)\n",
+			pr_fail("%s: failed at offset %" PRIdMAX " (0x%" PRIxMAX ") with unexpected error: %d (%s)\n",
 				args->name, (intmax_t)max, (intmax_t)max, errno, strerror(errno) );
+			rc = EXIT_FAILURE;
 		}
-		if (!sigxfsz)
-			pr_fail("%s: expected a SIGXFSZ signal at offset %jd (0x%jx), nothing happened\n",
+		if (!sigxfsz) {
+			pr_fail("%s: expected a SIGXFSZ signal at offset %" PRIdMAX " (0x%" PRIxMAX "), nothing happened\n",
 				args->name, (intmax_t)max, (intmax_t)max);
+			rc = EXIT_FAILURE;
+		}
 
 		/*
 		 *  Test #2, test for allocation 0..offset and file offset..max
@@ -260,34 +281,43 @@ static int stress_fsize(const stress_args_t *args)
 			rc = EXIT_FAILURE;
 			break;
 		}
-		stress_fsize_boundary(args, fd, &old_rlim, offset, max - offset);
+		if (stress_fsize_boundary(args, fd, &old_rlim, offset, max - offset) == EXIT_FAILURE) {
+			rc = EXIT_FAILURE;
+			break;
+		}
 
 		/* Should be able to set back to original size */
 		new_rlim = old_rlim;
 		if (setrlimit(RLIMIT_FSIZE, &new_rlim) < 0) {
-			pr_fail("%s: failed to set RLIMIT_FSIZE to %jd (0x%jx), errno=%d (%s)\n",
+			pr_fail("%s: failed to set RLIMIT_FSIZE to %" PRIdMAX " (0x%" PRIxMAX "), errno=%d (%s)\n",
 				args->name, (intmax_t)new_rlim.rlim_cur, (intmax_t)new_rlim.rlim_cur,
 				errno, strerror(errno));
+			rc = EXIT_FAILURE;
 		}
 
 		/*
 		 *  Test #3, work through all off_t sizes in powers of 2 - 1
 		 */
-		if (ftruncate(fd, 0) < 0) {
-			pr_inf("%s: truncating file to zero bytes failed, errno=%d (%s)\n",
-				args->name, errno, strerror(errno));
-			rc = EXIT_FAILURE;
-			break;
-		}
 		for (offset = 1; offset < max_offset; offset = (offset << 1 | 1)) {
-			stress_fsize_boundary(args, fd, &old_rlim, offset, 1);
+			if (ftruncate(fd, 0) < 0) {
+				pr_inf("%s: truncating file to zero bytes failed, errno=%d (%s)\n",
+					args->name, errno, strerror(errno));
+				rc = EXIT_FAILURE;
+				goto err;
+			}
+			if (stress_fsize_boundary(args, fd, &old_rlim, offset, 1) == EXIT_FAILURE) {
+				rc = EXIT_FAILURE;
+				goto err;
+			}
 		}
-		inc_counter(args);
-	} while (keep_stressing(args));
+		stress_bogo_inc(args);
+	} while (stress_continue(args));
 
+err:
 	duration = stress_time_now() - t;
 	rate = (duration > 0.0) ? (double)sigxfsz_count / duration : 0.0;
-	stress_metrics_set(args, 0, "SIGXFSZ signals per sec", rate);
+	stress_metrics_set(args, 0, "SIGXFSZ signals per sec",
+		rate, STRESS_METRIC_HARMONIC_MEAN);
 
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 	if (fd != -1)
@@ -297,15 +327,17 @@ static int stress_fsize(const stress_args_t *args)
 	return rc;
 }
 
-stressor_info_t stress_fsize_info = {
+const stressor_info_t stress_fsize_info = {
 	.stressor = stress_fsize,
 	.class = CLASS_FILESYSTEM | CLASS_OS,
+	.verify = VERIFY_ALWAYS,
 	.help = help
 };
 #else
-stressor_info_t stress_fsize_info = {
+const stressor_info_t stress_fsize_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_FILESYSTEM | CLASS_OS,
+	.verify = VERIFY_ALWAYS,
 	.help = help,
 	.unimplemented_reason = "built without fallocate(), RLIMIT_FSIZE or SIGXFSZ"
 };
