@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,6 +23,7 @@
 #include "core-mounts.h"
 
 #include <math.h>
+#include <time.h>
 
 #if defined(HAVE_LINUX_SYSCTL_H)
 #include <linux/sysctl.h>
@@ -82,11 +83,6 @@ static const stress_help_t help[] = {
 	{ NULL, NULL,			NULL }
 };
 
-static int stress_set_get_slow_sync(const char *opt)
-{
-        return stress_set_setting_true("get-slow-sync", opt);
-}
-
 static const stress_rusage_t rusages[] = {
 #if defined(RUSAGE_SELF)
 	{ RUSAGE_SELF, 		"RUSAGE_SELF",		true },
@@ -216,7 +212,7 @@ static int stress_getdomainname(stress_args_t *args)
 static int stress_gethostid(stress_args_t *args)
 {
 #if defined(HAVE_GETHOSTID)
-	VOID_RET(long, gethostid());
+	VOID_RET(long int, gethostid());
 #endif
 	(void)args;
 
@@ -235,6 +231,16 @@ static int stress_gethostname(stress_args_t *args)
 	return EXIT_SUCCESS;
 }
 
+static int stress_getlogin(stress_args_t *args)
+{
+#if defined(HAVE_GETLOGIN)
+	VOID_RET(char *, getlogin());
+#endif
+	(void)args;
+
+	return EXIT_SUCCESS;
+}
+
 static int stress_getcwd(stress_args_t *args)
 {
 	char *ptr;
@@ -324,7 +330,7 @@ static int stress_getgroups(stress_args_t *args)
 	 *  valgrind happy.
 	 */
 	(void)shim_memset(gids, 0, sizeof(gids));
-	VOID_RET(long, syscall(__NR_getgroups, -1, gids));
+	VOID_RET(long int, syscall(__NR_getgroups, -1, gids));
 #endif
 
 	return EXIT_SUCCESS;
@@ -1011,15 +1017,14 @@ static int stress_get(stress_args_t *args)
 	mypid = getpid();
 	verify = !!(g_opt_flags & OPT_FLAGS_VERIFY);
 
-	stress_set_proc_state(args->name, STRESS_STATE_RUN);
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
+	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	i = 0;
 
+
 	do {
-#if defined(HAVE_SYS_TIMEX_H) &&	\
-    defined(HAVE_ADJTIME)
-#endif
 		if (get_slow_sync) {
 			i = (size_t)(round(stress_time_now() * 10.0)) % SIZEOF_ARRAY(stress_get_funcs);
 		} else {
@@ -1031,6 +1036,9 @@ static int stress_get(stress_args_t *args)
 		stress_bogo_inc(args);
 	} while (stress_continue(args));
 
+	/* getlogin can re-set alarm(), so exercise it once at end */
+	stress_getlogin(args);
+
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 
 	stress_mount_free(mnts, mounts_max);
@@ -1038,15 +1046,15 @@ static int stress_get(stress_args_t *args)
 	return rc;
 }
 
-static const stress_opt_set_func_t opt_set_funcs[] = {
-	{ OPT_get_slow_sync,	stress_set_get_slow_sync },
-	{ 0,			NULL },
+static const stress_opt_t opts[] = {
+	{ OPT_get_slow_sync, "get-slow-sync", TYPE_ID_BOOL, 0, 1, NULL },
+	END_OPT,
 };
 
-stressor_info_t stress_get_info = {
+const stressor_info_t stress_get_info = {
 	.stressor = stress_get,
 	.class = CLASS_OS,
 	.verify = VERIFY_OPTIONAL,
-	.opt_set_funcs = opt_set_funcs,
+	.opts = opts,
 	.help = help
 };
