@@ -126,7 +126,7 @@ static int stress_getdents_dir(
 	unsigned int buf_sz;
 	const size_t page_size = args->page_size;
 
-	if (!stress_continue(args))
+	if (UNLIKELY(!stress_continue(args)))
 		return 0;
 
 	fd = open(path, O_RDONLY | O_DIRECTORY);
@@ -150,7 +150,7 @@ static int stress_getdents_dir(
 
 	do {
 		struct shim_linux_dirent *ptr = buf;
-		struct shim_linux_dirent *end;
+		const struct shim_linux_dirent *end;
 		double t;
 
 		t = stress_time_now();
@@ -214,7 +214,7 @@ static int stress_getdents64_dir(
 	unsigned int buf_sz;
 	const size_t page_size = args->page_size;
 
-	if (!stress_continue(args))
+	if (UNLIKELY(!stress_continue(args)))
 		return 0;
 
 	fd = open(path, O_RDONLY | O_DIRECTORY);
@@ -233,7 +233,7 @@ static int stress_getdents64_dir(
 
 	do {
 		struct shim_linux_dirent64 *ptr = (struct shim_linux_dirent64 *)buf;
-		struct shim_linux_dirent64 *end;
+		const struct shim_linux_dirent64 *end;
 		int nread;
 		double t;
 
