@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2022-2024, Red Hat Inc, Dorinda Bassey <dbassey@redhat.com>
- * Copyright (C) 2022-2024 Colin Ian King
+ * Copyright (C) 2022-2025, Red Hat Inc, Dorinda Bassey <dbassey@redhat.com>
+ * Copyright (C) 2022-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -50,7 +50,7 @@ static const stress_help_t help[] = {
 static const stress_opt_t opts[] = {
 	{ OPT_gpu_devnode, "gpu-devnode",  TYPE_ID_STR,    0, 0,        NULL },
 	{ OPT_gpu_frag,    "gpu-frag",     TYPE_ID_INT32,  1, INT_MAX,  NULL },
-	{ OPT_gpu_uploads, "gpu-uploads",  TYPE_ID_INT32,  1, INT_MAX,  NULL },
+	{ OPT_gpu_upload,  "gpu-upload",   TYPE_ID_INT32,  1, INT_MAX,  NULL },
 	{ OPT_gpu_size,    "gpu-tex-size", TYPE_ID_INT32,  1, INT_MAX,  NULL },
 	{ OPT_gpu_xsize,   "gpu-xsize",    TYPE_ID_UINT32, 1, UINT_MAX, NULL },
 	{ OPT_gpu_ysize,   "gpu-ysize",    TYPE_ID_UINT32, 1, UINT_MAX, NULL },
@@ -139,7 +139,7 @@ static GLuint compile_shader(
 		if (infoLen > 1) {
 			char *infoLog;
 
-			infoLog = malloc((size_t)infoLen);
+			infoLog = (char *)malloc((size_t)infoLen);
 			if (!infoLog) {
 				pr_inf_skip("%s: failed to allocate infoLog, skipping stressor\n", args->name);
 				glDeleteShader(shader);
@@ -194,7 +194,7 @@ static int load_shaders(stress_args_t *args)
 		if (infoLen > 1) {
 			char *infoLog;
 
-			infoLog = malloc((size_t)infoLen);
+			infoLog = (char *)malloc((size_t)infoLen);
 			if (!infoLog) {
 				pr_inf_skip("%s: failed to allocate infoLog, skipping stressor\n", name);
 				glDeleteProgram(program);
@@ -290,7 +290,7 @@ static int gles2_init(
 		glBindTexture(GL_TEXTURE_2D, texobj);
 
 		bytesPerImage = texsize * texsize * 4;
-		teximage = malloc((size_t)bytesPerImage);
+		teximage = (GLubyte *)malloc((size_t)bytesPerImage);
 		if (!teximage) {
 			pr_inf_skip("%s: failed to allocate teximage, skipping stressor\n", args->name);
 			return EXIT_NO_RESOURCE;
@@ -303,7 +303,7 @@ static void stress_gpu_run(const GLsizei texsize, const GLsizei uploads)
 {
 	if (texsize > 0) {
 		int i;
-		for (i = 0; stress_continue_flag() && (i < uploads); i++) {
+		for (i = 0; LIKELY(stress_continue_flag() && (i < uploads)); i++) {
 			glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, texsize,
 				     texsize, 0, GL_RGBA, GL_UNSIGNED_BYTE,
 				     teximage);
@@ -335,7 +335,7 @@ static int get_config(stress_args_t *args, EGLConfig *config)
 	}
 
 	/* Use calloc to avoid multiplication overflow */
-	configs = calloc((size_t)num_configs, sizeof(EGLConfig));
+	configs = (EGLConfig *)calloc((size_t)num_configs, sizeof(EGLConfig));
 	if (!configs) {
 		pr_inf_skip("%s: EGL: EGL allocation failed, skipping stressor\n", args->name);
 		return EXIT_NO_RESOURCE;
@@ -486,7 +486,7 @@ static void *stress_gpu_pthread(void *arg)
 	uint64_t sleep_usecs = 100000UL * (uint64_t)args->num_instances;
 	uint64_t start_sleep_usecs = 100000UL * (uint64_t)args->instance;
 
-	shim_usleep(start_sleep_usecs);
+	(void)shim_usleep(start_sleep_usecs);
 	while (stress_continue(args)) {
 		double freq_mhz;
 
@@ -496,7 +496,7 @@ static void *stress_gpu_pthread(void *arg)
 			gpu_freq_sum += freq_mhz;
 			gpu_freq_count++;
 		}
-		shim_usleep(sleep_usecs);
+		(void)shim_usleep(sleep_usecs);
 	}
 	return NULL;
 }
