@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -578,9 +578,9 @@ static void stress_hdd_opts(const char *opt_name, const char *opt_arg, stress_ty
 		}
 	}
 
-	stress_set_setting("hdd-flags", TYPE_ID_INT, &hdd_flags);
-	stress_set_setting("hdd-oflags", TYPE_ID_INT, &hdd_oflags);
-	stress_set_setting("hdd-opts-set", TYPE_ID_BOOL, &opts_set);
+	stress_set_setting("hdd", "hdd-flags", TYPE_ID_INT, &hdd_flags);
+	stress_set_setting("hdd", "hdd-oflags", TYPE_ID_INT, &hdd_oflags);
+	stress_set_setting("hdd", "hdd-opts-set", TYPE_ID_BOOL, &opts_set);
 	free(str);
 }
 
@@ -829,7 +829,7 @@ static int stress_hdd(stress_args_t *args)
 		}
 		(void)shim_unlink(filename);
 
-		if (!stress_continue(args)) {
+		if (UNLIKELY(!stress_continue(args))) {
 			(void)close(fd);
 			goto yielded;
 		}
@@ -854,7 +854,7 @@ static int stress_hdd(stress_args_t *args)
 				const uint64_t offset = (i == 0) ?
 					hdd_bytes : stress_mwc64modn(hdd_bytes) & ~511UL;
 rnd_wr_retry:
-				if (!stress_continue(args)) {
+				if (UNLIKELY(!stress_continue(args))) {
 					(void)close(fd);
 					goto yielded;
 				}
@@ -887,7 +887,7 @@ rnd_wr_retry:
 		if (hdd_flags & HDD_OPT_WR_SEQ) {
 			for (i = 0; i < hdd_bytes; i += hdd_write_size) {
 seq_wr_retry:
-				if (!stress_continue(args)) {
+				if (UNLIKELY(!stress_continue(args))) {
 					(void)close(fd);
 					goto yielded;
 				}
@@ -911,6 +911,8 @@ seq_wr_retry:
 					}
 					continue;
 				}
+				/* max size is offset + bytes written */
+				hdd_bytes_max = i + ret;
 				stress_bogo_inc(args);
 			}
 		}
@@ -928,7 +930,7 @@ seq_wr_retry:
 
 			for (i = 0; i < hdd_bytes_max; i += hdd_write_size) {
 seq_rd_retry:
-				if (!stress_continue(args)) {
+				if (UNLIKELY(!stress_continue(args))) {
 					(void)close(fd);
 					goto yielded;
 				}
@@ -1001,7 +1003,7 @@ seq_rd_retry:
 					goto finish;
 				}
 rnd_rd_retry:
-				if (!stress_continue(args)) {
+				if (UNLIKELY(!stress_continue(args))) {
 					(void)close(fd);
 					goto yielded;
 				}
