@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2021-2024 Colin Ian King.
+ * Copyright (C) 2021-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,6 +23,7 @@
 #include "core-out-of-memory.h"
 
 #include <sched.h>
+#include <time.h>
 
 static const stress_help_t help[] = {
 	{ NULL,	"hrtimers N",	  "start N workers that exercise high resolution timers" },
@@ -44,7 +45,7 @@ static uint64_t timer_counter;
 static uint64_t max_ops;
 static timer_t timerid;
 static double time_end;
-static long ns_delay;
+static long int ns_delay;
 static int overrun;
 void *lock;
 
@@ -89,7 +90,7 @@ static void MLOCKED_TEXT OPTIMIZE3 stress_hrtimers_handler(int sig)
 
 	if (UNLIKELY((timer_counter & 4095) == 0)) {
 		if (ns_delay >= 0) {
-			const long ns_adjust = ns_delay >> 2;
+			const long int ns_adjust = ns_delay >> 2;
 
 			if (timer_getoverrun(timerid)) {
 				ns_delay += ns_adjust;
@@ -153,8 +154,8 @@ static int stress_hrtimer_process(stress_args_t *args)
 	sev.sigev_signo = SIGRTMIN;
 	sev.sigev_value.sival_ptr = &timerid;
 	if (timer_create(CLOCK_REALTIME, &sev, &timerid) < 0) {
-		if ((errno == EAGAIN) || (errno == ENOMEM)) {
-			pr_inf_skip("%s: timer_create, errno=%d (%s), skipping stessor\n",
+		if ((errno == EAGAIN) || (errno == ENOMEM) || (errno == ENOTSUP)) {
+			pr_inf_skip("%s: timer_create, errno=%d (%s), skipping stressor\n",
 				args->name, errno, strerror(errno));
 			return EXIT_NO_RESOURCE;
 		}
@@ -171,7 +172,7 @@ static int stress_hrtimer_process(stress_args_t *args)
 	}
 
 	do {
-		shim_usleep(100000);
+		(void)shim_usleep(100000);
 	} while (stress_hrtimers_stress_continue());
 
 	stress_bogo_add_lock(args, lock, timer_counter);
@@ -217,7 +218,7 @@ static int stress_hrtimers(stress_args_t *args)
 	for (i = 0; i < PROCS_MAX; i++) {
 		stress_sync_start_init(&s_pids[i]);
 
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			goto reap;
 
 		s_pids[i].pid = fork();
@@ -247,7 +248,7 @@ static int stress_hrtimers(stress_args_t *args)
 
 	start_time = stress_time_now();
 	do {
-		shim_usleep(100000);
+		(void)shim_usleep(100000);
 	} while (stress_continue(args));
 
 reap:
@@ -274,7 +275,7 @@ tidy_s_pids:
 	return rc;
 }
 
-stressor_info_t stress_hrtimers_info = {
+const stressor_info_t stress_hrtimers_info = {
 	.stressor = stress_hrtimers,
 	.class = CLASS_SCHEDULER,
 	.opts = opts,
@@ -282,7 +283,7 @@ stressor_info_t stress_hrtimers_info = {
 	.help = help
 };
 #else
-stressor_info_t stress_hrtimers_info = {
+const stressor_info_t stress_hrtimers_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_SCHEDULER,
 	.opts = opts,
