@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2021-2024 Colin Ian King
+ * Copyright (C) 2021-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -151,6 +151,8 @@ static int stress_icache(stress_args_t *args)
 	void *page;
 	int ret;
 
+	stress_catch_sigsegv();
+
 	page = stress_mmap_populate(NULL, page_size,
 			PROT_READ | PROT_WRITE | PROT_EXEC,
 			MAP_ANONYMOUS | MAP_SHARED, -1, 0);
@@ -159,6 +161,7 @@ static int stress_icache(stress_args_t *args)
 			args->name, page_size);
 		return EXIT_NO_RESOURCE;
 	}
+	stress_set_vma_anon_name(page, page_size, "opcodes");
 	(void)shim_memcpy(page, &stress_ret_opcode.opcodes, stress_ret_opcode.len);
 
 	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
