@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -34,14 +34,22 @@
 static const stress_help_t help[] = {
 	{ NULL,	"icmp-flood N",		"start N ICMP packet flood workers" },
 	{ NULL,	"icmp-flood-ops N",	"stop after N ICMP bogo operations (ICMP packets)" },
+	{ NULL, "icmp-flood-max-size",	"use randomized packet sizes up to 65535 bytes" },
 	{ NULL,	NULL,			NULL }
 };
 
+static const stress_opt_t opts[] = {
+	{ OPT_icmp_flood_max_size, "icmp-flood-max-size", TYPE_ID_BOOL, 0, 1, NULL },
+	END_OPT,
+};
+
+
 #if defined(HAVE_NETINET_IP_H) &&	\
     defined(HAVE_NETINET_IP_ICMP_H) &&	\
     defined(HAVE_ICMPHDR)
 
-#define MAX_PAYLOAD_SIZE	(1000)
+#define MAX_PAYLOAD_SIZE	(65535 - sizeof(struct iphdr) - sizeof(struct icmphdr))
+#define DEFAULT_PAYLOAD_SIZE	(1000)
 #define MAX_PKT_LEN		(sizeof(struct iphdr) + \
 				 sizeof(struct icmphdr) + \
 				 MAX_PAYLOAD_SIZE + 1)
@@ -68,15 +76,22 @@ static int stress_icmp_flood(stress_args_t *args)
 {
 	int fd, rc = EXIT_FAILURE;
 	const int set_on = 1;
-	const unsigned long addr = inet_addr("127.0.0.1");
+	const unsigned long int addr = inet_addr("127.0.0.1");
 	struct sockaddr_in servaddr;
 	uint64_t counter, sendto_fails = 0, sendto_ok;
 	double bytes = 0.0, t_start, duration, rate;
+	const uint16_t id = htons((uint16_t)args->instance);
+	uint16_t seq = 0;
 
 	char ALIGN64 pkt[MAX_PKT_LEN];
 	struct iphdr *const ip_hdr = (struct iphdr *)pkt;
 	struct icmphdr *const icmp_hdr = (struct icmphdr *)(pkt + sizeof(struct iphdr));
 	char *const payload = pkt + sizeof(struct iphdr) + sizeof(struct icmphdr);
+	uint32_t max_payload_size;
+	bool icmp_flood_max_size = false;
+
+	(void)stress_get_setting("icmp-flood-max-size", &icmp_flood_max_size);
+	max_payload_size = icmp_flood_max_size ? MAX_PAYLOAD_SIZE : DEFAULT_PAYLOAD_SIZE;
 
 	(void)shim_memset(pkt, 0, sizeof(pkt));
 	stress_rndbuf(payload, MAX_PAYLOAD_SIZE);
@@ -108,36 +123,34 @@ static int stress_icmp_flood(stress_args_t *args)
 	stress_sync_start_wait(args);
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
+	(void)shim_memset(pkt, 0, sizeof(pkt));
+	ip_hdr->version = 4;
+	ip_hdr->ihl = 5;
+	ip_hdr->tos = 0;
+	ip_hdr->id = id;
+	ip_hdr->frag_off = 0;
+	ip_hdr->ttl = 64;
+	ip_hdr->protocol = IPPROTO_ICMP;
+	ip_hdr->saddr = (in_addr_t)addr;
+	ip_hdr->daddr = (in_addr_t)addr;
+
+	icmp_hdr->type = ICMP_ECHO;
+	icmp_hdr->code = 0;
+	icmp_hdr->un.echo.sequence = htons(seq);
+
+	stress_rndbuf(payload, MAX_PAYLOAD_SIZE);
+
 	t_start = stress_time_now();
 	do {
-		const size_t payload_len = stress_mwc32modn(MAX_PAYLOAD_SIZE) + 1;
+		const size_t payload_len = stress_mwc32modn(max_payload_size) + 1;
 		const size_t pkt_len =
 			sizeof(struct iphdr) + sizeof(struct icmphdr) + payload_len;
 		ssize_t ret;
 
-		(void)shim_memset(pkt, 0, sizeof(pkt));
-
-		ip_hdr->version = 4;
-		ip_hdr->ihl = 5;
-		ip_hdr->tos = 0;
 		ip_hdr->tot_len = htons(pkt_len);
-		ip_hdr->id = stress_mwc16();
-		ip_hdr->frag_off = 0;
-		ip_hdr->ttl = 64;
-		ip_hdr->protocol = IPPROTO_ICMP;
-		ip_hdr->saddr = (in_addr_t)addr;
-		ip_hdr->daddr = (in_addr_t)addr;
+		icmp_hdr->un.echo.id = id;
 
-		icmp_hdr->type = ICMP_ECHO;
-		icmp_hdr->code = 0;
-		icmp_hdr->un.echo.sequence = stress_mwc16();
-		icmp_hdr->un.echo.id = stress_mwc16();
-
-		/*
-		 * Generating random data is expensive so do it every 64 packets
-		 */
-		if ((stress_bogo_get(args) & 0x3f) == 0)
-			stress_rndbuf(payload, payload_len);
+		payload[0]++;
 		icmp_hdr->checksum = stress_ipv4_checksum((uint16_t *)icmp_hdr,
 			sizeof(struct icmphdr) + payload_len);
 
@@ -148,6 +161,7 @@ static int stress_icmp_flood(stress_args_t *args)
 			bytes += (double)ret;
 		}
 		stress_bogo_inc(args);
+		seq++;
 	} while (stress_continue(args));
 	duration = stress_time_now() - t_start;
 
@@ -179,6 +193,7 @@ const stressor_info_t stress_icmp_flood_info = {
 	.supported = stress_icmp_flood_supported,
 	.class = CLASS_OS | CLASS_NETWORK,
 	.verify = VERIFY_ALWAYS,
+	.opts = opts,
 	.help = help
 };
 #else
@@ -186,6 +201,7 @@ const stressor_info_t stress_icmp_flood_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_OS | CLASS_NETWORK,
 	.verify = VERIFY_ALWAYS,
+	.opts = opts,
 	.help = help,
 	.unimplemented_reason = "built without netinet/ip.h, netinet/ip_icmp.h or struct icmphdr support"
 };
