@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2024      Colin Ian King.
+ * Copyright (C) 2024-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -113,7 +113,7 @@ static int stress_insertionsort(stress_args_t *args)
 	}
 	n = (size_t)insertionsort_size;
 
-	if ((data = calloc(n, sizeof(*data))) == NULL) {
+	if ((data = (int32_t *)calloc(n, sizeof(*data))) == NULL) {
 		pr_inf_skip("%s: failed to allocate %zu integers, skipping stressor\n",
 			args->name, n);
 		return EXIT_NO_RESOURCE;
@@ -151,7 +151,7 @@ static int stress_insertionsort(stress_args_t *args)
 		sorted += (double)n;
 		if (g_opt_flags & OPT_FLAGS_VERIFY) {
 			for (ptr = data, i = 0; i < n - 1; i++, ptr++) {
-				if (*ptr > *(ptr + 1)) {
+				if (UNLIKELY(*ptr > *(ptr + 1))) {
 					pr_fail("%s: sort error "
 						"detected, incorrect ordering "
 						"found\n", args->name);
@@ -160,7 +160,7 @@ static int stress_insertionsort(stress_args_t *args)
 				}
 			}
 		}
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 
 		/* Reverse sort */
@@ -171,7 +171,7 @@ static int stress_insertionsort(stress_args_t *args)
 		sorted += (double)n;
 		if (g_opt_flags & OPT_FLAGS_VERIFY) {
 			for (ptr = data, i = 0; i < n - 1; i++, ptr++) {
-				if (*ptr < *(ptr + 1)) {
+				if (UNLIKELY(*ptr < *(ptr + 1))) {
 					pr_fail("%s: reverse sort "
 						"error detected, incorrect "
 						"ordering found\n", args->name);
@@ -180,7 +180,7 @@ static int stress_insertionsort(stress_args_t *args)
 				}
 			}
 		}
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 		/* And re-order  */
 		stress_sort_data_int32_mangle(data, n);
@@ -194,7 +194,7 @@ static int stress_insertionsort(stress_args_t *args)
 		sorted += (double)n;
 		if (g_opt_flags & OPT_FLAGS_VERIFY) {
 			for (ptr = data, i = 0; i < n - 1; i++, ptr++) {
-				if (*ptr < *(ptr + 1)) {
+				if (UNLIKELY(*ptr < *(ptr + 1))) {
 					pr_fail("%s: reverse sort "
 						"error detected, incorrect "
 						"ordering found\n", args->name);
@@ -203,7 +203,7 @@ static int stress_insertionsort(stress_args_t *args)
 				}
 			}
 		}
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 
 		stress_bogo_inc(args);
