@@ -90,7 +90,7 @@ static int stress_ioprio(stress_args_t *args)
 				goto cleanup_file;
 			}
 		}
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 		if (shim_ioprio_get(IOPRIO_WHO_PROCESS, 0) < 0) {
 			if (errno != EINVAL) {
@@ -100,7 +100,7 @@ static int stress_ioprio(stress_args_t *args)
 				goto cleanup_file;
 			}
 		}
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 #if defined(HAVE_GETPGRP)
 		if (shim_ioprio_get(IOPRIO_WHO_PGRP, grp) < 0) {
@@ -111,7 +111,7 @@ static int stress_ioprio(stress_args_t *args)
 				goto cleanup_file;
 			}
 		}
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 #else
 		UNEXPECTED
@@ -124,7 +124,7 @@ static int stress_ioprio(stress_args_t *args)
 				goto cleanup_file;
 			}
 		}
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 		/*
 		 *  Exercise invalid ioprio_get arguments
@@ -142,7 +142,7 @@ static int stress_ioprio(stress_args_t *args)
 				goto cleanup_file;
 			}
 		}
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 
 		for (i = 0; i < MAX_IOV; i++) {
@@ -158,10 +158,10 @@ static int stress_ioprio(stress_args_t *args)
 				goto cleanup_file;
 			}
 		}
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 		(void)shim_fsync(fd);
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 
 		/*
@@ -184,7 +184,7 @@ static int stress_ioprio(stress_args_t *args)
 				goto cleanup_file;
 			}
 		}
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 
 		if (pwritev(fd, iov, MAX_IOV, (off_t)512 * stress_mwc16()) < 0) {
@@ -194,10 +194,10 @@ static int stress_ioprio(stress_args_t *args)
 				goto cleanup_file;
 			}
 		}
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 		(void)shim_fsync(fd);
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 
 		for (i = 0; i < 8; i++) {
@@ -222,7 +222,7 @@ static int stress_ioprio(stress_args_t *args)
 			}
 			(void)shim_fsync(fd);
 		}
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 		for (i = 0; i < 8; i++) {
 			if (shim_ioprio_set(IOPRIO_WHO_PROCESS, args->pid,
