@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -49,11 +49,6 @@
 #define IMB_SHA512_DIGEST_SIZE_IN_BYTES	SHA512_DIGEST_SIZE_IN_BYTES
 #endif
 
-typedef struct {
-	double	ops;
-	double	duration;
-} ipsec_stats_t;
-
 static const stress_help_t help[] = {
 	{ NULL,	"ipsec-mb N",		"start N workers exercising the IPSec MB encoding" },
 	{ NULL, "ipsec-mb-feature F",	"specify CPU feature F" },
@@ -73,6 +68,11 @@ static const stress_help_t help[] = {
     defined(IMB_FEATURE_AVX2) &&	\
     defined(IMB_FEATURE_AVX512_SKX)
 
+typedef struct {
+	double	ops;
+	double	duration;
+} ipsec_stats_t;
+
 typedef void (*ipsec_func_t)(
         stress_args_t *args,
         struct IMB_MGR *mb_mgr,
@@ -96,6 +96,7 @@ typedef struct {
 } stress_ipsec_features_t;
 
 static stress_ipsec_features_t mb_features[] = {
+#if defined(HAVE_INIT_MB_MGR_AVX)
 	{
 		IMB_FEATURE_AVX | IMB_FEATURE_CMOV | IMB_FEATURE_AESNI,
 		init_mb_mgr_avx,
@@ -103,6 +104,7 @@ static stress_ipsec_features_t mb_features[] = {
 		false,
 		{ 0.0, 0.0 }
 	},
+#endif
 	{
 		IMB_FEATURE_AVX2 | IMB_FEATURE_AVX | IMB_FEATURE_CMOV |
 		IMB_FEATURE_AESNI,
@@ -751,7 +753,7 @@ static void stress_ipsec_all(
 {
 	size_t i;
 
-	for (i = 1; stress_continue(args) && (i < SIZEOF_ARRAY(stress_ipsec_funcs)); i++)
+	for (i = 1; LIKELY(stress_continue(args) && (i < SIZEOF_ARRAY(stress_ipsec_funcs))); i++)
 		stress_ipsec_call_func(args, mb_mgr, data, data_len, jobs, i);
 }
 
