@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -119,7 +119,7 @@ static void stress_itimer_handler(int sig)
 	if ((itimer_counter & 65535) == 0)
 		if (stress_time_now() > time_end)
 			goto cancel;
-	if (stress_continue_flag()) {
+	if (LIKELY(stress_continue_flag())) {
 		stress_itimer_set(&timer);
 		return;
 	}
@@ -204,7 +204,7 @@ static int stress_itimer(stress_args_t *args)
 }
 
 
-stressor_info_t stress_itimer_info = {
+const stressor_info_t stress_itimer_info = {
 	.stressor = stress_itimer,
 	.class = CLASS_INTERRUPT | CLASS_OS,
 	.opts = opts,
@@ -214,7 +214,7 @@ stressor_info_t stress_itimer_info = {
 
 #else
 
-stressor_info_t stress_itimer_info = {
+const stressor_info_t stress_itimer_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_SIGNAL | CLASS_INTERRUPT | CLASS_OS,
 	.opts = opts,
