@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -73,19 +73,23 @@ static const stress_opt_t opts[] = {
 #if defined(HAVE_LIB_JPEG) &&	\
     defined(HAVE_LIBJPEG_H)
 
-static inline ALWAYS_INLINE double OPTIMIZE3 stress_plasma(const double x, const double y, const double whence)
+static inline ALWAYS_INLINE double OPTIMIZE3 stress_plasma(
+	const double x,
+	const double y,
+	const double whence)
 {
 	const double tau = 2 * M_PI;
 	double cx, cy;
 	double value;
+	double third = 0.3333333333333333333L;
 
 	value = shim_sin((whence - x) * tau);
 	value += shim_cos((whence + y) * tau);
 	value += shim_sin((whence + x - y) * tau);
 	value += shim_sin((whence + x + y) * tau);
 
-	cx = x - 0.5 + shim_sin(whence * tau) / 3.0;
-	cy = y - 0.5 + shim_cos(whence * tau) / 3.0;
+	cx = x - 0.5 + shim_sin(whence * tau) * third;
+	cy = y - 0.5 + shim_cos(whence * tau) * third;
 	value += shim_sin(shim_sqrt(128.0 * (cx * cx + cy * cy)));
 
 	return value;
@@ -98,9 +102,10 @@ static void OPTIMIZE3 stress_rgb_plasma(
 {
 	register uint8_t *ptr = rgb;
 	register int32_t sy;
-	const double tx = ((double)stress_mwc32()) / 100.0;
-	const double ty = ((double)stress_mwc32()) / 100.0;
-	const double tz = ((double)stress_mwc32()) / 100.0;
+	const double hundredth = 0.01L;
+	const double tx = ((double)stress_mwc32()) * hundredth;
+	const double ty = ((double)stress_mwc32()) * hundredth;
+	const double tz = ((double)stress_mwc32()) * hundredth;
 	const double dx = 1.0 / (double)x_max;
 	const double dy = 1.0 / (double)y_max;
 	double y;
@@ -235,7 +240,10 @@ static void OPTIMIZE3 stress_rgb_flat(
  *  stress_jpeg_checksum_data()
  *	generate a 32 bit checksum on the jpeg compressed data
  */
-static void OPTIMIZE3 stress_jpeg_checksum_data(char *data, const size_t size, uint32_t *checksum)
+static void OPTIMIZE3 stress_jpeg_checksum_data(
+	char *data,
+	const size_t size,
+	uint32_t *checksum)
 {
 	register uint32_t sum = 0;
 	register uint8_t *ptr = (uint8_t *)data;
@@ -301,13 +309,16 @@ static int stress_rgb_compress_to_jpeg(
 
 PRAGMA_UNROLL_N(8)
 	for (y = 0; y < y_max; y++, rgb += row_stride) {
-		*yy %= y_max;
+
+		if (UNLIKELY(*yy >= y_max))
+			*yy = 0;
 		row_pointer[*yy] = rgb;
 		(*yy)++;
 	}
 
 	(void)jpeg_write_scanlines(&cinfo, row_pointer, (JDIMENSION)y_max);
 	jpeg_finish_compress(&cinfo);
+	(void)fflush(fp);
 	(void)fclose(fp);
 	jpeg_destroy_compress(&cinfo);
 	t2 = stress_time_now();
@@ -358,6 +369,7 @@ static int stress_jpeg(stress_args_t *args)
 			args->name, x_max, y_max, 3);
 		return EXIT_NO_RESOURCE;
 	}
+	stress_set_vma_anon_name(rgb, rgb_size, "rgb-data");
 	row_pointer_size = (size_t)y_max * sizeof(*row_pointer);
 	row_pointer = (JSAMPROW *)stress_mmap_populate(NULL, row_pointer_size,
 				PROT_READ | PROT_WRITE,
@@ -365,9 +377,10 @@ static int stress_jpeg(stress_args_t *args)
 	if (row_pointer == MAP_FAILED) {
 		pr_inf_skip("%s: cannot allocate row pointer array of size %" PRId32 " x %zu, skipping stressor\n",
 			args->name, y_max, sizeof(*row_pointer));
-		(void)munmap(rgb, rgb_size);
+		(void)munmap((void *)rgb, rgb_size);
 		return EXIT_NO_RESOURCE;
 	}
+	stress_set_vma_anon_name(row_pointer, row_pointer_size, "row-pointers");
 
 	stress_mwc_set_seed(0xf1379ab2, 0x679ce25d);
 
