@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -112,7 +112,7 @@ do {									\
 			args->name, rc, ret);				\
 		}							\
 	}								\
-	if (!stress_continue_flag())					\
+	if (UNLIKELY(!stress_continue_flag()))				\
 		goto reap;						\
 } while (0)
 
@@ -212,7 +212,7 @@ again:
 		if (stress_redo_fork(args, errno))
 			goto again;
 		(void)close(fd1);
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			goto finish;
 		pr_fail("%s: fork failed, errno=%d (%s)\n",
 			args->name, errno, strerror(errno));
@@ -285,7 +285,7 @@ again:
 
 #if defined(HAVE_SYS_EPOLL_H) &&	\
     NEED_GLIBC(2,3,2)
-			if ((sfd != -1) && (efd != -1)) {
+			if (LIKELY((sfd != -1) && (efd != -1))) {
 				struct shim_kcmp_epoll_slot slot;
 
 				slot.efd = (uint32_t)efd;
