@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2024 Colin Ian King
+ * Copyright (C) 2021-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,8 +19,11 @@
 #include "stress-ng.h"
 #include "core-arch.h"
 #include "core-builtin.h"
+#include "core-capabilities.h"
 #include "core-madvise.h"
 
+#include <sys/ioctl.h>
+
 #if defined(HAVE_LINUX_KVM_H)
 #include <linux/kvm.h>
 #endif
@@ -47,6 +50,47 @@ static const stress_help_t help[] = {
     !defined(__i386__) &&			\
     !defined(__i386)
 
+static int stress_kvm_open(const char *name, const bool report)
+{
+	int kvm_fd;
+
+	if ((kvm_fd = open("/dev/kvm", O_RDWR)) < 0) {
+		switch (errno) {
+		case ENOENT:
+			if (report)
+				pr_inf_skip("%s: /dev/kvm not available, skipping stress test\n",
+					name);
+			break;
+		case EPERM:
+		case EACCES:
+			if (report && !stress_check_capability(SHIM_CAP_SYS_ADMIN))
+				pr_inf_skip("%s stressor will be skipped, "
+					"need to be running with CAP_SYS_ADMIN "
+					"rights for this stressor\n", name);
+			break;
+		default:
+			if (report)
+				pr_fail("%s: open /dev/kvm failed, errno=%d (%s), skipping stress test\n",
+					name, errno, strerror(errno));
+			break;
+		}
+		return -1;
+	}
+	return kvm_fd;
+}
+
+static int stress_kvm_supported(const char *name)
+{
+	int kvm_fd;
+
+	kvm_fd = stress_kvm_open(name, true);
+	if (kvm_fd < 0)
+		return -1;
+
+	(void)close(kvm_fd);
+	return 0;
+}
+
 /*
  *  Minimal x86 kernel, read/increment/write port $80 loop
  */
@@ -69,12 +113,14 @@ static int stress_kvm(stress_args_t *args)
 {
 	bool pr_version = false;
 
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
+	stress_sync_start_wait(args);
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	do {
 		int kvm_fd, vm_fd, vcpu_fd, version, ret, i;
 		void *vm_mem;
-		size_t vm_mem_size = (stress_mwc16() + 2) * args->page_size;
+		const size_t vm_mem_size = (stress_mwc16() + 2) * args->page_size;
 		ssize_t run_size;
 		struct kvm_userspace_memory_region kvm_mem;
 		struct kvm_sregs sregs;
@@ -83,17 +129,9 @@ static int stress_kvm(stress_args_t *args)
 		bool run_ok = false;
 		uint8_t value = 0;
 
-		if ((kvm_fd = open("/dev/kvm", O_RDWR)) < 0) {
-			if (errno == ENOENT) {
-				if (args->instance == 0)
-					pr_inf_skip("%s: /dev/kvm not available, skipping stress test\n",
-						args->name);
-				return EXIT_NOT_IMPLEMENTED;
-			}
-			pr_fail("%s: open /dev/kvm failed, errno=%d (%s), skipping stress test\n",
-				args->name, errno, strerror(errno));
+		kvm_fd = stress_kvm_open(args->name, args->instance == 0);
+		if (kvm_fd < 0)
 			return EXIT_NOT_IMPLEMENTED;
-		}
 
 #if defined(KVM_GET_API_VERSION)
 		version = ioctl(kvm_fd, KVM_GET_API_VERSION, 0);
@@ -122,6 +160,7 @@ static int stress_kvm(stress_args_t *args)
 			-1, 0);
 		if (vm_mem == MAP_FAILED)
 			goto tidy_vm_fd;
+		stress_set_vma_anon_name(vm_mem, vm_mem_size, "vm-memory");
 		(void)stress_madvise_mergeable(vm_mem, vm_mem_size);
 
 		(void)shim_memset(&kvm_mem, 0, sizeof(kvm_mem));
@@ -203,8 +242,9 @@ static int stress_kvm(stress_args_t *args)
 				args->name, errno, strerror(errno));
 			goto tidy_vcpu_fd;
 		}
+		stress_set_vma_anon_name(run, (size_t)run_size, "kvm-run");
 
-		for (i = 0; i < 1000 && stress_continue(args); i++) {
+		for (i = 0; LIKELY((i < 1000) && stress_continue(args)); i++) {
 			uint8_t *port;
 
 			ret = ioctl(vcpu_fd, KVM_RUN, 0);
@@ -286,14 +326,15 @@ tidy_kvm_fd:
 	return EXIT_SUCCESS;
 }
 
-stressor_info_t stress_kvm_info = {
+const stressor_info_t stress_kvm_info = {
 	.stressor = stress_kvm,
 	.class = CLASS_DEV | CLASS_OS,
+	.supported = stress_kvm_supported,
 	.verify = VERIFY_ALWAYS,
 	.help = help
 };
 #else
-stressor_info_t stress_kvm_info = {
+const stressor_info_t stress_kvm_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_DEV | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
