@@ -1,6 +1,6 @@
 /*
  * Copyright (C)      2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -127,6 +127,8 @@ static void *stress_loadavg_func(void *arg)
 	(void)arg;
 	(void)shim_nice(19);	/* be very nice */
 
+	stress_random_small_sleep();
+
 	while ((stress_time_now() < args->time_end) && keep_thread_running()) {
 #if defined(LOADAVG_IO)
 		if (fd >= 0) {
@@ -249,7 +251,7 @@ static int stress_loadavg(stress_args_t *args)
 			stop_running();
 			break;
 		}
-		if (!(keep_running() && stress_continue(args)))
+		if (UNLIKELY(!(keep_running() && stress_continue(args))))
 			break;
 	}
 
