@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2024      Colin Ian King.
+ * Copyright (C) 2024-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -78,7 +78,7 @@ PRAGMA_UNROLL_N(8)
 	}
 	stress_bogo_inc(args);
 
-	if (first_run) {
+	if (UNLIKELY(first_run)) {
 		result = sum;
 		first_run = false;
 	}
@@ -103,7 +103,7 @@ PRAGMA_UNROLL_N(8)
 	}
 	stress_bogo_inc(args);
 
-	if (first_run) {
+	if (UNLIKELY(first_run)) {
 		result = sum;
 		first_run = false;
 	}
@@ -128,7 +128,7 @@ PRAGMA_UNROLL_N(8)
 	}
 	stress_bogo_inc(args);
 
-	if (first_run) {
+	if (UNLIKELY(first_run)) {
 		result = sum;
 		first_run = false;
 	}
@@ -154,7 +154,7 @@ PRAGMA_UNROLL_N(8)
 	}
 	stress_bogo_inc(args);
 
-	if (first_run) {
+	if (UNLIKELY(first_run)) {
 		result = sum;
 		first_run = false;
 	}
@@ -178,7 +178,7 @@ PRAGMA_UNROLL_N(8)
 	}
 	stress_bogo_inc(args);
 
-	if (first_run) {
+	if (UNLIKELY(first_run)) {
 		result = sum;
 		first_run = false;
 	}
@@ -202,7 +202,7 @@ PRAGMA_UNROLL_N(8)
 	}
 	stress_bogo_inc(args);
 
-	if (first_run) {
+	if (UNLIKELY(first_run)) {
 		result = sum;
 		first_run = false;
 	}
@@ -226,7 +226,7 @@ PRAGMA_UNROLL_N(8)
 	}
 	stress_bogo_inc(args);
 
-	if (first_run) {
+	if (UNLIKELY(first_run)) {
 		result = sum;
 		first_run = false;
 	}
@@ -250,7 +250,7 @@ PRAGMA_UNROLL_N(8)
 	}
 	stress_bogo_inc(args);
 
-	if (first_run) {
+	if (UNLIKELY(first_run)) {
 		result = sum;
 		first_run = false;
 	}
@@ -274,7 +274,7 @@ PRAGMA_UNROLL_N(8)
 	}
 	stress_bogo_inc(args);
 
-	if (first_run) {
+	if (UNLIKELY(first_run)) {
 		result = sum;
 		first_run = false;
 	}
@@ -298,7 +298,7 @@ PRAGMA_UNROLL_N(8)
 	}
 	stress_bogo_inc(args);
 
-	if (first_run) {
+	if (UNLIKELY(first_run)) {
 		result = sum;
 		first_run = false;
 	}
@@ -322,7 +322,7 @@ PRAGMA_UNROLL_N(8)
 	}
 	stress_bogo_inc(args);
 
-	if (first_run) {
+	if (UNLIKELY(first_run)) {
 		result = sum;
 		first_run = false;
 	}
@@ -346,7 +346,7 @@ PRAGMA_UNROLL_N(8)
 	}
 	stress_bogo_inc(args);
 
-	if (first_run) {
+	if (UNLIKELY(first_run)) {
 		result = sum;
 		first_run = false;
 	}
@@ -370,7 +370,7 @@ PRAGMA_UNROLL_N(8)
 	}
 	stress_bogo_inc(args);
 
-	if (first_run) {
+	if (UNLIKELY(first_run)) {
 		result = sum;
 		first_run = false;
 	}
@@ -394,7 +394,7 @@ PRAGMA_UNROLL_N(8)
 	}
 	stress_bogo_inc(args);
 
-	if (first_run) {
+	if (UNLIKELY(first_run)) {
 		result = sum;
 		first_run = false;
 	}
@@ -417,7 +417,7 @@ PRAGMA_UNROLL_N(8)
 	}
 	stress_bogo_inc(args);
 
-	if (first_run) {
+	if (UNLIKELY(first_run)) {
 		result = sum;
 		first_run = false;
 	}
@@ -493,7 +493,7 @@ static bool stress_logmath_exercise(stress_args_t *args, const size_t idx)
 	ret = stress_logmath_methods[idx].logmath_func(args);
 	stress_logmath_metrics[idx].duration += (stress_time_now() - t);
 	stress_logmath_metrics[idx].count += 1.0;
-	if (ret) {
+	if (UNLIKELY(ret)) {
 		if (idx != 0)
 			pr_fail("logmath: %s does not match expected result\n",
 				stress_logmath_methods[idx].name);
@@ -524,17 +524,14 @@ static int stress_logmath(stress_args_t *args)
 
 	(void)stress_get_setting("logmath-method", &logmath_method);
 
-	for (i = 0; i < SIZEOF_ARRAY(stress_logmath_metrics); i++) {
-		stress_logmath_metrics[i].duration = 0.0;
-		stress_logmath_metrics[i].count = 0.0;
-	}
+	stress_zero_metrics(stress_logmath_metrics, SIZEOF_ARRAY(stress_logmath_metrics));
 
 	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	do {
-		if (stress_logmath_exercise(args, logmath_method)) {
+		if (UNLIKELY(stress_logmath_exercise(args, logmath_method))) {
 			rc = EXIT_FAILURE;
 			break;
 		}
