@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -184,12 +184,12 @@ static int stress_lsearch(stress_args_t *args)
 	}
 	max = (size_t)lsearch_size;
 
-	if ((data = calloc(max, sizeof(*data))) == NULL) {
+	if ((data = (int32_t *)calloc(max, sizeof(*data))) == NULL) {
 		pr_inf_skip("%s: malloc failed allocating %zd integers, "
 			"out of memory, skipping stressor\n", args->name, max);
 		return EXIT_NO_RESOURCE;
 	}
-	if ((root = calloc(max, sizeof(*data))) == NULL) {
+	if ((root = (int32_t *)calloc(max, sizeof(*data))) == NULL) {
 		free(data);
 		pr_inf_skip("%s: malloc failed allocating %zd integers , "
 			"out of memory, skipping stressor\n", args->name, max);
@@ -209,13 +209,13 @@ static int stress_lsearch(stress_args_t *args)
 		stress_sort_data_int32_shuffle(data, max);
 
 		/* Step #1, populate with data */
-		for (i = 0; stress_continue_flag() && (i < max); i++) {
+		for (i = 0; LIKELY(stress_continue_flag() && (i < max)); i++) {
 			VOID_RET(void *, lsearch_func(&data[i], root, &n, sizeof(*data), stress_lsearch_cmp_int32));
 		}
 		/* Step #2, find */
 		stress_sort_compare_reset();
 		t = stress_time_now();
-		for (i = 0; stress_continue_flag() && (i < n); i++) {
+		for (i = 0; LIKELY(stress_continue_flag() && (i < n)); i++) {
 			int32_t *result;
 
 			result = lfind_func(&data[i], root, &n, sizeof(*data), stress_lsearch_cmp_int32);
