@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -861,10 +861,7 @@ static inline int stress_matrix_exercise(
 
 	current_method = matrix_methods[matrix_method].name;
 
-	for (i = 0; i < num_matrix_methods; i++) {
-		matrix_metrics[i].duration = 0.0;
-		matrix_metrics[i].count = 0.0;
-	}
+	stress_zero_metrics(matrix_metrics, num_matrix_methods);
 
 	a = (matrix_ptr_t)stress_mmap_populate(NULL, matrix_mmap_size,
 		PROT_READ | PROT_WRITE, flags, -1, 0);
@@ -872,18 +869,24 @@ static inline int stress_matrix_exercise(
 		pr_fail("%s: matrix allocation failed, out of memory\n", args->name);
 		goto tidy_ret;
 	}
+	stress_set_vma_anon_name(a, matrix_mmap_size, "matrix-a");
+
 	b = (matrix_ptr_t)stress_mmap_populate(NULL, matrix_mmap_size,
 		PROT_READ | PROT_WRITE, flags, -1, 0);
 	if (b == MAP_FAILED) {
 		pr_fail("%s: matrix allocation failed, out of memory\n", args->name);
 		goto tidy_a;
 	}
+	stress_set_vma_anon_name(b, matrix_mmap_size, "matrix-b");
+
 	r = (matrix_ptr_t)stress_mmap_populate(NULL, matrix_mmap_size,
 		PROT_READ | PROT_WRITE, flags, -1, 0);
 	if (r == MAP_FAILED) {
 		pr_fail("%s: matrix allocation failed, out of memory\n", args->name);
 		goto tidy_b;
 	}
+	stress_set_vma_anon_name(r, matrix_mmap_size, "matrix-r");
+
 	if (verify) {
 		s = (matrix_ptr_t)stress_mmap_populate(NULL, matrix_mmap_size,
 			PROT_READ | PROT_WRITE, flags, -1, 0);
@@ -1014,7 +1017,7 @@ static const stress_opt_t opts[] = {
 	END_OPT,
 };
 
-stressor_info_t stress_matrix_info = {
+const stressor_info_t stress_matrix_info = {
 	.stressor = stress_matrix,
 	.class = CLASS_CPU | CLASS_FP | CLASS_CPU_CACHE | CLASS_MEMORY | CLASS_COMPUTE,
 	.opts = opts,
@@ -1031,7 +1034,7 @@ static const stress_opt_t opts[] = {
 	END_OPT,
 };
 
-stressor_info_t stress_matrix_info = {
+const stressor_info_t stress_matrix_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_CPU | CLASS_FP | CLASS_CPU_CACHE | CLASS_MEMORY | CLASS_COMPUTE,
 	.opts = opts,
