@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2018-2021 Canonical, Ltd.
- * Copyright (C) 2021-2024 Colin Ian King.
+ * Copyright (C) 2021-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,18 +18,27 @@
  *
  */
 #include "stress-ng.h"
+#include "core-affinity.h"
 #include "core-arch.h"
 #include "core-asm-x86.h"
 #include "core-builtin.h"
 #include "core-cpu-cache.h"
+#include "core-numa.h"
 #include "core-pthread.h"
 
 static const stress_help_t help[] = {
 	{ NULL,	"mcontend N",	  "start N workers that produce memory contention" },
 	{ NULL,	"mcontend-ops N", "stop memory contention workers after N bogo-ops" },
+	{ NULL, "mcontend-numa",  "bind memory mappings to randomly selected NUMA nodes" },
 	{ NULL,	NULL,		  NULL }
 };
 
+static const stress_opt_t opts[] = {
+	{ OPT_mcontend_numa, "mcontend-numa", TYPE_ID_BOOL, 0, 1, NULL },
+	END_OPT,
+};
+
+
 #if defined(HAVE_LIB_PTHREAD)
 
 static sigset_t set;
@@ -37,6 +46,11 @@ static sigset_t set;
 #define MAX_READ_THREADS	(4)
 #define MAX_MAPPINGS		(2)
 
+#if defined(HAVE_SCHED_SETAFFINITY)
+static uint32_t n_cpus;
+static uint32_t *cpus;
+#endif
+
 /*
  *  page_write_sync()
  *	write a whole page of zeros to the backing file and
@@ -71,20 +85,28 @@ static inline OPTIMIZE3 void read64(uint64_t *data)
 	shim_builtin_prefetch(data);
 	v = vdata[0];
 	(void)v;
+	stress_asm_mb();
 	v = vdata[1];
 	(void)v;
+	stress_asm_mb();
 	v = vdata[3];
 	(void)v;
+	stress_asm_mb();
 	v = vdata[4];
 	(void)v;
+	stress_asm_mb();
 	v = vdata[5];
 	(void)v;
+	stress_asm_mb();
 	v = vdata[6];
 	(void)v;
+	stress_asm_mb();
 	v = vdata[7];
 	(void)v;
+	stress_asm_mb();
 	v = vdata[8];
 	(void)v;
+	stress_asm_mb();
 }
 
 #if defined(HAVE_ASM_X86_LFENCE)
@@ -96,27 +118,35 @@ static inline OPTIMIZE3 void read64_lfence(uint64_t *data)
 	v = vdata[0];
 	(void)v;
 	stress_asm_x86_lfence();
+	stress_asm_mb();
 	v = vdata[1];
 	(void)v;
 	stress_asm_x86_lfence();
+	stress_asm_mb();
 	v = vdata[3];
 	(void)v;
 	stress_asm_x86_lfence();
+	stress_asm_mb();
 	v = vdata[4];
 	(void)v;
 	stress_asm_x86_lfence();
+	stress_asm_mb();
 	v = vdata[5];
 	(void)v;
 	stress_asm_x86_lfence();
+	stress_asm_mb();
 	v = vdata[6];
 	(void)v;
 	stress_asm_x86_lfence();
+	stress_asm_mb();
 	v = vdata[7];
 	(void)v;
 	stress_asm_x86_lfence();
+	stress_asm_mb();
 	v = vdata[8];
 	(void)v;
 	stress_asm_x86_lfence();
+	stress_asm_mb();
 }
 #else
 static inline void read64_lfence(uint64_t *data)
@@ -140,85 +170,143 @@ static inline OPTIMIZE3 void stress_memory_contend(const stress_pthread_args_t *
 
 	for (i = 0; i < 1024; i++) {
 		vdata0[0] = (uint64_t)i;
+		stress_asm_mb();
 		vdata1[0] = (uint64_t)i;
+		stress_asm_mb();
 		vdata0[1] = (uint64_t)i;
+		stress_asm_mb();
 		vdata1[1] = (uint64_t)i;
+		stress_asm_mb();
 		vdata0[2] = (uint64_t)i;
+		stress_asm_mb();
 		vdata1[2] = (uint64_t)i;
+		stress_asm_mb();
 		vdata0[3] = (uint64_t)i;
+		stress_asm_mb();
 		vdata1[3] = (uint64_t)i;
+		stress_asm_mb();
 		vdata0[4] = (uint64_t)i;
+		stress_asm_mb();
 		vdata1[4] = (uint64_t)i;
+		stress_asm_mb();
 		vdata0[5] = (uint64_t)i;
+		stress_asm_mb();
 		vdata1[5] = (uint64_t)i;
+		stress_asm_mb();
 		vdata0[6] = (uint64_t)i;
+		stress_asm_mb();
 		vdata1[6] = (uint64_t)i;
+		stress_asm_mb();
 		vdata0[7] = (uint64_t)i;
+		stress_asm_mb();
 		vdata1[7] = (uint64_t)i;
+		stress_asm_mb();
 		read64(data0);
+		stress_asm_mb();
 		read64(data1);
+		stress_asm_mb();
 		read64_lfence(data0);
+		stress_asm_mb();
 		read64_lfence(data1);
+		stress_asm_mb();
 	}
 
 	for (i = 0; i < 1024; i++) {
 		vdata0[0] = (uint64_t)i;
 		shim_mfence();
+		stress_asm_mb();
 		vdata1[0] = (uint64_t)i;
 		shim_mfence();
+		stress_asm_mb();
 		vdata0[1] = (uint64_t)i;
 		shim_mfence();
+		stress_asm_mb();
 		vdata1[1] = (uint64_t)i;
 		shim_mfence();
+		stress_asm_mb();
 		vdata0[2] = (uint64_t)i;
 		shim_mfence();
+		stress_asm_mb();
 		vdata1[2] = (uint64_t)i;
 		shim_mfence();
+		stress_asm_mb();
 		vdata0[3] = (uint64_t)i;
 		shim_mfence();
+		stress_asm_mb();
 		vdata1[3] = (uint64_t)i;
 		shim_mfence();
+		stress_asm_mb();
 		vdata0[4] = (uint64_t)i;
 		shim_mfence();
+		stress_asm_mb();
 		vdata1[4] = (uint64_t)i;
 		shim_mfence();
+		stress_asm_mb();
 		vdata0[5] = (uint64_t)i;
 		shim_mfence();
+		stress_asm_mb();
 		vdata1[5] = (uint64_t)i;
 		shim_mfence();
+		stress_asm_mb();
 		vdata0[6] = (uint64_t)i;
 		shim_mfence();
+		stress_asm_mb();
 		vdata1[6] = (uint64_t)i;
 		shim_mfence();
+		stress_asm_mb();
 		vdata0[7] = (uint64_t)i;
 		shim_mfence();
+		stress_asm_mb();
 		vdata1[7] = (uint64_t)i;
 		shim_mfence();
+		stress_asm_mb();
 		read64(data0);
+		stress_asm_mb();
 		read64(data1);
+		stress_asm_mb();
 	}
 
 	for (i = 0; i < 1024; i++) {
 		vdata0[0] = (uint64_t)i;
+		stress_asm_mb();
 		vdata1[0] = (uint64_t)i;
+		stress_asm_mb();
 		vdata0[1] = (uint64_t)i;
+		stress_asm_mb();
 		vdata1[1] = (uint64_t)i;
+		stress_asm_mb();
 		vdata0[2] = (uint64_t)i;
+		stress_asm_mb();
 		vdata1[2] = (uint64_t)i;
+		stress_asm_mb();
 		vdata0[3] = (uint64_t)i;
+		stress_asm_mb();
 		vdata1[3] = (uint64_t)i;
+		stress_asm_mb();
 		vdata0[4] = (uint64_t)i;
+		stress_asm_mb();
 		vdata1[4] = (uint64_t)i;
+		stress_asm_mb();
 		vdata0[5] = (uint64_t)i;
+		stress_asm_mb();
 		vdata1[5] = (uint64_t)i;
+		stress_asm_mb();
 		vdata0[6] = (uint64_t)i;
+		stress_asm_mb();
 		vdata1[6] = (uint64_t)i;
+		stress_asm_mb();
 		vdata0[7] = (uint64_t)i;
+		stress_asm_mb();
 		vdata1[7] = (uint64_t)i;
+		stress_asm_mb();
 		shim_clflush(data0);
+		stress_asm_mb();
 		shim_clflush(data1);
+		stress_asm_mb();
 		read64(data0);
+		stress_asm_mb();
 		read64(data1);
+		stress_asm_mb();
 	}
 
 #if defined(STRESS_ARCH_X86) &&	\
@@ -226,38 +314,56 @@ static inline OPTIMIZE3 void stress_memory_contend(const stress_pthread_args_t *
 	for (i = 0; i < 1024; i++) {
 		vdata0[0] = (uint64_t)i;
 		stress_asm_x86_pause();
+		stress_asm_mb();
 		vdata1[0] = (uint64_t)i;
 		stress_asm_x86_pause();
+		stress_asm_mb();
 		vdata0[1] = (uint64_t)i;
 		stress_asm_x86_pause();
+		stress_asm_mb();
 		vdata1[1] = (uint64_t)i;
 		stress_asm_x86_pause();
+		stress_asm_mb();
 		vdata0[2] = (uint64_t)i;
 		stress_asm_x86_pause();
+		stress_asm_mb();
 		vdata1[2] = (uint64_t)i;
 		stress_asm_x86_pause();
+		stress_asm_mb();
 		vdata0[3] = (uint64_t)i;
 		stress_asm_x86_pause();
+		stress_asm_mb();
 		vdata1[3] = (uint64_t)i;
 		stress_asm_x86_pause();
+		stress_asm_mb();
 		vdata0[4] = (uint64_t)i;
 		stress_asm_x86_pause();
+		stress_asm_mb();
 		vdata1[4] = (uint64_t)i;
 		stress_asm_x86_pause();
+		stress_asm_mb();
 		vdata0[5] = (uint64_t)i;
 		stress_asm_x86_pause();
+		stress_asm_mb();
 		vdata1[5] = (uint64_t)i;
 		stress_asm_x86_pause();
+		stress_asm_mb();
 		vdata0[6] = (uint64_t)i;
 		stress_asm_x86_pause();
+		stress_asm_mb();
 		vdata1[6] = (uint64_t)i;
 		stress_asm_x86_pause();
+		stress_asm_mb();
 		vdata0[7] = (uint64_t)i;
 		stress_asm_x86_pause();
+		stress_asm_mb();
 		vdata1[7] = (uint64_t)i;
 		stress_asm_x86_pause();
+		stress_asm_mb();
 		read64(data0);
+		stress_asm_mb();
 		read64(data1);
+		stress_asm_mb();
 	}
 #endif
 	for (i = 0; i < 1024; i++) {
@@ -294,7 +400,9 @@ static inline OPTIMIZE3 void stress_memory_contend(const stress_pthread_args_t *
 		vdata1[7] = (uint64_t)i;
 		stress_asm_mb();
 		read64(data0);
+		stress_asm_mb();
 		read64(data1);
+		stress_asm_mb();
 	}
 	(void)shim_cacheflush((void *)data0, 64, SHIM_DCACHE);
 	(void)shim_cacheflush((void *)data1, 64, SHIM_DCACHE);
@@ -305,11 +413,7 @@ static inline OPTIMIZE3 void stress_memory_contend(const stress_pthread_args_t *
  */
 static void *stress_memory_contend_thread(void *arg)
 {
-	static void *nowt = NULL;
 	const stress_pthread_args_t *pa = (const stress_pthread_args_t *)arg;
-#if defined(HAVE_SCHED_SETAFFINITY)
-	const uint32_t cpus = (uint32_t)stress_get_processors_configured();
-#endif
 
 	/*
 	 *  Block all signals, let controlling thread
@@ -317,22 +421,24 @@ static void *stress_memory_contend_thread(void *arg)
 	 */
 	(void)sigprocmask(SIG_BLOCK, &set, NULL);
 
-	while (stress_continue_flag()) {
-#if defined(HAVE_SCHED_SETAFFINITY)
-		cpu_set_t mask;
-		const uint32_t cpu = stress_mwc32modn(cpus);
-#endif
+	stress_random_small_sleep();
+
+	while (LIKELY(stress_continue_flag())) {
 		stress_memory_contend(pa);
 
 #if defined(HAVE_SCHED_SETAFFINITY)
+		if (n_cpus > 0) {
+			cpu_set_t mask;
+			const uint32_t cpu = cpus[stress_mwc32modn(n_cpus)];
 
-		CPU_ZERO(&mask);
-		CPU_SET(cpu, &mask);
-		(void)sched_setaffinity(0, sizeof(mask), &mask);
+			CPU_ZERO(&mask);
+			CPU_SET(cpu, &mask);
+			(void)sched_setaffinity(0, sizeof(mask), &mask);
+		}
 #endif
 	}
 
-	return &nowt;
+	return &g_nowt;
 }
 
 /*
@@ -342,16 +448,31 @@ static void *stress_memory_contend_thread(void *arg)
 static int stress_mcontend(stress_args_t *args)
 {
 	size_t i;
+	const size_t page_size = args->page_size;
 	pthread_t pthreads[MAX_READ_THREADS];
 	int ret[MAX_READ_THREADS];
 	void *data[MAX_MAPPINGS];
 	char filename[PATH_MAX];
 	stress_pthread_args_t pa;
+	bool mcontend_numa = false;
 	int fd, rc;
+#if defined(HAVE_LINUX_MEMPOLICY_H)
+	stress_numa_mask_t *numa_mask = NULL;
+#endif
+
+	(void)stress_get_setting("mcontend-numa", &mcontend_numa);
+
+#if defined(HAVE_SCHED_SETAFFINITY)
+	n_cpus = stress_get_usable_cpus(&cpus, true);
+#endif
 
 	rc = stress_temp_dir_mk_args(args);
-	if (rc < 0)
+	if (rc < 0) {
+#if defined(HAVE_SCHED_SETAFFINITY)
+		stress_free_usable_cpus(&cpus);
+#endif
 		return stress_exit_status(-rc);
+	}
 	(void)stress_temp_filename_args(args,
 		filename, sizeof(filename), stress_mwc32());
 
@@ -361,16 +482,22 @@ static int stress_mcontend(stress_args_t *args)
 			args->name, errno, strerror(errno));
 		(void)shim_unlink(filename);
 		(void)stress_temp_dir_rm_args(args);
+#if defined(HAVE_SCHED_SETAFFINITY)
+		stress_free_usable_cpus(&cpus);
+#endif
 		return EXIT_NO_RESOURCE;
 	}
 	(void)shim_unlink(filename);
 
-	rc = page_write_sync(fd, args->page_size);
+	rc = page_write_sync(fd, page_size);
 	if (rc < 0) {
 		pr_inf("%s: mmap backing file write failed: errno=%d (%s)\n",
 			args->name, errno, strerror(errno));
 		(void)close(fd);
 		(void)stress_temp_dir_rm_args(args);
+#if defined(HAVE_SCHED_SETAFFINITY)
+		stress_free_usable_cpus(&cpus);
+#endif
 		return EXIT_NO_RESOURCE;
 
 	}
@@ -380,28 +507,66 @@ static int stress_mcontend(stress_args_t *args)
 	 *  Get two different mappings of the same physical page
 	 *  just to make things more interesting
 	 */
-	data[0] = stress_mmap_populate(NULL, args->page_size, PROT_READ | PROT_WRITE,
+	data[0] = stress_mmap_populate(NULL, page_size, PROT_READ | PROT_WRITE,
 			MAP_PRIVATE, fd, 0);
 	if (data[0] == MAP_FAILED) {
 		pr_inf("%s: mmap failed: errno=%d (%s)\n",
 			args->name, errno, strerror(errno));
 		(void)close(fd);
 		(void)stress_temp_dir_rm_args(args);
+#if defined(HAVE_SCHED_SETAFFINITY)
+		stress_free_usable_cpus(&cpus);
+#endif
 		return EXIT_NO_RESOURCE;
 	}
-	data[1] = stress_mmap_populate(NULL, args->page_size , PROT_READ | PROT_WRITE,
+	data[1] = stress_mmap_populate(NULL, page_size , PROT_READ | PROT_WRITE,
 			MAP_PRIVATE, fd, 0);
 	if (data[1] == MAP_FAILED) {
 		pr_inf("%s: mmap failed: errno=%d (%s)\n",
 			args->name, errno, strerror(errno));
-		(void)munmap(data[0], args->page_size);
+		(void)munmap(data[0], page_size);
 		(void)close(fd);
 		(void)stress_temp_dir_rm_args(args);
+#if defined(HAVE_SCHED_SETAFFINITY)
+		stress_free_usable_cpus(&cpus);
+#endif
 		return EXIT_NO_RESOURCE;
 	}
 	(void)close(fd);
-	(void)shim_mlock(data[0], args->page_size);
-	(void)shim_mlock(data[1], args->page_size);
+
+	if (mcontend_numa) {
+#if defined(HAVE_LINUX_MEMPOLICY_H)
+		if (stress_numa_nodes() > 1) {
+			numa_mask = stress_numa_mask_alloc();
+			if (!numa_mask) {
+				pr_inf("%s: cannot allocate NUMA mask, disabling --mcontend-numa\n",
+					args->name);
+				mcontend_numa = false;
+			}
+		} else {
+			if (args->instance == 0) {
+				pr_inf("%s: only 1 NUMA node available, disabling --mcontend-numa\n",
+					args->name);
+				mcontend_numa = false;
+			}
+		}
+#else
+		if (args->instance == 0)
+			pr_inf("%s: --mcontend-numa selected but not supported by this system, disabling option\n",
+				args->name);
+		mcontend_numa = false;
+#endif
+	}
+
+#if defined(HAVE_LINUX_MEMPOLICY_H)
+        if (mcontend_numa && numa_mask) {
+                stress_numa_randomize_pages(numa_mask, data[0], page_size, page_size);
+                stress_numa_randomize_pages(numa_mask, data[1], page_size, page_size);
+		stress_numa_mask_free(numa_mask);
+	}
+#endif
+	(void)shim_mlock(data[0], page_size);
+	(void)shim_mlock(data[1], page_size);
 
 	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
@@ -416,8 +581,8 @@ static int stress_mcontend(stress_args_t *args)
 	do {
 		stress_memory_contend(&pa);
 #if defined(HAVE_MSYNC)
-		(void)msync(data[0], args->page_size, MS_ASYNC);
-		(void)msync(data[1], args->page_size, MS_ASYNC);
+		(void)msync(data[0], page_size, MS_ASYNC);
+		(void)msync(data[1], page_size, MS_ASYNC);
 #endif
 		stress_bogo_inc(args);
 	} while (stress_continue(args));
@@ -430,10 +595,13 @@ static int stress_mcontend(stress_args_t *args)
 
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 
-	(void)munmap(data[0], args->page_size);
-	(void)munmap(data[1], args->page_size);
+	(void)munmap(data[0], page_size);
+	(void)munmap(data[1], page_size);
 
 	(void)stress_temp_dir_rm_args(args);
+#if defined(HAVE_SCHED_SETAFFINITY)
+	stress_free_usable_cpus(&cpus);
+#endif
 
 	return EXIT_SUCCESS;
 }
@@ -441,12 +609,14 @@ static int stress_mcontend(stress_args_t *args)
 const stressor_info_t stress_mcontend_info = {
 	.stressor = stress_mcontend,
 	.class = CLASS_MEMORY,
+	.opts = opts,
 	.help = help
 };
 #else
 const stressor_info_t stress_mcontend_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_MEMORY,
+	.opts = opts,
 	.help = help,
 	.unimplemented_reason = "built without pthread support"
 };
