@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -57,11 +57,11 @@ static OPTIMIZE3 void *memcpy_check_func(memcpy_func_t func, void *dest, const v
 {
 	void *ptr = func(dest, src, n);
 
-	if (shim_memcmp(dest, src, n)) {
+	if (UNLIKELY(shim_memcmp(dest, src, n))) {
 		pr_fail("%s: %s: memcpy content is different than expected\n", s_args_name, s_method_name);
 		memcpy_okay = false;
 	}
-	if (ptr != dest) {
+	if (UNLIKELY(ptr != dest)) {
 		pr_fail("%s: %s: memcpy return was %p and not %p as expected\n", s_args_name, s_method_name, ptr, dest);
 		memcpy_okay = false;
 	}
@@ -77,11 +77,11 @@ static OPTIMIZE3 void *memmove_check_func(memcpy_func_t func, void *dest, const
 {
 	void *ptr = func(dest, src, n);
 
-	if (shim_memcmp(dest, src, n)) {
+	if (UNLIKELY(shim_memcmp(dest, src, n))) {
 		pr_fail("%s: %s: memmove content is different than expected\n", s_args_name, s_method_name);
 		memcpy_okay = false;
 	}
-	if (ptr != dest) {
+	if (UNLIKELY(ptr != dest)) {
 		pr_fail("%s: %s: memmove return was %p and not %p as expected\n", s_args_name, s_method_name, ptr, dest);
 		memcpy_okay = false;
 	}
@@ -310,6 +310,8 @@ static int stress_memcpy(stress_args_t *args)
 		pr_inf("%s: cannot allocate %d sized buffer\n", args->name, MEMCPY_MEMSIZE * 3);
 		return EXIT_NO_RESOURCE;
 	}
+	stress_set_vma_anon_name(buf, 3 * MEMCPY_MEMSIZE, "memcpy-buffer");
+
 	str1 = buf;
 	str2 = str1 + MEMCPY_MEMSIZE;
 	str3 = str2 + MEMCPY_MEMSIZE;
