@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -43,14 +43,9 @@ static const stress_help_t help[] = {
 	{ NULL,	NULL,			NULL }
 };
 
-static int stress_set_memhotplug_mmap(const char *opt)
-{
-	return stress_set_setting_true("memhotplug-mmap", opt);
-}
-
-static const stress_opt_set_func_t opt_set_funcs[] = {
-	{ OPT_memhotplug_mmap,	stress_set_memhotplug_mmap },
-	{ 0,			NULL },
+static const stress_opt_t opts[] = {
+	{ OPT_memhotplug_mmap, "memhotplug-mmap", TYPE_ID_BOOL, 0, 1, NULL },
+	END_OPT,
 };
 
 #if defined(__linux__)
@@ -243,7 +238,7 @@ static void stress_segv_handler(int signum)
 static int stress_memhotplug(stress_args_t *args)
 {
 	DIR *dir;
-	struct dirent *d;
+	const struct dirent *d;
 	stress_mem_info_t *mem_info;
 	size_t i;
 	NOCLOBBER size_t n = 0, max;
@@ -282,7 +277,7 @@ static int stress_memhotplug(stress_args_t *args)
 	}
 	rewinddir(dir);
 
-	mem_info = calloc(n, sizeof(*mem_info));
+	mem_info = (stress_mem_info_t *)calloc(n, sizeof(*mem_info));
 	if (!mem_info) {
 		pr_inf_skip("%s: failed to allocate %zd mem_info structs, skipping stressor\n",
 			args->name, n);
@@ -313,8 +308,9 @@ static int stress_memhotplug(stress_args_t *args)
 	mmap_size = 0;
 	segv_count = 0;
 
-	stress_set_proc_state(args->name, STRESS_STATE_RUN);
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
+	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
         if (sigsetjmp(jmp_env, 1))
 		goto finish;
@@ -323,7 +319,7 @@ static int stress_memhotplug(stress_args_t *args)
 	do {
 		bool ok = false;
 
-		for (i = 0; stress_continue(args) && (i < max); i++) {
+		for (i = 0; LIKELY(stress_continue(args) && (i < max)); i++) {
 			stress_memhotplug_mem_toggle(memhotplug_mmap, &mem_info[i], &metrics);
 			if (!mem_info[i].timeout)
 				ok = true;
@@ -364,18 +360,18 @@ finish:
 	return EXIT_SUCCESS;
 }
 
-stressor_info_t stress_memhotplug_info = {
+const stressor_info_t stress_memhotplug_info = {
 	.stressor = stress_memhotplug,
 	.class = CLASS_OS,
-	.opt_set_funcs = opt_set_funcs,
+	.opts = opts,
 	.supported = stress_memhotplug_supported,
 	.help = help
 };
 #else
-stressor_info_t stress_memhotplug_info = {
+const stressor_info_t stress_memhotplug_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_OS,
-	.opt_set_funcs = opt_set_funcs,
+	.opts = opts,
 	.help = help,
 	.unimplemented_reason = "only supported on Linux"
 };
