@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,10 +23,12 @@
 #include "core-builtin.h"
 #include "core-cpu-cache.h"
 #include "core-madvise.h"
+#include "core-nt-load.h"
 #include "core-nt-store.h"
 #include "core-numa.h"
 #include "core-out-of-memory.h"
 #include "core-pthread.h"
+#include "core-pragma.h"
 #include "core-target-clones.h"
 
 #if defined(HAVE_LINUX_MEMPOLICY_H) &&	\
@@ -62,10 +64,7 @@ typedef struct {
 	uint32_t total_cpus;
 	uint32_t max_threads;
 #if defined(HAVE_MEMTHRASH_NUMA)
-	int numa_nodes;
-	unsigned long int max_numa_nodes;
-	unsigned long int *numa_node_mask;
-	size_t numa_node_mask_size;
+	stress_numa_mask_t *numa_mask;
 #endif
 } stress_memthrash_context_t;
 
@@ -242,6 +241,7 @@ static void OPTIMIZE3 stress_memthrash_memset64(
 #endif
 	/* normal temporal stores, non-SSE fallback */
 
+PRAGMA_UNROLL_N(4)
 	while (LIKELY(ptr < end)) {
 		*ptr++ = val;
 		*ptr++ = val;
@@ -499,6 +499,33 @@ static void OPTIMIZE3 stress_memthrash_spinread(
 	const size_t offset = stress_mwc32modn(size) & ~(size_t)3;
 
 	(void)context;
+
+#if defined(HAVE_NT_LOAD32)
+	if (stress_cpu_x86_has_sse2()) {
+		uint32_t *nt_ptr = (uint32_t *)(((uintptr_t)mem) + offset);
+
+		for (i = 0; !thread_terminate && (i < 65536); i++) {
+			(void)stress_nt_load32(nt_ptr);
+			stress_asm_mb();
+			(void)stress_nt_load32(nt_ptr);
+			stress_asm_mb();
+			(void)stress_nt_load32(nt_ptr);
+			stress_asm_mb();
+			(void)stress_nt_load32(nt_ptr);
+			stress_asm_mb();
+
+			(void)stress_nt_load32(nt_ptr);
+			stress_asm_mb();
+			(void)stress_nt_load32(nt_ptr);
+			stress_asm_mb();
+			(void)stress_nt_load32(nt_ptr);
+			stress_asm_mb();
+			(void)stress_nt_load32(nt_ptr);
+			stress_asm_mb();
+		}
+		return;
+	}
+#endif
 	ptr = (uint32_t *)(((uintptr_t)mem) + offset);
 
 	for (i = 0; !thread_terminate && (i < 65536); i++) {
@@ -524,6 +551,33 @@ static void OPTIMIZE3 stress_memthrash_spinwrite(
 	const size_t offset = stress_mwc32modn(size) & ~(size_t)3;
 
 	(void)context;
+
+#if defined(HAVE_NT_STORE32)
+	if (stress_cpu_x86_has_sse2()) {
+		uint32_t *nt_ptr = (uint32_t *)(((uintptr_t)mem) + offset);
+
+		for (i = 0; !thread_terminate && (i < 65536); i++) {
+			stress_nt_store32(nt_ptr, i);
+			stress_asm_mb();
+			stress_nt_store32(nt_ptr, i);
+			stress_asm_mb();
+			stress_nt_store32(nt_ptr, i);
+			stress_asm_mb();
+			stress_nt_store32(nt_ptr, i);
+			stress_asm_mb();
+
+			stress_nt_store32(nt_ptr, i);
+			stress_asm_mb();
+			stress_nt_store32(nt_ptr, i);
+			stress_asm_mb();
+			stress_nt_store32(nt_ptr, i);
+			stress_asm_mb();
+			stress_nt_store32(nt_ptr, i);
+			stress_asm_mb();
+		}
+		return;
+	}
+#endif
 	ptr = (uint32_t *)(((uintptr_t)mem) + offset);
 
 	for (i = 0; !thread_terminate && (i < 65536); i++) {
@@ -610,6 +664,7 @@ static void OPTIMIZE3 TARGET_CLONES stress_memthrash_reverse(
 	(void)context;
 	while (fwd < end) {
 		register uint8_t tmp;
+
 		tmp = *fwd;
 		*(fwd++) = *(--rev);
 		*rev = tmp;
@@ -624,21 +679,25 @@ static void OPTIMIZE3 TARGET_CLONES stress_memthrash_numa(
 	uint8_t *ptr;
 	const uint8_t *end = (uint8_t *)((uintptr_t)mem + mem_size);
 	const size_t page_size = context->args->page_size;
-	int node;
+	stress_numa_mask_t *numa_mask = context->numa_mask;
+	unsigned long int node;
 
-	if ((context->numa_nodes < 1) || (context->max_numa_nodes < 1))
+	if (!numa_mask)
 		return;
 
-	node = (unsigned long int)stress_mwc32modn((uint32_t)context->numa_nodes);
-	(void)shim_memset(context->numa_node_mask, 0, context->numa_node_mask_size);
+	node = (unsigned long int)stress_mwc32modn((uint32_t)numa_mask->nodes);
+	(void)shim_memset(numa_mask->mask, 0, numa_mask->mask_size);
 
 	for (ptr = (uint8_t *)mem; ptr < end; ptr += page_size) {
-		STRESS_SETBIT(context->numa_node_mask, (unsigned long int)node);
+		STRESS_SETBIT(numa_mask->mask, (unsigned long int)node);
 
-		(void)shim_mbind((void *)ptr, page_size, MPOL_PREFERRED, context->numa_node_mask, context->max_numa_nodes, 0);
-		STRESS_CLRBIT(context->numa_node_mask, (unsigned long int)node);
+		if (stress_mwc1())
+			(void)shim_mbind((void *)ptr, page_size, MPOL_PREFERRED, numa_mask->mask, numa_mask->max_nodes, 0);
+		else
+			(void)shim_mbind((void *)ptr, page_size, MPOL_BIND, numa_mask->mask, numa_mask->max_nodes, MPOL_MF_MOVE);
+		STRESS_CLRBIT(numa_mask->mask, (unsigned long int)node);
 		node++;
-		if (node >= context->numa_nodes)
+		if (node >= numa_mask->nodes)
 			node = 0;
 	}
 }
@@ -747,11 +806,13 @@ static void *stress_memthrash_func(void *ctxt)
 	 */
 	(void)sigprocmask(SIG_BLOCK, &set, NULL);
 
-	while (!thread_terminate && stress_continue(args)) {
+	stress_random_small_sleep();
+
+	while (LIKELY(!thread_terminate && stress_continue(args))) {
 		size_t j;
 
-		for (j = MATRIX_SIZE_MIN_SHIFT; j <= MATRIX_SIZE_MAX_SHIFT &&
-		     !thread_terminate && stress_continue(args); j++) {
+		for (j = MATRIX_SIZE_MIN_SHIFT; LIKELY(j <= MATRIX_SIZE_MAX_SHIFT &&
+		     !thread_terminate && stress_continue(args)); j++) {
 			size_t mem_size = 1 << (2 * j);
 			size_t i;
 
@@ -827,14 +888,14 @@ mmap_retry:
 	mem = stress_mmap_populate(NULL, MEM_SIZE, PROT_READ | PROT_WRITE,
 			MAP_PRIVATE | MAP_ANONYMOUS, -1, 0);
 	if (mem == MAP_FAILED) {
-		if (!stress_continue_flag()) {
+		if (UNLIKELY(!stress_continue_flag())) {
 			pr_dbg("%s: mmap failed: %d %s\n",
 				args->name, errno, strerror(errno));
 			free(pthread_info);
 			return EXIT_NO_RESOURCE;
 		}
 		(void)shim_usleep(100000);
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			goto reap_mem;
 		goto mmap_retry;
 	}
@@ -856,7 +917,7 @@ mmap_retry:
 				args->name, ret, strerror(ret));
 			goto reap;
 		}
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			goto reap;
 	}
 	/* Wait for SIGALRM or SIGINT/SIGHUP etc */
@@ -901,33 +962,10 @@ static int stress_memthrash(stress_args_t *args)
 	context.max_threads = stress_memthrash_max(args->num_instances, context.total_cpus);
 #if defined(HAVE_MEMTHRASH_NUMA)
 	{
-		size_t numa_elements;
-
-		context.numa_nodes = stress_numa_count_mem_nodes(&context.max_numa_nodes);
-		numa_elements = (context.max_numa_nodes + NUMA_LONG_BITS - 1) / NUMA_LONG_BITS;
-		numa_elements = numa_elements ? numa_elements : 1;
-
-		/* Some sanity checks are required */
-		if ((context.numa_nodes < 1) || (context.max_numa_nodes < 1)) {
-			if (args->instance == 0) {
+		context.numa_mask = stress_numa_mask_alloc();
+		if (!context.numa_mask) {
+			if (args->instance == 0)
 				pr_inf("%s: no NUMA nodes or maximum NUMA nodes, ignoring numa memthrash method\n", args->name);
-			}
-			context.numa_node_mask = NULL;
-			context.numa_node_mask_size = 0;
-			context.numa_nodes = 0;
-		} else {
-			context.numa_node_mask = (unsigned long int *)calloc((size_t)context.max_numa_nodes, numa_elements);
-			context.numa_node_mask_size = (size_t)context.max_numa_nodes * numa_elements;
-
-			if (!context.numa_node_mask) {
-				if (args->instance == 0) {
-					pr_inf_skip("%s: could not allocate %zd numa elements in numa mask, ignoring numa memthrash stressor\n",
-						args->name, numa_elements);
-				}
-				context.numa_node_mask = NULL;
-				context.numa_node_mask_size = 0;
-				context.numa_nodes = 0;
-			}
 		}
 	}
 #endif
@@ -959,7 +997,8 @@ static int stress_memthrash(stress_args_t *args)
 
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 #if defined(HAVE_MEMTHRASH_NUMA)
-	free(context.numa_node_mask);
+	if (context.numa_mask)
+		stress_numa_mask_free(context.numa_mask);
 #endif
 
 	return rc;
