@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2016-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -278,6 +278,7 @@ static int stress_mergesort(stress_args_t *args)
 			args->name, n);
 		return EXIT_NO_RESOURCE;
 	}
+	stress_set_vma_anon_name(data, data_size, "mergesort-data");
 
 	ret = sigsetjmp(jmp_env, 1);
 	if (ret) {
@@ -310,7 +311,7 @@ static int stress_mergesort(stress_args_t *args)
 		stress_sort_compare_reset();
 		t = stress_time_now();
 		/* Sort "random" data */
-		if (mergesort_func(data, n, sizeof(*data), stress_sort_cmp_fwd_int32) < 0) {
+		if (UNLIKELY(mergesort_func(data, n, sizeof(*data), stress_sort_cmp_fwd_int32) < 0)) {
 			pr_fail("%s: mergesort of random data failed: %d (%s)\n",
 				args->name, errno, strerror(errno));
 			rc = EXIT_FAILURE;
@@ -322,7 +323,7 @@ static int stress_mergesort(stress_args_t *args)
 
 			if (g_opt_flags & OPT_FLAGS_VERIFY) {
 				for (ptr = data, i = 0; i < n - 1; i++, ptr++) {
-					if (*ptr > *(ptr + 1)) {
+					if (UNLIKELY(*ptr > *(ptr + 1))) {
 						pr_fail("%s: sort error "
 							"detected, incorrect ordering "
 							"found\n", args->name);
@@ -332,7 +333,7 @@ static int stress_mergesort(stress_args_t *args)
 				}
 			}
 		}
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 
 		/* Reverse sort */
@@ -350,7 +351,7 @@ static int stress_mergesort(stress_args_t *args)
 
 			if (g_opt_flags & OPT_FLAGS_VERIFY) {
 				for (ptr = data, i = 0; i < n - 1; i++, ptr++) {
-					if (*ptr < *(ptr + 1)) {
+					if (UNLIKELY(*ptr < *(ptr + 1))) {
 						pr_fail("%s: reverse sort "
 							"error detected, incorrect "
 							"ordering found\n", args->name);
@@ -360,7 +361,7 @@ static int stress_mergesort(stress_args_t *args)
 				}
 			}
 		}
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 
 		/* And re-order */
@@ -383,7 +384,7 @@ static int stress_mergesort(stress_args_t *args)
 			if (g_opt_flags & OPT_FLAGS_VERIFY) {
 
 				for (ptr = data, i = 0; i < n - 1; i++, ptr++) {
-					if (*ptr < *(ptr + 1)) {
+					if (UNLIKELY(*ptr < *(ptr + 1))) {
 						pr_fail("%s: reverse sort "
 							"error detected, incorrect "
 							"ordering found\n", args->name);
@@ -393,9 +394,6 @@ static int stress_mergesort(stress_args_t *args)
 				}
 			}
 		}
-		if (!stress_continue_flag())
-			break;
-
 		stress_bogo_inc(args);
 	} while (stress_continue(args));
 
