@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2024      Colin Ian King.
+ * Copyright (C) 2024-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,6 +20,8 @@
 #include "core-builtin.h"
 #include "core-cpuidle.h"
 
+#include <time.h>
+
 #define NANOSLEEP_MAX_SHIFT	(20)
 #define NANOSLEEP_MAX_NS	(1U << NANOSLEEP_MAX_SHIFT)
 #define NANOSLEEP_LOOPS		(16)
@@ -240,7 +242,7 @@ static void stress_min_nanosleep_sched(stress_args_t *args, const size_t min_nan
 static inline size_t PURE stress_min_nanosleep_log2plus1(size_t n)
 {
 #if defined(HAVE_BUILTIN_CLZLL)
-	long long lln = (long long)n;
+	long long int lln = (long long int)n;
 
 	if (lln == 0)
 		return 0;
@@ -261,6 +263,8 @@ static void stress_min_nanosleep_init(const uint32_t num_instances)
 
 	delays = stress_mmap_populate(NULL, delays_size, PROT_READ | PROT_WRITE,
 					MAP_ANONYMOUS | MAP_SHARED, -1, 0);
+	if (delays != MAP_FAILED)
+		stress_set_vma_anon_name(delays, delays_size, "nanosleep-timings");
 }
 
 static void stress_min_nanosleep_deinit(void)
@@ -335,7 +339,7 @@ static int stress_min_nanosleep(stress_args_t *args)
 
 			tv.tv_sec = 0;
 			tv.tv_nsec = (long int)nsec;
-			if (clock_gettime(CLOCK_MONOTONIC, &t1) < 0) {
+			if (UNLIKELY(clock_gettime(CLOCK_MONOTONIC, &t1) < 0)) {
 				pr_inf("%s: clock_gettime with CLOCK_MONOTONIC failed, errno=%d (%s)\n",
 					args->name, errno, strerror(errno));
 				goto err;
@@ -349,7 +353,7 @@ static int stress_min_nanosleep(stress_args_t *args)
 				}
 			}
 
-			if (clock_gettime(CLOCK_MONOTONIC, &t2) < 0) {
+			if (UNLIKELY(clock_gettime(CLOCK_MONOTONIC, &t2) < 0)) {
 				pr_inf("%s: clock_gettime with CLOCK_MONOTONIC failed, errno=%d (%s)\n",
 					args->name, errno, strerror(errno));
 				goto err;
