@@ -130,7 +130,7 @@ static void stress_misaligned_int16rd(
 	(void)args;
 	(void)succeeded;
 
-	while (stress_continue_flag() && --i) {
+	while (LIKELY(stress_continue_flag() && --i)) {
 		(void)*ptr1;
 		stress_asm_mb();
 		(void)*ptr2;
@@ -195,7 +195,7 @@ static void stress_misaligned_int16wr(
 	volatile uint16_t *ptr16 = (uint16_t *)(buffer + page_size - 15);
 	volatile uint16_t *ptr17  = (uint16_t *)(buffer + 63);
 
-	while (stress_continue_flag() && --i) {
+	while (LIKELY(stress_continue_flag() && --i)) {
 		register uint16_t ui16 = (uint16_t)i;
 
 		*ptr1  = ui16;
@@ -305,7 +305,7 @@ static void stress_misaligned_int16inc(
 	(void)args;
 	(void)succeeded;
 
-	while (stress_continue_flag() && --i) {
+	while (LIKELY(stress_continue_flag() && --i)) {
 		(*ptr1)++;
 		stress_asm_mb();
 		(*ptr2)++;
@@ -376,7 +376,7 @@ static void stress_misaligned_int16atomic(
 	(void)args;
 	(void)succeeded;
 
-	while (stress_continue_flag() && --i) {
+	while (LIKELY(stress_continue_flag() && --i)) {
 		__atomic_fetch_add_2(ptr1, 1, __ATOMIC_SEQ_CST);
 		stress_asm_mb();
 		__atomic_fetch_add_2(ptr2, 1, __ATOMIC_SEQ_CST);
@@ -437,7 +437,7 @@ static void stress_misaligned_int32rd(
 	(void)args;
 	(void)succeeded;
 
-	while (stress_continue_flag() && --i) {
+	while (LIKELY(stress_continue_flag() && --i)) {
 		(void)*ptr1;
 		stress_asm_mb();
 		(void)*ptr2;
@@ -478,7 +478,7 @@ static void stress_misaligned_int32wr(
 	volatile uint32_t *ptr8 = (uint32_t *)(buffer + page_size - 13);
 	volatile uint32_t *ptr9 = (uint32_t *)(buffer + 63);
 
-	while (stress_continue_flag() && --i) {
+	while (LIKELY(stress_continue_flag() && --i)) {
 		register uint32_t ui32 = (uint32_t)i;
 
 		*ptr1 = ui32;
@@ -546,7 +546,7 @@ static void stress_misaligned_int32wrnt(
 	uint32_t *ptr8 = (uint32_t *)(buffer + page_size - 13);
 	uint32_t *ptr9 = (uint32_t *)(buffer + 63);
 
-	while (stress_continue_flag() && --i) {
+	while (LIKELY(stress_continue_flag() && --i)) {
 		register uint32_t ui32 = (uint32_t)i;
 
 		stress_nt_store32(ptr1, ui32);
@@ -607,7 +607,7 @@ static void stress_misaligned_int32inc(
 	(void)args;
 	(void)succeeded;
 
-	while (stress_continue_flag() && --i) {
+	while (LIKELY(stress_continue_flag() && --i)) {
 		(*ptr1)++;
 		stress_asm_mb();
 		(*ptr2)++;
@@ -654,7 +654,7 @@ static void stress_misaligned_int32atomic(
 	(void)args;
 	(void)succeeded;
 
-	while (stress_continue_flag() && --i) {
+	while (LIKELY(stress_continue_flag() && --i)) {
 		__atomic_fetch_add_4(ptr1, 1, __ATOMIC_SEQ_CST);
 		stress_asm_mb();
 		__atomic_fetch_add_4(ptr2, 1, __ATOMIC_SEQ_CST);
@@ -695,7 +695,7 @@ static void stress_misaligned_int64rd(
 	(void)args;
 	(void)succeeded;
 
-	while (stress_continue_flag() && --i) {
+	while (LIKELY(stress_continue_flag() && --i)) {
 		(void)*ptr1;
 		stress_asm_mb();
 		(void)*ptr2;
@@ -724,7 +724,7 @@ static void stress_misaligned_int64wr(
 	volatile uint64_t *ptr4 = (uint64_t *)(buffer + page_size - 9);
 	volatile uint64_t *ptr5 = (uint64_t *)(buffer + 63);
 
-	while (stress_continue_flag() && --i) {
+	while (LIKELY(stress_continue_flag() && --i)) {
 		register uint64_t ui64 = (uint64_t)i;
 
 		*ptr1 = ui64;
@@ -772,7 +772,7 @@ static void stress_misaligned_int64wrnt(
 	uint64_t *ptr4 = (uint64_t *)(buffer + page_size - 9);
 	uint64_t *ptr5 = (uint64_t *)(buffer + 63);
 
-	while (stress_continue_flag() && --i) {
+	while (LIKELY(stress_continue_flag() && --i)) {
 		register uint64_t ui64 = (uint64_t)i;
 
 		stress_nt_store64(ptr1, ui64);
@@ -816,7 +816,7 @@ static void stress_misaligned_int64inc(
 	(void)args;
 	(void)succeeded;
 
-	while (stress_continue_flag() && --i) {
+	while (LIKELY(stress_continue_flag() && --i)) {
 		(*ptr1)++;
 		stress_asm_mb();
 		(*ptr2)++;
@@ -851,7 +851,7 @@ static void stress_misaligned_int64atomic(
 	(void)args;
 	(void)succeeded;
 
-	while (stress_continue_flag() && --i) {
+	while (LIKELY(stress_continue_flag() && --i)) {
 		__atomic_fetch_add_8(ptr1, 1, __ATOMIC_SEQ_CST);
 		stress_asm_mb();
 		__atomic_fetch_add_8(ptr2, 1, __ATOMIC_SEQ_CST);
@@ -915,7 +915,7 @@ static void stress_misaligned_int128wr(
 	volatile __uint128_t *ptr2 = (__uint128_t *)(buffer + page_size - 1);
 	volatile __uint128_t *ptr3 = (__uint128_t *)(buffer + 63);
 
-	while (stress_continue_flag() && --i) {
+	while (LIKELY(stress_continue_flag() && --i)) {
 		__uint128_t ui128 = (__uint128_t)i;
 
 		*ptr1 = ui128;
@@ -953,7 +953,7 @@ static void stress_misaligned_int128wrnt(
 	__uint128_t *ptr2 = (__uint128_t *)(buffer + page_size - 1);
 	__uint128_t *ptr3 = (__uint128_t *)(buffer + 63);
 
-	while (stress_continue_flag() && --i) {
+	while (LIKELY(stress_continue_flag() && --i)) {
 		stress_nt_store128(ptr1, (__uint128_t)i);
 		stress_nt_store128(ptr2, (__uint128_t)i);
 		stress_nt_store128(ptr3, (__uint128_t)i);
@@ -999,7 +999,7 @@ static void stress_misaligned_int128atomic(
 	(void)args;
 	(void)succeeded;
 
-	while (stress_continue_flag() && --i) {
+	while (LIKELY(stress_continue_flag() && --i)) {
 		/* No add 16 variant, so do 2 x 8 adds for now */
 		__atomic_fetch_add_8(ptr1, 1, __ATOMIC_SEQ_CST);
 		__atomic_fetch_add_8(ptr1 + 1, 1, __ATOMIC_SEQ_CST);
@@ -1073,7 +1073,7 @@ static void stress_misaligned_all(
 	static bool exercised = false;
 	size_t i;
 
-	for (i = 1; i < SIZEOF_ARRAY(stress_misaligned_methods) && stress_continue_flag(); i++) {
+	for (i = 1; LIKELY(i < SIZEOF_ARRAY(stress_misaligned_methods) && stress_continue_flag()); i++) {
 		stress_misaligned_method_info_t *info = &stress_misaligned_methods[i];
 
 		if (UNLIKELY(info->disabled))
