@@ -84,7 +84,7 @@ static void stress_mknod_tidy(
 static int stress_mknod_find_dev(mode_t mode, dev_t *dev)
 {
 	DIR *dir;
-	struct dirent *d;
+	const struct dirent *d;
 	int rc = -1;
 
 	(void)shim_memset(dev, 0, sizeof(*dev));
@@ -156,7 +156,8 @@ static int stress_do_mknod(
 	 *  50% of the time use mknodat rather than mknod
 	 */
 	if ((dir_fd >= 0) && stress_mwc1()) {
-		char tmp[PATH_MAX], *filename;
+		char tmp[PATH_MAX];
+		const char *filename;
 
 		(void)shim_strscpy(tmp, path, sizeof(tmp));
 		filename = basename(tmp);
@@ -255,7 +256,7 @@ static int stress_mknod(stress_args_t *args)
 		if (blk_dev_ret == 0)
 			stress_mknod_test_dev(args, dir_fd, bad_fd, S_IFBLK, "S_IFBLK", blk_dev);
 
-		for (i = 0; stress_continue(args) && (i < n); i++) {
+		for (i = 0; LIKELY(stress_continue(args) && (i < n)); i++) {
 			char path[PATH_MAX];
 			register const uint64_t gray_code = (i >> 1) ^ i;
 			register const size_t j = stress_mwc32modn(num_nodes);
@@ -271,7 +272,7 @@ static int stress_mknod(stress_args_t *args)
 		}
 
 		stress_mknod_tidy(args, i);
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 		(void)sync();
 	} while (stress_continue(args));
