@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,7 +32,7 @@ static const stress_help_t help[] = {
 };
 
 static const stress_opt_t opts[] = {
-	{ OPT_mmapfork_bytes, "mmapfork-bytes", TYPE_ID_SIZE_T_BYTES, MIN_MMAPFORK_BYTES, MAX_MMAPFORK_BYTES, NULL },
+	{ OPT_mmapfork_bytes, "mmapfork-bytes", TYPE_ID_SIZE_T_BYTES_VM, MIN_MMAPFORK_BYTES, MAX_MMAPFORK_BYTES, NULL },
 	END_OPT,
 };
 
@@ -146,7 +146,7 @@ static int stress_mmapfork(stress_args_t *args)
 			s_pids[i].pid = -1;
 
 		for (i = 0; i < MAX_PIDS; i++) {
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				goto reap;
 
 			s_pids[i].pid = fork();
@@ -164,7 +164,7 @@ static int stress_mmapfork(stress_args_t *args)
 					_exit(MMAPFORK_FAILURE);
 
 				(void)shim_memset(&info, 0, sizeof(info));
-				if (sysinfo(&info) < 0) {
+				if (UNLIKELY(sysinfo(&info) < 0)) {
 					pr_fail("%s: sysinfo failed, errno=%d (%s)\n",
 						args->name, errno, strerror(errno));
 					_exit(MMAPFORK_FAILURE);
@@ -230,7 +230,7 @@ static int stress_mmapfork(stress_args_t *args)
 				continue;
 
 			if (shim_waitpid(s_pids[i].pid, &status, 0) < 0) {
-				if (errno != EINTR) {
+				if (UNLIKELY(errno != EINTR)) {
 					pr_err("%s: waitpid errno=%d (%s)\n",
 						args->name, errno, strerror(errno));
 				} else {
@@ -258,7 +258,7 @@ reap:
 
 #if defined(MADV_WIPEONFORK)
 	if (wipe_ptr != MAP_FAILED)
-		(void)munmap(wipe_ptr, wipe_size);
+		(void)munmap((void *)wipe_ptr, wipe_size);
 #endif
 
 	if (segv_count) {
@@ -286,7 +286,7 @@ reap:
 }
 
 
-stressor_info_t stress_mmapfork_info = {
+const stressor_info_t stress_mmapfork_info = {
 	.stressor = stress_mmapfork,
 	.class = CLASS_SCHEDULER | CLASS_VM | CLASS_OS,
 	.opts = opts,
@@ -294,7 +294,7 @@ stressor_info_t stress_mmapfork_info = {
 	.help = help
 };
 #else
-stressor_info_t stress_mmapfork_info = {
+const stressor_info_t stress_mmapfork_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_SCHEDULER | CLASS_VM | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
