@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023-2024 Colin Ian King
+ * Copyright (C) 2023-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -381,7 +381,7 @@ static int stress_mpfr(stress_args_t *args)
 
 		stress_mwc_get_seed(&w, &z);
 
-		for (i = 0; stress_continue(args) && (i < SIZEOF_ARRAY(stress_mpfr_methods)); i++) {
+		for (i = 0; LIKELY(stress_continue(args) && (i < SIZEOF_ARRAY(stress_mpfr_methods))); i++) {
 			double t1;
 
 			stress_mwc_set_seed(w, z);
@@ -398,7 +398,7 @@ static int stress_mpfr(stress_args_t *args)
 			metrics[i].count += 1.0;
 			stress_bogo_inc(args);
 
-			if (mpfr_cmp(r0, r1) != 0) {
+			if (UNLIKELY(mpfr_cmp(r0, r1) != 0)) {
 				pr_fail("%s: %s computation with %d precision inconsistent\n",
 					args->name, stress_mpfr_methods[i].name, (int)precision);
 				rc = EXIT_FAILURE;
