@@ -104,7 +104,7 @@ static int stress_mprotect_mem(
 
 	VOID_RET(int, sigsetjmp(jmp_env, 1));
 
-	while (stress_continue(args)) {
+	while (LIKELY(stress_continue(args))) {
 		const uint32_t page = stress_mwc32modn(mem_pages);
 		uint8_t *ptr = mem + (page_size * page);
 		const size_t max_size = (size_t)(mem_end - ptr);
@@ -115,7 +115,7 @@ static int stress_mprotect_mem(
 		if ((max_size < page_size) || (size < page_size))
 			continue;
 
-		for (i = 0; (i < 10) && stress_continue(args); i++) {
+		for (i = 0; LIKELY((i < 10) && stress_continue(args)); i++) {
 			const int j = stress_mwc16modn(n_flags);
 
 			if (LIKELY(mprotect((void *)ptr, size, prot_flags[j]) == 0)) {
