@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -177,6 +177,7 @@ static int stress_msync(stress_args_t *args)
 		rc = EXIT_NO_RESOURCE;
 		goto err_unmap;
 	}
+	stress_set_vma_anon_name(data, page_size, "read-buffer");
 
 	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
@@ -199,16 +200,16 @@ static int stress_msync(stress_args_t *args)
 
 		(void)shim_memset(buf + offset, val, page_size);
 		ret = shim_msync(buf + offset, page_size, MS_SYNC);
-		if (ret < 0) {
+		if (UNLIKELY(ret < 0)) {
 			pr_fail("%s: msync MS_SYNC on "
-				"offset %jd failed, errno=%d (%s)\n",
+				"offset %" PRIdMAX " failed, errno=%d (%s)\n",
 				args->name, (intmax_t)offset, errno,
 				strerror(errno));
 			goto do_invalidate;
 		}
 		ret = lseek(fd, offset, SEEK_SET);
-		if (ret == (off_t)-1) {
-			pr_err("%s: cannot seet to offset %jd, "
+		if (UNLIKELY(ret == (off_t)-1)) {
+			pr_err("%s: cannot seet to offset %" PRIdMAX ", "
 				"errno=%d (%s)\n",
 				args->name, (intmax_t)offset, errno,
 				strerror(errno));
@@ -216,12 +217,12 @@ static int stress_msync(stress_args_t *args)
 			break;
 		}
 		ret = read(fd, data, page_size);
-		if (ret < (ssize_t)page_size) {
+		if (UNLIKELY(ret < (ssize_t)page_size)) {
 			pr_fail("%s: read failed, errno=%d (%s)\n",
 				args->name, errno, strerror(errno));
 			goto do_invalidate;
 		}
-		if (stress_page_check(data, val, page_size) < 0) {
+		if (UNLIKELY(stress_page_check(data, val, page_size) < 0)) {
 			pr_fail("%s: msync'd data in file different "
 				"to data in memory\n", args->name);
 		}
@@ -236,28 +237,28 @@ do_invalidate:
 		(void)shim_memset(buf + offset, val, page_size);
 
 		ret = lseek(fd, offset, SEEK_SET);
-		if (ret == (off_t)-1) {
-			pr_err("%s: cannot seet to offset %jd, errno=%d (%s)\n",
+		if (UNLIKELY(ret == (off_t)-1)) {
+			pr_err("%s: cannot seet to offset %" PRIdMAX ", errno=%d (%s)\n",
 				args->name, (intmax_t)offset, errno,
 				strerror(errno));
 			rc = EXIT_NO_RESOURCE;
 			break;
 		}
 		ret = read(fd, data, page_size);
-		if (ret < (ssize_t)page_size) {
+		if (UNLIKELY(ret < (ssize_t)page_size)) {
 			pr_fail("%s: read failed, errno=%d (%s)\n",
 				args->name, errno, strerror(errno));
 			goto do_next;
 		}
 		ret = shim_msync(buf + offset, page_size, MS_INVALIDATE);
-		if (ret < 0) {
+		if (UNLIKELY(ret < 0)) {
 			pr_fail("%s: msync MS_INVALIDATE on "
-				"offset %jd failed, errno=%d (%s)\n",
+				"offset %" PRIdMAX " failed, errno=%d (%s)\n",
 				args->name, (intmax_t)offset, errno,
 				strerror(errno));
 			goto do_next;
 		}
-		if (stress_page_check(buf + offset, val, page_size) < 0) {
+		if (UNLIKELY(stress_page_check(buf + offset, val, page_size) < 0)) {
 			pr_fail("%s: msync'd data in memory "
 				"different to data in file\n", args->name);
 		}
@@ -277,7 +278,7 @@ do_invalidate:
     defined(MS_INVALIDATE)
 		/* Force EBUSY when invalidating on a locked page */
 		ret = shim_mlock(buf + offset, page_size);
-		if (ret == 0) {
+		if (LIKELY(ret == 0)) {
 			VOID_RET(int, shim_msync(buf + offset, page_size, MS_INVALIDATE));
 			VOID_RET(int, shim_munlock(buf + offset, page_size));
 		}
