@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -17,6 +17,7 @@
  *
  */
 #include "stress-ng.h"
+#include "core-affinity.h"
 #include "core-builtin.h"
 #include "core-pthread.h"
 
@@ -33,7 +34,7 @@ static const stress_help_t help[] = {
 	{ NULL, "mutex-affinity",	"change CPU affinity randomly across locks" },
 	{ NULL,	"mutex-ops N",		"stop after N mutex bogo operations" },
 	{ NULL, "mutex-procs N",	"select the number of concurrent processes" },
-	{ NULL,	NULL,		NULL }
+	{ NULL,	NULL,			NULL }
 };
 
 static const stress_opt_t opts[] = {
@@ -60,6 +61,11 @@ static const stress_opt_t opts[] = {
     defined(HAVE_SCHED_GET_PRIORITY_MAX) &&	\
     defined(SCHED_FIFO)
 
+#if defined(HAVE_PTHREAD_SETAFFINITY_NP)
+uint32_t *cpus;
+uint32_t n_cpus;
+#endif
+
 static pthread_mutex_t ALIGN64 mutex;
 
 typedef struct {
@@ -74,29 +80,22 @@ typedef struct {
 } pthread_info_t;
 
 /*
- *  mutex_exercise()
+ *  stress_mutex_exercise()
  *	exercise the mutex
  */
-static void OPTIMIZE3 *mutex_exercise(void *arg)
+static void OPTIMIZE3 *stress_mutex_exercise(void *arg)
 {
 	pthread_info_t *pthread_info = (pthread_info_t *)arg;
 	stress_args_t *args = pthread_info->args;
-	static void *nowt = NULL;
 	const int max = (pthread_info->prio_max * 7) / 8;
 	int metrics_count = 0;
-#if defined(HAVE_PTHREAD_SETAFFINITY_NP)
-	uint32_t cpus = (uint32_t)stress_get_processors_configured();
-#endif
 #if defined(HAVE_PTHREAD_MUTEXATTR)
 	int mutexattr_ret;
 	pthread_mutexattr_t mutexattr;
 #endif
-#if defined(HAVE_PTHREAD_SETAFFINITY_NP)
-	if (!cpus)
-		cpus = 1;
-#endif
 
 	stress_mwc_reseed();
+	stress_random_small_sleep();
 
 #if defined(HAVE_PTHREAD_MUTEXATTR)
 	/*
@@ -117,7 +116,7 @@ static void OPTIMIZE3 *mutex_exercise(void *arg)
 
 		if (LIKELY(metrics_count > 0)) {
 			/* fast non-metrics lock path */
-			if (UNLIKELY(pthread_mutex_lock(&mutex) < 0)) {
+			if (UNLIKELY(pthread_mutex_lock(&mutex) != 0)) {
 				pr_fail("%s: pthread_mutex_lock failed, errno=%d (%s)\n",
 					args->name, errno, strerror(errno));
 				break;
@@ -127,25 +126,25 @@ static void OPTIMIZE3 *mutex_exercise(void *arg)
 			double t;
 
 			t = stress_time_now();
-			if (UNLIKELY(pthread_mutex_lock(&mutex) < 0)) {
+			if (LIKELY(pthread_mutex_lock(&mutex) == 0)) {
+				pthread_info->lock_duration += stress_time_now() - t;
+				pthread_info->lock_count += 1.0;
+			} else {
 				pr_fail("%s: pthread_mutex_lock failed, errno=%d (%s)\n",
 					args->name, errno, strerror(errno));
 				break;
-			} else {
-				pthread_info->lock_duration += stress_time_now() - t;
-				pthread_info->lock_count += 1.0;
 			}
 		}
 		metrics_count++;
-		if (metrics_count > 1000)
+		if (UNLIKELY(metrics_count > 1000))
 			metrics_count = 0;
 
 		param.sched_priority = pthread_info->prio_min;
 		(void)pthread_setschedparam(pthread_info->pthread, SCHED_FIFO, &param);
 #if defined(HAVE_PTHREAD_SETAFFINITY_NP)
-		if (pthread_info->mutex_affinity) {
+		if ((pthread_info->mutex_affinity) && (n_cpus > 0)) {
 			cpu_set_t cpuset;
-			const uint32_t cpu = stress_mwc32modn(cpus);
+			const uint32_t cpu = cpus[stress_mwc32modn(n_cpus)];
 
 			CPU_ZERO(&cpuset);
 			CPU_SET(cpu, &cpuset);
@@ -154,9 +153,9 @@ static void OPTIMIZE3 *mutex_exercise(void *arg)
 		}
 #endif
 		stress_bogo_inc(args);
-		shim_sched_yield();
+		(void)shim_sched_yield();
 
-		if (UNLIKELY(pthread_mutex_unlock(&mutex) < 0)) {
+		if (UNLIKELY(pthread_mutex_unlock(&mutex) != 0)) {
 			pr_fail("%s: pthread_mutex_unlock failed, errno=%d (%s)\n",
 				args->name, errno, strerror(errno));
 			break;
@@ -169,7 +168,7 @@ static void OPTIMIZE3 *mutex_exercise(void *arg)
 	}
 #endif
 
-	return &nowt;
+	return &g_nowt;
 }
 
 /*
@@ -205,6 +204,10 @@ static int stress_mutex(stress_args_t *args)
 		return EXIT_FAILURE;
 	}
 
+#if defined(HAVE_PTHREAD_SETAFFINITY_NP)
+	n_cpus = stress_get_usable_cpus(&cpus, true);
+#endif
+
 	prio_min = sched_get_priority_min(SCHED_FIFO);
 	prio_max = sched_get_priority_max(SCHED_FIFO);
 
@@ -223,7 +226,7 @@ static int stress_mutex(stress_args_t *args)
 		pthread_info[i].lock_duration = 0.0;
 		pthread_info[i].lock_count = 0.0;
 		pthread_info[i].ret = pthread_create(&pthread_info[i].pthread, NULL,
-                                mutex_exercise, (void *)&pthread_info[i]);
+                                stress_mutex_exercise, (void *)&pthread_info[i]);
 		if ((pthread_info[i].ret) && (pthread_info[i].ret != EAGAIN)) {
 			pr_fail("%s: pthread create failed, errno=%d (%s)\n",
 				args->name, pthread_info[i].ret, strerror(pthread_info[i].ret));
@@ -231,12 +234,15 @@ static int stress_mutex(stress_args_t *args)
 		}
 		created = true;
 
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 	}
 
 	if (!created) {
 		pr_inf("%s: could not create any pthreads\n", args->name);
+#if defined(HAVE_PTHREAD_SETAFFINITY_NP)
+		stress_free_usable_cpus(&cpus);
+#endif
 		return EXIT_NO_RESOURCE;
 	}
 
@@ -261,6 +267,9 @@ static int stress_mutex(stress_args_t *args)
 	stress_metrics_set(args, 0, "nanosecs per mutex",
 		rate * STRESS_DBL_NANOSECOND, STRESS_METRIC_HARMONIC_MEAN);
 
+#if defined(HAVE_PTHREAD_SETAFFINITY_NP)
+	stress_free_usable_cpus(&cpus);
+#endif
 	return EXIT_SUCCESS;
 }
 
