@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2017-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -99,10 +99,10 @@ static int monitor(stress_args_t *args, const int sock)
 		NLMSG_OK(nlmsghdr, (unsigned int)len);
 		nlmsghdr = NLMSG_NEXT(nlmsghdr, len)) {
 
-		struct cn_msg *cn_msg;
-		struct proc_event *proc_ev;
+		const struct cn_msg *cn_msg;
+		const struct proc_event *proc_ev;
 
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			return 0;
 
 		if ((nlmsghdr->nlmsg_type == NLMSG_ERROR) ||
@@ -114,7 +114,7 @@ static int monitor(stress_args_t *args, const int sock)
 		    (cn_msg->id.val != CN_VAL_PROC))
 			continue;
 
-		proc_ev = (struct proc_event *)cn_msg->data;
+		proc_ev = (const struct proc_event *)cn_msg->data;
 
 		switch (proc_ev->what) {
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,14)
