@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2017-2021 Canonical, Ltd.
- * Copyright (C) 2022-2023 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,6 +20,7 @@
 #include "stress-ng.h"
 #include "core-builtin.h"
 #include "core-capabilities.h"
+#include <sys/socket.h>
 
 #if defined(HAVE_LINUX_CN_PROC_H)
 #include <linux/cn_proc.h>
@@ -86,7 +87,7 @@ static int stress_netlink_task_supported(const char *name)
  *	send a netlink cmd
  */
 static int OPTIMIZE3 stress_netlink_sendcmd(
-	const stress_args_t *args,
+	stress_args_t *args,
 	const int sock,
 	const uint16_t nlmsg_type,
 	const uint32_t nlmsg_pid,
@@ -112,7 +113,7 @@ static int OPTIMIZE3 stress_netlink_sendcmd(
 	na = (struct nlattr *)GENL_MSG_DATA(&nlmsg);
 	na->nla_type = nla_type;
 	na->nla_len = nla_len + NLA_HDRLEN;
-	(void)memcpy(NLA_DATA(na), nla_data, (size_t)nla_len);
+	(void)shim_memcpy(NLA_DATA(na), nla_data, (size_t)nla_len);
 	nlmsg.n.nlmsg_len += NLMSG_ALIGN(na->nla_len);
 
 	nlmsgbuf = (char *)&nlmsg;
@@ -124,15 +125,22 @@ static int OPTIMIZE3 stress_netlink_sendcmd(
 	while (nlmsgbuf_len > 0) {
 		register ssize_t len;
 
+		/* Keep static analysis tools happy */
+		if (UNLIKELY(nlmsgbuf_len > (ssize_t)sizeof(stress_nlmsg_t)))
+			break;
+
 		len = sendto(sock, nlmsgbuf, (size_t)nlmsgbuf_len, 0,
 			(struct sockaddr *)&addr, sizeof(addr));
-		if ((len < 0) &&
-		    (errno != EAGAIN) &&
-		    (errno != EINTR)) {
+		if (UNLIKELY(len < 0)) {
+			if ((errno == EAGAIN) || (errno == EINTR))
+				return 0;
 			pr_fail("%s: sendto failed: %d (%s)\n",
 				args->name, errno, strerror(errno));
 			return -1;
 		}
+		/* avoid underflowing nlmsgbuf_len on subtraction */
+		if (UNLIKELY(len > nlmsgbuf_len))
+			break;
 		nlmsgbuf_len -= len;
 		nlmsgbuf += len;
 	}
@@ -146,7 +154,7 @@ static int OPTIMIZE3 stress_netlink_sendcmd(
  *	switches are incrementing over time.
  */
 static void OPTIMIZE3 stress_parse_payload(
-	const stress_args_t *args,
+	stress_args_t *args,
 	struct nlattr *na,
 	const pid_t pid,
 	uint64_t *nivcsw)
@@ -164,7 +172,7 @@ static void OPTIMIZE3 stress_parse_payload(
 		case TASKSTATS_TYPE_PID:
 			task_pid = *(pid_t *)NLA_DATA(na);
 			if (UNLIKELY(task_pid != pid)) {
-				pr_fail("%s: TASKSTATS_TYPE_PID got pid %" PRIdMAX ", "
+				pr_fail("%s: TASKSTATS_TYPE_PID got PID %" PRIdMAX ", "
 					"expected %" PRIdMAX "\n",
 					args->name,
 					(intmax_t)task_pid, (intmax_t)pid);
@@ -191,7 +199,7 @@ static void OPTIMIZE3 stress_parse_payload(
  *	monitor parent's activity using taskstats info
  */
 static int OPTIMIZE3 stress_netlink_taskstats_monitor(
-	const stress_args_t *args,
+	stress_args_t *args,
 	const int sock,
 	const pid_t pid,
 	const uint16_t id,
@@ -242,7 +250,7 @@ static int OPTIMIZE3 stress_netlink_taskstats_monitor(
  *  stress_netlink_task()
  *	stress netlink task events
  */
-static int stress_netlink_task(const stress_args_t *args)
+static int stress_netlink_task(stress_args_t *args)
 {
 	int ret, sock = -1;
 	ssize_t len;
@@ -308,10 +316,12 @@ static int stress_netlink_task(const stress_args_t *args)
 		return EXIT_FAILURE;
 	}
 
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
+	stress_sync_start_wait(args);
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	do {
-		if (stress_netlink_taskstats_monitor(args, sock, pid, id, &nivcsw) < 0)
+		if (UNLIKELY(stress_netlink_taskstats_monitor(args, sock, pid, id, &nivcsw) < 0))
 			break;
 	} while (stress_continue(args));
 
@@ -326,7 +336,7 @@ static int stress_netlink_task(const stress_args_t *args)
 	return EXIT_SUCCESS;
 }
 
-stressor_info_t stress_netlink_task_info = {
+const stressor_info_t stress_netlink_task_info = {
 	.stressor = stress_netlink_task,
 	.supported = stress_netlink_task_supported,
 	.class = CLASS_SCHEDULER | CLASS_OS,
@@ -334,7 +344,7 @@ stressor_info_t stress_netlink_task_info = {
 	.help = help
 };
 #else
-stressor_info_t stress_netlink_task_info = {
+const stressor_info_t stress_netlink_task_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_SCHEDULER | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
