@@ -26,6 +26,15 @@
 #define _GNU_SOURCE
 #endif
 
+#ifndef _LARGEFILE_SOURCE
+#define _LARGEFILE_SOURCE	(1)
+#endif
+
+#ifdef _FILE_OFFSET_BITS
+#undef _FILE_OFFSET_BITS
+#endif
+#define _FILE_OFFSET_BITS 	(64)
+
 #if defined(__TINYC__) ||	\
     defined(__PCC__)
 #undef _FORTIFY_SOURCE
@@ -89,6 +98,12 @@
 #define _REENTRANT
 #endif
 
+/* Stop pcc complaining about attribute COLD not being available */
+#if defined(__PCC__)
+#undef __COLD
+#define __COLD
+#endif
+
 /*
  *  Standard includes, assume we have this as the
  *  minimal standard baseline
