@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -67,12 +67,14 @@ static int stress_nice(stress_args_t *args)
 	}
 #endif
 #endif
-	stress_set_proc_state(args->name, STRESS_STATE_RUN);
+
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
+	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	do {
 		pid_t pid;
-		int which = stress_mwc1();
+		const int which = stress_mwc1();
 
 		pid = fork();
 		if (pid == 0) {
@@ -123,7 +125,7 @@ static int stress_nice(stress_args_t *args)
 #if defined(HAVE_SETPRIORITY)
 			case 1:
 				pid = getpid();
-				for (i = min_prio; (i <= max_prio) && stress_continue(args); i++) {
+				for (i = min_prio; LIKELY((i <= max_prio) && stress_continue(args)); i++) {
 					errno = 0;
 					(void)setpriority(PRIO_PROCESS, (id_t)pid, i);
 					if (!errno)
@@ -133,7 +135,7 @@ static int stress_nice(stress_args_t *args)
 				break;
 #endif
 			default:
-				for (i = -19; (i < 20) && stress_continue(args); i++) {
+				for (i = -19; LIKELY((i < 20) && stress_continue(args)); i++) {
 					int ret;
 #if defined(HAVE_GETPRIORITY)
 					int old_prio, new_prio;
@@ -195,7 +197,7 @@ static int stress_nice(stress_args_t *args)
 ;
 }
 
-stressor_info_t stress_nice_info = {
+const stressor_info_t stress_nice_info = {
 	.stressor = stress_nice,
 	.class = CLASS_SCHEDULER | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
@@ -203,7 +205,7 @@ stressor_info_t stress_nice_info = {
 };
 
 #else
-stressor_info_t stress_nice_info = {
+const stressor_info_t stress_nice_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_SCHEDULER | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
