@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -102,7 +102,7 @@ static int stress_oom_pipe_child(stress_args_t *args, void *ctxt)
 	for (i = 0; i < max_pipes * 2; i++)
 		fds[i] = -1;
 
-	for (i = 0; stress_continue(args) && (i < max_pipes); i++) {
+	for (i = 0; LIKELY(stress_continue(args) && (i < max_pipes)); i++) {
 		int *pfd = fds + (2 * i);
 
 		if ((g_opt_flags & OPT_FLAGS_OOM_AVOID) && stress_low_memory(page_size))
@@ -135,7 +135,7 @@ static int stress_oom_pipe_child(stress_args_t *args, void *ctxt)
 
 	do {
 		/* Set to maximum size */
-		for (i = 0, fd = fds; stress_continue(args) && (i < max_pipes); i++, fd += 2) {
+		for (i = 0, fd = fds; LIKELY(stress_continue(args) && (i < max_pipes)); i++, fd += 2) {
 			size_t max_size = context->max_pipe_size;
 
 			if ((fd[0] < 0) || (fd[1] < 0))
@@ -151,7 +151,7 @@ static int stress_oom_pipe_child(stress_args_t *args, void *ctxt)
 				pipe_empty(fd[0], max_size, page_size, rd_buffer);
 		}
 		/* Set to invalid size */
-		for (i = 0, fd = fds; stress_continue(args) && (i < max_pipes); i++, fd += 2) {
+		for (i = 0, fd = fds; LIKELY(stress_continue(args) && (i < max_pipes)); i++, fd += 2) {
 			if ((fd[0] < 0) || (fd[1] < 0))
 				continue;
 			(void)fcntl(fd[0], F_SETPIPE_SZ, -1);
@@ -159,7 +159,7 @@ static int stress_oom_pipe_child(stress_args_t *args, void *ctxt)
 		}
 
 		/* Set to minimum size */
-		for (i = 0, fd = fds; stress_continue(args) && (i < max_pipes); i++, fd += 2) {
+		for (i = 0, fd = fds; LIKELY(stress_continue(args) && (i < max_pipes)); i++, fd += 2) {
 			if ((fd[0] < 0) || (fd[1] < 0))
 				continue;
 			(void)fcntl(fd[0], F_SETPIPE_SZ, page_size);
@@ -205,11 +205,11 @@ static int stress_oom_pipe(stress_args_t *args)
 	context.max_fd = stress_get_file_limit();
 	context.max_pipe_size = stress_probe_max_pipe_size();
 
-	context.fds = calloc(context.max_fd, sizeof(*context.fds));
+	context.fds = (int *)calloc(context.max_fd, sizeof(*context.fds));
 	if (!context.fds) {
 		/* Shrink down */
 		context.max_fd = 1024 * 1024;
-		context.fds = calloc(context.max_fd, sizeof(*context.fds));
+		context.fds = (int *)calloc(context.max_fd, sizeof(*context.fds));
 		if (!context.fds) {
 			pr_inf_skip("%s: cannot allocate %zd file descriptors, skipping stressor\n",
 				args->name, context.max_fd);
