@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -156,7 +156,7 @@ static struct sock_filter filter[] = {
 };
 
 static struct sock_fprog prog = {
-	.len = (unsigned short)SIZEOF_ARRAY(filter),
+	.len = (unsigned short int)SIZEOF_ARRAY(filter),
 	.filter = filter
 };
 #endif
@@ -201,14 +201,54 @@ static inline void OPTIMIZE3 stress_opcode_random(
 	const void *ops_end,
 	const volatile uint64_t *op)
 {
-	register uint32_t *ops = (uint32_t *)ops_begin;
+#if defined(STRESS_ARCH_X86)
+	static const uint8_t x86_prefixes[] = {
+		0xf0,	/* lock */
+		0xf1,	/* repne/repnz */
+		0xf3,	/* rep or repe/repz */
+		0x2e,	/* CS segment override */
+		0x36,	/* SS segment override */
+		0x3e,	/* DS segment override */
+		0x26,	/* ES segment override */
+		0x64,	/* FS segment override */
+		0x65,	/* GS segment override */
+		0x2e,	/* branch not taken */
+		0x3e,	/* branch taken */
+		0x66,	/* operand size override */
+		0x67,	/* address size override */
+	};
+
+	static const uint8_t x86_prefix_length[] = {
+		1, 1, 1, 1, 1, 1, 1, 1,
+		1, 1, 1, 1, 1, 1, 1, 1,
+		1, 1, 1, 1, 1, 1, 1, 1,
+		1, 1, 1, 1, 1, 1, 1, 1,
+		1, 1, 1, 1, 1, 1, 1, 1,
+		2, 2, 2, 2, 2, 2, 2, 2,
+		3, 3, 3, 3, 4, 4, 8, 14,
+		15, 16, 17
+	};
+	uint32_t rnd;
+#endif
+	register uint32_t *ops32 = (uint32_t *)ops_begin;
 
 	(void)op;
 	(void)page_size;
 
 PRAGMA_UNROLL_N(8)
-	while (ops < (const uint32_t *)ops_end)
-		*(ops++) = stress_mwc32();
+	while (ops32 < (const uint32_t *)ops_end)
+		*(ops32++) = stress_mwc32();
+
+#if defined(STRESS_ARCH_X86)
+	rnd = stress_mwc32();
+	if ((rnd & 0xff) < 8) {
+		register uint8_t *ops8 = (uint8_t *)ops_begin;
+		int i, n = x86_prefix_length[stress_mwc8modn(SIZEOF_ARRAY(x86_prefix_length))];
+
+		for (i = 0; (i < n) && (ops8 < (const uint8_t *)ops_end); i++)
+			*(ops8++) = x86_prefixes[stress_mwc8modn(SIZEOF_ARRAY(x86_prefixes))];
+	}
+#endif
 }
 
 #if !defined(STRESS_OPCODE_SIZE)
@@ -293,7 +333,7 @@ static void OPTIMIZE3 stress_opcode_mixed(
 	const void *ops_end,
 	const volatile uint64_t *op)
 {
-	register uint64_t tmp = *op;
+	register const uint64_t tmp = *op;
 	register uint64_t *ops = (uint64_t *)ops_begin;
 
 	(void)page_size;
@@ -444,7 +484,7 @@ again:
 		if (pid < 0) {
 			if (stress_redo_fork(args, errno))
 				goto again;
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				goto finish;
 			pr_fail("%s: fork failed, errno=%d (%s)\n",
 				args->name, errno, strerror(errno));
@@ -513,6 +553,9 @@ again:
 			 * corruption since the child will
 			 * die soon anyhow
 			 */
+			(void)fflush(stdout);
+			(void)fflush(stderr);
+
 			(void)fclose(stdin);
 			(void)fclose(stdout);
 			(void)fclose(stderr);
@@ -636,7 +679,7 @@ static const stress_opt_t opts[] = {
 	END_OPT,
 };
 
-stressor_info_t stress_opcode_info = {
+const stressor_info_t stress_opcode_info = {
 	.stressor = stress_opcode,
 	.class = CLASS_CPU | CLASS_OS,
 	.opts = opts,
@@ -649,7 +692,7 @@ static const stress_opt_t opts[] = {
 	END_OPT,
 };
 
-stressor_info_t stress_opcode_info = {
+const stressor_info_t stress_opcode_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_CPU | CLASS_OS,
 	.opts = opts,
