@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -78,12 +78,12 @@ static void stress_pageswap_unmap(
 
 		(void)madvise(pi, size, MADV_PAGEOUT);
 		stress_pageswap_count_paged_out(pi, size, count);
-		if (verify && (pi->self != pi)) {
+		if (UNLIKELY(verify && (pi->self != pi))) {
 			pr_fail("%s: page at %p does not contain expected data\n",
 				args->name, (void *)pi);
 			*rc = EXIT_FAILURE;
 		}
-		(void)munmap(pi, pi->size);
+		(void)munmap((void *)pi, pi->size);
 		pi = next;
 	}
 	*head = NULL;
@@ -117,7 +117,7 @@ static int stress_pageswap_child(stress_args_t *args, void *context)
 
 		pi = (page_info_t *)mmap(NULL, page_size, PROT_READ | PROT_WRITE,
 			MAP_ANONYMOUS | MAP_SHARED, -1, 0);
-		if (pi == MAP_FAILED) {
+		if (UNLIKELY(pi == MAP_FAILED)) {
 			stress_pageswap_unmap(args, &head, &count, &rc);
 			max = 0;
 		} else {
@@ -132,7 +132,7 @@ static int stress_pageswap_child(stress_args_t *args, void *context)
 			if (oldhead)
 				(void)madvise(oldhead, oldhead->size, MADV_PAGEOUT);
 
-			if (max++ > 65536) {
+			if (UNLIKELY(max++ > 65536)) {
 				stress_pageswap_unmap(args, &head, &count, &rc);
 				max = 0;
 			}
@@ -169,7 +169,7 @@ static int stress_pageswap(stress_args_t *args)
 	return rc;
 }
 
-stressor_info_t stress_pageswap_info = {
+const stressor_info_t stress_pageswap_info = {
 	.stressor = stress_pageswap,
 	.supported = stress_pageswap_supported,
 	.class = CLASS_OS | CLASS_VM,
@@ -179,7 +179,7 @@ stressor_info_t stress_pageswap_info = {
 
 #else
 
-stressor_info_t stress_pageswap_info = {
+const stressor_info_t stress_pageswap_info = {
 	.stressor = stress_unimplemented,
 	.supported = stress_pageswap_supported,
 	.class = CLASS_OS | CLASS_VM,
