@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,10 +32,19 @@ static const stress_help_t help[] = {
 #if defined(HAVE_PERSONALITY)
 
 /* Personalities are determined at build time */
-static const unsigned long personalities[] ALIGN64 = {
+static const unsigned long int personalities[] ALIGN64 = {
 #include "personality.h"
 };
 
+static int stress_personality_supported(const char *name)
+{
+	if (SIZEOF_ARRAY(personalities) == 0) {
+		pr_inf_skip("%s: stressor will be skipped, no personalities to stress test\n", name);
+		return -1;
+	}
+	return 0;
+}
+
 /*
  *  stress_personality()
  *	stress system by rapid open/close calls
@@ -44,8 +53,10 @@ static int stress_personality(stress_args_t *args)
 {
 	const size_t n = SIZEOF_ARRAY(personalities);
 	bool *failed;
+	int rc = EXIT_SUCCESS;
 
-	if (n == 0) {
+	if (UNLIKELY(n == 0)) {
+		/* should never reach here, but just in case we do.. */
 		pr_inf_skip("%s: no personalities to stress test, skipping stressor\n", args->name);
 		return EXIT_NOT_IMPLEMENTED;
 	}
@@ -60,16 +71,18 @@ static int stress_personality(stress_args_t *args)
 	if (args->instance == 0)
 		pr_dbg("%s: exercising %zu personalities\n", args->name, n);
 
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
+	stress_sync_start_wait(args);
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	do {
 		size_t i, fails = 0;
 
 		for (i = 0; i < n; i++) {
-			const unsigned long p = personalities[i];
+			const unsigned long int p = personalities[i];
 			int ret;
 
-			if (!stress_continue_flag())
+			if (UNLIKELY(!stress_continue_flag()))
 				break;
 			if (UNLIKELY(failed[i])) {
 				fails++;
@@ -84,6 +97,8 @@ static int stress_personality(stress_args_t *args)
 			if (UNLIKELY(ret < 0)) {
 				pr_fail("%s: failed to get personality, errno=%d (%s)\n",
 					args->name, errno, strerror(errno));
+				rc = EXIT_FAILURE;
+				break;
 			}
 			/*
 			 *  Exercise invalid personalities
@@ -91,9 +106,10 @@ static int stress_personality(stress_args_t *args)
 			VOID_RET(int, personality(0xbad00000 | stress_mwc32()));
 			VOID_RET(int, personality(p));
 		}
-		if (fails == n) {
+		if (UNLIKELY(fails == n)) {
 			pr_fail("%s: all %zu personalities failed "
 				"to be set\n", args->name, fails);
+			rc = EXIT_FAILURE;
 			break;
 		}
 		stress_bogo_inc(args);
@@ -103,17 +119,18 @@ static int stress_personality(stress_args_t *args)
 
 	free(failed);
 
-	return EXIT_SUCCESS;
+	return rc;
 }
 
-stressor_info_t stress_personality_info = {
+const stressor_info_t stress_personality_info = {
 	.stressor = stress_personality,
 	.class = CLASS_OS,
 	.verify = VERIFY_ALWAYS,
+	.supported = stress_personality_supported,
 	.help = help
 };
 #else
-stressor_info_t stress_personality_info = {
+const stressor_info_t stress_personality_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_OS,
 	.verify = VERIFY_ALWAYS,
