@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -137,7 +137,7 @@ static int stress_pipeherd(stress_args_t *args)
     defined(HAVE_RUSAGE_RU_NVCSW)
 	t1 = stress_time_now();
 #endif
-	for (i = 0; stress_continue(args) && (i < PIPE_HERD_MAX); i++) {
+	for (i = 0; LIKELY(stress_continue(args) && (i < PIPE_HERD_MAX)); i++) {
 		pid_t pid;
 
 		pid = fork();
