@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2016-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -95,37 +95,6 @@ stress_prefetch_method_t prefetch_methods[] = {
 #endif
 };
 
-static int stress_set_prefetch_L3_size(const char *opt)
-{
-	uint64_t prefetch_L3_size;
-	size_t sz;
-
-	prefetch_L3_size = stress_get_uint64_byte(opt);
-	stress_check_range_bytes("prefetch-L3-size", prefetch_L3_size,
-		MIN_PREFETCH_L3_SIZE, MAX_PREFETCH_L3_SIZE);
-	sz = (size_t)prefetch_L3_size;
-
-	return stress_set_setting("prefetch-L3-size", TYPE_ID_SIZE_T, &sz);
-}
-
-static int stress_set_prefetch_method(const char *opt)
-{
-	size_t i;
-
-	for (i = 0; i < SIZEOF_ARRAY(prefetch_methods); i++) {
-		if (!strcmp(prefetch_methods[i].name, opt)) {
-			return stress_set_setting("prefetch-method", TYPE_ID_SIZE_T, &i);
-		}
-	}
-
-	(void)fprintf(stderr, "prefetch-method must be one of:");
-	for (i = 0; i < SIZEOF_ARRAY(prefetch_methods); i++) {
-		(void)fprintf(stderr, " %s", prefetch_methods[i].name);
-	}
-	(void)fprintf(stderr, "\n");
-	return -1;
-}
-
 static inline uint64_t get_prefetch_L3_size(stress_args_t *args)
 {
 	uint64_t cache_size = DEFAULT_PREFETCH_L3_SIZE;
@@ -208,7 +177,7 @@ static inline void stress_prefetch_none(const void *addr)
 			checksum += *(ptr + 7);				\
 			ptr += 8;					\
 		}							\
-		if (checksum != checksum_sane) {			\
+		if (UNLIKELY(checksum != checksum_sane)) {		\
 			pr_fail("%s: %s method: checksum failure, got "	\
 				"0x%" PRIx64 ", expected 0x%" PRIx64 "\n",\
 				args->name, type,			\
@@ -347,7 +316,7 @@ static uint64_t stress_prefetch_data_set(uint64_t *l3_data, const uint64_t *l3_d
 		seed = (a * seed + c);
 		val = seed;
 		seed = (a * seed + c);
-		val |= (uint64_t)seed << 32;;
+		val |= (uint64_t)seed << 32;
 
 		*(l3_data++) = val;
 		checksum += val;
@@ -401,6 +370,7 @@ static int stress_prefetch(stress_args_t *args)
 			args->name, l3_data_mmap_size);
 		return EXIT_NO_RESOURCE;
 	}
+	stress_set_vma_anon_name(l3_data, l3_data_mmap_size, "l3data");
 
 	l3_data_end = (uint64_t *)((uintptr_t)l3_data + l3_data_size);
 	checksum_sane = stress_prefetch_data_set(l3_data, l3_data_end);
@@ -413,10 +383,12 @@ static int stress_prefetch(stress_args_t *args)
 		prefetch_info[i].rate = 0.0;
 	}
 	if (args->instance == 0) {
-		pr_inf("%s: using a %zd KB L3 cache with prefetch method '%s'\n",
+		pr_inf("%s: using a %zdK L3 cache with prefetch method '%s'\n",
 		args->name, l3_data_size >> 10, prefetch_methods[prefetch_method].name);
 	}
 
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
+	stress_sync_start_wait(args);
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	do {
@@ -425,7 +397,7 @@ static int stress_prefetch(stress_args_t *args)
 				prefetch_method, i, checksum_sane,
 				l3_data, l3_data_end, &total_count,
 				verify, &success);
-			if (!success)
+			if (UNLIKELY(!success))
 				break;
 		}
 		stress_bogo_inc(args);
@@ -447,7 +419,7 @@ static int stress_prefetch(stress_args_t *args)
 
 	non_prefetch_rate = prefetch_info[0].rate / (double)GB;
 	stress_metrics_set(args, 0, "GB per sec non-prefetch read rate",
-		non_prefetch_rate, STRESS_HARMONIC_MEAN);
+		non_prefetch_rate, STRESS_METRIC_HARMONIC_MEAN);
 
 	if (best_rate > 0.0)
 		ns = STRESS_DBL_NANOSECOND * (double)prefetch_info[best].offset / best_rate;
@@ -460,7 +432,7 @@ static int stress_prefetch(stress_args_t *args)
 
 	best_rate /= (double)GB;
 	stress_metrics_set(args, 1, "GB per sec best read rate",
-		best_rate, STRESS_HARMONIC_MEAN);
+		best_rate, STRESS_METRIC_HARMONIC_MEAN);
 
 	/* sanity check prefetch rates */
 	if (verify && check_prefetch_rate && (best_rate < non_prefetch_rate)) {
@@ -477,16 +449,21 @@ static int stress_prefetch(stress_args_t *args)
 	return success ? EXIT_SUCCESS : EXIT_FAILURE;
 }
 
-static const stress_opt_set_func_t opt_set_funcs[] = {
-	{ OPT_prefetch_l3_size,	stress_set_prefetch_L3_size },
-	{ OPT_prefetch_method,	stress_set_prefetch_method  },
-	{ 0,			NULL }
+static const char *stress_prefetch_method(const size_t i)
+{
+	return (i < SIZEOF_ARRAY(prefetch_methods)) ? prefetch_methods[i].name : NULL;
+}
+
+static const stress_opt_t opts[] = {
+	{ OPT_prefetch_l3_size,	"prefetch-l3-size", TYPE_ID_SIZE_T_BYTES_VM, MIN_PREFETCH_L3_SIZE, MAX_PREFETCH_L3_SIZE, NULL },
+	{ OPT_prefetch_method,	"prefetch-method",  TYPE_ID_SIZE_T_METHOD, 0, 0, stress_prefetch_method },
+	END_OPT,
 };
 
-stressor_info_t stress_prefetch_info = {
+const stressor_info_t stress_prefetch_info = {
 	.stressor = stress_prefetch,
 	.class = CLASS_CPU | CLASS_CPU_CACHE | CLASS_MEMORY,
-	.opt_set_funcs = opt_set_funcs,
+	.opts = opts,
 	.verify = VERIFY_OPTIONAL,
 	.help = help
 };
