@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2014-2021 Canonical, Ltd.
- * Copyright (C) 2021-2024 Colin Ian King.
+ * Copyright (C) 2021-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -96,7 +96,7 @@ static int stress_dirent_proc_prune(struct dirent **dlist, const int n)
 
 			if (stress_is_dot_filename(dlist[i]->d_name))
 				ignore = true;
-			else if (isdigit((int)dlist[i]->d_name[0])) {
+			else if (isdigit((unsigned char)dlist[i]->d_name[0])) {
 				/* only allow a small numeric files.. */
 				ignore = (digit_count > 1);
 				digit_count++;
@@ -285,12 +285,12 @@ static inline void stress_proc_rw(
 		(void)shim_strscpy(path, proc_path, sizeof(path));
 		(void)shim_pthread_spin_unlock(&lock);
 
-		if (!*path || !stress_continue_flag())
+		if (UNLIKELY(!*path || !stress_continue_flag()))
 			break;
 
 		if (!strncmp(path, "/proc/self", 10))
 			writeable = false;
-		if (!strncmp(path, "/proc", 5) && isdigit(path[5]))
+		if (!strncmp(path, "/proc", 5) && isdigit((unsigned char)path[5]))
 			writeable = false;
 
 		t_start = stress_time_now();
@@ -360,7 +360,7 @@ static inline void stress_proc_rw(
 		for (i = 0; i < 4096 * PROC_BUF_SZ; i++) {
 			const ssize_t sz = 1 + stress_mwc32modn((uint32_t)sizeof(buffer));
 
-			if (!stress_continue_flag())
+			if (UNLIKELY(!stress_continue_flag()))
 				break;
 			ret = read(fd, buffer, (size_t)sz);
 			if (ret < 0)
@@ -378,7 +378,7 @@ static inline void stress_proc_rw(
 		if ((fd = open(path, O_RDONLY | O_NONBLOCK)) < 0)
 			return;
 		for (i = 0; ; i++) {
-			if (!stress_continue_flag())
+			if (UNLIKELY(!stress_continue_flag()))
 				break;
 			if (((i & 0x0f) == 0) && ((stress_time_now() - t_start) > threshold))
 				goto timeout_close;
@@ -516,7 +516,7 @@ mmap_test:
 			fds[0].events = POLLIN;
 			fds[0].revents = 0;
 
-			VOID_RET(int, ppoll(fds, 1, &ts, &sigmask));
+			VOID_RET(int, shim_ppoll(fds, 1, &ts, &sigmask));
 		}
 #endif
 
@@ -604,7 +604,6 @@ timeout_close:
  */
 static void *stress_proc_rw_thread(void *ctxt_ptr)
 {
-	static void *nowt = NULL;
 	const stress_ctxt_t *ctxt = (stress_ctxt_t *)ctxt_ptr;
 
 	/*
@@ -620,7 +619,7 @@ static void *stress_proc_rw_thread(void *ctxt_ptr)
 			break;
 	}
 
-	return &nowt;
+	return &g_nowt;
 }
 
 /*
@@ -640,7 +639,7 @@ static void stress_proc_dir(
 	int i, n, ret;
 	char tmp[PATH_MAX];
 
-	if (!stress_continue_flag())
+	if (UNLIKELY(!stress_continue_flag()))
 		return;
 
 	/* Don't want to go too deep */
@@ -656,7 +655,7 @@ static void stress_proc_dir(
 	}
 
 	/* Non-directories files first */
-	for (i = 0; (i < n) && stress_continue_flag(); i++) {
+	for (i = 0; LIKELY((i < n) && stress_continue_flag()); i++) {
 		struct dirent *d = dlist[i];
 		unsigned char type;
 
@@ -688,7 +687,7 @@ static void stress_proc_dir(
 	}
 
 	/* Now recurse on directories */
-	for (i = 0; (i < n) && stress_continue_flag(); i++) {
+	for (i = 0; LIKELY((i < n) && stress_continue_flag()); i++) {
 		struct dirent *d = dlist[i];
 
 		if (d && (shim_dirent_type(path, d) == SHIM_DT_DIR)) {
@@ -727,14 +726,14 @@ static char *stress_random_pid(void)
 	 *  try 32 random probes before giving up
 	 */
 	for (i = 0, j = 0; i < 32; i++) {
-		char *name;
+		const char *name;
 
 		j += (size_t)stress_mwc32();
 		j %= (size_t)n;
 
 		name = dlist[j]->d_name;
 
-		if (isdigit(name[0])) {
+		if (isdigit((unsigned char)name[0])) {
 			(void)stress_mk_filename(path, sizeof(path), "/proc", name);
 			break;
 		}
@@ -804,7 +803,7 @@ static int stress_procfs(stress_args_t *args)
 			const struct dirent *d = dlist[i];
 			unsigned char type;
 
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				break;
 
 			stress_mk_filename(procfspath, sizeof(procfspath), "/proc", d->d_name);
@@ -825,7 +824,7 @@ static int stress_procfs(stress_args_t *args)
 			stress_bogo_inc(args);
 		}
 
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 
 		stress_proc_dir(&ctxt, stress_random_pid(), true, 0);
