@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -72,7 +72,7 @@ static int stress_pty(stress_args_t *args)
 
 	(void)stress_get_setting("pty-max", &pty_max);
 
-	ptys = calloc(pty_max, sizeof(*ptys));
+	ptys = (stress_pty_info_t *)calloc(pty_max, sizeof(*ptys));
 	if (!ptys) {
 		pr_inf_skip("%s: allocation of pty array failed: %d (%s) "
 			"skipping stressor\n",
@@ -132,7 +132,7 @@ static int stress_pty(stress_args_t *args)
 					}
 				}
 			}
-			if (!stress_continue_flag())
+			if (UNLIKELY(!stress_continue_flag()))
 				goto clean;
 		}
 		/*
@@ -443,7 +443,7 @@ static int stress_pty(stress_args_t *args)
 #endif
 				}
 			}
-			if (!stress_continue_flag())
+			if (UNLIKELY(!stress_continue_flag()))
 				goto clean;
 		}
 #if defined(TIOCSETD) &&	\
@@ -474,20 +474,20 @@ static int stress_pty(stress_args_t *args)
 				}
 				VOID_RET(int, ioctl(ptys[i].follower, TIOCSETD, &orig_ldisc));
 				pr_block_end();
-				shim_sched_yield();
+				(void)shim_sched_yield();
 			}
 		}
 #endif
 
 #if defined(HAVE_PATHCONF)
 #if defined(_PC_MAX_CANON)
-		VOID_RET(long, pathconf("/dev/ptmx", _PC_MAX_CANON));
+		VOID_RET(long int, pathconf("/dev/ptmx", _PC_MAX_CANON));
 #endif
 #if defined(_PC_MAX_INPUT)
-		VOID_RET(long, pathconf("/dev/ptmx", _PC_MAX_INPUT));
+		VOID_RET(long int, pathconf("/dev/ptmx", _PC_MAX_INPUT));
 #endif
 #if defined(_PC_VDISABLE)
-		VOID_RET(long, pathconf("/dev/ptmx", _PC_VDISABLE));
+		VOID_RET(long int, pathconf("/dev/ptmx", _PC_VDISABLE));
 #endif
 #endif
 
