@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -349,7 +349,7 @@ static int OPTIMIZE3 stress_qsort(stress_args_t *args)
 		if (!stress_qsort_verify_forward(args, data, n, &rc))
 			break;
 
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 
 		/* Reverse sort */
@@ -363,7 +363,7 @@ static int OPTIMIZE3 stress_qsort(stress_args_t *args)
 		if (!stress_qsort_verify_reverse(args, data, n, &rc))
 			break;
 
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 
 		stress_sort_data_int32_mangle(data, n);
@@ -414,7 +414,7 @@ static const stress_opt_t opts[] = {
 	END_OPT,
 };
 
-stressor_info_t stress_qsort_info = {
+const stressor_info_t stress_qsort_info = {
 	.stressor = stress_qsort,
 	.class = CLASS_CPU_CACHE | CLASS_CPU | CLASS_MEMORY | CLASS_SORT,
 	.opts = opts,
