@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -120,12 +120,12 @@ static int radixsort_nonlibc(
 	if (nmemb < 2)
 		return 0;
 
-	b = malloc(sizeof(*b) * nmemb);
+	b = (const unsigned char **)malloc(sizeof(*b) * nmemb);
 	if (!b) {
 		errno = ENOMEM;
 		return -1;
 	}
-	lengths = malloc(sizeof(*lengths) * nmemb);
+	lengths = (unsigned short int *)malloc(sizeof(*lengths) * nmemb);
 	if (!lengths) {
 		free(b);
 		errno = ENOMEM;
@@ -216,13 +216,13 @@ static int stress_radixsort(stress_args_t *args)
 	}
 	n = (int)radixsort_size;
 
-	text = calloc((size_t)n, STR_SIZE);
+	text = (unsigned char *)calloc((size_t)n, STR_SIZE);
 	if (!text) {
 		pr_inf_skip("%s: calloc failed allocating %d strings, "
 			"skipping stressor\n", args->name, n);
 		return EXIT_NO_RESOURCE;
 	}
-	data = calloc((size_t)n, sizeof(*data));
+	data = (const unsigned char **)calloc((size_t)n, sizeof(*data));
 	if (!data) {
 		pr_inf_skip("%s: calloc failed allocating %d string pointers, "
 			"skipping stressor\n", args->name, n);
@@ -261,7 +261,7 @@ static int stress_radixsort(stress_args_t *args)
 	do {
 		/* Sort "random" data */
 		(void)radixsort_func(data, n, NULL, 0);
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 
 		if (g_opt_flags & OPT_FLAGS_VERIFY) {
