@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -51,7 +51,7 @@ static int stress_ramfs_supported(const char *name)
 }
 
 static const stress_opt_t opts[] = {
-	{ OPT_ramfs_size, "ramfs-size", TYPE_ID_UINT64_BYTES, 1 * MB, 1 * GB, NULL },
+	{ OPT_ramfs_size, "ramfs-size", TYPE_ID_UINT64_BYTES_VM, 1 * MB, 1 * GB, NULL },
 	{ OPT_ramfs_fill, "ramfs-fill", TYPE_ID_BOOL, 0, 1, NULL },
 	END_OPT,
 };
@@ -103,7 +103,7 @@ static void stress_ramfs_umount(stress_args_t *args, const char *path)
 #endif
 		if (ret == 0) {
 			if (i > 1) {
-				shim_nanosleep_uint64(ns);
+				(void)shim_nanosleep_uint64(ns);
 			}
 			continue;
 		}
@@ -118,7 +118,7 @@ static void stress_ramfs_umount(stress_args_t *args, const char *path)
 		case EBUSY:
 		case ENOMEM:
 			/* Wait and then re-try */
-			shim_nanosleep_uint64(ns);
+			(void)shim_nanosleep_uint64(ns);
 			break;
 		case EINVAL:
 			/*
@@ -417,14 +417,14 @@ static int stress_ramfs_mount(stress_args_t *args)
 
 	do {
 again:
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 
 		pid = fork();
 		if (pid < 0) {
 			if (stress_redo_fork(args, errno))
 				goto again;
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				goto finish;
 			pr_err("%s: fork failed: errno=%d (%s)\n",
 				args->name, errno, strerror(errno));
@@ -469,7 +469,7 @@ finish:
 	return EXIT_SUCCESS;
 }
 
-stressor_info_t stress_ramfs_info = {
+const stressor_info_t stress_ramfs_info = {
 	.stressor = stress_ramfs_mount,
 	.class = CLASS_OS,
 	.opts = opts,
@@ -478,7 +478,7 @@ stressor_info_t stress_ramfs_info = {
 	.help = help
 };
 #else
-stressor_info_t stress_ramfs_info = {
+const stressor_info_t stress_ramfs_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_OS,
 	.opts = opts,
