@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2024 Colin Ian King
+ * Copyright (C) 2021-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -45,49 +45,9 @@ typedef struct stress_randlist_item {
 	uint8_t data[];
 } stress_randlist_item_t;
 
-/*
- *  stress_set_randlist_compact()
- *      set randlist compact mode setting
- */
-static int stress_set_randlist_compact(const char *opt)
-{
-	return stress_set_setting_true("randlist-compact", opt);
-}
-
-/*
- *  stress_set_randlist_items()
- *      set randlist number of items from given option string
- */
-static int stress_set_randlist_items(const char *opt)
-{
-	uint32_t items;
-	size_t randlist_items;
-
-	items = stress_get_uint32(opt);
-	stress_check_range("randlist-size", (uint64_t)items, 1, 0xffffffff);
-	randlist_items = (size_t)items;
-	return stress_set_setting("randlist-items", TYPE_ID_SIZE_T, &randlist_items);
-}
-
-/*
- *  stress_set_randlist_size()
- *      set randlist size from given option string
- */
-static int stress_set_randlist_size(const char *opt)
-{
-	uint64_t size;
-	size_t randlist_size;
-
-	size = stress_get_uint64_byte(opt);
-	stress_check_range("randlist-size", size, 1, STRESS_RANDLIST_MAX_SIZE);
-
-	randlist_size = (size_t)size;
-	return stress_set_setting("randlist-size", TYPE_ID_SIZE_T, &randlist_size);
-}
-
 static void stress_randlist_free_item(stress_randlist_item_t **item, const size_t randlist_size)
 {
-	if (!*item)
+	if (UNLIKELY(!*item))
 		return;
 
 	if ((*item)->alloc_type == STRESS_RANDLIST_ALLOC_HEAP)
@@ -135,7 +95,7 @@ static inline uint8_t OPTIMIZE3 stress_randlist_bad_data(
 
 PRAGMA_UNROLL_N(8)
 	while (data < end) {
-		if (*(data++) != dataval)
+		if (UNLIKELY(*(data++) != dataval))
 			return true;
 	}
 	return false;
@@ -156,15 +116,15 @@ static inline void OPTIMIZE3 stress_randlist_exercise(
 		ptr->dataval = dataval;
 		(void)shim_memset(ptr->data, dataval, randlist_size);
 		dataval++;
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 	}
 
 	for (ptr = head; ptr; ptr = ptr->next) {
 		shim_builtin_prefetch(ptr->next);
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
-		if (verify && stress_randlist_bad_data(ptr, randlist_size)) {
+		if (UNLIKELY(verify && stress_randlist_bad_data(ptr, randlist_size))) {
 			pr_fail("%s: data check failure in list object at 0x%p\n", args->name, ptr);
 			*rc = EXIT_FAILURE;
 		}
@@ -197,7 +157,7 @@ static int stress_randlist(stress_args_t *args)
 	if (randlist_size >= args->page_size)
 		do_mmap = true;
 
-	ptrs = calloc(randlist_items, sizeof(stress_randlist_item_t *));
+	ptrs = (stress_randlist_item_t **)calloc(randlist_items, sizeof(stress_randlist_item_t *));
 	if (!ptrs) {
 		pr_inf_skip("%s: cannot allocate %zd temporary pointers, skipping stressor\n",
 			args->name, randlist_items);
@@ -207,7 +167,7 @@ static int stress_randlist(stress_args_t *args)
 	if (randlist_compact) {
 		const size_t size = sizeof(*ptr) + randlist_size;
 
-		compact_ptr = calloc(randlist_items, size);
+		compact_ptr = (stress_randlist_item_t *)calloc(randlist_items, size);
 		if (!compact_ptr) {
 			stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 			free(ptrs);
@@ -216,7 +176,7 @@ static int stress_randlist(stress_args_t *args)
 		}
 
 		for (ptr = compact_ptr, i = 0; i < randlist_items; i++) {
-			if (!stress_continue_flag()) {
+			if (UNLIKELY(!stress_continue_flag())) {
 				stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 				stress_randlist_free_ptrs(compact_ptr, ptrs, i, randlist_size);
 				stress_randlist_enomem(args);
@@ -230,7 +190,7 @@ static int stress_randlist(stress_args_t *args)
 		for (i = 0; i < randlist_items; i++) {
 			const size_t size = sizeof(*ptr) + randlist_size;
 
-			if (!stress_continue_flag()) {
+			if (UNLIKELY(!stress_continue_flag())) {
 				stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 				stress_randlist_free_ptrs(compact_ptr, ptrs, i, randlist_size);
 				return EXIT_SUCCESS;
@@ -240,7 +200,7 @@ retry:
 				ptr = (stress_randlist_item_t *)stress_mmap_populate(NULL, size,
 					PROT_READ | PROT_WRITE,
 					MAP_PRIVATE | MAP_ANONYMOUS, -1, 0);
-				if (ptr == MAP_FAILED) {
+				if (UNLIKELY(ptr == MAP_FAILED)) {
 					do_mmap = false;
 					goto retry;
 				}
@@ -248,7 +208,7 @@ retry:
 				mmap_allocs++;
 			} else {
 				ptr = (stress_randlist_item_t *)calloc(1, size);
-				if (!ptr) {
+				if (UNLIKELY(!ptr)) {
 					stress_randlist_free_ptrs(compact_ptr, ptrs, i, randlist_size);
 					stress_randlist_enomem(args);
 					return EXIT_NO_RESOURCE;
@@ -270,7 +230,7 @@ retry:
 		ptrs[i] = ptrs[n];
 		ptrs[n] = ptr;
 
-		if (!stress_continue_flag()) {
+		if (UNLIKELY(!stress_continue_flag())) {
 			stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 			stress_randlist_free_ptrs(compact_ptr, ptrs, i, randlist_size);
 			return EXIT_SUCCESS;
@@ -288,8 +248,9 @@ retry:
 	head = ptrs[0];
 	free(ptrs);
 
-	stress_set_proc_state(args->name, STRESS_STATE_RUN);
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
+	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	do {
 		stress_randlist_exercise(args, head, randlist_size, verify, &rc);
@@ -313,17 +274,17 @@ retry:
 	return rc;
 }
 
-static const stress_opt_set_func_t opt_set_funcs[] = {
-	{ OPT_randlist_compact,	stress_set_randlist_compact },
-	{ OPT_randlist_items,	stress_set_randlist_items },
-	{ OPT_randlist_size,	stress_set_randlist_size },
-	{ 0,                    NULL }
+static const stress_opt_t opts[] = {
+	{ OPT_randlist_compact,	"randlist-compact", TYPE_ID_BOOL, 0, 1, NULL },
+	{ OPT_randlist_items,	"randlist-items",   TYPE_ID_SIZE_T, 1, 0xffffffffULL, NULL },
+	{ OPT_randlist_size,	"randlist-size",    TYPE_ID_SIZE_T, 1, STRESS_RANDLIST_MAX_SIZE, NULL },
+	END_OPT,
 };
 
-stressor_info_t stress_randlist_info = {
+const stressor_info_t stress_randlist_info = {
 	.stressor = stress_randlist,
 	.class = CLASS_MEMORY,
-	.opt_set_funcs = opt_set_funcs,
+	.opts = opts,
 	.verify = VERIFY_OPTIONAL,
 	.help = help
 };
