@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -521,7 +521,7 @@ again:
 	if (pid < 0) {
 		if (stress_redo_fork(args, errno))
 			goto again;
-		if (!stress_continue(args)) {
+		if (UNLIKELY(!stress_continue(args))) {
 			rc = EXIT_SUCCESS;
 			goto finish;
 		}
@@ -541,7 +541,7 @@ finish:
 	return rc;
 }
 
-stressor_info_t stress_rawpkt_info = {
+const stressor_info_t stress_rawpkt_info = {
 	.stressor = stress_rawpkt,
 	.class = CLASS_NETWORK | CLASS_OS,
 	.opts = opts,
@@ -550,7 +550,7 @@ stressor_info_t stress_rawpkt_info = {
 	.help = help
 };
 #else
-stressor_info_t stress_rawpkt_info = {
+const stressor_info_t stress_rawpkt_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_NETWORK | CLASS_OS,
 	.opts = opts,
