@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2021-2024 Colin Ian King
+ * Copyright (C) 2021-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,6 +21,7 @@
 #include "core-arch.h"
 #include "core-asm-x86.h"
 #include "core-asm-ppc64.h"
+#include "core-builtin.h"
 #include "core-cpu.h"
 
 #if defined(HAVE_SYS_CAPABILITY_H)
@@ -108,14 +109,16 @@ static int stress_rdrand_supported(const char *name)
 		rdrand_supported = true;
 		return 0;
 	}
-	pr_inf_skip("%s stressor will be skipped, CPU "
-		"does not support the instruction 'darn'\n", name);
-	return -1;
-#else
-	pr_inf_skip("%s stressor will be skipped, cannot"
-		"determine if CPU is a power9 the instruction 'darn'\n", name);
-	return -1;
 #endif
+#if defined(HAVE_BUILTIN_CPU_IS_POWER10)
+	if (__builtin_cpu_is("power10")) {
+		rdrand_supported = true;
+		return 0;
+	}
+#endif
+	pr_inf_skip("%s stressor will be skipped, cannot detect if the CPU "
+		"supports the instruction 'darn'\n", name);
+	return -1;
 }
 
 static inline uint64_t rand64(void)
@@ -265,7 +268,7 @@ static int stress_rdrand(stress_args_t *args)
 #endif
 	static uint64_t ALIGN64 counters[16];
 
-	(void)memset(counters, 0, sizeof(counters));
+	(void)shim_memset(counters, 0, sizeof(counters));
 #if defined(HAVE_SEED_CAPABILITY)
 	(void)stress_get_setting("rdrand-seed", &rdrand_seed);
 #endif
@@ -380,7 +383,7 @@ static int stress_rdrand(stress_args_t *args)
 	return rc;
 }
 
-stressor_info_t stress_rdrand_info = {
+const stressor_info_t stress_rdrand_info = {
 	.stressor = stress_rdrand,
 	.supported = stress_rdrand_supported,
 	.opts = opts,
@@ -397,7 +400,7 @@ static int stress_rdrand_supported(const char *name)
 	return -1;
 }
 
-stressor_info_t stress_rdrand_info = {
+const stressor_info_t stress_rdrand_info = {
 	.stressor = stress_unimplemented,
 	.supported = stress_rdrand_supported,
 	.opts = opts,
