@@ -168,7 +168,7 @@ static int stress_readahead(stress_args_t *args)
 		size_t j;
 		const off_t o = i / BUF_SIZE;
 seq_wr_retry:
-		if (!stress_continue_flag()) {
+		if (UNLIKELY(!stress_continue_flag())) {
 			pr_inf("%s: test expired during test setup "
 				"(writing of data file)\n", args->name);
 			rc = EXIT_SUCCESS;
@@ -216,7 +216,7 @@ PRAGMA_UNROLL_N(8)
 		for (i = 0; i < MAX_OFFSETS; i++) {
 			ssize_t pret;
 rnd_rd_retry:
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				break;
 
 			pret = pread(fd, buf, BUF_SIZE, offsets[i]);
