@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,29 +29,10 @@ static const stress_help_t help[] = {
 	{ NULL,	NULL,			NULL }
 };
 
-static int stress_set_remap_mlock(const char *opt)
-{
-	return stress_set_setting_true("remap-mlock", opt);
-}
-
-static int stress_set_remap_pages(const char *opt)
-{
-        size_t remap_pages;
-
-        remap_pages = (size_t)stress_get_uint64(opt);
-        stress_check_range("remap-pages", (uint64_t)remap_pages, 1, 0x80000000);
-
-	if ((remap_pages & (remap_pages - 1)) != 0) {
-		(void)fprintf(stderr, "Value for option --remap-pages %zu must be a power of 2\n", remap_pages);
-                longjmp(g_error_env, 1);
-	}
-        return stress_set_setting("remap-pages", TYPE_ID_SIZE_T, &remap_pages);
-}
-
-static const stress_opt_set_func_t opt_set_funcs[] = {
-	{ OPT_remap_mlock,	stress_set_remap_mlock },
-	{ OPT_remap_pages,	stress_set_remap_pages },
-	{ 0,			NULL },
+static const stress_opt_t opts[] = {
+	{ OPT_remap_mlock, "remap-mlock", TYPE_ID_BOOL, 0, 1, NULL },
+	{ OPT_remap_pages, "remap-pages", TYPE_ID_SIZE_T, 1, 0x80000000ULL, NULL },
+	END_OPT,
 };
 
 #if defined(HAVE_REMAP_FILE_PAGES) &&	\
@@ -89,7 +70,7 @@ static bool OPTIMIZE3 check_order(
 	size_t i;
 
 	for (i = 0; i < remap_pages; i++) {
-		if (data[i * stride] != order[i]) {
+		if (UNLIKELY(data[i * stride] != order[i])) {
 			pr_fail("%s: remap %s order pages failed\n",
 				args->name, ordering);
 			return true;
@@ -172,6 +153,12 @@ static int stress_remap(stress_args_t *args)
 	(void)stress_get_setting("remap-mlock", &remap_mlock);
 	(void)stress_get_setting("remap-pages", &remap_pages);
 
+	if ((remap_pages & (remap_pages - 1)) != 0) {
+		(void)pr_inf("%s: value for option --remap-pages %zu must be a power of 2, falling back to using default %d\n",
+			args->name, remap_pages, N_PAGES);
+		remap_pages = N_PAGES;
+	}
+
 	data_size = remap_pages * page_size;
 	data = (stress_mapdata_t *)stress_mmap_populate(NULL, data_size,
 			PROT_READ | PROT_WRITE,
@@ -183,6 +170,7 @@ static int stress_remap(stress_args_t *args)
 			errno, strerror(errno));
 		return EXIT_NO_RESOURCE;
 	}
+	stress_set_vma_anon_name(data, data_size, "remap-pages");
 	if (remap_mlock)
 		(void)shim_mlock(data, data_size);
 
@@ -197,6 +185,7 @@ static int stress_remap(stress_args_t *args)
 		(void)munmap((void *)data, data_size);
 		return EXIT_NO_RESOURCE;
 	}
+	stress_set_vma_anon_name(order, order_size, "remap-ordering");
 	if (remap_mlock)
 		(void)shim_mlock(order, order_size);
 
@@ -208,6 +197,7 @@ static int stress_remap(stress_args_t *args)
 			PROT_READ | PROT_WRITE,
 			MAP_SHARED | MAP_ANONYMOUS, -1, 0);
 	if (mapped != MAP_FAILED) {
+		stress_set_vma_anon_name(mapped, mapped_size, "mapped-data");
 		if (remap_mlock)
 			(void)shim_mlock(mapped, mapped_size);
 		/*
@@ -228,8 +218,9 @@ static int stress_remap(stress_args_t *args)
 		mapped = NULL;
 	}
 
-	stress_set_proc_state(args->name, STRESS_STATE_RUN);
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
+	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	do {
 		/* Reverse pages */
@@ -240,7 +231,7 @@ static int stress_remap(stress_args_t *args)
 			rc = EXIT_NO_RESOURCE;
 			break;
 		}
-		if (check_order(args, stride, data, remap_pages, order, "reverse")) {
+		if (UNLIKELY(check_order(args, stride, data, remap_pages, order, "reverse"))) {
 			rc = EXIT_FAILURE;
 			break;
 		}
@@ -262,7 +253,7 @@ PRAGMA_UNROLL_N(4)
 			rc = EXIT_NO_RESOURCE;
 			break;
 		}
-		if (check_order(args, stride, data, remap_pages, order, "random")) {
+		if (UNLIKELY(check_order(args, stride, data, remap_pages, order, "random"))) {
 			rc = EXIT_FAILURE;
 			break;
 		}
@@ -275,7 +266,7 @@ PRAGMA_UNROLL_N(4)
 			rc = EXIT_NO_RESOURCE;
 			break;
 		}
-		if (check_order(args, stride, data, remap_pages, order, "all-to-1")) {
+		if (UNLIKELY(check_order(args, stride, data, remap_pages, order, "all-to-1"))) {
 			rc = EXIT_FAILURE;
 			break;
 		}
@@ -288,7 +279,7 @@ PRAGMA_UNROLL_N(4)
 			rc = EXIT_NO_RESOURCE;
 			break;
 		}
-		if (check_order(args, stride, data, remap_pages, order, "forward")) {
+		if (UNLIKELY(check_order(args, stride, data, remap_pages, order, "forward"))) {
 			rc = EXIT_FAILURE;
 			break;
 		}
@@ -333,17 +324,17 @@ PRAGMA_UNROLL_N(4)
 	return rc;
 }
 
-stressor_info_t stress_remap_info = {
+const stressor_info_t stress_remap_info = {
 	.stressor = stress_remap,
-	.opt_set_funcs = opt_set_funcs,
+	.opts = opts,
 	.class = CLASS_MEMORY | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
 	.help = help
 };
 #else
-stressor_info_t stress_remap_info = {
+const stressor_info_t stress_remap_info = {
 	.stressor = stress_unimplemented,
-	.opt_set_funcs = opt_set_funcs,
+	.opts = opts,
 	.class = CLASS_MEMORY | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
 	.help = help,
