@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -148,25 +148,25 @@ static ssize_t stress_revio_write(
 #endif
 
 	ret = write(fd, buf, count);
-	if (!stress_continue_flag())
+	if (UNLIKELY(!stress_continue_flag()))
 		return ret;
 
 #if defined(HAVE_FSYNC)
 	if (revio_flags & REVIO_OPT_FSYNC)
 		(void)shim_fsync(fd);
-	if (!stress_continue_flag())
+	if (UNLIKELY(!stress_continue_flag()))
 		return ret;
 #endif
 #if defined(HAVE_FDATASYNC)
 	if (revio_flags & REVIO_OPT_FDATASYNC)
 		(void)shim_fdatasync(fd);
-	if (!stress_continue_flag())
+	if (UNLIKELY(!stress_continue_flag()))
 		return ret;
 #endif
 #if defined(HAVE_SYNCFS)
 	if (revio_flags & REVIO_OPT_SYNCFS)
 		(void)syncfs(fd);
-	if (!stress_continue_flag())
+	if (UNLIKELY(!stress_continue_flag()))
 		return ret;
 #endif
 
@@ -179,7 +179,8 @@ static ssize_t stress_revio_write(
  */
 static void stress_revio_opts(const char *opt_name, const char *opt_arg, stress_type_id_t *type_id, void *value)
 {
-	char *str, *ptr, *token;
+	char *str, *ptr;
+	const char *token;
 	int revio_flags = 0;
 	int revio_oflags = 0;
 	bool opts_set = false;
@@ -234,9 +235,9 @@ static void stress_revio_opts(const char *opt_name, const char *opt_arg, stress_
 		}
 	}
 
-	stress_set_setting("revio-flags", TYPE_ID_INT, &revio_flags);
-	stress_set_setting("revio-oflags", TYPE_ID_INT, &revio_oflags);
-	stress_set_setting("revio-opts-set", TYPE_ID_BOOL, &opts_set);
+	stress_set_setting("revio", "revio-flags", TYPE_ID_INT, &revio_flags);
+	stress_set_setting("revio", "revio-oflags", TYPE_ID_INT, &revio_oflags);
+	stress_set_setting("revio", "revio-opts-set", TYPE_ID_BOOL, &opts_set);
 	free(str);
 }
 
@@ -255,7 +256,7 @@ static int stress_revio_advise(stress_args_t *args, const int fd, const int flag
 	if (!(flags & REVIO_OPT_FADV_MASK))
 		return 0;
 
-	for (i = 0; stress_continue(args) && (i < SIZEOF_ARRAY(revio_opts)); i++) {
+	for (i = 0; LIKELY(stress_continue(args) && (i < SIZEOF_ARRAY(revio_opts))); i++) {
 		if (revio_opts[i].flag & flags) {
 			if (posix_fadvise(fd, 0, 0, revio_opts[i].advice) < 0) {
 				pr_fail("%s: posix_fadvise failed, errno=%d (%s)\n",
@@ -401,7 +402,7 @@ static int stress_revio(stress_args_t *args)
 			off_t lseek_ret;
 			const off_t offset = (off_t)(revio_bytes - i);
 seq_wr_retry:
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				break;
 
 			lseek_ret = lseek(fd, offset, SEEK_SET);
