@@ -104,10 +104,12 @@ static void OPTIMIZE3 *stress_sem_thrash(void *arg)
 	stress_args_t *args = p_args->args;
 	stress_sem_pthread_t *pthread = (stress_sem_pthread_t *)p_args->data;
 
+	stress_random_small_sleep();
+
 	do {
 		int i, j = -1;
 
-		for (i = 0; (i < 1000) && stress_continue_flag(); i++) {
+		for (i = 0; LIKELY((i < 1000) && stress_continue_flag()); i++) {
 			int value;
 			struct timespec ts;
 
@@ -257,7 +259,7 @@ static int stress_sem(stress_args_t *args)
 				args->name, sem_pthreads[i].ret, strerror(sem_pthreads[i].ret));
 			break;
 		}
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 		created = true;
 	}
