@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -39,7 +39,7 @@ typedef struct {
 	int	err;		/* copy of errno */
 } session_error_t;
 
-static char * PURE stress_session_error(int err)
+static char * PURE stress_session_error(const int err)
 {
 	switch (err) {
 	case STRESS_SESSION_SUCCESS:
@@ -85,7 +85,7 @@ static int stress_session_set_and_get(stress_args_t *args, const int fd)
 	pid_t sid, gsid;
 
 	sid = setsid();
-	if (sid == (pid_t)-1) {
+	if (UNLIKELY(sid == (pid_t)-1)) {
 		stress_session_return_status(fd, errno, STRESS_SESSION_SETSID_FAILED);
 		pr_inf("%s: setsid failed: errno=%d (%s)\n",
 			args->name, errno, strerror(errno));
@@ -93,14 +93,14 @@ static int stress_session_set_and_get(stress_args_t *args, const int fd)
 	}
 
 	gsid = getsid(getpid());
-	if (gsid == (pid_t)-1) {
+	if (UNLIKELY(gsid == (pid_t)-1)) {
 		stress_session_return_status(fd, errno, STRESS_SESSION_GETSID_FAILED);
 		pr_inf("%s: getsid failed: errno=%d (%s)\n",
 			args->name, errno, strerror(errno));
 		return STRESS_SESSION_GETSID_FAILED;
 	}
 
-	if (gsid != sid) {
+	if (UNLIKELY(gsid != sid)) {
 		stress_session_return_status(fd, errno, STRESS_SESSION_WRONGSID_FAILED);
 		pr_inf("%s getsid failed, got session ID %d, expected %d\n",
 			args->name, (int)gsid, (int)sid);
@@ -156,7 +156,7 @@ static int stress_session_child(stress_args_t *args, const int fd)
 			ret = shim_waitpid(pid, &status, 0);
 #endif
 			if (ret < 0) {
-				if ((errno != EINTR) && (errno == ECHILD)) {
+				if (UNLIKELY((errno != EINTR) && (errno == ECHILD))) {
 					stress_session_return_status(fd, errno, STRESS_SESSION_WAITPID_FAILED);
 					return STRESS_SESSION_WAITPID_FAILED;
 				}
@@ -241,7 +241,7 @@ static int stress_session(stress_args_t *args)
 	return rc;
 }
 
-stressor_info_t stress_session_info = {
+const stressor_info_t stress_session_info = {
 	.stressor = stress_session,
 	.class = CLASS_SCHEDULER | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
