@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -292,8 +292,10 @@ static int stress_sigfpe(stress_args_t *args)
 	}
 
 	(void)alarm(0);
-	stress_set_proc_state(args->name, STRESS_STATE_RUN);
+
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
+	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	for (;;) {
 #if defined(STRESS_CHECK_SIGINFO)
@@ -328,8 +330,8 @@ static int stress_sigfpe(stress_args_t *args)
 #if defined(STRESS_CHECK_SIGINFO)
 			if (verify) {
 				if (signum == SIGFPE) {
-					if ((siginfo.si_code >= 0) &&
-				            (siginfo.si_code != expected_err_code)) {
+					if (UNLIKELY((siginfo.si_code >= 0) &&
+						     (siginfo.si_code != expected_err_code))) {
 						pr_fail("%s: got SIGFPE error %d (%s), expecting %d (%s)\n",
 							args->name,
 							siginfo.si_code, stress_sigfpe_errstr(siginfo.si_code),
@@ -375,7 +377,7 @@ static int stress_sigfpe(stress_args_t *args)
 			}
 		}
 		i++;
-		if (i >= (int)SIZEOF_ARRAY(fpe_errs))
+		if (UNLIKELY(i >= (int)SIZEOF_ARRAY(fpe_errs)))
 			i = 0;
 	}
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
@@ -385,14 +387,14 @@ static int stress_sigfpe(stress_args_t *args)
 	return rc;
 }
 
-stressor_info_t stress_sigfpe_info = {
+const stressor_info_t stress_sigfpe_info = {
 	.stressor = stress_sigfpe,
-	.class = CLASS_INTERRUPT | CLASS_OS,
+	.class = CLASS_SIGNAL | CLASS_OS,
 	.verify = VERIFY_OPTIONAL,
 	.help = help
 };
 #else
-stressor_info_t stress_sigfpe_info = {
+const stressor_info_t stress_sigfpe_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_SIGNAL | CLASS_OS,
 	.verify = VERIFY_OPTIONAL,
