@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2024      Colin Ian King.
+ * Copyright (C) 2024-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,6 +29,7 @@ static const stress_help_t help[] = {
 #define HAVE_ILLEGAL_OP
 static void stress_illegal_op(void)
 {
+	__asm__ __volatile(".inst 0x0000bfff\n");
 	__asm__ __volatile(".inst 0x0000dead\n");
 }
 #endif
@@ -53,6 +54,8 @@ static void stress_illegal_op(void)
 #define HAVE_ILLEGAL_OP
 static void stress_illegal_op(void)
 {
+	/* Loong64 is LE */
+	__asm__ __volatile__(".byte 0x3f,0x00,0x00,0x00\n");
 }
 #endif
 
@@ -65,7 +68,20 @@ static void stress_illegal_op(void)
 #endif
 
 #if defined(STRESS_ARCH_MIPS)
-/* No implemented */
+#if defined(__MIPSEB__) || defined(__MIPSEB) || defined(_MIPSEB) || defined(MIPSEB)
+#define HAVE_ILLEGAL_OP
+static void stress_illegal_op(void)
+{
+	__asm__ __volatile__(".byte 0x00,0x00,0x00,0x3b\n");
+}
+#endif
+#if defined(__MIPSEL__) || defined(__MIPSEL) || defined(_MIPSEL) || defined(MIPSEL)
+#define HAVE_ILLEGAL_OP
+static void stress_illegal_op(void)
+{
+	__asm__ __volatile__(".byte 0x3b,0x00,0x00,0x00\n");
+}
+#endif
 #endif
 
 #if defined(STRESS_ARCH_PPC64)
@@ -179,15 +195,15 @@ static int stress_sigill(stress_args_t *args)
 		 * We return here if we get a SIGILL, so
 		 * first check if we need to terminate
 		 */
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			break;
 
 		if (ret) {
 			/* Signal was tripped */
 #if defined(SA_SIGINFO)
-			if (verify &&
-			    (signo != -1) &&
-			    (signo != SIGILL)) {
+			if (UNLIKELY(verify &&
+				     (signo != -1) &&
+				     (signo != SIGILL))) {
 				pr_fail("%s: expecting SIGILL, got %s instead\n",
 					args->name, strsignal(signo));
 			}
@@ -248,14 +264,17 @@ static int stress_sigill(stress_args_t *args)
 		action.sa_flags = SA_SIGINFO;
 #endif
 		ret = sigaction(SIGILL, &action, NULL);
-		if (ret < 0) {
+		if (UNLIKELY(ret < 0)) {
 			pr_fail("%s: sigaction SIGILL: errno=%d (%s)\n",
 				args->name, errno, strerror(errno));
 			break;
-
-
 		}
-
+		ret = sigaction(SIGBUS, &action, NULL);
+		if (UNLIKELY(ret < 0)) {
+			pr_fail("%s: sigaction SIGBUS: errno=%d (%s)\n",
+				args->name, errno, strerror(errno));
+			break;
+		}
 		stress_illegal_op();
 	}
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
