@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -40,6 +40,9 @@ static const int defined_signals[] = {
 #if defined(SIGCHLD)
 	SIGCHLD,
 #endif
+#if defined(SIGCONT)
+	SIGCONT,
+#endif
 #if defined(SIGEMT)
 	SIGEMT,
 #endif
@@ -52,12 +55,12 @@ static const int defined_signals[] = {
 #if defined(SIGILL)
 	SIGILL,
 #endif
-#if defined(SIGINT)
-	SIGINT,
-#endif
 #if defined(SIGINFO)
 	SIGINFO,
 #endif
+#if defined(SIGINT)
+	SIGINT,
+#endif
 #if defined(SIGIO)
 	SIGIO,
 #endif
@@ -97,21 +100,27 @@ static const int defined_signals[] = {
 #if defined(SIGTRAP)
 	SIGTRAP,
 #endif
+#if defined(SIGTSTP)
+	SIGTSTP,
+#endif
 #if defined(SIGTTIN)
 	SIGTTIN,
 #endif
 #if defined(SIGTTOU)
 	SIGTTOU,
 #endif
+#if defined(SIGUNUSED)
+	SIGUNUSED,
+#endif
+#if defined(SIGURG)
+	SIGURG,
+#endif
 #if defined(SIGUSR1)
 	SIGUSR1,
 #endif
 #if defined(SIGUSR2)
 	SIGUSR2,
 #endif
-#if defined(SIGURG)
-	SIGURG,
-#endif
 #if defined(SIGVTALRM)
 	SIGVTALRM,
 #endif
@@ -315,7 +324,7 @@ finish:
 	}
 
 	if (args->instance == 0) {
-		buf = calloc(sz, sizeof(*buf));
+		buf = (char *)calloc(sz, sizeof(*buf));
 		if (buf) {
 			for (ptr = buf, i = 0; i < max_signals; i++) {
 				if (signal_info.signalled & STRESS_BIT_ULL(i)) {
