@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -55,7 +55,8 @@ static int stress_sigrt(stress_args_t *args)
 			args->name, stress_sigrt_metrics_size);
 		return EXIT_NO_RESOURCE;
 	}
-	pids = calloc((size_t)MAX_RTPIDS, sizeof(*pids));
+	stress_set_vma_anon_name(stress_sigrt_metrics, stress_sigrt_metrics_size, "metrics");
+	pids = (pid_t *)calloc((size_t)MAX_RTPIDS, sizeof(*pids));
 	if (!pids) {
 		pr_inf_skip("%s: cannot allocate array of %zd pids, skipping stressor\n",
 			args->name, (size_t)MAX_RTPIDS);
@@ -63,10 +64,8 @@ static int stress_sigrt(stress_args_t *args)
 		return EXIT_NO_RESOURCE;
 	}
 
+	stress_zero_metrics(stress_sigrt_metrics, MAX_RTPIDS);
 	for (i = 0; i < MAX_RTPIDS; i++) {
-		stress_sigrt_metrics[i].duration = 0.0;
-		stress_sigrt_metrics[i].count = 0.0;
-
 		if (stress_sighandler(args->name, i + SIGRTMIN, stress_sighandler_nop, NULL) < 0) {
 			free(pids);
 			(void)munmap((void *)stress_sigrt_metrics, stress_sigrt_metrics_size);
@@ -74,8 +73,9 @@ static int stress_sigrt(stress_args_t *args)
 		}
 	}
 
-	stress_set_proc_state(args->name, STRESS_STATE_RUN);
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
+	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	for (i = 0; i < MAX_RTPIDS; i++) {
 again:
@@ -83,7 +83,7 @@ again:
 		if (pids[i] < 0) {
 			if (stress_redo_fork(args, errno))
 				goto again;
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				goto reap;
 			pr_err("%s: fork failed, errno=%d (%s)\n",
 				args->name, errno, strerror(errno));
@@ -103,7 +103,6 @@ again:
 			(void)shim_memset(&info, 0, sizeof info);
 
 			while (stress_continue_flag()) {
-
 				if (UNLIKELY(sigwaitinfo(&mask, &info) < 0)) {
 					if (errno == EINTR)
 						continue;
@@ -193,14 +192,14 @@ reap:
 	return rc;
 }
 
-stressor_info_t stress_sigrt_info = {
+const stressor_info_t stress_sigrt_info = {
 	.stressor = stress_sigrt,
-	.class = CLASS_INTERRUPT | CLASS_OS,
+	.class = CLASS_SIGNAL | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
 	.help = help
 };
 #else
-stressor_info_t stress_sigrt_info = {
+const stressor_info_t stress_sigrt_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_SIGNAL | CLASS_OS,
 	.verify = VERIFY_ALWAYS,
