@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,15 +21,15 @@
 #include "core-arch.h"
 
 static const stress_help_t help[] = {
-	{ NULL,	"sigtrap N",	 "start N workers generating segmentation faults" },
-	{ NULL,	"sigtrap-ops N", "stop after N bogo segmentation faults" },
+	{ NULL,	"sigtrap N",	 "start N workers generating SIGTRAP signals" },
+	{ NULL,	"sigtrap-ops N", "stop after N bogo SIGTRAP operations" },
 	{ NULL,	NULL,		 NULL }
 };
 
 #if defined(SIGTRAP)
 
 static uint64_t counter;
-double t, duration;
+static double t, duration;
 
 static void MLOCKED_TEXT stress_sigtrap_handler(int num)
 {
@@ -47,7 +47,7 @@ static void MLOCKED_TEXT stress_sigtrap_handler(int num)
  */
 static int stress_sigtrap(stress_args_t *args)
 {
-	uint64_t raised = 0;
+	uint64_t raised ALIGN64 = 0;
 	double rate = 0.0;
 
 	counter = 0;
