@@ -43,7 +43,8 @@ static inline void OPTIMIZE3 socket_pair_memset(
 	uint8_t val,
 	const size_t sz)
 {
-	register uint8_t *ptr, *buf_end = buf + sz;
+	register uint8_t *ptr;
+	register const uint8_t *buf_end = buf + sz;
 	register uint8_t checksum = 0;
 
 PRAGMA_UNROLL_N(4)
@@ -60,7 +61,7 @@ static inline int OPTIMIZE3 socket_pair_memchk(
 	uint8_t *buf,
 	const size_t sz)
 {
-	register uint8_t *ptr, *buf_end = buf + sz;
+	register const uint8_t *ptr, *buf_end = buf + sz;
 	register uint8_t checksum = 0;
 
 PRAGMA_UNROLL_N(4)
@@ -226,7 +227,7 @@ again:
 			uint8_t buf[SOCKET_PAIR_BUF] ALIGN64;
 			ssize_t n;
 
-			for (i = 0; stress_continue(args) && (i < max); i++) {
+			for (i = 0; LIKELY(stress_continue(args) && (i < max)); i++) {
 				errno = 0;
 
 				n = read(socket_pair_fds[i][0], buf, sizeof(buf));
@@ -271,14 +272,14 @@ abort:
 		socket_pair_close(socket_pair_fds, max, 0);
 
 		do {
-			for (i = 0; stress_continue(args) && (i < max); i++) {
+			for (i = 0; LIKELY(stress_continue(args) && (i < max)); i++) {
 				ssize_t wret;
 
 				/* Low memory avoidance, re-start */
 				if (UNLIKELY(oom_avoid)) {
 					while (stress_low_memory(low_mem_size)) {
 						low_memory_count++;
-						if (!stress_continue_flag())
+						if (UNLIKELY(!stress_continue_flag()))
 							goto tidy;
 						(void)shim_usleep(100000);
 					}
