@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2021-2024 Colin Ian King.
+ * Copyright (C) 2021-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -156,29 +156,17 @@ static void MLOCKED_TEXT NORETURN stress_rlimit_handler(int signum)
  */
 static void drop_niceness(void)
 {
-	int nice_val, i;
-
-	errno = 0;
-	nice_val = nice(0);
-
-	/* Should never fail */
-	if (errno)
-		return;
+	int i;
 
 	/*
 	 *  Traditionally no more than -20, but see if we
 	 *  can force it lower if we are originally running
 	 *  at nice level 19
 	 */
-	for (i = 0; i < 40; i++) {
-		int old_nice_val = nice_val;
-
+	errno = EPERM;
+	for (i = -40; (i < 0) && errno; i++) {
 		errno = 0;
-		nice_val = nice(-1);
-		if (errno)
-			return;
-		if (nice_val == old_nice_val)
-			return;
+		VOID_RET(int, nice(i));
 	}
 }
 
@@ -201,7 +189,7 @@ static void stress_softlockup_child(
 	 *  ramping up the scheduler priority
 	 */
 	while (softlockup_start && stress_continue(args)) {
-		shim_usleep(100000);
+		(void)shim_usleep(100000);
 	}
 
 	/*
@@ -353,7 +341,7 @@ again:
 		if (s_pids[i].pid < 0) {
 			if (stress_redo_fork(args, errno))
 				goto again;
-			if (!stress_continue(args))
+			if (UNLIKELY(!stress_continue(args)))
 				goto finish;
 			pr_inf("%s: cannot fork, errno=%d (%s)\n",
 				args->name, errno, strerror(errno));
