@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -58,6 +58,7 @@ static int stress_spawn_supported(const char *name)
  */
 static int stress_spawn(stress_args_t *args)
 {
+	int rc = EXIT_SUCCESS;
 	char *path;
 	char exec_path[PATH_MAX];
 	uint64_t spawn_fails = 0, spawn_calls = 0;
@@ -86,6 +87,8 @@ static int stress_spawn(stress_args_t *args)
 	}
 	argv_new[0] = path;
 
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
+	stress_sync_start_wait(args);
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	do {
@@ -97,6 +100,7 @@ static int stress_spawn(stress_args_t *args)
 		if (ret < 0) {
 			pr_fail("%s: posix_spawn failed, errno=%d (%s)\n",
 				args->name, errno, strerror(errno));
+			rc = EXIT_FAILURE;
 			spawn_fails++;
 		} else {
 			int status;
@@ -113,13 +117,14 @@ static int stress_spawn(stress_args_t *args)
 		pr_fail("%s: %" PRIu64 " spawns failed (%.2f%%)\n",
 			args->name, spawn_fails,
 			(double)spawn_fails * 100.0 / (double)(spawn_calls));
+		rc = EXIT_FAILURE;
 	}
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 
-	return EXIT_SUCCESS;
+	return rc;
 }
 
-stressor_info_t stress_spawn_info = {
+const stressor_info_t stress_spawn_info = {
 	.stressor = stress_spawn,
 	.supported = stress_spawn_supported,
 	.class = CLASS_SCHEDULER | CLASS_OS,
@@ -127,7 +132,7 @@ stressor_info_t stress_spawn_info = {
 	.help = help
 };
 #else
-stressor_info_t stress_spawn_info = {
+const stressor_info_t stress_spawn_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_SCHEDULER | CLASS_OS,
 	.verify = VERIFY_OPTIONAL,
