@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -134,7 +134,7 @@ static void stress_splice_looped_pipe(
 {
 	ssize_t ret;
 
-	if (!*use_splice_loop)
+	if (UNLIKELY(!*use_splice_loop))
 		return;
 
 	ret = splice(fds3[0], 0, fds4[1], 0, 4096, stress_splice_flag());
