@@ -164,8 +164,8 @@ static int stress_sync_file(stress_args_t *args)
 				continue;
 			break;
 		}
-		for (offset = 0; stress_continue_flag() &&
-		     (offset < (shim_off64_t)sync_file_bytes); ) {
+		for (offset = 0; LIKELY(stress_continue_flag() &&
+		     (offset < (shim_off64_t)sync_file_bytes)); ) {
 			const shim_off64_t sz = (stress_mwc32() & 0x1fc00) + KB;
 
 			ret = shim_sync_file_range(fd, offset, sz, mode);
@@ -205,8 +205,8 @@ static int stress_sync_file(stress_args_t *args)
 				continue;
 			break;
 		}
-		for (offset = 0; stress_continue_flag() &&
-		     (offset < (shim_off64_t)sync_file_bytes); ) {
+		for (offset = 0; LIKELY(stress_continue_flag() &&
+		     (offset < (shim_off64_t)sync_file_bytes)); ) {
 			const shim_off64_t sz = (stress_mwc32() & 0x1fc00) + KB;
 
 			ret = shim_sync_file_range(fd, sync_file_bytes - offset, sz, mode);
@@ -232,8 +232,8 @@ static int stress_sync_file(stress_args_t *args)
 				continue;
 			break;
 		}
-		for (i = 0; stress_continue_flag() &&
-		     (i < (shim_off64_t)sync_file_bytes / (shim_off64_t)(128 * KB)); i++) {
+		for (i = 0; LIKELY(stress_continue_flag() &&
+		     (i < (shim_off64_t)sync_file_bytes / (shim_off64_t)(128 * KB))); i++) {
 			offset = (shim_off64_t)(stress_mwc64modn((uint64_t)sync_file_bytes) & ~((128 * KB) - 1));
 
 			ret = shim_sync_file_range(fd, offset, 128 * KB, mode);
