@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2024 Colin Ian King
+ * Copyright (C) 2021-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -134,10 +134,10 @@ static void stress_syncload_rdrand(void)
 
 static void stress_syncload_sched_yield(void)
 {
-	shim_sched_yield();
-	shim_sched_yield();
-	shim_sched_yield();
-	shim_sched_yield();
+	(void)shim_sched_yield();
+	(void)shim_sched_yield();
+	(void)shim_sched_yield();
+	(void)shim_sched_yield();
 }
 
 static void stress_syncload_mfence(void)
@@ -175,10 +175,7 @@ static void stress_syncload_atomic(void)
 
 static void stress_syncload_nice(void)
 {
-	int niceness;
-
-	niceness = nice(0);
-	(void)niceness;
+	VOID_RET(int, nice(0));
 }
 
 static void stress_syncload_spinwrite(void)
@@ -314,7 +311,7 @@ static int stress_syncload(stress_args_t *args)
 		const stress_syncload_op_t op = stress_syncload_ops[delay_type];
 
 		delay_type++;
-		if (delay_type >= SIZEOF_ARRAY(stress_syncload_ops))
+		if (UNLIKELY(delay_type >= SIZEOF_ARRAY(stress_syncload_ops)))
 			delay_type = 0;
 
 		timeout += sec_busy;
@@ -326,7 +323,7 @@ static int stress_syncload(stress_args_t *args)
 		if (now < timeout) {
 			const uint64_t duration_us = (uint64_t)((timeout - now) * 1000000);
 
-			shim_nanosleep_uint64(duration_us * 1000);
+			(void)shim_nanosleep_uint64(duration_us * 1000);
 		}
 
 		stress_bogo_inc(args);
@@ -336,7 +333,7 @@ static int stress_syncload(stress_args_t *args)
 	return EXIT_SUCCESS;
 }
 
-stressor_info_t stress_syncload_info = {
+const stressor_info_t stress_syncload_info = {
 	.stressor = stress_syncload,
 	.class = CLASS_CPU,
 	.opts = opts,
