@@ -1229,7 +1229,7 @@ static void bad_lstat3(stress_bad_addr_t *ba, volatile uint64_t *counter)
 static void bad_madvise(stress_bad_addr_t *ba, volatile uint64_t *counter)
 {
 	(*counter)++;
-	VOID_RET(int, madvise((void *)ba->addr, 8192, MADV_NORMAL));
+	VOID_RET(int, shim_madvise((void *)ba->addr, 8192, SHIM_MADV_NORMAL));
 }
 #else
 UNEXPECTED
@@ -1512,8 +1512,8 @@ UNEXPECTED
 static void bad_ppoll1(stress_bad_addr_t *ba, volatile uint64_t *counter)
 {
 	void *addr = (char *)ba->addr;
-	struct timespec *ts = (struct timespec *)inc_addr(addr, sizeof(struct pollfd));
-	sigset_t *ss = (sigset_t *)(inc_addr(addr, sizeof(struct pollfd) + sizeof(struct timespec)));
+	const struct timespec *ts = (struct timespec *)inc_addr(addr, sizeof(struct pollfd));
+	const sigset_t *ss = (sigset_t *)(inc_addr(addr, sizeof(struct pollfd) + sizeof(struct timespec)));
 
 	(*counter)++;
 	VOID_RET(int, shim_ppoll((struct pollfd *)addr, (nfds_t)1, ts, ss));
@@ -2389,7 +2389,7 @@ static inline int stress_do_syscall(stress_args_t *args)
 	/* force update of 1 bit mwc random val */
 	(void)stress_mwc1();
 
-	if (!stress_continue(args))
+	if (UNLIKELY(!stress_continue(args)))
 		return 0;
 	pid = fork();
 	if (pid < 0) {
@@ -2478,7 +2478,7 @@ static int stress_sysbadaddr_child(stress_args_t *args, void *context)
 
 			state->addr_index = 0;
 			while (state->addr_index < SIZEOF_ARRAY(bad_addrs)) {
-				void *addr = bad_addrs[state->addr_index].addr;
+				const void *addr = bad_addrs[state->addr_index].addr;
 
 				if (addr)
 					stress_do_syscall(args);
