@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -52,7 +52,7 @@ static pid_t stress_tee_spawn(
 {
 	pid_t pid;
 
-	if (pipe(fds) < 0) {
+	if (UNLIKELY(pipe(fds) < 0)) {
 		pr_err("%s: pipe failed: %d (%s)\n",
 			args->name, errno, strerror(errno));
 		return -1;
@@ -65,13 +65,12 @@ again:
 			goto again;
 		(void)close(fds[0]);
 		(void)close(fds[1]);
-		if (!stress_continue(args))
+		if (UNLIKELY(!stress_continue(args)))
 			return -1;
 		pr_err("%s: fork failed: %d (%s)\n",
 			args->name, errno, strerror(errno));
 		return -1;
-	}
-	if (pid == 0) {
+	} else if (pid == 0) {
 		stress_parent_died_alarm();
 		(void)sched_settings_apply(true);
 
@@ -132,9 +131,10 @@ static void stress_tee_pipe_read(stress_args_t *args, int fds[2])
 
 	while (stress_continue_flag()) {
 		register size_t n = 0;
-		ssize_t ret;
 
 		while (n < sizeof(data)) {
+			ssize_t ret;
+
 			ret = read(fds[0], &data, sizeof(data));
 			if (UNLIKELY(ret < 0)) {
 				switch (errno) {
@@ -274,7 +274,7 @@ static int stress_tee(stress_args_t *args)
 				goto do_splice;
 			}
 		}
-		if (len == 0)
+		if (UNLIKELY(len == 0))
 			break;
 
 		if (UNLIKELY(len < 0)) {
@@ -311,7 +311,7 @@ do_splice:
 			len -= slen;
 		}
 
-		if (exercise_tee(args, release, pipe_in[0], pipe_out[1]) < 0)
+		if (UNLIKELY(exercise_tee(args, release, pipe_in[0], pipe_out[1]) < 0))
 			goto tidy_child2;
 
 		stress_bogo_inc(args);
@@ -338,14 +338,14 @@ tidy_fd:
 	return ret;
 }
 
-stressor_info_t stress_tee_info = {
+const stressor_info_t stress_tee_info = {
 	.stressor = stress_tee,
 	.class = CLASS_PIPE_IO | CLASS_OS | CLASS_SCHEDULER,
 	.verify = VERIFY_ALWAYS,
 	.help = help
 };
 #else
-stressor_info_t stress_tee_info = {
+const stressor_info_t stress_tee_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_PIPE_IO | CLASS_OS | CLASS_SCHEDULER,
 	.verify = VERIFY_ALWAYS,
