@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -112,7 +112,8 @@ static const touch_method_t touch_methods[] = {
  */
 static void stress_touch_opts(const char *opt_name, const char *opt_arg, stress_type_id_t *type_id, void *value)
 {
-	char *str, *ptr, *token;
+	char *str, *ptr;
+	const char *token;
 	int open_flags = 0;
 
 	str = stress_const_optdup(opt_arg);
@@ -161,7 +162,7 @@ static void stress_touch_dir_clean(stress_args_t *args)
 {
 	char tmp[PATH_MAX];
 	DIR *dir;
-	struct dirent *d;
+	const struct dirent *d;
 
 	sync();
 	stress_temp_dir(tmp, sizeof(tmp), args->name,
@@ -171,10 +172,17 @@ static void stress_touch_dir_clean(stress_args_t *args)
 	if (!dir)
 		return;
 	while ((d = readdir(dir)) != NULL) {
-		char filename[PATH_MAX + sizeof(d->d_name) + 1];
+		/*
+		 * One file name (with a path) and one NUL character (PATH_MAX),
+		 * one slash (1), another file name without a path (NAME_MAX).
+		 * This can produce a result that exceeds the OS limit, but the
+		 * buffer size will be sufficient to join the strings safely
+		 * without upsetting the compiler.
+		 */
+		char filename[PATH_MAX + 1 + NAME_MAX];
 		struct stat statbuf;
 
-		(void)snprintf(filename, sizeof(filename), "%s/%s\n", tmp, d->d_name);
+		(void)snprintf(filename, sizeof(filename), "%s/%s", tmp, d->d_name);
 		if (shim_stat(filename, &statbuf) < 0)
 			continue;
 		if ((statbuf.st_mode & S_IFMT) == S_IFREG)
@@ -194,12 +202,12 @@ static void stress_touch_loop(
 		int fd, ret;
 
 		ret = stress_lock_acquire(touch_lock);
-		if (ret)
+		if (UNLIKELY(ret))
 			break;
 		counter = stress_bogo_get(args);
 		stress_bogo_inc(args);
 		ret = stress_lock_release(touch_lock);
-		if (ret)
+		if (UNLIKELY(ret))
 			break;
 		(void)stress_temp_filename_args(args, filename,
 			sizeof(filename), counter);
@@ -220,7 +228,7 @@ static void stress_touch_loop(
 			break;
 		}
 
-		if (fd < 0) {
+		if (UNLIKELY(fd < 0)) {
 			switch (errno) {
 #if defined(EEXIST)
 			case EEXIST:
