@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2016-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -126,7 +126,7 @@ typedef struct btree_node {
 } btree_node_t;
 
 /*
- *  We can enable struct packing for x86 since
+ *  We can enable struct packing for 64 bit x86 since
  *  this allows unaligned access of packed pointers.
  *  For large trees where stressing becomes memory
  *  bound once the tree is larger than the cache
@@ -134,7 +134,7 @@ typedef struct btree_node {
  *  since the memory stall penalty is much larger than
  *  the misaligned pointer access penalty.
  */
-#if !defined(STRESS_ARCH_X86)
+#if !defined(STRESS_ARCH_X86_64)
 #undef PACKED
 #define PACKED
 #endif
@@ -217,12 +217,12 @@ PRAGMA_UNROLL_N(4)
 	}
 	metrics->insert += stress_time_now() - t;
 
-	/* Manditory forward tree check */
+	/* Mandatory forward tree check */
 	t = stress_time_now();
 PRAGMA_UNROLL_N(4)
 	for (node = nodes, i = 0; i < n; i++, node++) {
 		find = RB_FIND(stress_rb_tree, &rb_root, node);
-		if (!find) {
+		if (UNLIKELY(!find)) {
 			pr_fail("%s: rb tree node #%zd not found\n",
 				args->name, i);
 			*rc = EXIT_FAILURE;
@@ -234,7 +234,7 @@ PRAGMA_UNROLL_N(4)
 		/* optional reverse find */
 		for (node = &nodes[n - 1], i = n - 1; node >= nodes; node--, i--) {
 			find = RB_FIND(stress_rb_tree, &rb_root, node);
-			if (!find) {
+			if (UNLIKELY(!find)) {
 				pr_fail("%s: rb tree node #%zd not found\n",
 					args->name, i);
 				*rc = EXIT_FAILURE;
@@ -246,7 +246,7 @@ PRAGMA_UNROLL_N(4)
 			const size_t j = stress_mwc32modn(n);
 
 			find = RB_FIND(stress_rb_tree, &rb_root, &nodes[j]);
-			if (!find) {
+			if (UNLIKELY(!find)) {
 				pr_fail("%s: rb tree node #%zd not found\n",
 					args->name, j);
 				*rc = EXIT_FAILURE;
@@ -294,12 +294,12 @@ PRAGMA_UNROLL_N(4)
 	}
 	metrics->insert += stress_time_now() - t;
 
-	/* Manditory forward tree check */
+	/* Mandatory forward tree check */
 	t = stress_time_now();
 PRAGMA_UNROLL_N(4)
 	for (node = nodes, i = 0; i < n; i++, node++) {
 		find = SPLAY_FIND(stress_splay_tree, &splay_root, node);
-		if (!find) {
+		if (UNLIKELY(!find)) {
 			pr_fail("%s: splay tree node #%zd not found\n",
 				args->name, i);
 			*rc = EXIT_FAILURE;
@@ -311,7 +311,7 @@ PRAGMA_UNROLL_N(4)
 		/* optional reverse find */
 		for (node = &nodes[n - 1], i = n - 1; node >= nodes; node--, i--) {
 			find = SPLAY_FIND(stress_splay_tree, &splay_root, node);
-			if (!find) {
+			if (UNLIKELY(!find)) {
 				pr_fail("%s: splay tree node #%zd not found\n",
 					args->name, i);
 				*rc = EXIT_FAILURE;
@@ -322,7 +322,7 @@ PRAGMA_UNROLL_N(4)
 			const size_t j = stress_mwc32modn(n);
 
 			find = SPLAY_FIND(stress_splay_tree, &splay_root, &nodes[j]);
-			if (!find) {
+			if (UNLIKELY(!find)) {
 				pr_fail("%s: splay tree node #%zd not found\n",
 					args->name, j);
 				*rc = EXIT_FAILURE;
@@ -388,7 +388,7 @@ static void OPTIMIZE3 stress_tree_binary(
 {
 	size_t i;
 	struct tree_node *node, *head = NULL;
-	struct tree_node *find;
+	const struct tree_node *find;
 	double t;
 
 	t = stress_time_now();
@@ -398,12 +398,12 @@ PRAGMA_UNROLL_N(4)
 	}
 	metrics->insert += stress_time_now() - t;
 
-	/* Manditory forward tree check */
+	/* Mandatory forward tree check */
 	t = stress_time_now();
 PRAGMA_UNROLL_N(4)
 	for (node = nodes, i = 0; i < n; i++, node++) {
 		find = binary_find(head, node);
-		if (!find) {
+		if (UNLIKELY(!find)) {
 			pr_fail("%s: binary tree node #%zd not found\n",
 				args->name, i);
 			*rc = EXIT_FAILURE;
@@ -415,7 +415,7 @@ PRAGMA_UNROLL_N(4)
 		/* optional reverse find */
 		for (node = &nodes[n - 1], i = n - 1; node >= nodes; node--, i--) {
 			find = binary_find(head, node);
-			if (!find) {
+			if (UNLIKELY(!find)) {
 				pr_fail("%s: binary tree node #%zd not found\n",
 					args->name, i);
 				*rc = EXIT_FAILURE;
@@ -426,7 +426,7 @@ PRAGMA_UNROLL_N(4)
 			const size_t j = stress_mwc32modn(n);
 
 			find = binary_find(head, &nodes[j]);
-			if (!find) {
+			if (UNLIKELY(!find)) {
 				pr_fail("%s: binary tree node #%zd not found\n",
 					args->name, j);
 				*rc = EXIT_FAILURE;
@@ -602,7 +602,7 @@ static void OPTIMIZE3 stress_tree_avl(
 {
 	size_t i;
 	struct tree_node *node, *head = NULL;
-	struct tree_node *find;
+	const struct tree_node *find;
 	double t;
 
 	t = stress_time_now();
@@ -612,12 +612,12 @@ PRAGMA_UNROLL_N(4)
 	}
 	metrics->insert += stress_time_now() - t;
 
-	/* Manditory forward tree check */
+	/* Mandatory forward tree check */
 	t = stress_time_now();
 PRAGMA_UNROLL_N(4)
 	for (node = nodes, i = 0; i < n; i++, node++) {
 		find = avl_find(head, node);
-		if (!find) {
+		if (UNLIKELY(!find)) {
 			pr_fail("%s: avl tree node #%zd not found\n",
 				args->name, i);
 			*rc = EXIT_FAILURE;
@@ -629,7 +629,7 @@ PRAGMA_UNROLL_N(4)
 		/* optional reverse find */
 		for (node = &nodes[n - 1], i = n - 1; node >= nodes; node--, i--) {
 			find = avl_find(head, node);
-			if (!find) {
+			if (UNLIKELY(!find)) {
 				pr_fail("%s: avl tree node #%zd not found\n",
 					args->name, i);
 				*rc = EXIT_FAILURE;
@@ -640,7 +640,7 @@ PRAGMA_UNROLL_N(4)
 			const size_t j = stress_mwc32modn(n);
 
 			find = avl_find(head, &nodes[j]);
-			if (!find) {
+			if (UNLIKELY(!find)) {
 				pr_fail("%s: avl tree node #%zd not found\n",
 					args->name, j);
 				*rc = EXIT_FAILURE;
@@ -838,12 +838,12 @@ PRAGMA_UNROLL_N(4)
 		btree_insert(&root, node->value);
 	metrics->insert += stress_time_now() - t;
 
-	/* Manditory forward tree check */
+	/* Mandatory forward tree check */
 	t = stress_time_now();
 PRAGMA_UNROLL_N(4)
 	for (node = nodes, i = 0; i < n; i++, node++) {
 		find = btree_find(root, node->value);
-		if (!find) {
+		if (UNLIKELY(!find)) {
 			pr_fail("%s: btree node #%zd not found\n",
 				args->name, i);
 			*rc = EXIT_FAILURE;
@@ -855,7 +855,7 @@ PRAGMA_UNROLL_N(4)
 		/* optional reverse find */
 		for (node = &nodes[n - 1], i = n - 1; node >= nodes; node--, i--) {
 			find = btree_find(root, node->value);
-			if (!find) {
+			if (UNLIKELY(!find)) {
 				pr_fail("%s: btree node #%zd not found\n",
 					args->name, i);
 				*rc = EXIT_FAILURE;
@@ -866,7 +866,7 @@ PRAGMA_UNROLL_N(4)
 			const size_t j = stress_mwc32modn(n);
 
 			find = btree_find(root, nodes[j].value);
-			if (!find) {
+			if (UNLIKELY(!find)) {
 				pr_fail("%s: btree node #%zd not found\n",
 					args->name, j);
 				*rc = EXIT_FAILURE;
@@ -987,7 +987,7 @@ static int stress_tree(stress_args_t *args)
 			tree_size = MIN_TREE_SIZE;
 	}
 	n = (size_t)tree_size;
-	nodes = calloc(n, sizeof(*nodes));
+	nodes = (struct tree_node *)calloc(n, sizeof(*nodes));
 	if (!nodes) {
 		pr_inf_skip("%s: malloc failed allocating %zd tree nodes, "
 			"skipping stressor\n", args->name, n);
@@ -1048,7 +1048,7 @@ tidy:
 	return rc;
 }
 
-stressor_info_t stress_tree_info = {
+const stressor_info_t stress_tree_info = {
 	.stressor = stress_tree,
 	.class = CLASS_CPU_CACHE | CLASS_CPU | CLASS_MEMORY | CLASS_SEARCH,
 	.opts = opts,
