@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -111,11 +111,11 @@ static void check_unshare(
 
 	t = stress_time_now();
 	ret = shim_unshare(flags);
-	if ((ret < 0) &&
-            (errno != EPERM) &&
-            (errno != EACCES) &&
-            (errno != EINVAL) &&
-            (errno != ENOSPC)) {
+	if (UNLIKELY((ret < 0) &&
+		     (errno != EPERM) &&
+		     (errno != EACCES) &&
+		     (errno != EINVAL) &&
+		     (errno != ENOSPC))) {
 		pr_fail("%s: unshare(%s) failed, errno=%d (%s)\n",
 			args->name, flags_name,
 			errno, strerror(errno));
@@ -170,6 +170,7 @@ static int stress_unshare(stress_args_t *args)
 			args->name, unshare_info_size);
 		return EXIT_NO_RESOURCE;
 	}
+	stress_set_vma_anon_name(unshare_info, unshare_info_size, "unshare-metrics");
 
 	for (i = 0; i < MAX_PIDS; i++) {
 		unshare_info[i].duration = 0.0;
@@ -196,7 +197,7 @@ static int stress_unshare(stress_args_t *args)
 			int clone_flag = 0;
 			const bool do_flag_perm = stress_mwc1();
 
-			if (!stress_continue_flag())
+			if (UNLIKELY(!stress_continue_flag()))
 				break;
 			if (!enough_memory()) {
 				/* memory too low, back off */
