@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -103,9 +103,9 @@ static int stress_supported(const char *name)
  *  x86_64_syscall0()
  *      syscall 0 arg wrapper
  */
-static inline long x86_64_syscall0(const long number)
+static inline long int x86_64_syscall0(const long int number)
 {
-	register long ret;
+	register long int ret;
 
 	__asm__ __volatile__("syscall\n\t"
 			: "=a" (ret)
@@ -130,7 +130,7 @@ static int stress_sigsys_libc_mapping(uintptr_t *begin, uintptr_t *end)
 	uint64_t offset, dev_major, dev_minor, inode;
 
 	fp = fopen("/proc/self/maps", "r");
-	if (!fp)
+	if (UNLIKELY(!fp))
 		goto err;
 
 	*begin = ~(uintptr_t)0;
@@ -248,7 +248,7 @@ static int OPTIMIZE3 stress_usersyscall(stress_args_t *args)
 		}
 		/*  Expect ENOSYS for the system call return */
 		errno = 0;
-		VOID_RET(long, syscall(USR_SYSCALL));
+		VOID_RET(long int, syscall(USR_SYSCALL));
 		if (UNLIKELY(errno != ENOSYS)) {
 			pr_fail("%s: didn't get ENOSYS on user syscall, errno=%d (%s)\n",
 				args->name, errno, strerror(errno));
@@ -258,7 +258,7 @@ static int OPTIMIZE3 stress_usersyscall(stress_args_t *args)
 		 *  Test case 2: call user syscall with
 		 *  dispatcher enabled
 		 */
-		if (metrics_count++ < 1000) {
+		if (LIKELY(metrics_count++ < 1000)) {
 			dispatcher_on();
 			ret = (int)syscall(USR_SYSCALL);
 			dispatcher_off();
