@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -110,7 +110,7 @@ static int OPTIMIZE3 stress_utime(stress_args_t *args)
 
 #if defined(HAVE_PATHCONF) &&	\
     defined(_PC_TIMESTAMP_RESOLUTION)
-	VOID_RET(long, pathconf(filename, _PC_TIMESTAMP_RESOLUTION));
+	VOID_RET(long int, pathconf(filename, _PC_TIMESTAMP_RESOLUTION));
 #endif
 	stress_rndstr(hugename, sizeof(hugename));
 
@@ -487,7 +487,7 @@ STRESS_PRAGMA_POP
 #else
 		UNEXPECTED
 #endif
-		if (metrics_count++ > 1000)
+		if (UNLIKELY(metrics_count++ > 1000))
 			metrics_count = 0;
 		stress_bogo_inc(args);
 	} while (stress_continue(args));
