@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Colin Ian King
+ * Copyright (C) 2022-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -58,7 +58,7 @@ VEC_TYPE_T(__uint128_t, u128, 4)
  *  various 64 byte vectors and shuffle masks
  *	s = vector being shuffled
  *	o = vector of original data to sanity check shuffle
- *	mask1 = vector of shuffling posistions
+ *	mask1 = vector of shuffling positions
  *	mask2 = vector to shuffle positions to shuffle back to
  *		original position
  */
@@ -117,37 +117,45 @@ static double stress_vecshuf_all(
 #else
 
 #define STRESS_VEC_BUILTIN_SHUFFLE(tag, elements)		\
-static inline void shim_builtin_shuffle_ ## tag ## _ ## elements(\
+static inline ALWAYS_INLINE void shim_builtin_shuffle_ ## tag ## _ ## elements(\
 	stress_scalar_ ## tag ## _t *dst,			\
 	stress_scalar_ ## tag ## _t *src,			\
 	stress_scalar_ ## tag ## _t *mask)			\
 {								\
 	register int i;						\
 								\
-	for (i = 0; i < elements; i++) 				\
-		dst[i] = src[mask[i]];				\
+PRAGMA_UNROLL_N(elements)					\
+	for (i = 0; i < elements; i++) {			\
+		const stress_scalar_ ## tag ## _t m = mask[i];	\
+		dst[i] = src[m];				\
+	}							\
 }
 
-#define SHIM_SHUFFLE_u8_64(dst, src, mask)	shim_builtin_shuffle_u8_64((void *)&(dst), (void *)&(src), (void *)&(mask))
+#define SHIM_SHUFFLE_u8_64(dst, src, mask)	\
+	shim_builtin_shuffle_u8_64((void *)&(dst), (void *)&(src), (void *)&(mask))
 STRESS_VEC_BUILTIN_SHUFFLE(u8, 64)
 
-#define SHIM_SHUFFLE_u16_32(dst, src, mask)	shim_builtin_shuffle_u16_32((void *)&(dst), (void *)&(src), (void *)&(mask))
+#define SHIM_SHUFFLE_u16_32(dst, src, mask) \
+	shim_builtin_shuffle_u16_32((void *)&(dst), (void *)&(src), (void *)&(mask))
 STRESS_VEC_BUILTIN_SHUFFLE(u16, 32)
 
-#define SHIM_SHUFFLE_u32_16(dst, src, mask)	shim_builtin_shuffle_u32_16((void *)&(dst), (void *)&(src), (void *)&(mask))
+#define SHIM_SHUFFLE_u32_16(dst, src, mask) \
+	shim_builtin_shuffle_u32_16((void *)&(dst), (void *)&(src), (void *)&(mask))
 STRESS_VEC_BUILTIN_SHUFFLE(u32, 16)
 
-#define SHIM_SHUFFLE_u64_8(dst, src, mask)	shim_builtin_shuffle_u64_8((void *)&(dst), (void *)&(src), (void *)&(mask))
+#define SHIM_SHUFFLE_u64_8(dst, src, mask) \
+	shim_builtin_shuffle_u64_8((void *)&(dst), (void *)&(src), (void *)&(mask))
 STRESS_VEC_BUILTIN_SHUFFLE(u64, 8)
 #if defined(HAVE_INT128_T)
 STRESS_VEC_BUILTIN_SHUFFLE(u128, 4)
-#define SHIM_SHUFFLE_u128_4(dst, src, mask)	shim_builtin_shuffle_u128_4((void *)&(dst), (void *)&(src), (void *)&(mask))
+#define SHIM_SHUFFLE_u128_4(dst, src, mask) \
+	shim_builtin_shuffle_u128_4((void *)&(dst), (void *)&(src), (void *)&(mask))
 #endif
 #endif
 
-#define STRESS_VEC_SHUFFLE(tag, elements)				\
-static double TARGET_CLONES OPTIMIZE3 stress_vecshuf_ ## tag ## _ ## elements (	\
-	stress_args_t *args,					\
+#define STRESS_VEC_SHUFFLE(tag, elements, opt)				\
+static double TARGET_CLONES opt stress_vecshuf_ ## tag ## _ ## elements (	\
+	stress_args_t *args,						\
 	stress_vec_data_t *data)					\
 {									\
 	stress_vec_ ## tag ## _ ## elements ## _t *RESTRICT s;		\
@@ -174,12 +182,27 @@ PRAGMA_UNROLL_N(4)							\
 	return t2 - t1;							\
 }
 
-STRESS_VEC_SHUFFLE(u8,   64)
-STRESS_VEC_SHUFFLE(u16,  32)
-STRESS_VEC_SHUFFLE(u32,  16)
-STRESS_VEC_SHUFFLE(u64,   8)
+#if defined(STRESS_ARCH_X86)
+/*
+ *  Force optimization levels 1 for non-64 bit
+ *  shuffles on x86 to workaround gcc/clang
+ *  store-to-load forwarding optimization issue
+ */
+STRESS_VEC_SHUFFLE(u8,   64, OPTIMIZE2)
+STRESS_VEC_SHUFFLE(u16,  32, OPTIMIZE1)
+STRESS_VEC_SHUFFLE(u32,  16, OPTIMIZE1)
+STRESS_VEC_SHUFFLE(u64,   8, OPTIMIZE1)
 #if defined(HAVE_INT128_T)
-STRESS_VEC_SHUFFLE(u128,  4)
+STRESS_VEC_SHUFFLE(u128,  4, OPTIMIZE1)
+#endif
+#else
+STRESS_VEC_SHUFFLE(u8,   64, OPTIMIZE2)
+STRESS_VEC_SHUFFLE(u16,  32, OPTIMIZE2)
+STRESS_VEC_SHUFFLE(u32,  16, OPTIMIZE2)
+STRESS_VEC_SHUFFLE(u64,   8, OPTIMIZE2)
+#if defined(HAVE_INT128_T)
+STRESS_VEC_SHUFFLE(u128,  4, OPTIMIZE2)
+#endif
 #endif
 
 typedef struct {
@@ -232,30 +255,6 @@ static double stress_vecshuf_all(
 	return 0.0;
 }
 
-/*
- *  stress_set_vecshuf_method()
- *	set the default vector floating point stress method
- */
-static int stress_set_vecshuf_method(const char *name)
-{
-	size_t i;
-
-	for (i = 0; i < SIZEOF_ARRAY(stress_vecshuf_funcs); i++) {
-		if (!strcmp(stress_vecshuf_funcs[i].name, name)) {
-			stress_set_setting("vecshuf-method", TYPE_ID_SIZE_T, &i);
-			return 0;
-		}
-	}
-
-	(void)fprintf(stderr, "vecshuf-method must be one of:");
-	for (i = 0; i < SIZEOF_ARRAY(stress_vecshuf_funcs); i++) {
-		(void)fprintf(stderr, " %s", stress_vecshuf_funcs[i].name);
-	}
-	(void)fprintf(stderr, "\n");
-
-	return -1;
-}
-
 #define VEC_SET_DATA(type, elements, mwc)			\
 do {								\
 	for (i = 0; i < elements; i++) {			\
@@ -320,18 +319,18 @@ static void stress_vecshuf_set_mask(stress_vec_data_t *data)
 #endif
 }
 
-#define VEC_CHECK(type, elements, fail)				\
-do {								\
-	for (i = 0; i < elements; i++) {			\
-		if (data-> type ## _ ## elements.s.i[i] !=	\
-		    data-> type ## _ ## elements.o.i[i]) {	\
-			pr_fail("%s: shuffling error, in "	\
-				# type "x" # elements		\
-				"vector\n", args->name);	\
-			fail = true;				\
-			break;					\
-		}						\
-	}							\
+#define VEC_CHECK(type, elements, fail)					\
+do {									\
+	for (i = 0; i < elements; i++) {				\
+		if (UNLIKELY(data-> type ## _ ## elements.s.i[i] !=	\
+			     data-> type ## _ ## elements.o.i[i])) {	\
+			pr_fail("%s: shuffling error, in "		\
+				# type "x" # elements			\
+				"vector\n", args->name);		\
+			fail = true;					\
+			break;						\
+		}							\
+	}								\
 } while (0)
 
 static bool stress_vecshuf_check_data(
@@ -348,7 +347,6 @@ static bool stress_vecshuf_check_data(
 #if defined(HAVE_INT128_T)
 	VEC_CHECK(u128, 4, fail);
 #endif
-
 	return fail;
 }
 
@@ -357,6 +355,7 @@ static int stress_vecshuf(stress_args_t *args)
 	stress_vec_data_t *data;
 	size_t vecshuf_method = 0;	/* "all" */
 	size_t i;
+	int rc = EXIT_SUCCESS;
 
 	stress_catch_sigill();
 
@@ -368,6 +367,7 @@ static int stress_vecshuf(stress_args_t *args)
 			args->name, sizeof(*data));
 		return EXIT_NO_RESOURCE;
 	}
+	stress_set_vma_anon_name(data, sizeof(*data), "vecshuf-data");
 
 	for (i = 1; i < SIZEOF_ARRAY(stress_vecshuf_funcs); i++) {
 		stress_vecshuf_funcs[i].duration = 0.0;
@@ -378,15 +378,20 @@ static int stress_vecshuf(stress_args_t *args)
 	(void)stress_get_setting("vecshuf-method", &vecshuf_method);
 
 	stress_vecshuf_set_data(data);
+
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
+	stress_sync_start_wait(args);
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	do {
 		stress_vecshuf_set_mask(data);
 		stress_vecshuf_call_method(args, data, vecshuf_method);
-		stress_vecshuf_check_data(args, data);
+		if (UNLIKELY(stress_vecshuf_check_data(args, data))) {
+			rc = EXIT_FAILURE;
+			break;
+		}
 	} while (stress_continue(args));
 
-
 	if (args->instance == 0) {
 		double total_duration = 0.0;
 		double inverse_sum_ops = 0.0;
@@ -437,42 +442,37 @@ static int stress_vecshuf(stress_args_t *args)
 
 	(void)munmap((void *)data, sizeof(*data));
 
-	return EXIT_SUCCESS;
+	return rc;
 }
 
-static const stress_opt_set_func_t opt_set_funcs[] = {
-        { OPT_vecshuf_method,	stress_set_vecshuf_method },
+static const char *stress_vecshuf_method(const size_t i)
+{
+	return (i < SIZEOF_ARRAY(stress_vecshuf_funcs)) ? stress_vecshuf_funcs[i].name : NULL;
+}
+
+static const stress_opt_t opts[] = {
+        { OPT_vecshuf_method, "vecshuf-method", TYPE_ID_SIZE_T_METHOD, 0, 0, stress_vecshuf_method },
+	END_OPT,
 };
 
-stressor_info_t stress_vecshuf_info = {
+const stressor_info_t stress_vecshuf_info = {
 	.stressor = stress_vecshuf,
-	.class = CLASS_CPU | CLASS_CPU_CACHE,
-	.opt_set_funcs = opt_set_funcs,
+	.class = CLASS_CPU | CLASS_INTEGER | CLASS_COMPUTE | CLASS_VECTOR,
+	.opts = opts,
 	.verify = VERIFY_ALWAYS,
 	.help = help
 };
 #else
 
-/*
- *  stress_set_vecshuf_method()
- *	set the default vector floating point stress method, no-op
- */
-static int stress_set_vecshuf_method(const char *name)
-{
-	(void)name;
-
-	fprintf(stderr, "option --vecshuf-method is not implemented, ignoring option '%s'\n", name);
-	return 0;
-}
-
-static const stress_opt_set_func_t opt_set_funcs[] = {
-        { OPT_vecshuf_method,	stress_set_vecshuf_method },
+static const stress_opt_t opts[] = {
+        { OPT_vecshuf_method, "vecshuf_method", TYPE_ID_SIZE_T_METHOD, 0, 0, stress_unimplemented_method },
+	END_OPT,
 };
 
-stressor_info_t stress_vecshuf_info = {
+const stressor_info_t stress_vecshuf_info = {
 	.stressor = stress_unimplemented,
-	.class = CLASS_CPU | CLASS_CPU_CACHE,
-	.opt_set_funcs = opt_set_funcs,
+	.class = CLASS_CPU | CLASS_INTEGER | CLASS_COMPUTE | CLASS_VECTOR,
+	.opts = opts,
 	.verify = VERIFY_ALWAYS,
 	.help = help,
 	.unimplemented_reason = "built without compiler support for vector shuffling operations"
