@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2024 Colin Ian King
+ * Copyright (C) 2021-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -273,14 +273,14 @@ static int stress_vecwide(stress_args_t *args)
 	return rc;
 }
 
-stressor_info_t stress_vecwide_info = {
+const stressor_info_t stress_vecwide_info = {
 	.stressor = stress_vecwide,
 	.class = CLASS_CPU | CLASS_INTEGER | CLASS_COMPUTE | CLASS_VECTOR,
 	.verify = VERIFY_OPTIONAL,
 	.help = help
 };
 #else
-stressor_info_t stress_vecwide_info = {
+const stressor_info_t stress_vecwide_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_CPU | CLASS_INTEGER | CLASS_COMPUTE | CLASS_VECTOR,
 	.verify = VERIFY_OPTIONAL,
