@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -168,7 +168,7 @@ cleanup:
 
 	(void)close(ctxt->pipe_wr[1]);
 	(void)close(ctxt->pipe_rd[0]);
-	(void)munmap(buf, ctxt->sz);
+	(void)munmap((void *)buf, ctxt->sz);
 	return rc;
 }
 
@@ -208,7 +208,7 @@ static int OPTIMIZE3 stress_vm_parent(stress_context_t *ctxt)
 
 		/* Wait for address of child's buffer */
 redo_rd2:
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 		rwret = read(ctxt->pipe_wr[0], &msg_rd, sizeof(msg_rd));
 		if (UNLIKELY(rwret < 0)) {
@@ -305,7 +305,7 @@ redo_rd2:
 		msg_wr.val = val;
 		val++;
 redo_wr2:
-		if (!stress_continue_flag())
+		if (UNLIKELY(!stress_continue_flag()))
 			break;
 		/* Inform child that memory has been changed */
 		rwret = write(ctxt->pipe_rd[1], &msg_wr, sizeof(msg_wr));
@@ -350,7 +350,7 @@ fail:
 	(void)close(ctxt->pipe_rd[1]);
 	if (ctxt->pid > 1)
 		stress_kill_and_wait(args, ctxt->pid, SIGALRM, false);
-	(void)munmap(localbuf, ctxt->sz);
+	(void)munmap((void *)localbuf, ctxt->sz);
 
 	return EXIT_SUCCESS;
 }
