@@ -51,7 +51,7 @@
 static size_t stress_vm_cache_line_size;
 
 /*
- *  the VM stress test has diffent methods of vm stressor
+ *  the VM stress test has different methods of vm stressor
  */
 typedef size_t (*stress_vm_func)(void *buf, void *buf_end, const size_t sz,
 		stress_args_t *args, const uint64_t max_ops);
@@ -85,7 +85,7 @@ static const stress_help_t help[] = {
 #endif
 	{ NULL,	 "vm-madvise M", "specify mmap'd vm buffer madvise advice" },
 	{ NULL,	 "vm-method M",	 "specify stress vm method M, default is all" },
-	{ NULL,	 "vm-numa",	 "bind memory mappings to randonly selected NUMA nodes" },
+	{ NULL,	 "vm-numa",	 "bind memory mappings to randomly selected NUMA nodes" },
 	{ NULL,	 "vm-ops N",	 "stop after N vm bogo operations" },
 #if defined(MAP_POPULATE)
 	{ NULL,	 "vm-populate",	 "populate (prefault) page tables for a mapping" },
@@ -222,7 +222,7 @@ static inline ALWAYS_INLINE PURE OPTIMIZE3 uint64_t stress_vm_mod(register uint6
  */
 static void stress_vm_check(const char *name, const size_t bit_errors)
 {
-	if (bit_errors && (g_opt_flags & OPT_FLAGS_VERIFY))
+	if (UNLIKELY(bit_errors && (g_opt_flags & OPT_FLAGS_VERIFY)))
 #if INJECT_BIT_ERRORS
 		pr_dbg("%s: detected %zu memory error%s\n",
 			name, bit_errors, bit_errors == 1 ? "" : "s");
@@ -1079,7 +1079,7 @@ static size_t TARGET_CLONES stress_vm_swap(
 
 	stress_mwc_set_seed(w1, z1);
 	for (ptr = (uint8_t *)buf; ptr < (uint8_t *)buf_end; ptr += chunk_sz) {
-		uint8_t *p = (uint8_t *)ptr;
+		const uint8_t *p = (uint8_t *)ptr;
 		const uint8_t *p_end = (uint8_t *)ptr + chunk_sz;
 		uint8_t val = stress_mwc8();
 
@@ -1764,7 +1764,7 @@ static size_t TARGET_CLONES stress_vm_prime_zero(
 
 #if SIZE_MAX > UINT32_MAX
 	/* Unlikely.. */
-	if (sz > (1ULL << 63))
+	if (UNLIKELY(sz > (1ULL << 63)))
 		return 0;
 #endif
 	for (ptr = (uint8_t *)buf + offset; ptr < (uint8_t *)buf_end; ptr += prime)
@@ -1796,7 +1796,7 @@ static size_t TARGET_CLONES stress_vm_prime_zero(
 	stress_vm_check("prime-zero", bit_errors);
 abort:
 	offset++;
-	if (offset >= prime)
+	if (UNLIKELY(offset >= prime))
 		offset = 0;
 	stress_bogo_set(args, c);
 	return bit_errors;
@@ -1824,7 +1824,7 @@ static size_t TARGET_CLONES stress_vm_prime_one(
 
 #if SIZE_MAX > UINT32_MAX
 	/* Unlikely.. */
-	if (sz > (1ULL << 63))
+	if (UNLIKELY(sz > (1ULL << 63)))
 		return 0;
 #endif
 	for (ptr = (uint8_t *)buf + offset; ptr < (uint8_t *)buf_end; ptr += prime)
@@ -1856,7 +1856,7 @@ static size_t TARGET_CLONES stress_vm_prime_one(
 	stress_vm_check("prime-one", bit_errors);
 abort:
 	offset++;
-	if (offset >= prime)
+	if (UNLIKELY(offset >= prime))
 		offset = 0;
 	stress_bogo_set(args, c);
 	return bit_errors;
@@ -1884,7 +1884,7 @@ static size_t TARGET_CLONES stress_vm_prime_gray_zero(
 
 #if SIZE_MAX > UINT32_MAX
 	/* Unlikely.. */
-	if (sz > (1ULL << 63))
+	if (UNLIKELY(sz > (1ULL << 63)))
 		return 0;
 #endif
 	for (ptr = (uint8_t *)buf + offset; ptr < (uint8_t *)buf_end; ptr += prime)
@@ -1916,7 +1916,7 @@ static size_t TARGET_CLONES stress_vm_prime_gray_zero(
 	stress_vm_check("prime-gray-zero", bit_errors);
 abort:
 	offset++;
-	if (offset >= prime)
+	if (UNLIKELY(offset >= prime))
 		offset = 0;
 	stress_bogo_set(args, c);
 	return bit_errors;
@@ -1944,7 +1944,7 @@ static size_t TARGET_CLONES stress_vm_prime_gray_one(
 
 #if SIZE_MAX > UINT32_MAX
 	/* Unlikely.. */
-	if (sz > (1ULL << 63))
+	if (UNLIKELY(sz > (1ULL << 63)))
 		return 0;
 #endif
 	for (ptr = (uint8_t *)buf + offset; ptr < (uint8_t *)buf_end; ptr += prime)
@@ -1976,7 +1976,7 @@ static size_t TARGET_CLONES stress_vm_prime_gray_one(
 	stress_vm_check("prime-gray-one", bit_errors);
 abort:
 	offset++;
-	if (offset >= prime)
+	if (UNLIKELY(offset >= prime))
 		offset = 0;
 	stress_bogo_set(args, c);
 	return bit_errors;
@@ -2297,7 +2297,7 @@ static size_t TARGET_CLONES stress_vm_rowhammer(
 	(void)buf_end;
 	(void)max_ops;
 
-	if (!n) {
+	if (UNLIKELY(!n)) {
 		pr_dbg("stress-vm: rowhammer: zero uint32_t integers could "
 			"be hammered, aborting\n");
 		return 0;
@@ -2383,7 +2383,8 @@ static size_t TARGET_CLONES stress_vm_mscan(
 	const uint64_t max_ops)
 {
 	size_t bit_errors = 0;
-	register uint8_t *ptr = (uint8_t *)buf, *end;
+	register uint8_t *ptr = (uint8_t *)buf;
+	register const uint8_t *end;
 	register uint64_t c = stress_bogo_get(args);
 
 	(void)sz;
@@ -3048,7 +3049,7 @@ do {						\
 
 /*
  *  stress_vm_checkerboard()
- *	fill adjecent bytes with alternative bit patterns
+ *	fill adjacent bytes with alternative bit patterns
  */
 static size_t TARGET_CLONES stress_vm_checkerboard(
 	void *buf,
@@ -3214,7 +3215,7 @@ static size_t stress_vm_all(
 
 	bit_errors = vm_methods[i].func(buf, buf_end, sz, args, max_ops);
 	i++;
-	if (i >= SIZEOF_ARRAY(vm_methods))
+	if (UNLIKELY(i >= SIZEOF_ARRAY(vm_methods)))
 		i = 1;
 
 	return bit_errors;
@@ -3277,9 +3278,9 @@ static int stress_vm_child(stress_args_t *args, void *ctxt)
 
 	do {
 		if (!vm_keep || (buf == NULL)) {
-			if (!stress_continue_flag())
+			if (UNLIKELY(!stress_continue_flag()))
 				return EXIT_SUCCESS;
-			if (((g_opt_flags & OPT_FLAGS_OOM_AVOID) && stress_low_memory(buf_sz))) {
+			if (UNLIKELY(((g_opt_flags & OPT_FLAGS_OOM_AVOID) && stress_low_memory(buf_sz)))) {
 				buf = MAP_FAILED;
 				errno = ENOMEM;
 			} else {
@@ -3298,7 +3299,7 @@ static int stress_vm_child(stress_args_t *args, void *ctxt)
 					MAP_PRIVATE | MAP_ANONYMOUS |
 					vm_flags, -1, 0);
 			}
-			if (buf == MAP_FAILED) {
+			if (UNLIKELY(buf == MAP_FAILED)) {
 				buf = NULL;
 				no_mem_retries++;
 				if (no_mem_retries >= NO_MEM_RETRIES_MAX) {
@@ -3330,7 +3331,7 @@ static int stress_vm_child(stress_args_t *args, void *ctxt)
 			else
 				(void)shim_madvise(buf, buf_sz, advice);
 #if defined(HAVE_LINUX_MEMPOLICY_H)
-			if (context->vm_numa)
+			if (UNLIKELY(context->vm_numa))
 				stress_numa_randomize_pages(context->numa_mask, buf, page_size, buf_sz);
 #endif
 		}
@@ -3417,6 +3418,11 @@ static int stress_vm(stress_args_t *args)
 #if defined(HAVE_LINUX_MEMPOLICY_H)
 		if (stress_numa_nodes() > 1) {
 			context.numa_mask = stress_numa_mask_alloc();
+			if (!context.numa_mask) {
+				pr_inf("%s: cannot allocate NUMA mask, disabling --vm-numa\n",
+					args->name);
+				context.vm_numa = false;
+			}
 		} else {
 			if (args->instance == 0) {
 				pr_inf("%s: only 1 NUMA node available, disabling --vm-numa\n",
@@ -3439,7 +3445,7 @@ static int stress_vm(stress_args_t *args)
 	if (args->instance == 0)
 		pr_dbg("%s: using method '%s'\n", args->name, context.vm_method->name);
 
-	for (retries = 0; (retries < 100) && stress_continue_flag(); retries++) {
+	for (retries = 0; LIKELY((retries < 100) && stress_continue_flag()); retries++) {
 		context.bit_error_count = (uint64_t *)
 			stress_mmap_populate(NULL, page_size,
 				PROT_READ | PROT_WRITE,
@@ -3452,11 +3458,15 @@ static int stress_vm(stress_args_t *args)
 
 	/* Cannot allocate a single page for bit error counter */
 	if (context.bit_error_count == MAP_FAILED) {
-		if (stress_continue_flag()) {
+		if (LIKELY(stress_continue_flag())) {
 			pr_err("%s: could not mmap bit error counter: "
 				"retry count=%zu, errno=%d (%s)\n",
 				args->name, retries, err, strerror(err));
 		}
+#if defined(HAVE_LINUX_MEMPOLICY_H)
+		if (context.numa_mask)
+			stress_numa_mask_free(context.numa_mask);
+#endif
 		return EXIT_NO_RESOURCE;
 	}
 	stress_set_vma_anon_name(context.bit_error_count, page_size, "bit-error-count");
@@ -3481,7 +3491,7 @@ static int stress_vm(stress_args_t *args)
 	(void)munmap((void *)context.bit_error_count, page_size);
 
 #if defined(HAVE_LINUX_MEMPOLICY_H)
-	if (context.vm_numa)
+	if (context.numa_mask)
 		stress_numa_mask_free(context.numa_mask);
 #endif
 	tmp_counter = stress_bogo_get(args) >> VM_BOGO_SHIFT;
