@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2024      Colin Ian King.
+ * Copyright (C) 2024-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,9 +23,14 @@
 #include "core-killpid.h"
 #include "core-out-of-memory.h"
 #include "core-pthread.h"
+#include "core-put.h"
+
+#if defined(HAVE_SYS_PRCTL_H)
+#include <sys/prctl.h>
+#endif
 
 #define STRESS_VMA_PROCS	(2)
-#define STRESS_VMA_PAGES	(16)
+#define STRESS_VMA_PAGES	(32)
 
 static const stress_help_t help[] = {
 	{ NULL,	"vma N",	"start N workers that exercise kernel VMA structures" },
@@ -36,16 +41,16 @@ static const stress_help_t help[] = {
 #if defined(HAVE_LIB_PTHREAD)
 
 typedef struct {
-	stress_args_t *args;
-	void *data;
-	pid_t pid;
+	stress_args_t *args;			/* stress-ng context */
+	void *data;				/* mmap'd data, size STRESS_VMA_PAGES */
+	pid_t pid;				/* process ID */
 } stress_vma_context_t;
 
 typedef void * (*stress_vma_func_t)(void *ptr);
 
 typedef struct {
-	stress_vma_func_t	vma_func;
-	size_t 			count;
+	stress_vma_func_t	vma_func;	/* vma stressing function */
+	size_t 			count;		/* number of instances to invoke */
 } stress_thread_info_t;
 
 #define STRESS_VMA_MMAP		(0)
@@ -69,7 +74,7 @@ typedef struct {
 	} s;
 } stress_vma_metrics_t;
 
-static const char *stress_vma_metrics_name[] = {
+static const char * const stress_vma_metrics_name[] = {
 	"mmaps",	/* STRESS_VMA_MMAP */
 	"munmaps",	/* STRESS_VMA_MUNMAP */
 	"mlocks",	/* STRESS_VMA_MLOCK */
@@ -97,8 +102,38 @@ static bool stress_vma_continue(stress_args_t *args)
         return stress_vma_metrics->s.metrics[STRESS_VMA_MMAP] < args->max_ops;
 }
 
+#if defined(__linux__) &&		\
+    defined(HAVE_SYS_PRCTL_H) &&	\
+    defined(PR_SET_VMA) &&		\
+    defined(PR_SET_VMA_ANON_NAME)
+static void stress_vma_page_name(const void *addr, size_t page_size)
+{
+	static const char charset[] = " !\"#%&()*+,-,/0123456789:;<=>?@"
+				      "ABCDEFGHIJKLMNOPQRSTUVWXYZ^_"
+				      "abcdefghijklmnopqrstuvwxyz{|}~\177";
+
+	if (stress_mwc1()) {
+		char name[80];
+
+		size_t i;
+		const size_t len = 10 + stress_mwc8modn(sizeof(name) - 11);
+
+		for (i = 0; i < len; i++) {
+			const size_t idx = (size_t)stress_mwc8modn(sizeof(charset));
+
+			name[i] = charset[idx];
+		}
+		name[i] = '\0';
+		stress_set_vma_anon_name(addr, page_size, name);
+	} else {
+		stress_set_vma_anon_name(addr, page_size, NULL);
+	}
+}
+#endif
+
+
 /*
- *  stress_vma_get_addr()
+ *  stress_mmapaddr_get_addr()
  *	try to find an unmapp'd address
  */
 static void *stress_mmapaddr_get_addr(stress_args_t *args)
@@ -106,57 +141,87 @@ static void *stress_mmapaddr_get_addr(stress_args_t *args)
 	const uintptr_t mask = ~(((uintptr_t)args->page_size) - 1);
 	void *addr = NULL;
 	uintptr_t ui_addr;
+	size_t i;
+	char *text_start, *text_end, *heap_end;
+	const size_t page_size = args->page_size;
+	size_t mmap_size = page_size * STRESS_VMA_PAGES;
+
+	/* Determine text start and heap end */
+	stress_exec_text_addr(&text_start, &text_end);
+	if (UNLIKELY((!text_start) && (!text_end)))
+		return NULL;
+	addr = malloc(1);
+	if (UNLIKELY(!addr))
+		return NULL;
+
+	/* determine page aligned heap end and some slop */
+	heap_end = (void *)(((uintptr_t)addr & mask) + (page_size * 16));
+	free(addr);
 
 	while (stress_vma_continue_flag && stress_vma_continue(args)) {
-		int fd[2], err;
-		ssize_t ret;
+		uintptr_t test_addr;
 
 		if (sizeof(uintptr_t) > 4) {
-			const uint64_t page_63 = (stress_mwc64() << 12) & 0x7fffffffffffffffULL;
+			const uint64_t addr_bits = stress_mwc8modn(28) + 32;
+			const uint64_t addr_mask = (1ULL << addr_bits) - 1ULL;
 
-			if (stress_mwc1()) {
-				ui_addr = stress_mwc64modn((1ULL << 38) - 1) | page_63;
-			} else {
-				ui_addr = (1ULL << 36) | page_63;
-			}
+			ui_addr = stress_mwc64() & addr_mask;
 			/* occasionally use 32 bit addr in 64 bit addr space */
 			if (stress_mwc8modn(5) == 0)
 				ui_addr &= 0x7fffffffUL;
 		} else {
-			const uint32_t page_31 = (stress_mwc32() << 12) & 0x7fffffffUL;
+			const uint64_t addr_bits = stress_mwc8modn(31);
+			const uint64_t addr_mask = (1ULL << addr_bits) - 1ULL;
 
-			if (stress_mwc1())
-				ui_addr = stress_mwc32modn((1UL << 28) - 1) | page_31;
-			else
-				ui_addr = (1ULL << 20) | page_31;
+			ui_addr = stress_mwc32() & addr_mask;
 		}
 		addr = (void *)(ui_addr & mask);
 
-		if (pipe(fd) < 0)
-			return NULL;
-		/* Can we read the page at addr into a pipe? */
-		ret = write(fd[1], addr, args->page_size);
-		err = errno;
+		/* retry if we're in text and heap sections */
+		if ((addr >= (void *)text_start) && ((void *)((uintptr_t)addr + mmap_size) <= (void *)heap_end))
+			continue;
 
-		(void)close(fd[0]);
-		(void)close(fd[1]);
+		for (i = 0, test_addr = (uintptr_t)addr; i < STRESS_VMA_PAGES; i++, test_addr += page_size) {
+			int fd[2], err;
+			ssize_t ret;
 
-		/* Not mapped or readable */
-		if ((ret < 0) && (err == EFAULT)) {
-			void *mapped;
+			if (UNLIKELY(pipe(fd) < 0))
+				return NULL;
+			/* Can we read the page at addr into a pipe? */
 
-			/* Is it actually mappable? */
-			mapped = mmap(addr, args->page_size * 16, PROT_READ | PROT_WRITE,
-					MAP_FIXED | MAP_ANONYMOUS | MAP_PRIVATE, -1, 0);
-			if (mapped != MAP_FAILED) {
-				(void)munmap(mapped, args->page_size);
+			ret = write(fd[1], (void *)test_addr, page_size);
+			err = errno;
+			(void)close(fd[0]);
+			(void)close(fd[1]);
+
+			/* Not mapped or readable */
+			if ((ret < 0) && (err == EFAULT)) {
+				void *mapped;
+
+				/* Is it actually mappable? */
+				mapped = mmap((void *)test_addr, page_size, PROT_READ | PROT_WRITE,
+						MAP_FIXED | MAP_ANONYMOUS | MAP_SHARED, -1, 0);
+				if (LIKELY(mapped == MAP_FAILED)) {
+					(void)munmap(mapped, page_size);
+					addr = NULL;
+					break;
+				}
+			} else {
+				addr = NULL;
 				break;
 			}
 		}
+		/* all pages deemed unused then we've found a suitable address */
+		if (i == STRESS_VMA_PAGES)
+			break;
 	}
 	return addr;
 }
 
+/*
+ *  stress_vma_mmap()
+ *	mmap pages
+ */
 static void *stress_vma_mmap(void *ptr)
 {
 	stress_vma_context_t *ctxt = (stress_vma_context_t *)ptr;
@@ -173,9 +238,10 @@ static void *stress_vma_mmap(void *ptr)
 			PROT_READ | PROT_EXEC,
 		};
 
+		const size_t offset = page_size * stress_mwc8modn(STRESS_VMA_PAGES);
 		const int prot = prots[stress_mwc8modn(SIZEOF_ARRAY(prots))];
 		int flags = MAP_FIXED | MAP_ANONYMOUS;
-		void *mapped;
+		const void *mapped;
 
 		flags |= (stress_mwc1() ? MAP_SHARED : MAP_PRIVATE);
 #if defined(MAP_GROWSDOWN)
@@ -192,15 +258,25 @@ static void *stress_vma_mmap(void *ptr)
 		if (flags & MAP_POPULATE)
 			flags |= (stress_mwc1() ? MAP_NONBLOCK : 0);
 #endif
-		/* Map and grow */
-		errno = 0;
-		mapped = mmap((void *)data, page_size, prot, flags, -1, 0);
-		if (mapped != MAP_FAILED)
+		/* Map */
+		mapped = mmap((void *)(data + offset), page_size, prot, flags, -1, 0);
+		if (LIKELY(mapped != MAP_FAILED)) {
+#if defined(__linux__) &&		\
+    defined(HAVE_SYS_PRCTL_H) &&	\
+    defined(PR_SET_VMA) &&		\
+    defined(PR_SET_VMA_ANON_NAME)
+			stress_vma_page_name(mapped, page_size);
+#endif
 			stress_vma_metrics->s.metrics[STRESS_VMA_MMAP]++;
+		}
 	}
 	return NULL;
 }
 
+/*
+ *  stress_vma_munmap()
+ *	munmap pages
+ */
 static void *stress_vma_munmap(void *ptr)
 {
 	stress_vma_context_t *ctxt = (stress_vma_context_t *)ptr;
@@ -210,14 +286,17 @@ static void *stress_vma_munmap(void *ptr)
 
 	while (stress_vma_continue_flag && stress_vma_continue(args)) {
 		const size_t offset = page_size * stress_mwc8modn(STRESS_VMA_PAGES);
-		const size_t size = page_size * stress_mwc8modn(STRESS_VMA_PAGES);
 
-		if (munmap((void *)(data + offset), size) == 0)
+		if (LIKELY(munmap((void *)(data + offset), page_size) == 0))
 			stress_vma_metrics->s.metrics[STRESS_VMA_MUNMAP]++;
 	}
 	return NULL;
 }
 
+/*
+ *  stress_vma_mlock()
+ *	mlock pages
+ */
 static void *stress_vma_mlock(void *ptr)
 {
 	stress_vma_context_t *ctxt = (stress_vma_context_t *)ptr;
@@ -237,13 +316,17 @@ static void *stress_vma_mlock(void *ptr)
 		if (shim_mlock2((void *)(data + offset), len, flags) == 0) {
 			stress_vma_metrics->s.metrics[STRESS_VMA_MLOCK]++;
 		} else {
-			if (shim_mlock((void *)(data + offset), len) == 0)
+			if (LIKELY(shim_mlock((void *)(data + offset), len) == 0))
 				stress_vma_metrics->s.metrics[STRESS_VMA_MLOCK]++;
 		}
 	}
 	return NULL;
 }
 
+/*
+ *  stress_vma_mmap()
+ *	munlock pages
+ */
 static void *stress_vma_munlock(void *ptr)
 {
 	stress_vma_context_t *ctxt = (stress_vma_context_t *)ptr;
@@ -255,12 +338,17 @@ static void *stress_vma_munlock(void *ptr)
 		const size_t offset = page_size * stress_mwc8modn(STRESS_VMA_PAGES);
 		const size_t len = page_size * stress_mwc8modn(STRESS_VMA_PAGES);
 
-		if (munlock((void *)(data + offset), len) == 0)
+		if (LIKELY(munlock((void *)(data + offset), len) == 0))
 			stress_vma_metrics->s.metrics[STRESS_VMA_MUNLOCK]++;
 	}
 	return NULL;
 }
 
+#if defined(HAVE_MADVISE)
+/*
+ *  stress_vma_madvise()
+ *	madvise pages
+ */
 static void *stress_vma_madvise(void *ptr)
 {
 	stress_vma_context_t *ctxt = (stress_vma_context_t *)ptr;
@@ -317,8 +405,13 @@ static void *stress_vma_madvise(void *ptr)
 	}
 	return NULL;
 }
+#endif
 
 #if defined(HAVE_MINCORE)
+/*
+ *  stress_vma_mincore()
+ *	exercise mincore on pages
+ */
 static void *stress_vma_mincore(void *ptr)
 {
 	stress_vma_context_t *ctxt = (stress_vma_context_t *)ptr;
@@ -332,13 +425,17 @@ static void *stress_vma_mincore(void *ptr)
 		const size_t len = page_size * pages;
 		unsigned char vec[STRESS_VMA_PAGES];
 
-		if (shim_mincore((void *)(data + offset), len, vec) == 0)
+		if (LIKELY(shim_mincore((void *)(data + offset), len, vec) == 0))
 			stress_vma_metrics->s.metrics[STRESS_VMA_MINCORE]++;
 	}
 	return NULL;
 }
 #endif
 
+/*
+ *  stress_vma_mprotect()
+ *	exercise mprotect on pages
+ */
 static void *stress_vma_mprotect(void *ptr)
 {
 	stress_vma_context_t *ctxt = (stress_vma_context_t *)ptr;
@@ -367,12 +464,16 @@ static void *stress_vma_mprotect(void *ptr)
 		const size_t offset = page_size * stress_mwc8modn(STRESS_VMA_PAGES);
 		const size_t len = page_size * stress_mwc8modn(STRESS_VMA_PAGES);
 
-		if (mprotect((void *)(data + offset), len, prot[i]) == 0)
+		if (LIKELY(mprotect((void *)(data + offset), len, prot[i]) == 0))
 			stress_vma_metrics->s.metrics[STRESS_VMA_MPROTECT]++;
 	}
 	return NULL;
 }
 
+/*
+ *  stress_vma_msync()
+ *	msync pages
+ */
 static void *stress_vma_msync(void *ptr)
 {
 	stress_vma_context_t *ctxt = (stress_vma_context_t *)ptr;
@@ -397,13 +498,17 @@ static void *stress_vma_msync(void *ptr)
 		const size_t offset = page_size * stress_mwc8modn(STRESS_VMA_PAGES);
 		const size_t len = page_size * stress_mwc8modn(STRESS_VMA_PAGES);
 
-		if (msync((void *)(data + offset), len, flags[i]) == 0)
+		if (LIKELY(msync((void *)(data + offset), len, flags[i]) == 0))
 			stress_vma_metrics->s.metrics[STRESS_VMA_MSYNC]++;
 	}
 	return NULL;
 }
 
 #if defined(__linux__)
+/*
+ *  stress_vma_msync()
+ *	exercise /proc/self/maps
+ */
 static void *stress_vma_maps(void *ptr)
 {
 	stress_vma_context_t *ctxt = (stress_vma_context_t *)ptr;
@@ -411,11 +516,11 @@ static void *stress_vma_maps(void *ptr)
 	int fd;
 
 	fd = open("/proc/self/maps", O_RDONLY);
-	if (fd != -1) {
+	if (LIKELY(fd != -1)) {
 		while (stress_vma_continue_flag && stress_vma_continue(args)) {
 			char buf[4096];
 
-			if (lseek(fd, 0, SEEK_SET) < 0)
+			if (UNLIKELY(lseek(fd, 0, SEEK_SET) < 0))
 				break;
 			while (read(fd, buf, sizeof(buf)) > 1)
 				;
@@ -427,6 +532,10 @@ static void *stress_vma_maps(void *ptr)
 }
 #endif
 
+/*
+ *  stress_vma_access()
+ *	read access pages
+ */
 static void *stress_vma_access(void *ptr)
 {
 	stress_vma_context_t *ctxt = (stress_vma_context_t *)ptr;
@@ -436,10 +545,10 @@ static void *stress_vma_access(void *ptr)
 
 	while (stress_vma_continue_flag && stress_vma_continue(args)) {
 		const size_t offset = page_size * stress_mwc8modn(STRESS_VMA_PAGES);
-		uint8_t *ptr8 = (uint8_t *)(data + offset);
+		volatile const uint8_t *ptr8 = (volatile uint8_t *)(data + offset);
 
 		stress_vma_metrics->s.metrics[STRESS_VMA_ACCESS]++;
-		++(*ptr8);
+		stress_uint8_put(*ptr8);
 	}
 	return NULL;
 }
@@ -449,7 +558,9 @@ static const stress_thread_info_t vma_funcs[] = {
 	{ stress_vma_munmap,	1 },
 	{ stress_vma_mlock,	1 },
 	{ stress_vma_munlock,	1 },
+#if defined(HAVE_MADVISE)
 	{ stress_vma_madvise,	1 },
+#endif
 #if defined(HAVE_MINCORE)
 	{ stress_vma_mincore,	1 },
 #endif
@@ -458,9 +569,13 @@ static const stress_thread_info_t vma_funcs[] = {
 #if defined(__linux__)
 	{ stress_vma_maps,	1 },
 #endif
-	{ stress_vma_access,	20 }
+	{ stress_vma_access,	20 },
 };
 
+/*
+ *  stress_vm_handle_sigsegv()
+ *	account for SIGSEGV signals
+ */
 static void stress_vm_handle_sigsegv(int signo)
 {
 	(void)signo;
@@ -468,6 +583,10 @@ static void stress_vm_handle_sigsegv(int signo)
 	stress_vma_metrics->s.metrics[STRESS_VMA_SIGSEGV]++;
 }
 
+/*
+ *  stress_vm_handle_sigbus()
+ *	account for SIGBUS signals
+ */
 static void stress_vm_handle_sigbus(int signo)
 {
 	(void)signo;
@@ -493,14 +612,14 @@ static void stress_vma_loop(
 		pid_t pid;
 		int status;
 
+		stress_vma_continue_flag = true;
+
 		stress_mwc_reseed();
 		ctxt->data = stress_mmapaddr_get_addr(args);
 
-		stress_vma_continue_flag = true;
-
 		pid = fork();
 		if (pid < 0) {
-			shim_usleep_interruptible(100000);
+			(void)shim_usleep_interruptible(100000);
 			continue;
 		} else if (pid == 0) {
 			pthread_t pthreads[n];
@@ -519,7 +638,7 @@ static void stress_vma_loop(
 				}
 			}
 			/* Let pthreads run for 10 seconds */
-			sleep(10);
+			(void)sleep(10);
 			for (i = 0; i < j; i++) {
 				if (pthreads_ret[i] == 0) {
 					VOID_RET(int, pthread_kill(pthreads[i], SIGBUS));
@@ -531,7 +650,7 @@ static void stress_vma_loop(
 			_exit(0);
 		}
 
-		sleep(10);
+		(void)sleep(10);
 		stress_vma_continue_flag = false;
 		VOID_RET(int, kill(pid, SIGKILL));
 		VOID_RET(int, shim_waitpid(pid, &status, 0));
@@ -555,7 +674,7 @@ static int stress_vma_child(stress_args_t *args, void *void_ctxt)
 	for (i = 0; i < STRESS_VMA_PROCS; i++)
 		stress_sync_start_init(&s_pids[i]);
 
-	for (i = 0; (stress_continue(args)) && (i < STRESS_VMA_PROCS); i++) {
+	for (i = 0; LIKELY(stress_continue(args) && (i < STRESS_VMA_PROCS)); i++) {
 		s_pids[i].pid = fork();
 		if (s_pids[i].pid < 0)
 			continue;
@@ -576,7 +695,7 @@ static int stress_vma_child(stress_args_t *args, void *void_ctxt)
 	stress_sync_start_cont_list(s_pids_head);
 
 	do {
-		sleep(1);
+		(void)sleep(1);
 		stress_bogo_set(args, stress_vma_metrics->s.metrics[STRESS_VMA_MMAP]);
 	} while (stress_continue(args));
 
@@ -615,9 +734,11 @@ static int stress_vma(stress_args_t *args)
 		(void)munmap(stress_vma_page, args->page_size);
 		return EXIT_NO_RESOURCE;
 	}
+	stress_set_vma_anon_name(stress_vma_metrics, sizeof(*stress_vma_metrics), "vma-metrics");
 
-	stress_set_proc_state(args->name, STRESS_STATE_RUN);
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
+	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	t1 = stress_time_now();
 	ret = stress_oomable_child(args, &ctxt, stress_vma_child, STRESS_OOMABLE_NORMAL);
@@ -639,13 +760,13 @@ static int stress_vma(stress_args_t *args)
 	return ret;
 }
 
-stressor_info_t stress_vma_info = {
+const stressor_info_t stress_vma_info = {
 	.stressor = stress_vma,
 	.class = CLASS_VM,
 	.help = help
 };
 #else
-stressor_info_t stress_vma_info = {
+const stressor_info_t stress_vma_info = {
 	.stressor = stress_unimplemented,
 	.class = CLASS_VM,
 	.help = help,
