@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023-2024 Colin Ian King.
+ * Copyright (C) 2023-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -35,8 +35,9 @@
 
 static const stress_help_t help[] = {
 	{ NULL,	"vnni N",		"start N workers performing vector neural network ops" },
-	{ NULL,	"vnni-ops N",		"stop after N vnni bogo operations" },
 	{ NULL,	"vnni-intrinsic",	"use x86 intrinsic vnni methods, disable generic methods" },
+	{ NULL,	"vnni-method M",	"specify specific vnni methods to exercise" },
+	{ NULL,	"vnni-ops N",		"stop after N vnni bogo operations" },
 	{ NULL,	NULL,		 NULL }
 };
 
@@ -90,10 +91,12 @@ typedef struct {
 	double				 duration;		/* usage duration */
 } stress_vnni_method_t;
 
+static bool vnni_checksum_okay;
+
 static uint32_t OPTIMIZE3 stress_vnni_checksum(void)
 {
 	uint32_t sum = 0;
-	uint8_t *ptr = result;
+	const uint8_t *ptr = result;
 	const uint8_t *end = result + VEC_SIZE_BYTES;
 
 	while (ptr < end) {
@@ -132,7 +135,8 @@ PRAGMA_UNROLL_N(VEC_VNNI512_LOOPS)
     defined(HAVE_IMMINTRIN_H) &&	\
     defined(HAVE_MM256_LOADU_SI256) &&	\
     defined(HAVE_MM256_ADD_EPI8) &&	\
-    defined(HAVE_MM256_STOREU_SI256)
+    defined(HAVE_MM256_STOREU_SI256) &&	\
+    defined(HAVE_TARGET_CLONES_AVXVNNI)
 #define HAVE_STRESS_VNNI_VPADDB256
 static void TARGET_AVXVNNI OPTIMIZE3 stress_vnni_vpaddb256(stress_args_t *args)
 {
@@ -156,7 +160,8 @@ PRAGMA_UNROLL_N(VEC_VNNI256_LOOPS)
     defined(HAVE_IMMINTRIN_H) &&	\
     defined(HAVE_MM_LOADU_SI128) &&	\
     defined(HAVE_MM_ADD_EPI8) &&	\
-    defined(HAVE_MM_STOREU_SI128)
+    defined(HAVE_MM_STOREU_SI128) &&	\
+    defined(HAVE_TARGET_CLONES_AVXVNNI)
 #define HAVE_STRESS_VNNI_VPADDB128
 static void TARGET_AVXVNNI OPTIMIZE3 stress_vnni_vpaddb128(stress_args_t *args)
 {
@@ -216,7 +221,8 @@ PRAGMA_UNROLL_N(VEC_VNNI512_LOOPS)
     defined(HAVE_IMMINTRIN_H) &&	\
     defined(HAVE_MM256_LOADU_SI256) &&	\
     defined(HAVE_MM256_DPBUSD_EPI32) &&	\
-    defined(HAVE_MM256_STOREU_SI256)
+    defined(HAVE_MM256_STOREU_SI256) &&	\
+    defined(HAVE_TARGET_CLONES_AVXVNNI)
 #define HAVE_STRESS_VNNI_VPDPBUSD256
 static void TARGET_AVXVNNI OPTIMIZE3 stress_vnni_vpdpbusd256(stress_args_t *args)
 {
@@ -241,7 +247,8 @@ PRAGMA_UNROLL_N(VEC_VNNI256_LOOPS)
     defined(HAVE_IMMINTRIN_H) &&	\
     defined(HAVE_MM_LOADU_SI128) &&	\
     defined(HAVE_MM_DPBUSD_EPI32) &&	\
-    defined(HAVE_MM_STOREU_SI128)
+    defined(HAVE_MM_STOREU_SI128) &&	\
+    defined(HAVE_TARGET_CLONES_AVXVNNI)
 #define HAVE_STRESS_VNNI_VPDPBUSD128
 static void TARGET_AVXVNNI OPTIMIZE3 stress_vnni_vpdpbusd128(stress_args_t *args)
 {
@@ -309,7 +316,8 @@ PRAGMA_UNROLL_N(VEC_VNNI512_LOOPS)
     defined(HAVE_IMMINTRIN_H) &&	\
     defined(HAVE_MM256_LOADU_SI256) &&	\
     defined(HAVE_MM256_DPWSSD_EPI32) &&	\
-    defined(HAVE_MM256_STOREU_SI256)
+    defined(HAVE_MM256_STOREU_SI256) &&	\
+    defined(HAVE_TARGET_CLONES_AVXVNNI)
 #define HAVE_STRESS_VNNI_VPDPWSSD256
 static void TARGET_AVXVNNI OPTIMIZE3 stress_vnni_vpdpwssd256(stress_args_t *args)
 {
@@ -334,7 +342,8 @@ PRAGMA_UNROLL_N(VEC_VNNI256_LOOPS)
     defined(HAVE_IMMINTRIN_H) &&	\
     defined(HAVE_MM_LOADU_SI128) &&	\
     defined(HAVE_MM_DPWSSD_EPI32) &&	\
-    defined(HAVE_MM_STOREU_SI128)
+    defined(HAVE_MM_STOREU_SI128) &&	\
+    defined(HAVE_TARGET_CLONES_AVXVNNI)
 #define HAVE_STRESS_VNNI_VPDPWSSD128
 static void TARGET_AVXVNNI OPTIMIZE3 stress_vnni_vpdpwssd128(stress_args_t *args)
 {
@@ -358,8 +367,8 @@ PRAGMA_UNROLL_N(VEC_VNNI128_LOOPS)
 static void TARGET_CLONES OPTIMIZE3 stress_vnni_vpdpwssd(stress_args_t *args)
 {
 	register int i, j;
-	int16_t *a16 = (int16_t *)a_init;
-	int16_t *b16 = (int16_t *)b_init;
+	const int16_t *a16 = (int16_t *)a_init;
+	const int16_t *b16 = (int16_t *)b_init;
 	int32_t *r32 = (int32_t *)result;
 	register const int32_t *c32 = (int32_t *)c_init;
 
@@ -470,9 +479,10 @@ static void OPTIMIZE3 stress_vnni_exercise(stress_args_t *args, const size_t n)
 	/* and checksum the last computation */
 	checksum = stress_vnni_checksum();
 	expected_checksum = little_endian ? method->vnni_checksum_le : method->vnni_checksum_be;
-	if (checksum != expected_checksum) {
+	if (UNLIKELY(checksum != expected_checksum)) {
 		pr_fail("%s: checksum mismatch for %s, got %" PRIx32 ", expected %" PRIx32 "\n",
 			args->name, method->name, checksum, expected_checksum);
+		vnni_checksum_okay = false;
 	}
 	stress_bogo_inc(args);
 }
@@ -481,42 +491,13 @@ static void stress_vnni_all(stress_args_t *args)
 {
 	size_t i;
 
-	for (i = 1; stress_continue(args) && (i < SIZEOF_ARRAY(stress_vnni_methods)); i++) {
-		if (stress_vnni_methods[i].vnni_capable) {
+	for (i = 1; LIKELY(stress_continue(args) && (i < SIZEOF_ARRAY(stress_vnni_methods))); i++) {
+		if (LIKELY(stress_vnni_methods[i].vnni_capable)) {
 			stress_vnni_exercise(args, i);
 		}
 	}
 }
 
-static int stress_set_vnni_intrinsic(const char *opt)
-{
-	return stress_set_setting_true("vnni-intrinsic", opt);
-}
-
-/*
- *  stress_set_vnni_method()
- *	set the default vnni stress method
- */
-static int stress_set_vnni_method(const char *name)
-{
-	size_t i;
-
-	for (i = 0; i < SIZEOF_ARRAY(stress_vnni_methods); i++) {
-		if (!strcmp(stress_vnni_methods[i].name, name)) {
-			stress_set_setting("vnni-method", TYPE_ID_SIZE_T, &i);
-			return 0;
-		}
-	}
-
-	(void)fprintf(stderr, "vnni-method must be one of:");
-	for (i = 0; i < SIZEOF_ARRAY(stress_vnni_methods); i++) {
-		(void)fprintf(stderr, " %s", stress_vnni_methods[i].name);
-	}
-	(void)fprintf(stderr, "\n");
-
-	return -1;
-}
-
 /*
  *  stress_vnni()
  *	stress intel VNNI ops
@@ -527,6 +508,7 @@ static int stress_vnni(stress_args_t *args)
 
 	stress_catch_sigill();
 
+	vnni_checksum_okay = true;
 	little_endian = stress_little_endian();
 
 	stress_mwc_set_seed(0x172fb3ea, 0xd9c02f73);
@@ -570,15 +552,17 @@ static int stress_vnni(stress_args_t *args)
 			args->name);
 	}
 
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
+	stress_sync_start_wait(args);
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	do {
-		if (vnni_method) {
+		if (UNLIKELY(vnni_method)) {
 			stress_vnni_exercise(args, vnni_method);
 		} else {
 			stress_vnni_all(args);
 		}
-	} while (stress_continue(args));
+	} while (vnni_checksum_okay && stress_continue(args));
 
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 
@@ -591,24 +575,29 @@ static int stress_vnni(stress_args_t *args)
 
 			(void)snprintf(buf, sizeof(buf), "%s ops per sec", stress_vnni_methods[i].name);
 			stress_metrics_set(args, j, buf,
-				rate, STRESS_HARMONIC_MEAN);
+				rate, STRESS_METRIC_HARMONIC_MEAN);
 			j++;
 		}
 	}
 
-	return EXIT_SUCCESS;
+	return vnni_checksum_okay ? EXIT_SUCCESS : EXIT_FAILURE;
 }
 
-static const stress_opt_set_func_t opt_set_funcs[] = {
-	{ OPT_vnni_intrinsic,	stress_set_vnni_intrinsic },
-	{ OPT_vnni_method,	stress_set_vnni_method },
-	{ 0,			NULL },
+static const char *stress_vnni_method(const size_t i)
+{
+	return (i < SIZEOF_ARRAY(stress_vnni_methods)) ? stress_vnni_methods[i].name : NULL;
+}
+
+static const stress_opt_t opts[] = {
+	{ OPT_vnni_intrinsic, "vnni-intrinsic", TYPE_ID_BOOL, 0, 1, NULL },
+	{ OPT_vnni_method,    "vnni-method",    TYPE_ID_SIZE_T_METHOD, 0, 0, stress_vnni_method },
+	END_OPT,
 };
 
-stressor_info_t stress_vnni_info = {
+const stressor_info_t stress_vnni_info = {
 	.stressor = stress_vnni,
-	.class = CLASS_CPU,
-	.opt_set_funcs = opt_set_funcs,
+	.class = CLASS_CPU | CLASS_INTEGER | CLASS_COMPUTE | CLASS_VECTOR,
+	.opts = opts,
 	.verify = VERIFY_ALWAYS,
 	.help = help
 };
