@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,6 +21,8 @@
 #include "core-arch.h"
 #include "core-cpu.h"
 
+#include <time.h>
+
 static const stress_help_t help[] = {
 	{ NULL,	"x86syscall N",		"start N workers exercising functions using syscall" },
 	{ NULL,	"x86syscall-func F",	"use just syscall function F" },
@@ -37,7 +39,7 @@ static const stress_opt_t opts[] = {
     !defined(HAVE_COMPILER_PCC) &&	\
     defined(STRESS_ARCH_X86_64)
 
-typedef long (*stress_wfunc_t)(void);
+typedef long int (*stress_wfunc_t)(void);
 
 /*
  *  syscall symbol mapping name to address and wrapper function
@@ -85,9 +87,9 @@ static int stress_x86syscall_supported(const char *name)
  *  x86_64_syscall0()
  *	syscall 0 arg wrapper
  */
-static inline long OPTIMIZE3 x86_64_syscall0(long number)
+static inline long int OPTIMIZE3 x86_64_syscall0(long int number)
 {
-	long ret;
+	long int ret;
 
 	__asm__ __volatile__("syscall\n\t"
 			: "=a" (ret)
@@ -104,11 +106,11 @@ static inline long OPTIMIZE3 x86_64_syscall0(long number)
  *  x86_64_syscall1()
  *	syscall 1 arg wrapper
  */
-static inline long OPTIMIZE3 x86_64_syscall1(long number, long arg1)
+static inline long int OPTIMIZE3 x86_64_syscall1(long int number, long int arg1)
 {
-	long ret;
-	long tmp_arg1 = arg1;
-	register long asm_arg1 __asm__("rdi") = tmp_arg1;
+	long int ret;
+	long int tmp_arg1 = arg1;
+	register long int asm_arg1 __asm__("rdi") = tmp_arg1;
 
 	__asm__ __volatile__("syscall\n\t"
 			: "=a" (ret)
@@ -125,13 +127,13 @@ static inline long OPTIMIZE3 x86_64_syscall1(long number, long arg1)
  *  x86_64_syscall2()
  *	syscall 2 arg wrapper
  */
-static inline long OPTIMIZE3 x86_64_syscall2(long number, long arg1, long arg2)
+static inline long int OPTIMIZE3 x86_64_syscall2(long int number, int long arg1, int long arg2)
 {
-	long ret;
-	long tmp_arg1 = arg1;
-	long tmp_arg2 = arg2;
-	register long asm_arg1 __asm__("rdi") = tmp_arg1;
-	register long asm_arg2 __asm__("rsi") = tmp_arg2;
+	long int ret;
+	long int tmp_arg1 = arg1;
+	long int tmp_arg2 = arg2;
+	register long int asm_arg1 __asm__("rdi") = tmp_arg1;
+	register long int asm_arg2 __asm__("rsi") = tmp_arg2;
 
 	__asm__ __volatile__("syscall\n\t"
 			: "=a" (ret)
@@ -148,15 +150,15 @@ static inline long OPTIMIZE3 x86_64_syscall2(long number, long arg1, long arg2)
  *  x86_64_syscall3()
  *	syscall 3 arg wrapper
  */
-static inline long OPTIMIZE3 x86_64_syscall3(long number, long arg1, long arg2, long arg3)
+static inline long int OPTIMIZE3 x86_64_syscall3(long int number, long int arg1, long int arg2, long int arg3)
 {
-	long ret;
-	long tmp_arg1 = arg1;
-	long tmp_arg2 = arg2;
-	long tmp_arg3 = arg3;
-	register long asm_arg1 __asm__("rdi") = tmp_arg1;
-	register long asm_arg2 __asm__("rsi") = tmp_arg2;
-	register long asm_arg3 __asm__("rdx") = tmp_arg3;
+	long int ret;
+	long int tmp_arg1 = arg1;
+	long int tmp_arg2 = arg2;
+	long int tmp_arg3 = arg3;
+	register long int asm_arg1 __asm__("rdi") = tmp_arg1;
+	register long int asm_arg2 __asm__("rsi") = tmp_arg2;
+	register long int asm_arg3 __asm__("rdx") = tmp_arg3;
 
 	__asm__ __volatile__("syscall\n\t"
 			: "=a" (ret)
@@ -174,7 +176,7 @@ static inline long OPTIMIZE3 x86_64_syscall3(long number, long arg1, long arg2,
  *  wrap_getuid()
  *	invoke getuid()
  */
-static long wrap_getuid(void)
+static long int wrap_getuid(void)
 {
 	return x86_64_syscall0(__NR_getuid);
 }
@@ -185,7 +187,7 @@ static long wrap_getuid(void)
  *  wrap_geteuid()
  *	invoke geteuid()
  */
-static long wrap_geteuid(void)
+static long int wrap_geteuid(void)
 {
 	return x86_64_syscall0(__NR_geteuid);
 }
@@ -196,7 +198,7 @@ static long wrap_geteuid(void)
  *  wrap_getgid()
  *	invoke getgid()
  */
-static long wrap_getgid(void)
+static long int wrap_getgid(void)
 {
 	return x86_64_syscall0(__NR_getgid);
 }
@@ -207,7 +209,7 @@ static long wrap_getgid(void)
  *  wrap_getpid()
  *	invoke getpid()
  */
-static long wrap_getpid(void)
+static long int wrap_getpid(void)
 {
 	return x86_64_syscall0(__NR_getpid);
 }
@@ -218,11 +220,11 @@ static long wrap_getpid(void)
  *  wrap_getcpu()
  *	invoke getcpu()
  */
-static long wrap_getcpu(void)
+static long int wrap_getcpu(void)
 {
-	unsigned cpu, node;
+	unsigned int cpu, node;
 
-	return x86_64_syscall3(__NR_getcpu, (long)&cpu, (long)&node, (long)NULL);
+	return x86_64_syscall3(__NR_getcpu, (long int)&cpu, (long int)&node, (long int)NULL);
 }
 #endif
 
@@ -231,11 +233,11 @@ static long wrap_getcpu(void)
  *  wrap_gettimeofday()
  *	invoke gettimeofday()
  */
-static long wrap_gettimeofday(void)
+static long int wrap_gettimeofday(void)
 {
 	struct timeval tv;
 
-	return x86_64_syscall2(__NR_gettimeofday, (long)&tv, (long)NULL);
+	return x86_64_syscall2(__NR_gettimeofday, (long int)&tv, (long int)NULL);
 }
 #endif
 
@@ -244,11 +246,11 @@ static long wrap_gettimeofday(void)
  *  wrap_time()
  *	invoke time()
  */
-static long wrap_time(void)
+static long int wrap_time(void)
 {
 	time_t t;
 
-	return x86_64_syscall1(__NR_time, (long)&t);
+	return x86_64_syscall1(__NR_time, (long int)&t);
 }
 #endif
 
@@ -256,9 +258,9 @@ static long wrap_time(void)
  *  wrap_dummy()
  *	dummy empty function for baseline
  */
-static long wrap_dummy(void)
+static long int wrap_dummy(void)
 {
-	return (long)-1;
+	return (long int)-1;
 }
 
 /*
@@ -435,8 +437,8 @@ static int stress_x86syscall(stress_args_t *args)
 		const pid_t pid2 = (pid_t)x86_64_syscall0(__NR_getpid);
 
 		if (pid1 != pid2) {
-			pr_fail("%s: getpid syscall returned PID %jd, "
-				"expected PID %jd\n",
+			pr_fail("%s: getpid syscall returned PID %" PRIdMAX ", "
+				"expected PID %" PRIdMAX "\n",
 				args->name, (intmax_t)pid2, (intmax_t)pid1);
 			rc = EXIT_FAILURE;
 		}
@@ -448,8 +450,8 @@ static int stress_x86syscall(stress_args_t *args)
 		const pid_t gid2 = (gid_t)x86_64_syscall0(__NR_getgid);
 
 		if (gid1 != gid2) {
-			pr_fail("%s: getgid syscall returned GID %jd, "
-				"expected GID %jd\n",
+			pr_fail("%s: getgid syscall returned GID %" PRIdMAX ", "
+				"expected GID %" PRIdMAX "\n",
 				args->name, (intmax_t)gid2, (intmax_t)gid1);
 			rc = EXIT_FAILURE;
 		}
@@ -461,8 +463,8 @@ static int stress_x86syscall(stress_args_t *args)
 		const uid_t uid2 = (uid_t)x86_64_syscall0(__NR_getuid);
 
 		if (uid1 != uid2) {
-			pr_fail("%s: getuid syscall returned UID %jd, "
-				"expected UID %jd\n",
+			pr_fail("%s: getuid syscall returned UID %" PRIdMAX ", "
+				"expected UID %" PRIdMAX "\n",
 				args->name, (intmax_t)uid2, (intmax_t)uid1);
 			rc = EXIT_FAILURE;
 		}
@@ -474,8 +476,8 @@ static int stress_x86syscall(stress_args_t *args)
 		const uid_t uid2 = (uid_t)x86_64_syscall0(__NR_geteuid);
 
 		if (uid1 != uid2) {
-			pr_fail("%s: geteuid syscall returned UID %jd, "
-				"expected UID %jd\n",
+			pr_fail("%s: geteuid syscall returned UID %" PRIdMAX ", "
+				"expected UID %" PRIdMAX "\n",
 				args->name, (intmax_t)uid2, (intmax_t)uid1);
 			rc = EXIT_FAILURE;
 		}
@@ -486,7 +488,7 @@ static int stress_x86syscall(stress_args_t *args)
 		time_t time1 = 0, time2 = 0;
 
 		if ((time(&time1) != (time_t)-1) &&
-		    ((time_t)x86_64_syscall1(__NR_time, (long)&time2) != (time_t)-1)) {
+		    ((time_t)x86_64_syscall1(__NR_time, (long int)&time2) != (time_t)-1)) {
 			if (time2 < time1) {
 				pr_fail("%s: time syscall returned %" PRIdMAX
 					" which was less than expected value %" PRIdMAX "\n",
