@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2024 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,6 +18,7 @@
  *
  */
 #include "stress-ng.h"
+#include "core-helper.h"
 #include "core-madvise.h"
 #include "core-pragma.h"
 
@@ -34,30 +35,6 @@ static const stress_help_t help[] = {
 	{ NULL,	NULL,		NULL }
 };
 
-/*
- *  stress_is_not_zero()
- *	checks if buffer is zero, buffer must be 64 bit aligned
- */
-static bool OPTIMIZE3 stress_is_not_zero(uint64_t *buffer, const size_t len)
-{
-	register const uint8_t *end8 = ((uint8_t *)buffer) + len;
-	register uint8_t *ptr8;
-	register const uint64_t *end64 = buffer + (len / sizeof(uint64_t));
-	register uint64_t *ptr64;
-
-PRAGMA_UNROLL_N(8)
-	for (ptr64 = buffer; ptr64 < end64; ptr64++) {
-		if (UNLIKELY(*ptr64))
-			return true;
-	}
-PRAGMA_UNROLL_N(8)
-	for (ptr8 = (uint8_t *)ptr64; ptr8 < end8; ptr8++) {
-		if (UNLIKELY(*ptr8))
-			return true;
-	}
-	return false;
-}
-
 #if defined(__linux__)
 
 typedef struct {
@@ -111,6 +88,7 @@ static int stress_zero(stress_args_t *args)
 			args->name);
 		return EXIT_NO_RESOURCE;
 	}
+	stress_set_vma_anon_name(rd_buffer, page_size, "read-buffer");
 	(void)stress_madvise_mergeable(rd_buffer, page_size);
 
 	wr_buffer = stress_mmap_populate(NULL, page_size,
@@ -122,6 +100,7 @@ static int stress_zero(stress_args_t *args)
 		(void)munmap(rd_buffer, page_size);
 		return EXIT_NO_RESOURCE;
 	}
+	stress_set_vma_anon_name(wr_buffer, page_size, "write-buffer");
 	(void)stress_madvise_mergeable(wr_buffer, page_size);
 
 	if ((fd = open("/dev/zero", flags)) < 0) {
@@ -161,7 +140,7 @@ static int stress_zero(stress_args_t *args)
 		} while (stress_continue(args));
 		duration += stress_time_now() - t;
 
-		if ((ret > 0) && stress_is_not_zero((uint64_t *)rd_buffer, (size_t)ret)) {
+		if ((ret > 0) && stress_data_is_not_zero((uint64_t *)rd_buffer, (size_t)ret)) {
 			pr_fail("%s: non-zero value from a read of /dev/zero\n",
 				args->name);
 			rc = EXIT_FAILURE;
@@ -181,7 +160,7 @@ static int stress_zero(stress_args_t *args)
 			double t;
 
 			t = stress_time_now();
-			for (i = 0; (i < 1024) && stress_continue(args); i++) {
+			for (i = 0; LIKELY((i < 1024) && stress_continue(args)); i++) {
 				ret = read(fd, rd_buffer, page_size);
 				if (UNLIKELY(ret < 0)) {
 					if ((errno == EAGAIN) || (errno == EINTR))
@@ -198,7 +177,7 @@ static int stress_zero(stress_args_t *args)
 			}
 			duration += stress_time_now() - t;
 
-			if ((ret > 0) && stress_is_not_zero((uint64_t *)rd_buffer, (size_t)ret)) {
+			if ((ret > 0) && stress_data_is_not_zero((uint64_t *)rd_buffer, (size_t)ret)) {
 				pr_fail("%s: non-zero value from a read of /dev/zero\n",
 					args->name);
 				rc = EXIT_FAILURE;
@@ -241,7 +220,7 @@ static int stress_zero(stress_args_t *args)
 					(void)munmap(rd_buffer, page_size);
 					return EXIT_FAILURE;
 				}
-				if (stress_is_not_zero((uint64_t *)rd_buffer, (size_t)ret)) {
+				if (stress_data_is_not_zero((uint64_t *)rd_buffer, (size_t)ret)) {
 					pr_fail("%s: memory mapped page of /dev/zero using %s is not zero\n",
 						args->name, mmap_flags[i].flag_str);
 				}
